Class: Google::Apis::ComputeBeta::AllocationResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AllocationResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#health_info ⇒ Google::Apis::ComputeBeta::AllocationResourceStatusHealthInfo
Health information for the reservation.
-
#reservation_block_count ⇒ Fixnum
The number of reservation blocks associated with this reservation.
-
#reservation_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#specific_sku_allocation ⇒ Google::Apis::ComputeBeta::AllocationResourceStatusSpecificSkuAllocation
Contains Properties set for the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationResourceStatus
constructor
A new instance of AllocationResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationResourceStatus
Returns a new instance of AllocationResourceStatus.
1538 1539 1540 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1538 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_info ⇒ Google::Apis::ComputeBeta::AllocationResourceStatusHealthInfo
Health information for the reservation.
Corresponds to the JSON property healthInfo
1521 1522 1523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1521 def health_info @health_info end |
#reservation_block_count ⇒ Fixnum
The number of reservation blocks associated with this reservation.
Corresponds to the JSON property reservationBlockCount
1526 1527 1528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1526 def reservation_block_count @reservation_block_count end |
#reservation_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
1531 1532 1533 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1531 def reservation_maintenance @reservation_maintenance end |
#specific_sku_allocation ⇒ Google::Apis::ComputeBeta::AllocationResourceStatusSpecificSkuAllocation
Contains Properties set for the reservation.
Corresponds to the JSON property specificSkuAllocation
1536 1537 1538 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1536 def specific_sku_allocation @specific_sku_allocation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1543 1544 1545 1546 1547 1548 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1543 def update!(**args) @health_info = args[:health_info] if args.key?(:health_info) @reservation_block_count = args[:reservation_block_count] if args.key?(:reservation_block_count) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @specific_sku_allocation = args[:specific_sku_allocation] if args.key?(:specific_sku_allocation) end |