Class: Google::Apis::ComputeBeta::AllocationResourceStatusSpecificSkuAllocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains Properties set for the reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationResourceStatusSpecificSkuAllocation

Returns a new instance of AllocationResourceStatusSpecificSkuAllocation.



1614
1615
1616
# File 'lib/google/apis/compute_beta/classes.rb', line 1614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_instance_template_idString

ID of the instance template used to populate reservation properties. Corresponds to the JSON property sourceInstanceTemplateId

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/compute_beta/classes.rb', line 1606

def source_instance_template_id
  @source_instance_template_id
end

#utilizationsHash<String,Fixnum>

Per service utilization breakdown. The Key is the Google Cloud managed service name. Corresponds to the JSON property utilizations

Returns:

  • (Hash<String,Fixnum>)


1612
1613
1614
# File 'lib/google/apis/compute_beta/classes.rb', line 1612

def utilizations
  @utilizations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1619
1620
1621
1622
# File 'lib/google/apis/compute_beta/classes.rb', line 1619

def update!(**args)
  @source_instance_template_id = args[:source_instance_template_id] if args.key?(:source_instance_template_id)
  @utilizations = args[:utilizations] if args.key?(:utilizations)
end