Class: Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
-
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
constructor
A new instance of AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk
Returns a new instance of AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk.
1641 1642 1643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_size_gb ⇒ Fixnum
Specifies the size of the disk in base-2 GB.
Corresponds to the JSON property diskSizeGb
1632 1633 1634 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1632 def disk_size_gb @disk_size_gb end |
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME. The default isSCSI.
For performance characteristics of SCSI over NVMe, seeLocal SSD performance.
Corresponds to the JSON property interface
1639 1640 1641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1639 def interface @interface end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1646 1647 1648 1649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1646 def update!(**args) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @interface = args[:interface] if args.key?(:interface) end |