Class: Google::Apis::ComputeBeta::AllocationSpecificSkuReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

This reservation type allows to pre allocate specific instance configuration.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationSpecificSkuReservation

Returns a new instance of AllocationSpecificSkuReservation.



1739
1740
1741
# File 'lib/google/apis/compute_beta/classes.rb', line 1739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assured_countFixnum

Output only. [Output Only] Indicates how many instances are actually usable currently. Corresponds to the JSON property assuredCount

Returns:

  • (Fixnum)


1707
1708
1709
# File 'lib/google/apis/compute_beta/classes.rb', line 1707

def assured_count
  @assured_count
end

#countFixnum

Specifies the number of resources that are allocated. Corresponds to the JSON property count

Returns:

  • (Fixnum)


1712
1713
1714
# File 'lib/google/apis/compute_beta/classes.rb', line 1712

def count
  @count
end

#in_use_countFixnum

Output only. [Output Only] Indicates how many instances are in use. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


1717
1718
1719
# File 'lib/google/apis/compute_beta/classes.rb', line 1717

def in_use_count
  @in_use_count
end

#instance_propertiesGoogle::Apis::ComputeBeta::AllocationSpecificSkuAllocationReservedInstanceProperties

Properties of the SKU instances being reserved. Next ID: 9 Corresponds to the JSON property instanceProperties



1723
1724
1725
# File 'lib/google/apis/compute_beta/classes.rb', line 1723

def instance_properties
  @instance_properties
end

#source_instance_templateString

Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:

Returns:

  • (String)


1737
1738
1739
# File 'lib/google/apis/compute_beta/classes.rb', line 1737

def source_instance_template
  @source_instance_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1744
1745
1746
1747
1748
1749
1750
# File 'lib/google/apis/compute_beta/classes.rb', line 1744

def update!(**args)
  @assured_count = args[:assured_count] if args.key?(:assured_count)
  @count = args[:count] if args.key?(:count)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template)
end