Class: Google::Apis::ComputeBeta::AttachedDiskInitializeParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttachedDiskInitializeParams

Returns a new instance of AttachedDiskInitializeParams.



2215
2216
2217
# File 'lib/google/apis/compute_beta/classes.rb', line 2215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the attached disk. Valid values are arm64 or x86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


1987
1988
1989
# File 'lib/google/apis/compute_beta/classes.rb', line 1987

def architecture
  @architecture
end

#descriptionString

An optional description. Provide this property when creating the disk. Corresponds to the JSON property description

Returns:

  • (String)


1992
1993
1994
# File 'lib/google/apis/compute_beta/classes.rb', line 1992

def description
  @description
end

#disk_nameString

Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created. Corresponds to the JSON property diskName

Returns:

  • (String)


2000
2001
2002
# File 'lib/google/apis/compute_beta/classes.rb', line 2000

def disk_name
  @disk_name
end

#disk_size_gbFixnum

Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


2009
2010
2011
# File 'lib/google/apis/compute_beta/classes.rb', line 2009

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Specifies the disk type used for the boot disk or an additional data disk. For valid disk type values, see Supported types for Hyperdisk volumes and Persistent Disk type variables. When creating a single instance, you must provide either the full or partial URL of the disk type. For example, the following values are valid:

  • https://www.googleapis.com/compute/v1/projects/project/zones/zone/ diskTypes/diskType
  • projects/project/zones/zone/diskTypes/diskType
  • zones/zone/diskTypes/diskType When creating an instance template, instance flexibility policy, or when creating or updating an all-instances configuration, you specify the disk type without a URL, for example, hyperdisk-balanced. If you omit this field for a disk, the default disk type depends on the instance's machine series, as follows.

  • For first- and second-generation machine series like N1, N2, T2, and M1, the default disk type is Standard Persistent Disk (pd-standard).

  • For C3, C3D, and M3 the default is Balanced Persistent Disk (pd-balanced).

  • For other third-generation machine series like A3, H3, Z3, all fourth-generation types like C4, N4, M4, and newer machine series, the default is Hyperdisk Balanced (hyperdisk-balanced). The disk type you specify must be compatible with the instance's machine series. For a list of machine series that support Persistent Disk, see Machine series support for Persistent Disk. For a list of machine series that support Hyperdisk, seeMachine series support for Hyperdisk. Corresponds to the JSON property diskType

Returns:

  • (String)


2049
2050
2051
# File 'lib/google/apis/compute_beta/classes.rb', line 2049

def disk_type
  @disk_type
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Whether this disk is using confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


2054
2055
2056
# File 'lib/google/apis/compute_beta/classes.rb', line 2054

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Guest OS features are applied by merginginitializeParams.guestOsFeatures anddisks.guestOsFeatures Corresponds to the JSON property guestOsFeatures



2065
2066
2067
# File 'lib/google/apis/compute_beta/classes.rb', line 2065

def guest_os_features
  @guest_os_features
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by thedisks. setLabels method. This field is only applicable for persistent disks. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2072
2073
2074
# File 'lib/google/apis/compute_beta/classes.rb', line 2072

def labels
  @labels
end

#licensesArray<String>

A list of publicly visible licenses. Reserved for Google's use. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2077
2078
2079
# File 'lib/google/apis/compute_beta/classes.rb', line 2077

def licenses
  @licenses
end

#multi_writerBoolean Also known as: multi_writer?

Indicates whether or not the disk can be read/write attached to more than one instance. Corresponds to the JSON property multiWriter

Returns:

  • (Boolean)


2083
2084
2085
# File 'lib/google/apis/compute_beta/classes.rb', line 2083

def multi_writer
  @multi_writer
end

#on_update_actionString

Specifies which action to take on instance update with this disk. Default is to use the existing disk. Corresponds to the JSON property onUpdateAction

Returns:

  • (String)


2090
2091
2092
# File 'lib/google/apis/compute_beta/classes.rb', line 2090

def on_update_action
  @on_update_action
end

#provisioned_iopsFixnum

Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


2098
2099
2100
# File 'lib/google/apis/compute_beta/classes.rb', line 2098

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


2105
2106
2107
# File 'lib/google/apis/compute_beta/classes.rb', line 2105

def provisioned_throughput
  @provisioned_throughput
end

#replica_zonesArray<String>

Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


2113
2114
2115
# File 'lib/google/apis/compute_beta/classes.rb', line 2113

def replica_zones
  @replica_zones
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


2124
2125
2126
# File 'lib/google/apis/compute_beta/classes.rb', line 2124

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


2131
2132
2133
# File 'lib/google/apis/compute_beta/classes.rb', line 2131

def resource_policies
  @resource_policies
end

#source_imageString

The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required. To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/ debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family If the source image is deleted later, this field will not be set. Corresponds to the JSON property sourceImage

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/compute_beta/classes.rb', line 2153

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys. Corresponds to the JSON property sourceImageEncryptionKey



2164
2165
2166
# File 'lib/google/apis/compute_beta/classes.rb', line 2164

def source_image_encryption_key
  @source_image_encryption_key
end

#source_instant_snapshotString

The source instant-snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot or initializeParams.sourceInstantSnapshotinitializeParams.sourceImage or disks. source is required. To create a disk with a snapshot that you created, specify the snapshot name in the following format: us-central1-a/instantSnapshots/my-backup If the source instant-snapshot is deleted later, this field will not be set. Corresponds to the JSON property sourceInstantSnapshot

Returns:

  • (String)


2178
2179
2180
# File 'lib/google/apis/compute_beta/classes.rb', line 2178

def source_instant_snapshot
  @source_instant_snapshot
end

#source_snapshotString

The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams. sourceImage or disks.source is required. To create a disk with a snapshot that you created, specify the snapshot name in the following format: global/snapshots/my-backup If the source snapshot is deleted later, this field will not be set. Note: You cannot create VMs in bulk using a snapshot as the source. Use an image instead when you create VMs using the bulk insert method. Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


2194
2195
2196
# File 'lib/google/apis/compute_beta/classes.rb', line 2194

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source snapshot. Corresponds to the JSON property sourceSnapshotEncryptionKey



2200
2201
2202
# File 'lib/google/apis/compute_beta/classes.rb', line 2200

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#storage_poolString

The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


2213
2214
2215
# File 'lib/google/apis/compute_beta/classes.rb', line 2213

def storage_pool
  @storage_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2220
2221
2222
2223
2224
2225
2226
2227
2228
2229
2230
2231
2232
2233
2234
2235
2236
2237
2238
2239
2240
2241
2242
2243
# File 'lib/google/apis/compute_beta/classes.rb', line 2220

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @description = args[:description] if args.key?(:description)
  @disk_name = args[:disk_name] if args.key?(:disk_name)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @labels = args[:labels] if args.key?(:labels)
  @licenses = args[:licenses] if args.key?(:licenses)
  @multi_writer = args[:multi_writer] if args.key?(:multi_writer)
  @on_update_action = args[:on_update_action] if args.key?(:on_update_action)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
end