Class: Google::Apis::ComputeBeta::AuditConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies the audit configuration for a service. The configuration determines which permission types are logged, and what identities, if any, are exempted from logging. An AuditConfig must have one or more AuditLogConfigs. If there are AuditConfigs for both allServices and a specific service, the union of the two AuditConfigs is used for that service: the log_types specified in each AuditConfig are enabled, and the exempted_members in each AuditLogConfig are exempted. Example Policy with multiple AuditConfigs: "audit_configs": [ "service": "allServices", "audit_log_configs": [ "log_type": "DATA_READ", "exempted_members": [ "user:jose@example.com" ] , "log_type": "DATA_WRITE" , "log_type": "ADMIN_READ" ] , "service": "sampleservice.googleapis.com", "audit_log_configs": [ "log_type": "DATA_READ" , "log_type": "DATA_WRITE", "exempted_members": [ "user:aliya@example.com" ] ] ] For sampleservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ logging. It also exempts jose@example.com from DATA_READ logging, and aliya@example.com from DATA_WRITE logging.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AuditConfig

Returns a new instance of AuditConfig.



2273
2274
2275
# File 'lib/google/apis/compute_beta/classes.rb', line 2273

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audit_log_configsArray<Google::Apis::ComputeBeta::AuditLogConfig>

The configuration for logging of each type of permission. Corresponds to the JSON property auditLogConfigs



2264
2265
2266
# File 'lib/google/apis/compute_beta/classes.rb', line 2264

def audit_log_configs
  @audit_log_configs
end

#serviceString

Specifies a service that will be enabled for audit logging. For example, storage.googleapis.com, cloudsql.googleapis.com. allServices is a special value that covers all services. Corresponds to the JSON property service

Returns:

  • (String)


2271
2272
2273
# File 'lib/google/apis/compute_beta/classes.rb', line 2271

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2278
2279
2280
2281
# File 'lib/google/apis/compute_beta/classes.rb', line 2278

def update!(**args)
  @audit_log_configs = args[:audit_log_configs] if args.key?(:audit_log_configs)
  @service = args[:service] if args.key?(:service)
end