Class: Google::Apis::ComputeBeta::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



2551
2552
2553
# File 'lib/google/apis/compute_beta/classes.rb', line 2551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2511
2512
2513
# File 'lib/google/apis/compute_beta/classes.rb', line 2511

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2516
2517
2518
# File 'lib/google/apis/compute_beta/classes.rb', line 2516

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2523
2524
2525
# File 'lib/google/apis/compute_beta/classes.rb', line 2523

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2533
2534
2535
# File 'lib/google/apis/compute_beta/classes.rb', line 2533

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2538
2539
2540
# File 'lib/google/apis/compute_beta/classes.rb', line 2538

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2544
2545
2546
# File 'lib/google/apis/compute_beta/classes.rb', line 2544

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2549
2550
2551
# File 'lib/google/apis/compute_beta/classes.rb', line 2549

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2556
2557
2558
2559
2560
2561
2562
2563
2564
# File 'lib/google/apis/compute_beta/classes.rb', line 2556

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end