Class: Google::Apis::ComputeBeta::AutoscalingPolicyCustomMetricUtilization
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AutoscalingPolicyCustomMetricUtilization
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Custom utilization metric policy.
Instance Attribute Summary collapse
-
#filter ⇒ String
A filter string, compatible with a Stackdriver Monitoringfilter string forTimeSeries.list API call.
-
#metric ⇒ String
The identifier (type) of the Stackdriver Monitoring metric.
-
#single_instance_assignment ⇒ Float
If scaling is based on a per-group metric value that represents the total amount of work to be done or resource usage, set this value to an amount assigned for a single instance of the scaled group.
-
#utilization_target ⇒ Float
The target value of the metric that autoscaler maintains.
-
#utilization_target_type ⇒ String
Defines how target utilization value is expressed for a Stackdriver Monitoring metric.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingPolicyCustomMetricUtilization
constructor
A new instance of AutoscalingPolicyCustomMetricUtilization.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalingPolicyCustomMetricUtilization
Returns a new instance of AutoscalingPolicyCustomMetricUtilization.
3140 3141 3142 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3140 def initialize(**args) update!(**args) end |
Instance Attribute Details
#filter ⇒ String
A filter string, compatible with a Stackdriver Monitoringfilter string forTimeSeries.list API call. This filter is used to select a specific TimeSeries for the purpose of autoscaling and to determine whether the metric is exporting per-instance or per-group data. For the filter to be valid for autoscaling purposes, the following rules apply:
- You can only use the AND operator for joining selectors.
- You can only use direct equality comparison operator (=) without any functions for each selector.
- You can specify the metric in both the filter string and in the metric field. However, if specified in both places, the metric must be identical.
- The monitored resource type determines what kind of values are expected for the metric. If it is a gce_instance, the autoscaler expects the metric to include a separate TimeSeries for each instance in a group. In such a case, you cannot filter on resource labels.
If the resource type is any other value, the autoscaler expects this metric to contain values that apply to the entire autoscaled instance group and resource label filtering can be performed to point autoscaler at the correct TimeSeries to scale upon. This is called a per-group metric for the purpose of autoscaling.
If not specified, the type defaults to
gce_instance.
Try to provide a filter that is selective enough to pick just one
TimeSeries for the autoscaled group or for each of the instances (if you
are using gce_instance resource type). If multiple
TimeSeries are returned upon the query execution, the autoscaler will sum
their respective values to obtain its scaling value.
Corresponds to the JSON property filter
3096 3097 3098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3096 def filter @filter end |
#metric ⇒ String
The identifier (type) of the Stackdriver Monitoring metric. The metric
cannot have negative values.
The metric must have a value type of INT64 orDOUBLE.
Corresponds to the JSON property metric
3103 3104 3105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3103 def metric @metric end |
#single_instance_assignment ⇒ Float
If scaling is based on a per-group metric value that represents the
total amount of work to be done or resource usage, set this value to an
amount assigned for a single instance of the scaled group. Autoscaler
keeps the number of instances proportional to the value of this
metric. The metric itself does not change value due to group
resizing.
A good metric to use with the target is for examplepubsub.googleapis.com/
subscription/num_undelivered_messages
or a custom metric exporting the total number of requests coming to
your instances.
A bad example would be a metric exporting an average or median latency,
since this value can't include a chunk assignable to a single instance,
it could be better used with utilization_target instead.
Corresponds to the JSON property singleInstanceAssignment
3120 3121 3122 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3120 def single_instance_assignment @single_instance_assignment end |
#utilization_target ⇒ Float
The target value of the metric that autoscaler maintains. This
must be a positive value. A utilization metric scales number of
virtual machines handling requests to increase or decrease
proportionally to the metric.
For example, a good metric to use as a utilization_target ishttps://www.
googleapis.com/compute/v1/instance/network/received_bytes_count.
The autoscaler works to keep this value constant for each of the
instances.
Corresponds to the JSON property utilizationTarget
3132 3133 3134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3132 def utilization_target @utilization_target end |
#utilization_target_type ⇒ String
Defines how target utilization value is expressed for a Stackdriver
Monitoring metric. Either GAUGE,DELTA_PER_SECOND, or DELTA_PER_MINUTE.
Corresponds to the JSON property utilizationTargetType
3138 3139 3140 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3138 def utilization_target_type @utilization_target_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3145 3146 3147 3148 3149 3150 3151 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3145 def update!(**args) @filter = args[:filter] if args.key?(:filter) @metric = args[:metric] if args.key?(:metric) @single_instance_assignment = args[:single_instance_assignment] if args.key?(:single_instance_assignment) @utilization_target = args[:utilization_target] if args.key?(:utilization_target) @utilization_target_type = args[:utilization_target_type] if args.key?(:utilization_target_type) end |