Class: Google::Apis::ComputeBeta::Awsv4Signature
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Awsv4Signature
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication. The service name for generating the authentication header will always default to 's3'.
Instance Attribute Summary collapse
-
#access_key ⇒ String
The access key used for s3 bucket authentication.
-
#access_key_id ⇒ String
The identifier of an access key used for s3 bucket authentication.
-
#access_key_version ⇒ String
The optional version identifier for the access key.
-
#origin_region ⇒ String
The name of the cloud region of your origin.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Awsv4Signature
constructor
A new instance of Awsv4Signature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Awsv4Signature
Returns a new instance of Awsv4Signature.
59 60 61 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59 def initialize(**args) update!(**args) end |
Instance Attribute Details
#access_key ⇒ String
The access key used for s3 bucket authentication. Required for updating or
creating a backend that uses AWS v4 signature authentication, but will not
be returned as part of the configuration when queried with a REST API GET
request.
Corresponds to the JSON property accessKey
39 40 41 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39 def access_key @access_key end |
#access_key_id ⇒ String
The identifier of an access key used for s3 bucket authentication.
Corresponds to the JSON property accessKeyId
44 45 46 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44 def access_key_id @access_key_id end |
#access_key_version ⇒ String
The optional version identifier for the access key. You can use this to
keep track of different iterations of your access key.
Corresponds to the JSON property accessKeyVersion
50 51 52 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50 def access_key_version @access_key_version end |
#origin_region ⇒ String
The name of the cloud region of your origin. This is a free-form field with
the name of the region your cloud uses to host your origin. For example,
"us-east-1" for AWS or "us-ashburn-1" for OCI.
Corresponds to the JSON property originRegion
57 58 59 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57 def origin_region @origin_region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64 65 66 67 68 69 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64 def update!(**args) @access_key = args[:access_key] if args.key?(:access_key) @access_key_id = args[:access_key_id] if args.key?(:access_key_id) @access_key_version = args[:access_key_version] if args.key?(:access_key_version) @origin_region = args[:origin_region] if args.key?(:origin_region) end |