Class: Google::Apis::ComputeBeta::BackendBucketCdnPolicyCacheKeyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message containing what to include in the cache key for a request for Cloud CDN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketCdnPolicyCacheKeyPolicy

Returns a new instance of BackendBucketCdnPolicyCacheKeyPolicy.



4041
4042
4043
# File 'lib/google/apis/compute_beta/classes.rb', line 4041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_http_headersArray<String>

Allows HTTP request headers (by name) to be used in the cache key. Corresponds to the JSON property includeHttpHeaders

Returns:

  • (Array<String>)


4032
4033
4034
# File 'lib/google/apis/compute_beta/classes.rb', line 4032

def include_http_headers
  @include_http_headers
end

#query_string_whitelistArray<String>

Names of query string parameters to include in cache keys. Default parameters are always included. '&' and '=' will be percent encoded and not treated as delimiters. Corresponds to the JSON property queryStringWhitelist

Returns:

  • (Array<String>)


4039
4040
4041
# File 'lib/google/apis/compute_beta/classes.rb', line 4039

def query_string_whitelist
  @query_string_whitelist
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4046
4047
4048
4049
# File 'lib/google/apis/compute_beta/classes.rb', line 4046

def update!(**args)
  @include_http_headers = args[:include_http_headers] if args.key?(:include_http_headers)
  @query_string_whitelist = args[:query_string_whitelist] if args.key?(:query_string_whitelist)
end