Class: Google::Apis::ComputeBeta::BackendBucketList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendBucketList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of BackendBucket resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketList
constructor
A new instance of BackendBucketList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketList
Returns a new instance of BackendBucketList.
4123 4124 4125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4091 4092 4093 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4091 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4096 4097 4098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4096 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
4101 4102 4103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4101 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4111 4112 4113 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4111 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4116 4117 4118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4116 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4121 4122 4123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4121 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4128 4129 4130 4131 4132 4133 4134 4135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4128 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |