Class: Google::Apis::ComputeBeta::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4259
4260
4261
# File 'lib/google/apis/compute_beta/classes.rb', line 4259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4225
4226
4227
# File 'lib/google/apis/compute_beta/classes.rb', line 4225

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4230
4231
4232
# File 'lib/google/apis/compute_beta/classes.rb', line 4230

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4237
4238
4239
# File 'lib/google/apis/compute_beta/classes.rb', line 4237

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4247
4248
4249
# File 'lib/google/apis/compute_beta/classes.rb', line 4247

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4252
4253
4254
# File 'lib/google/apis/compute_beta/classes.rb', line 4252

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4257
4258
4259
# File 'lib/google/apis/compute_beta/classes.rb', line 4257

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4264
4265
4266
4267
4268
4269
4270
4271
# File 'lib/google/apis/compute_beta/classes.rb', line 4264

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end