Class: Google::Apis::ComputeBeta::BackendBucketParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendBucketParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Additional Backend Bucket parameters.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Tag keys/values directly bound to this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketParams
constructor
A new instance of BackendBucketParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketParams
Returns a new instance of BackendBucketParams.
4275 4276 4277 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4275 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Tag keys/values directly bound to this resource.
Tag keys and values have the same definition as resource
manager tags. The field is allowed for INSERT
only. The keys/values to set on the resource should be specified in
either ID : or Namespaced format
:.
For example the following are valid inputs:
"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456""123/environment" : "production", "345/abc" : "xyz"Note:- Invalid combinations of ID & namespaced format is not supported. For
instance:
"123/environment" : "tagValues/444"is invalid. Corresponds to the JSON propertyresourceManagerTags
4273 4274 4275 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4273 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4280 4281 4282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4280 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |