Class: Google::Apis::ComputeBeta::BackendService
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendService
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Backend Service resource. A backend service defines how Google Cloud load balancers distribute traffic. The backend service configuration contains a set of values, such as the protocol used to connect to backends, various distribution and session settings, health checks, and timeouts. These settings provide fine-grained control over how your load balancer behaves. Most of the settings have default values that allow for easy configuration if you need to get started quickly. Backend services in Google Compute Engine can be either regionally or globally scoped.
Instance Attribute Summary collapse
-
#affinity_cookie_ttl_sec ⇒ Fixnum
Lifetime of cookies in seconds.
-
#backends ⇒ Array<Google::Apis::ComputeBeta::Backend>
The list of backends that serve this BackendService.
-
#cdn_policy ⇒ Google::Apis::ComputeBeta::BackendServiceCdnPolicy
Message containing Cloud CDN configuration for a backend service.
-
#circuit_breakers ⇒ Google::Apis::ComputeBeta::CircuitBreakers
Settings controlling the volume of requests, connections and retries to this backend service.
-
#compression_mode ⇒ String
Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header.
-
#connection_draining ⇒ Google::Apis::ComputeBeta::ConnectionDraining
Message containing connection draining configuration.
-
#connection_tracking_policy ⇒ Google::Apis::ComputeBeta::BackendServiceConnectionTrackingPolicy
Connection Tracking configuration for this BackendService.
-
#consistent_hash ⇒ Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettings
This message defines settings for a consistent hash style load balancer.
-
#creation_timestamp ⇒ String
Output only.
-
#custom_metrics ⇒ Array<Google::Apis::ComputeBeta::BackendServiceCustomMetric>
List of custom metrics that are used for theWEIGHTED_ROUND_ROBIN locality_lb_policy.
-
#custom_request_headers ⇒ Array<String>
Headers that the load balancer adds to proxied requests.
-
#custom_response_headers ⇒ Array<String>
Headers that the load balancer adds to proxied responses.
-
#description ⇒ String
An optional description of this resource.
-
#dynamic_forwarding ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwarding
Defines a dynamic forwarding configuration for the backend service.
-
#edge_security_policy ⇒ String
[Output Only] The resource URL for the edge security policy associated with this backend service.
-
#enable_cdn ⇒ Boolean
(also: #enable_cdn?)
If true, enables Cloud CDN for the backend service of a global external Application Load Balancer.
-
#external_managed_migration_state ⇒ String
Specifies the canary migration state.
-
#external_managed_migration_testing_percentage ⇒ Float
Determines the fraction of requests that should be processed by the Global external Application Load Balancer.
-
#failover_policy ⇒ Google::Apis::ComputeBeta::BackendServiceFailoverPolicy
For load balancers that have configurable failover: Internal passthrough Network Load Balancers and external passthrough Network Load Balancers.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#ha_policy ⇒ Google::Apis::ComputeBeta::BackendServiceHaPolicy
Configures self-managed High Availability (HA) for External and Internal Protocol Forwarding.
-
#health_checks ⇒ Array<String>
The list of URLs to the healthChecks, httpHealthChecks (legacy), or httpsHealthChecks (legacy) resource for health checking this backend service.
-
#iap ⇒ Google::Apis::ComputeBeta::BackendServiceIap
Identity-Aware Proxy Corresponds to the JSON property
iap. -
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#ip_address_selection_policy ⇒ String
Specifies a preference for traffic sent from the proxy to the backend (or from the client to the backend for proxyless gRPC).
-
#kind ⇒ String
Output only.
-
#load_balancing_scheme ⇒ String
Specifies the load balancer type.
-
#locality_lb_policies ⇒ Array<Google::Apis::ComputeBeta::BackendServiceLocalityLoadBalancingPolicyConfig>
A list of locality load-balancing policies to be used in order of preference.
-
#locality_lb_policy ⇒ String
The load balancing algorithm used within the scope of the locality.
-
#log_config ⇒ Google::Apis::ComputeBeta::BackendServiceLogConfig
The available logging options for the load balancer traffic served by this backend service.
-
#max_stream_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#metadatas ⇒ Hash<String,String>
Deployment metadata associated with the resource to be set by a GKE hub controller and read by the backend RCTH Corresponds to the JSON property
metadatas. -
#name ⇒ String
Name of the resource.
-
#network ⇒ String
The URL of the network to which this backend service belongs.
-
#network_pass_through_lb_traffic_policy ⇒ Google::Apis::ComputeBeta::BackendServiceNetworkPassThroughLbTrafficPolicy
Configures traffic steering properties of internal passthrough Network Load Balancers.
-
#orchestration_info ⇒ Google::Apis::ComputeBeta::BackendServiceOrchestrationInfo
A message containing information about the resource or system that manages the backend service.
-
#outlier_detection ⇒ Google::Apis::ComputeBeta::OutlierDetection
Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.
-
#params ⇒ Google::Apis::ComputeBeta::BackendServiceParams
Additional Backend Service parameters.
-
#port ⇒ Fixnum
Deprecated in favor of portName.
-
#port_name ⇒ String
A named port on a backend instance group representing the port for communication to the backend VMs in that group.
-
#protocol ⇒ String
The protocol this BackendService uses to communicate with backends.
-
#region ⇒ String
Output only.
-
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this backend service.
-
#security_settings ⇒ Google::Apis::ComputeBeta::SecuritySettings
The authentication and authorization settings for a BackendService.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#service_bindings ⇒ Array<String>
URLs of networkservices.ServiceBinding resources.
-
#service_lb_policy ⇒ String
URL to networkservices.ServiceLbPolicy resource.
-
#session_affinity ⇒ String
Type of session affinity to use.
-
#strong_session_affinity_cookie ⇒ Google::Apis::ComputeBeta::BackendServiceHttpCookie
The HTTP cookie used for stateful session affinity.
-
#subsetting ⇒ Google::Apis::ComputeBeta::Subsetting
Subsetting configuration for this BackendService.
-
#timeout_sec ⇒ Fixnum
The backend service timeout has a different meaning depending on the type of load balancer.
-
#tls_settings ⇒ Google::Apis::ComputeBeta::BackendServiceTlsSettings
Configuration for Backend Authenticated TLS and mTLS.
-
#used_by ⇒ Array<Google::Apis::ComputeBeta::BackendServiceUsedBy>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendService
constructor
A new instance of BackendService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendService
Returns a new instance of BackendService.
5022 5023 5024 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affinity_cookie_ttl_sec ⇒ Fixnum
Lifetime of cookies in seconds. This setting is applicable to Application
Load Balancers and Traffic Director and requires
GENERATED_COOKIE or HTTP_COOKIE session affinity.
If set to 0, the cookie is non-persistent and lasts only until
the end of the browser session (or equivalent). The maximum allowed value
is two weeks (1,209,600).
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property affinityCookieTtlSec
4518 4519 4520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4518 def @affinity_cookie_ttl_sec end |
#backends ⇒ Array<Google::Apis::ComputeBeta::Backend>
The list of backends that serve this BackendService.
Corresponds to the JSON property backends
4523 4524 4525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4523 def backends @backends end |
#cdn_policy ⇒ Google::Apis::ComputeBeta::BackendServiceCdnPolicy
Message containing Cloud CDN configuration for a backend service.
Corresponds to the JSON property cdnPolicy
4528 4529 4530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4528 def cdn_policy @cdn_policy end |
#circuit_breakers ⇒ Google::Apis::ComputeBeta::CircuitBreakers
Settings controlling the volume of requests, connections and retries to this
backend service.
Corresponds to the JSON property circuitBreakers
4534 4535 4536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4534 def circuit_breakers @circuit_breakers end |
#compression_mode ⇒ String
Compress text responses using Brotli or gzip compression, based on
the client's Accept-Encoding header.
Corresponds to the JSON property compressionMode
4540 4541 4542 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4540 def compression_mode @compression_mode end |
#connection_draining ⇒ Google::Apis::ComputeBeta::ConnectionDraining
Message containing connection draining configuration.
Corresponds to the JSON property connectionDraining
4545 4546 4547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4545 def connection_draining @connection_draining end |
#connection_tracking_policy ⇒ Google::Apis::ComputeBeta::BackendServiceConnectionTrackingPolicy
Connection Tracking configuration for this BackendService.
Corresponds to the JSON property connectionTrackingPolicy
4550 4551 4552 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4550 def connection_tracking_policy @connection_tracking_policy end |
#consistent_hash ⇒ Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettings
This message defines settings for a consistent hash style load balancer.
Corresponds to the JSON property consistentHash
4555 4556 4557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4555 def consistent_hash @consistent_hash end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
4561 4562 4563 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4561 def @creation_timestamp end |
#custom_metrics ⇒ Array<Google::Apis::ComputeBeta::BackendServiceCustomMetric>
List of custom metrics that are used for theWEIGHTED_ROUND_ROBIN
locality_lb_policy.
Corresponds to the JSON property customMetrics
4567 4568 4569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4567 def custom_metrics @custom_metrics end |
#custom_request_headers ⇒ Array<String>
Headers that the load balancer adds to proxied requests. See Creating
custom
headers.
Corresponds to the JSON property customRequestHeaders
4574 4575 4576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4574 def custom_request_headers @custom_request_headers end |
#custom_response_headers ⇒ Array<String>
Headers that the load balancer adds to proxied responses. See Creating
custom
headers.
Corresponds to the JSON property customResponseHeaders
4581 4582 4583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4581 def custom_response_headers @custom_response_headers end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
4587 4588 4589 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4587 def description @description end |
#dynamic_forwarding ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwarding
Defines a dynamic forwarding configuration for the backend service.
Corresponds to the JSON property dynamicForwarding
4592 4593 4594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4592 def dynamic_forwarding @dynamic_forwarding end |
#edge_security_policy ⇒ String
[Output Only] The resource URL for the edge security policy associated with
this backend service.
Corresponds to the JSON property edgeSecurityPolicy
4598 4599 4600 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4598 def edge_security_policy @edge_security_policy end |
#enable_cdn ⇒ Boolean Also known as: enable_cdn?
If true, enables Cloud CDN for the backend service of a
global external Application Load Balancer.
Corresponds to the JSON property enableCDN
4604 4605 4606 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4604 def enable_cdn @enable_cdn end |
#external_managed_migration_state ⇒ String
Specifies the canary migration state. Possible values are PREPARE,
TEST_BY_PERCENTAGE, and TEST_ALL_TRAFFIC.
To begin the migration from EXTERNAL to EXTERNAL_MANAGED, the state must be
changed to PREPARE. The state must be changed to TEST_ALL_TRAFFIC before
the loadBalancingScheme can be changed to EXTERNAL_MANAGED. Optionally, the
TEST_BY_PERCENTAGE state can be used to migrate traffic by percentage using
externalManagedMigrationTestingPercentage.
Rolling back a migration requires the states to be set in reverse order. So
changing the scheme from EXTERNAL_MANAGED to EXTERNAL requires the state to
be set to TEST_ALL_TRAFFIC at the same time. Optionally, the
TEST_BY_PERCENTAGE state can be used to migrate some traffic back to
EXTERNAL or PREPARE can be used to migrate all traffic back to EXTERNAL.
Corresponds to the JSON property externalManagedMigrationState
4621 4622 4623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4621 def external_managed_migration_state @external_managed_migration_state end |
#external_managed_migration_testing_percentage ⇒ Float
Determines the fraction of requests that should be processed by the Global
external Application Load Balancer.
The value of this field must be in the range [0, 100].
Session affinity options will slightly affect this routing behavior, for
more details, see:Session
Affinity.
This value can only be set if the loadBalancingScheme in the BackendService
is set to EXTERNAL (when using the classic Application Load Balancer) and
the migration state is TEST_BY_PERCENTAGE.
Corresponds to the JSON property externalManagedMigrationTestingPercentage
4634 4635 4636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4634 def external_managed_migration_testing_percentage @external_managed_migration_testing_percentage end |
#failover_policy ⇒ Google::Apis::ComputeBeta::BackendServiceFailoverPolicy
For load balancers that have configurable
failover:
Internal passthrough Network Load
Balancers
and external passthrough
Network Load
Balancers.
On failover or failback, this field indicates whether connection draining
will be honored. Google Cloud has a fixed connection draining timeout of
10 minutes. A setting of true terminates existing TCP
connections to the active pool during failover and failback, immediately
draining traffic. A setting of false allows existing TCP
connections to persist, even on VMs no longer in the active pool, for up
to the duration of the connection draining timeout (10 minutes).
Corresponds to the JSON property failoverPolicy
4654 4655 4656 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4654 def failover_policy @failover_policy end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a BackendService. An up-to-date fingerprint must be provided in
order to update the BackendService, otherwise the request will
fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a BackendService.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
4666 4667 4668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4666 def fingerprint @fingerprint end |
#ha_policy ⇒ Google::Apis::ComputeBeta::BackendServiceHaPolicy
Configures self-managed High Availability (HA) for External and Internal
Protocol Forwarding.
The backends of this regional backend service must only specify zonal
network endpoint groups (NEGs) of type GCE_VM_IP.
When haPolicy is set for an Internal Passthrough Network Load Balancer, the
regional backend service must set the network field. All zonal NEGs must
belong to the same network. However, individual NEGs can
belong to different subnetworks of that network.
When haPolicy is specified, the set of attached network endpoints across
all backends comprise an High Availability domain from which one endpoint
is selected as the active endpoint (the leader) that receives all
traffic.
haPolicy can be added only at backend service creation time. Once set up,
it cannot be deleted.
Note that haPolicy is not for load balancing, and therefore cannot be
specified with sessionAffinity, connectionTrackingPolicy, and
failoverPolicy.
haPolicy requires customers to be responsible for tracking backend
endpoint health and electing a leader among the healthy endpoints.
Therefore, haPolicy cannot be specified with healthChecks.
haPolicy can only be specified for External Passthrough Network Load
Balancers and Internal Passthrough Network Load Balancers.
Corresponds to the JSON property haPolicy
4692 4693 4694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4692 def ha_policy @ha_policy end |
#health_checks ⇒ Array<String>
The list of URLs to the healthChecks, httpHealthChecks (legacy), or
httpsHealthChecks (legacy) resource for health checking this backend
service. Not all backend services support legacy health checks. See
Load balancer guide. Currently, at most one health check can be
specified for each backend service. Backend services with
instance group or zonal NEG backends must have a health check unless
haPolicy is specified. Backend services with internet or serverless NEG
backends must not have a health check.
healthChecks[] cannot be specified with haPolicy.
Corresponds to the JSON property healthChecks
4705 4706 4707 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4705 def health_checks @health_checks end |
#iap ⇒ Google::Apis::ComputeBeta::BackendServiceIap
Identity-Aware Proxy
Corresponds to the JSON property iap
4710 4711 4712 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4710 def iap @iap end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
4716 4717 4718 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4716 def id @id end |
#ip_address_selection_policy ⇒ String
Specifies a preference for traffic sent from the proxy to the backend (or from the client to the backend for proxyless gRPC). The possible values are:
- IPV4_ONLY: Only send IPv4 traffic to the backends of the backend service (Instance Group, Managed Instance Group, Network Endpoint Group), regardless of traffic from the client to the proxy. Only IPv4 health checks are used to check the health of the backends. This is the default setting.
- PREFER_IPV6: Prioritize the connection to the endpoint's IPv6 address over its IPv4 address (provided there is a healthy IPv6 address).
IPV6_ONLY: Only send IPv6 traffic to the backends of the backend service (Instance Group, Managed Instance Group, Network Endpoint Group), regardless of traffic from the client to the proxy. Only IPv6 health checks are used to check the health of the backends. This field is applicable to either:
Advanced global external Application Load Balancer (load balancing scheme EXTERNAL_MANAGED),
Regional external Application Load Balancer,
Internal proxy Network Load Balancer (load balancing scheme INTERNAL_MANAGED),
Regional internal Application Load Balancer (load balancing scheme INTERNAL_MANAGED),
Traffic Director with Envoy proxies and proxyless gRPC (load balancing scheme INTERNAL_SELF_MANAGED). Corresponds to the JSON property
ipAddressSelectionPolicy
4749 4750 4751 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4749 def ip_address_selection_policy @ip_address_selection_policy end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#backendService
for backend services.
Corresponds to the JSON property kind
4755 4756 4757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4755 def kind @kind end |
#load_balancing_scheme ⇒ String
Specifies the load balancer type. A backend service
created for one type of load balancer cannot be used with another.
For more information, refer toChoosing
a load balancer.
Corresponds to the JSON property loadBalancingScheme
4763 4764 4765 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4763 def load_balancing_scheme @load_balancing_scheme end |
#locality_lb_policies ⇒ Array<Google::Apis::ComputeBeta::BackendServiceLocalityLoadBalancingPolicyConfig>
A list of locality load-balancing policies to be used in order of
preference. When you use localityLbPolicies, you must set at least one
value for either the localityLbPolicies[].policy or the
localityLbPolicies[].customPolicy field. localityLbPolicies overrides any
value set in the localityLbPolicy field.
For an example of how to use this field, seeDefine
a list of preferred policies.
Caution: This field and its children are intended for use in a service mesh
that includes gRPC clients only. Envoy proxies can't use backend services
that have this configuration.
Corresponds to the JSON property localityLbPolicies
4777 4778 4779 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4777 def locality_lb_policies @locality_lb_policies end |
#locality_lb_policy ⇒ String
The load balancing algorithm used within the scope of the locality. The possible values are:
- ROUND_ROBIN: This is a simple policy in which each healthy backend is selected in round robin order. This is the default.
- LEAST_REQUEST: An O(1) algorithm which selects two random healthy hosts and picks the host which has fewer active requests.
- RING_HASH: The ring/modulo hash load balancer implements consistent hashing to backends. The algorithm has the property that the addition/removal of a host from a set of N hosts only affects 1/N of the requests.
- RANDOM: The load balancer selects a random healthy host.
- ORIGINAL_DESTINATION: Backend host is selected based on the client connection metadata, i.e., connections are opened to the same address as the destination address of the incoming connection before the connection was redirected to the load balancer.
- MAGLEV: used as a drop in replacement for the ring hash load balancer. Maglev is not as stable as ring hash but has faster table lookup build times and host selection times. For more information about Maglev, see Maglev: A Fast and Reliable Software Network Load Balancer.
- WEIGHTED_ROUND_ROBIN: Per-endpoint Weighted Round Robin Load Balancing using weights computed from Backend reported Custom Metrics. If set, the Backend Service responses are expected to contain non-standard HTTP response header field Endpoint-Load-Metrics. The reported metrics to use for computing the weights are specified via thecustomMetrics field.
This field is applicable to either:
- A regional backend service with the service protocol set to HTTP, HTTPS, HTTP2 or H2C, and load_balancing_scheme set to INTERNAL_MANAGED.
- A global backend service with the load_balancing_scheme set to INTERNAL_SELF_MANAGED, INTERNAL_MANAGED, or EXTERNAL_MANAGED.
If sessionAffinity is not configured—that is, if session affinity remains at the default value of NONE—then the default value for localityLbPolicy is ROUND_ROBIN. If session affinity is set to a value other than NONE, then the default value for localityLbPolicy isMAGLEV.
Only ROUND_ROBIN and RING_HASH are supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true.
localityLbPolicy cannot be specified with haPolicy.
Corresponds to the JSON property localityLbPolicy
4832 4833 4834 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4832 def locality_lb_policy @locality_lb_policy end |
#log_config ⇒ Google::Apis::ComputeBeta::BackendServiceLogConfig
The available logging options for the load balancer traffic served by this
backend service.
Corresponds to the JSON property logConfig
4838 4839 4840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4838 def log_config @log_config end |
#max_stream_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxStreamDuration
4846 4847 4848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4846 def max_stream_duration @max_stream_duration end |
#metadatas ⇒ Hash<String,String>
Deployment metadata associated with the resource to be set by a GKE hub
controller and read by the backend RCTH
Corresponds to the JSON property metadatas
4852 4853 4854 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4852 def @metadatas end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
4863 4864 4865 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4863 def name @name end |
#network ⇒ String
The URL of the network to which this backend service belongs.
This field must be set for Internal Passthrough Network Load Balancers when
the haPolicy is enabled, and for External Passthrough Network Load
Balancers when the haPolicy fastIpMove is enabled.
This field can only be specified when the load balancing scheme is set
toINTERNAL, or when the load balancing scheme is set toEXTERNAL and haPolicy
fastIpMove is enabled.
Corresponds to the JSON property network
4874 4875 4876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4874 def network @network end |
#network_pass_through_lb_traffic_policy ⇒ Google::Apis::ComputeBeta::BackendServiceNetworkPassThroughLbTrafficPolicy
Configures traffic steering properties of internal passthrough Network
Load Balancers.
networkPassThroughLbTrafficPolicy cannot be specified with haPolicy.
Corresponds to the JSON property networkPassThroughLbTrafficPolicy
4881 4882 4883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4881 def network_pass_through_lb_traffic_policy @network_pass_through_lb_traffic_policy end |
#orchestration_info ⇒ Google::Apis::ComputeBeta::BackendServiceOrchestrationInfo
A message containing information about the resource or system that manages
the backend service.
Corresponds to the JSON property orchestrationInfo
4887 4888 4889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4887 def orchestration_info @orchestration_info end |
#outlier_detection ⇒ Google::Apis::ComputeBeta::OutlierDetection
Settings controlling the eviction of unhealthy hosts from the load balancing
pool for the backend service.
Corresponds to the JSON property outlierDetection
4893 4894 4895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4893 def outlier_detection @outlier_detection end |
#params ⇒ Google::Apis::ComputeBeta::BackendServiceParams
Additional Backend Service parameters.
Corresponds to the JSON property params
4898 4899 4900 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4898 def params @params end |
#port ⇒ Fixnum
Deprecated in favor of portName. The TCP port to connect on
the backend. The default value is 80.
For internal passthrough Network Load Balancers and external passthrough
Network Load Balancers, omit port.
Corresponds to the JSON property port
4906 4907 4908 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4906 def port @port end |
#port_name ⇒ String
A named port on a backend instance group representing the port for
communication to the backend VMs in that group. The
named port must be defined on each backend instance
group.
This parameter has no meaning if the backends are NEGs. For internal
passthrough Network Load Balancers and external passthrough Network Load
Balancers, omit port_name.
Corresponds to the JSON property portName
4918 4919 4920 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4918 def port_name @port_name end |
#protocol ⇒ String
The protocol this BackendService uses to communicate
with backends.
Possible values are HTTP, HTTPS, HTTP2, H2C, TCP, SSL, UDP or GRPC.
depending on the chosen load balancer or Traffic Director configuration.
Refer to the documentation for the load balancers or for Traffic Director
for more information.
Must be set to GRPC when the backend service is referenced by a URL map
that is bound to target gRPC proxy.
Corresponds to the JSON property protocol
4930 4931 4932 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4930 def protocol @protocol end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional backend
service
resides. This field is not applicable to global backend services.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
4939 4940 4941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4939 def region @region end |
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this
backend service.
Corresponds to the JSON property securityPolicy
4945 4946 4947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4945 def security_policy @security_policy end |
#security_settings ⇒ Google::Apis::ComputeBeta::SecuritySettings
The authentication and authorization settings for a BackendService.
Corresponds to the JSON property securitySettings
4950 4951 4952 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4950 def security_settings @security_settings end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
4955 4956 4957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4955 def self_link @self_link end |
#service_bindings ⇒ Array<String>
URLs of networkservices.ServiceBinding resources.
Can only be set if load balancing scheme is INTERNAL_SELF_MANAGED.
If set, lists of backends and health checks must be both empty.
Corresponds to the JSON property serviceBindings
4962 4963 4964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4962 def service_bindings @service_bindings end |
#service_lb_policy ⇒ String
URL to networkservices.ServiceLbPolicy resource.
Can only be set if load balancing scheme is EXTERNAL_MANAGED,
INTERNAL_MANAGED or INTERNAL_SELF_MANAGED and the scope is global.
Corresponds to the JSON property serviceLbPolicy
4969 4970 4971 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4969 def service_lb_policy @service_lb_policy end |
#session_affinity ⇒ String
Type of session affinity to use. The default is NONE.
Only NONE and HEADER_FIELD are supported
when the backend service is referenced by a URL map that is bound to
target gRPC proxy that has validateForProxyless field set to true.
For more details, see:
Session
Affinity.
sessionAffinity cannot be specified with haPolicy.
Corresponds to the JSON property sessionAffinity
4982 4983 4984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4982 def session_affinity @session_affinity end |
#strong_session_affinity_cookie ⇒ Google::Apis::ComputeBeta::BackendServiceHttpCookie
The HTTP cookie used for stateful session affinity.
Corresponds to the JSON property strongSessionAffinityCookie
4987 4988 4989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4987 def @strong_session_affinity_cookie end |
#subsetting ⇒ Google::Apis::ComputeBeta::Subsetting
Subsetting configuration for this BackendService.
Currently this is applicable only for Internal TCP/UDP load balancing,
Internal HTTP(S) load balancing and Traffic Director.
Corresponds to the JSON property subsetting
4994 4995 4996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4994 def subsetting @subsetting end |
#timeout_sec ⇒ Fixnum
The backend service timeout has a different meaning depending on the
type of load balancer. For more information see,
Backend service settings.
The default is 30 seconds.
The full range of timeout values allowed goes from 1
through 2,147,483,647 seconds.
This value can be overridden in the PathMatcher configuration of the
UrlMap that references this backend service.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Instead, use maxStreamDuration.
Corresponds to the JSON property timeoutSec
5009 5010 5011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5009 def timeout_sec @timeout_sec end |
#tls_settings ⇒ Google::Apis::ComputeBeta::BackendServiceTlsSettings
Configuration for Backend Authenticated TLS and mTLS. May only be specified
when the backend protocol is SSL, HTTPS or HTTP2.
Corresponds to the JSON property tlsSettings
5015 5016 5017 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5015 def tls_settings @tls_settings end |
#used_by ⇒ Array<Google::Apis::ComputeBeta::BackendServiceUsedBy>
Output only. [Output Only] List of resources referencing given backend service.
Corresponds to the JSON property usedBy
5020 5021 5022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5020 def used_by @used_by end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5027 5028 5029 5030 5031 5032 5033 5034 5035 5036 5037 5038 5039 5040 5041 5042 5043 5044 5045 5046 5047 5048 5049 5050 5051 5052 5053 5054 5055 5056 5057 5058 5059 5060 5061 5062 5063 5064 5065 5066 5067 5068 5069 5070 5071 5072 5073 5074 5075 5076 5077 5078 5079 5080 5081 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5027 def update!(**args) @affinity_cookie_ttl_sec = args[:affinity_cookie_ttl_sec] if args.key?(:affinity_cookie_ttl_sec) @backends = args[:backends] if args.key?(:backends) @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy) @circuit_breakers = args[:circuit_breakers] if args.key?(:circuit_breakers) @compression_mode = args[:compression_mode] if args.key?(:compression_mode) @connection_draining = args[:connection_draining] if args.key?(:connection_draining) @connection_tracking_policy = args[:connection_tracking_policy] if args.key?(:connection_tracking_policy) @consistent_hash = args[:consistent_hash] if args.key?(:consistent_hash) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_metrics = args[:custom_metrics] if args.key?(:custom_metrics) @custom_request_headers = args[:custom_request_headers] if args.key?(:custom_request_headers) @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers) @description = args[:description] if args.key?(:description) @dynamic_forwarding = args[:dynamic_forwarding] if args.key?(:dynamic_forwarding) @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy) @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn) @external_managed_migration_state = args[:external_managed_migration_state] if args.key?(:external_managed_migration_state) @external_managed_migration_testing_percentage = args[:external_managed_migration_testing_percentage] if args.key?(:external_managed_migration_testing_percentage) @failover_policy = args[:failover_policy] if args.key?(:failover_policy) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @ha_policy = args[:ha_policy] if args.key?(:ha_policy) @health_checks = args[:health_checks] if args.key?(:health_checks) @iap = args[:iap] if args.key?(:iap) @id = args[:id] if args.key?(:id) @ip_address_selection_policy = args[:ip_address_selection_policy] if args.key?(:ip_address_selection_policy) @kind = args[:kind] if args.key?(:kind) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @locality_lb_policies = args[:locality_lb_policies] if args.key?(:locality_lb_policies) @locality_lb_policy = args[:locality_lb_policy] if args.key?(:locality_lb_policy) @log_config = args[:log_config] if args.key?(:log_config) @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration) @metadatas = args[:metadatas] if args.key?(:metadatas) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_pass_through_lb_traffic_policy = args[:network_pass_through_lb_traffic_policy] if args.key?(:network_pass_through_lb_traffic_policy) @orchestration_info = args[:orchestration_info] if args.key?(:orchestration_info) @outlier_detection = args[:outlier_detection] if args.key?(:outlier_detection) @params = args[:params] if args.key?(:params) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @protocol = args[:protocol] if args.key?(:protocol) @region = args[:region] if args.key?(:region) @security_policy = args[:security_policy] if args.key?(:security_policy) @security_settings = args[:security_settings] if args.key?(:security_settings) @self_link = args[:self_link] if args.key?(:self_link) @service_bindings = args[:service_bindings] if args.key?(:service_bindings) @service_lb_policy = args[:service_lb_policy] if args.key?(:service_lb_policy) @session_affinity = args[:session_affinity] if args.key?(:session_affinity) @strong_session_affinity_cookie = args[:strong_session_affinity_cookie] if args.key?(:strong_session_affinity_cookie) @subsetting = args[:subsetting] if args.key?(:subsetting) @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec) @tls_settings = args[:tls_settings] if args.key?(:tls_settings) @used_by = args[:used_by] if args.key?(:used_by) end |