Class: Google::Apis::ComputeBeta::BackendServiceCdnPolicyBypassCacheOnRequestHeader

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Bypass the cache when the specified request headers are present, e.g. Pragma or Authorization headers. Values are case insensitive. The presence of such a header overrides the cache_mode setting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceCdnPolicyBypassCacheOnRequestHeader

Returns a new instance of BackendServiceCdnPolicyBypassCacheOnRequestHeader.



5349
5350
5351
# File 'lib/google/apis/compute_beta/classes.rb', line 5349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The header field name to match on when bypassing cache. Values are case-insensitive. Corresponds to the JSON property headerName

Returns:

  • (String)


5347
5348
5349
# File 'lib/google/apis/compute_beta/classes.rb', line 5347

def header_name
  @header_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5354
5355
5356
# File 'lib/google/apis/compute_beta/classes.rb', line 5354

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
end