Class: Google::Apis::ComputeBeta::BackendServiceDynamicForwarding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Defines a dynamic forwarding configuration for the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceDynamicForwarding

Returns a new instance of BackendServiceDynamicForwarding.



5634
5635
5636
# File 'lib/google/apis/compute_beta/classes.rb', line 5634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forward_proxyGoogle::Apis::ComputeBeta::BackendServiceDynamicForwardingForwardProxy

Defines Dynamic Forwarding Proxy configuration. Corresponds to the JSON property forwardProxy



5625
5626
5627
# File 'lib/google/apis/compute_beta/classes.rb', line 5625

def forward_proxy
  @forward_proxy
end

#ip_port_selectionGoogle::Apis::ComputeBeta::BackendServiceDynamicForwardingIpPortSelection

Defines a IP:PORT based dynamic forwarding configuration for the backend service. Some ranges are restricted: Restricted ranges. Corresponds to the JSON property ipPortSelection



5632
5633
5634
# File 'lib/google/apis/compute_beta/classes.rb', line 5632

def ip_port_selection
  @ip_port_selection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5639
5640
5641
5642
# File 'lib/google/apis/compute_beta/classes.rb', line 5639

def update!(**args)
  @forward_proxy = args[:forward_proxy] if args.key?(:forward_proxy)
  @ip_port_selection = args[:ip_port_selection] if args.key?(:ip_port_selection)
end