Class: Google::Apis::ComputeBeta::BackendServiceGroupHealth
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceGroupHealth
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations on the network endpoint group.
-
#health_status ⇒ Array<Google::Apis::ComputeBeta::HealthStatus>
Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks.
-
#kind ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceGroupHealth
constructor
A new instance of BackendServiceGroupHealth.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceGroupHealth
Returns a new instance of BackendServiceGroupHealth.
5734 5735 5736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations on the network endpoint group.
Corresponds to the JSON property annotations
5719 5720 5721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5719 def annotations @annotations end |
#health_status ⇒ Array<Google::Apis::ComputeBeta::HealthStatus>
Health state of the backend instances or endpoints in requested instance or
network endpoint group, determined based on configured health checks.
Corresponds to the JSON property healthStatus
5725 5726 5727 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5725 def health_status @health_status end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
backendServiceGroupHealth for the health of backend
services.
Corresponds to the JSON property kind
5732 5733 5734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5732 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5739 5740 5741 5742 5743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5739 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @health_status = args[:health_status] if args.key?(:health_status) @kind = args[:kind] if args.key?(:kind) end |