Class: Google::Apis::ComputeBeta::BackendServiceIap
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceIap
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Identity-Aware Proxy
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Whether the serving infrastructure will authenticate and authorize all incoming requests.
-
#oauth2_client_id ⇒ String
OAuth2 client ID to use for the authentication flow.
-
#oauth2_client_secret ⇒ String
OAuth2 client secret to use for the authentication flow.
-
#oauth2_client_secret_sha256 ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceIap
constructor
A new instance of BackendServiceIap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceIap
Returns a new instance of BackendServiceIap.
5954 5955 5956 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Whether the serving infrastructure will authenticate and authorize all
incoming requests.
Corresponds to the JSON property enabled
5931 5932 5933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5931 def enabled @enabled end |
#oauth2_client_id ⇒ String
OAuth2 client ID to use for the authentication flow.
Corresponds to the JSON property oauth2ClientId
5937 5938 5939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5937 def oauth2_client_id @oauth2_client_id end |
#oauth2_client_secret ⇒ String
OAuth2 client secret to use for the authentication flow.
For security reasons, this value cannot be retrieved via the API.
Instead, the SHA-256 hash of the value is returned in the
oauth2ClientSecretSha256 field.
Corresponds to the JSON property oauth2ClientSecret
5946 5947 5948 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5946 def oauth2_client_secret @oauth2_client_secret end |
#oauth2_client_secret_sha256 ⇒ String
Output only. [Output Only] SHA256 hash value for the field
oauth2_client_secret above.
Corresponds to the JSON property oauth2ClientSecretSha256
5952 5953 5954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5952 def oauth2_client_secret_sha256 @oauth2_client_secret_sha256 end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5959 5960 5961 5962 5963 5964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5959 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id) @oauth2_client_secret = args[:oauth2_client_secret] if args.key?(:oauth2_client_secret) @oauth2_client_secret_sha256 = args[:oauth2_client_secret_sha256] if args.key?(:oauth2_client_secret_sha256) end |