Class: Google::Apis::ComputeBeta::BackendServiceOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A message containing information about the resource or system that manages the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceOrchestrationInfo

Returns a new instance of BackendServiceOrchestrationInfo.



6459
6460
6461
# File 'lib/google/apis/compute_beta/classes.rb', line 6459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The resource URI of the resource or system that manages the backend service. Corresponds to the JSON property resourceUri

Returns:

  • (String)


6457
6458
6459
# File 'lib/google/apis/compute_beta/classes.rb', line 6457

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6464
6465
6466
# File 'lib/google/apis/compute_beta/classes.rb', line 6464

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end