Class: Google::Apis::ComputeBeta::BackendServiceTlsSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceTlsSettings

Returns a new instance of BackendServiceTlsSettings.



6573
6574
6575
# File 'lib/google/apis/compute_beta/classes.rb', line 6573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authentication_configString

Reference to the BackendAuthenticationConfig resource from the networksecurity.googleapis.com namespace. Can be used in authenticating TLS connections to the backend, as specified by the authenticationMode field. Can only be specified if authenticationMode is not NONE. Corresponds to the JSON property authenticationConfig

Returns:

  • (String)


6514
6515
6516
# File 'lib/google/apis/compute_beta/classes.rb', line 6514

def authentication_config
  @authentication_config
end

#identityString

Assigns the Managed Identity for the BackendService Workload. Use this property to configure the load balancer back-end to use certificates and roots of trust provisioned by the Managed Workload Identity system. The identity property is the fully-specified SPIFFE ID to use in the SVID presented by the Load Balancer Workload. The SPIFFE ID must be a resource starting with the trustDomain property value, followed by the path to the Managed Workload Identity. Supported SPIFFE ID format:

  • ///ns//sa/ The Trust Domain within the Managed Identity must refer to a valid Workload Identity Pool. The TrustConfig and CertificateIssuanceConfig will be inherited from the Workload Identity Pool. Restrictions:

  • If you set the identity property, you cannot manually set the following fields:

  • tlsSettings.sni

  • tlsSettings.subjectAltNames

  • tlsSettings.authenticationConfig

When defining a identity for a RegionBackendServices, the corresponding Workload Identity Pool must have a ca_pool configured in the same region. The system will set up a read-onlytlsSettings.authenticationConfig for the Managed Identity. Corresponds to the JSON property identity

Returns:

  • (String)


6547
6548
6549
# File 'lib/google/apis/compute_beta/classes.rb', line 6547

def identity
  @identity
end

#sniString

Server Name Indication - see RFC3546 section 3.1. If set, the load balancer sends this string as the SNI hostname in the TLS connection to the backend, and requires that this string match a Subject Alternative Name (SAN) in the backend's server certificate. With a Regional Internet NEG backend, if the SNI is specified here, the load balancer uses it regardless of whether the Regional Internet NEG is specified with FQDN or IP address and port. When both sni and subjectAltNames[] are specified, the load balancer matches the backend certificate's SAN only to subjectAltNames[]. Corresponds to the JSON property sni

Returns:

  • (String)


6560
6561
6562
# File 'lib/google/apis/compute_beta/classes.rb', line 6560

def sni
  @sni
end

#subject_alt_namesArray<Google::Apis::ComputeBeta::BackendServiceTlsSettingsSubjectAltName>

A list of Subject Alternative Names (SANs) that the Load Balancer verifies during a TLS handshake with the backend. When the server presents its X.509 certificate to the Load Balancer, the Load Balancer inspects the certificate's SAN field, and requires that at least one SAN match one of the subjectAltNames in the list. This field is limited to 5 entries. When both sni and subjectAltNames[] are specified, the load balancer matches the backend certificate's SAN only to subjectAltNames[]. Corresponds to the JSON property subjectAltNames



6571
6572
6573
# File 'lib/google/apis/compute_beta/classes.rb', line 6571

def subject_alt_names
  @subject_alt_names
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6578
6579
6580
6581
6582
6583
# File 'lib/google/apis/compute_beta/classes.rb', line 6578

def update!(**args)
  @authentication_config = args[:authentication_config] if args.key?(:authentication_config)
  @identity = args[:identity] if args.key?(:identity)
  @sni = args[:sni] if args.key?(:sni)
  @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names)
end