Class: Google::Apis::ComputeBeta::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeBeta::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeBeta::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#rx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
7029 7030 7031 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7029 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
6978 6979 6980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6978 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
6983 6984 6985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6983 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeBeta::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
6988 6989 6990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6988 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeBeta::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
6993 6994 6995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6993 def control_packet_intervals @control_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
7001 7002 7003 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7001 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
7007 7008 7009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7007 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
7012 7013 7014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7012 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
7017 7018 7019 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7017 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
7022 7023 7024 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7022 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
7027 7028 7029 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7027 def uptime_ms @uptime_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7034 7035 7036 7037 7038 7039 7040 7041 7042 7043 7044 7045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7034 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) end |