Class: Google::Apis::ComputeBeta::BfdStatusPacketCounts
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BfdStatusPacketCounts
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD session.
-
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the beginning of the current BFD session.
-
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the beginning of the current BFD session.
-
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD session.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatusPacketCounts
constructor
A new instance of BfdStatusPacketCounts.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatusPacketCounts
Returns a new instance of BfdStatusPacketCounts.
7076 7077 7078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_rx ⇒ Fixnum
Number of packets received since the beginning of the current BFD
session.
Corresponds to the JSON property numRx
7056 7057 7058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7056 def num_rx @num_rx end |
#num_rx_rejected ⇒ Fixnum
Number of packets received that were rejected because of errors since the
beginning of the current BFD session.
Corresponds to the JSON property numRxRejected
7062 7063 7064 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7062 def num_rx_rejected @num_rx_rejected end |
#num_rx_successful ⇒ Fixnum
Number of packets received that were successfully processed since the
beginning of the current BFD session.
Corresponds to the JSON property numRxSuccessful
7068 7069 7070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7068 def num_rx_successful @num_rx_successful end |
#num_tx ⇒ Fixnum
Number of packets transmitted since the beginning of the current BFD
session.
Corresponds to the JSON property numTx
7074 7075 7076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7074 def num_tx @num_tx end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7081 7082 7083 7084 7085 7086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7081 def update!(**args) @num_rx = args[:num_rx] if args.key?(:num_rx) @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected) @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful) @num_tx = args[:num_tx] if args.key?(:num_tx) end |