Class: Google::Apis::ComputeBeta::BulkInsertInstanceResource
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BulkInsertInstanceResource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A transient resource used in compute.instances.bulkInsert and compute.regionInstances.bulkInsert . This resource is not persisted anywhere, it is used only for processing the requests.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
The maximum number of instances to create.
-
#instance_flexibility_policy ⇒ Google::Apis::ComputeBeta::InstanceFlexibilityPolicy
A flexible specification of machine types for instances to create.
-
#instance_properties ⇒ Google::Apis::ComputeBeta::InstanceProperties
The instance properties defining the VM instances to be created.
-
#location_policy ⇒ Google::Apis::ComputeBeta::LocationPolicy
Configuration for location policy among multiple possible locations (e.g. preferences for zone selection among zones in a single region).
-
#min_count ⇒ Fixnum
The minimum number of instances to create.
-
#name_pattern ⇒ String
The string pattern used for the names of the VMs.
-
#per_instance_properties ⇒ Hash<String,Google::Apis::ComputeBeta::BulkInsertInstanceResourcePerInstanceProperties>
Per-instance properties to be set on individual instances.
-
#source_instance_template ⇒ String
Specifies the instance template from which to create instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BulkInsertInstanceResource
constructor
A new instance of BulkInsertInstanceResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BulkInsertInstanceResource
Returns a new instance of BulkInsertInstanceResource.
7444 7445 7446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
The maximum number of instances to create.
Corresponds to the JSON property count
7374 7375 7376 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7374 def count @count end |
#instance_flexibility_policy ⇒ Google::Apis::ComputeBeta::InstanceFlexibilityPolicy
A flexible specification of machine types for instances to create.
Corresponds to the JSON property instanceFlexibilityPolicy
7379 7380 7381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7379 def instance_flexibility_policy @instance_flexibility_policy end |
#instance_properties ⇒ Google::Apis::ComputeBeta::InstanceProperties
The instance properties defining the VM instances to be created. Required
if sourceInstanceTemplate is not provided.
Corresponds to the JSON property instanceProperties
7385 7386 7387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7385 def instance_properties @instance_properties end |
#location_policy ⇒ Google::Apis::ComputeBeta::LocationPolicy
Configuration for location policy among multiple possible locations
(e.g. preferences for zone selection among zones in a single region).
Corresponds to the JSON property locationPolicy
7391 7392 7393 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7391 def location_policy @location_policy end |
#min_count ⇒ Fixnum
The minimum number of instances to create. If no min_count is
specified then count is used as the default value. Ifmin_count instances
cannot be created, then no instances will
be created and instances already created will be deleted.
Corresponds to the JSON property minCount
7399 7400 7401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7399 def min_count @min_count end |
#name_pattern ⇒ String
The string pattern used for the names of the VMs.
Either name_pattern or per_instance_properties
must be set. The pattern must contain one continuous sequence of
placeholder hash characters (#) with each character corresponding to one
digit of the generated instance name. Example: a name_pattern
of inst-#### generates instance names such asinst-0001 and inst-0002. If
existing instances
in the same project and zone have names that match the name pattern
then the generated instance numbers start after the biggest
existing number. For example, if there exists an instance with nameinst-0050,
then instance names generated using the patterninst-#### begin with inst-0051.
The name pattern
placeholder #...# can contain up to 18 characters.
Corresponds to the JSON property namePattern
7416 7417 7418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7416 def name_pattern @name_pattern end |
#per_instance_properties ⇒ Hash<String,Google::Apis::ComputeBeta::BulkInsertInstanceResourcePerInstanceProperties>
Per-instance properties to be set on individual instances.
Keys of this map specify requested instance names.
Can be empty if name_pattern is used.
Corresponds to the JSON property perInstanceProperties
7423 7424 7425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7423 def per_instance_properties @per_instance_properties end |
#source_instance_template ⇒ String
Specifies the instance template from which to create instances. You may combine sourceInstanceTemplate withinstanceProperties to override specific values from an existing instance template. Bulk API follows the semantics of JSON Merge Patch described by RFC 7396. It can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/ instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate
This field is optional.
Corresponds to the JSON property
sourceInstanceTemplate
7442 7443 7444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7442 def source_instance_template @source_instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7449 7450 7451 7452 7453 7454 7455 7456 7457 7458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7449 def update!(**args) @count = args[:count] if args.key?(:count) @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @location_policy = args[:location_policy] if args.key?(:location_policy) @min_count = args[:min_count] if args.key?(:min_count) @name_pattern = args[:name_pattern] if args.key?(:name_pattern) @per_instance_properties = args[:per_instance_properties] if args.key?(:per_instance_properties) @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template) end |