Class: Google::Apis::ComputeBeta::BundledLocalSsds
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BundledLocalSsds
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#default_interface ⇒ String
The default disk interface if the interface is not specified.
-
#partition_count ⇒ Fixnum
The number of partitions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BundledLocalSsds
constructor
A new instance of BundledLocalSsds.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BundledLocalSsds
Returns a new instance of BundledLocalSsds.
7387 7388 7389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_interface ⇒ String
The default disk interface if the interface is not specified.
Corresponds to the JSON property defaultInterface
7380 7381 7382 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7380 def default_interface @default_interface end |
#partition_count ⇒ Fixnum
The number of partitions.
Corresponds to the JSON property partitionCount
7385 7386 7387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7385 def partition_count @partition_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7392 7393 7394 7395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7392 def update!(**args) @default_interface = args[:default_interface] if args.key?(:default_interface) @partition_count = args[:partition_count] if args.key?(:partition_count) end |