Class: Google::Apis::ComputeBeta::CacheKeyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message containing what to include in the cache key for a request for Cloud CDN.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CacheKeyPolicy

Returns a new instance of CacheKeyPolicy.



7702
7703
7704
# File 'lib/google/apis/compute_beta/classes.rb', line 7702

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#include_hostBoolean Also known as: include_host?

If true, requests to different hosts will be cached separately. Corresponds to the JSON property includeHost

Returns:

  • (Boolean)


7657
7658
7659
# File 'lib/google/apis/compute_beta/classes.rb', line 7657

def include_host
  @include_host
end

#include_http_headersArray<String>

Allows HTTP request headers (by name) to be used in the cache key. Corresponds to the JSON property includeHttpHeaders

Returns:

  • (Array<String>)


7663
7664
7665
# File 'lib/google/apis/compute_beta/classes.rb', line 7663

def include_http_headers
  @include_http_headers
end

#include_named_cookiesArray<String>

Allows HTTP cookies (by name) to be used in the cache key. The name=value pair will be used in the cache key Cloud CDN generates. Corresponds to the JSON property includeNamedCookies

Returns:

  • (Array<String>)


7669
7670
7671
# File 'lib/google/apis/compute_beta/classes.rb', line 7669

def include_named_cookies
  @include_named_cookies
end

#include_protocolBoolean Also known as: include_protocol?

If true, http and https requests will be cached separately. Corresponds to the JSON property includeProtocol

Returns:

  • (Boolean)


7674
7675
7676
# File 'lib/google/apis/compute_beta/classes.rb', line 7674

def include_protocol
  @include_protocol
end

#include_query_stringBoolean Also known as: include_query_string?

If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist. If neither is set, the entire query string will be included. If false, the query string will be excluded from the cache key entirely. Corresponds to the JSON property includeQueryString

Returns:

  • (Boolean)


7683
7684
7685
# File 'lib/google/apis/compute_beta/classes.rb', line 7683

def include_query_string
  @include_query_string
end

#query_string_blacklistArray<String>

Names of query string parameters to exclude in cache keys. All other parameters will be included. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters. Corresponds to the JSON property queryStringBlacklist

Returns:

  • (Array<String>)


7692
7693
7694
# File 'lib/google/apis/compute_beta/classes.rb', line 7692

def query_string_blacklist
  @query_string_blacklist
end

#query_string_whitelistArray<String>

Names of query string parameters to include in cache keys. All other parameters will be excluded. Either specify query_string_whitelist or query_string_blacklist, not both. '&' and '=' will be percent encoded and not treated as delimiters. Corresponds to the JSON property queryStringWhitelist

Returns:

  • (Array<String>)


7700
7701
7702
# File 'lib/google/apis/compute_beta/classes.rb', line 7700

def query_string_whitelist
  @query_string_whitelist
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7707
7708
7709
7710
7711
7712
7713
7714
7715
# File 'lib/google/apis/compute_beta/classes.rb', line 7707

def update!(**args)
  @include_host = args[:include_host] if args.key?(:include_host)
  @include_http_headers = args[:include_http_headers] if args.key?(:include_http_headers)
  @include_named_cookies = args[:include_named_cookies] if args.key?(:include_named_cookies)
  @include_protocol = args[:include_protocol] if args.key?(:include_protocol)
  @include_query_string = args[:include_query_string] if args.key?(:include_query_string)
  @query_string_blacklist = args[:query_string_blacklist] if args.key?(:query_string_blacklist)
  @query_string_whitelist = args[:query_string_whitelist] if args.key?(:query_string_whitelist)
end