Class: Google::Apis::ComputeBeta::CalendarModeRecommendation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A single recommendation to create requested resources. Contains detailed recommendations for every future resources specification specified in CalendarModeAdviceRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeRecommendation

Returns a new instance of CalendarModeRecommendation.



7998
7999
8000
# File 'lib/google/apis/compute_beta/classes.rb', line 7998

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendations_per_specHash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendation>

Recommendations for every future resource specification passed in CalendarModeAdviceRequest. Keys of the map correspond to keys specified in the request. Corresponds to the JSON property recommendationsPerSpec



7996
7997
7998
# File 'lib/google/apis/compute_beta/classes.rb', line 7996

def recommendations_per_spec
  @recommendations_per_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8003
8004
8005
# File 'lib/google/apis/compute_beta/classes.rb', line 8003

def update!(**args)
  @recommendations_per_spec = args[:recommendations_per_spec] if args.key?(:recommendations_per_spec)
end