Class: Google::Apis::ComputeBeta::CapacityHistoryRequestLocationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityHistoryRequestLocationPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Location policy for this request.
Instance Attribute Summary collapse
-
#location ⇒ String
The region or zone to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequestLocationPolicy
constructor
A new instance of CapacityHistoryRequestLocationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequestLocationPolicy
Returns a new instance of CapacityHistoryRequestLocationPolicy.
8345 8346 8347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
The region or zone to get capacity history for. It can be a partial or full URL. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone
This field is optional.
Corresponds to the JSON property
location
8343 8344 8345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8343 def location @location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8350 8351 8352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8350 def update!(**args) @location = args[:location] if args.key?(:location) end |