Class: Google::Apis::ComputeBeta::CapacityHistoryResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains the capacity history.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityHistoryResponse

Returns a new instance of CapacityHistoryResponse.



8452
8453
8454
# File 'lib/google/apis/compute_beta/classes.rb', line 8452

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationString

Output only. The location (region or zone) for which the capacity history is returned. It is returned as a URL - For example,https://www.googleapis.com/compute/v1/ projects/project/zones/zone. Corresponds to the JSON property location

Returns:

  • (String)


8435
8436
8437
# File 'lib/google/apis/compute_beta/classes.rb', line 8435

def location
  @location
end

#machine_typeString

The machine type for which the capacity history is returned. Corresponds to the JSON property machineType

Returns:

  • (String)


8440
8441
8442
# File 'lib/google/apis/compute_beta/classes.rb', line 8440

def machine_type
  @machine_type
end

#preemption_historyArray<Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord>

The preemption history for the requested machine type and location. Corresponds to the JSON property preemptionHistory



8445
8446
8447
# File 'lib/google/apis/compute_beta/classes.rb', line 8445

def preemption_history
  @preemption_history
end

#price_historyArray<Google::Apis::ComputeBeta::CapacityHistoryResponsePriceRecord>

The price history for the requested machine type and location. Corresponds to the JSON property priceHistory



8450
8451
8452
# File 'lib/google/apis/compute_beta/classes.rb', line 8450

def price_history
  @price_history
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8457
8458
8459
8460
8461
8462
# File 'lib/google/apis/compute_beta/classes.rb', line 8457

def update!(**args)
  @location = args[:location] if args.key?(:location)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @preemption_history = args[:preemption_history] if args.key?(:preemption_history)
  @price_history = args[:price_history] if args.key?(:price_history)
end