Class: Google::Apis::ComputeBeta::ConfidentialInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ConfidentialInstanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A set of Confidential Instance options.
Instance Attribute Summary collapse
-
#confidential_instance_type ⇒ String
Defines the type of technology used by the confidential instance.
-
#enable_confidential_compute ⇒ Boolean
(also: #enable_confidential_compute?)
Defines whether the instance should have confidential compute enabled.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfidentialInstanceConfig
constructor
A new instance of ConfidentialInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfidentialInstanceConfig
Returns a new instance of ConfidentialInstanceConfig.
9772 9773 9774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#confidential_instance_type ⇒ String
Defines the type of technology used by the confidential instance.
Corresponds to the JSON property confidentialInstanceType
9764 9765 9766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9764 def confidential_instance_type @confidential_instance_type end |
#enable_confidential_compute ⇒ Boolean Also known as: enable_confidential_compute?
Defines whether the instance should have confidential compute enabled.
Corresponds to the JSON property enableConfidentialCompute
9769 9770 9771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9769 def enable_confidential_compute @enable_confidential_compute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9777 9778 9779 9780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9777 def update!(**args) @confidential_instance_type = args[:confidential_instance_type] if args.key?(:confidential_instance_type) @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute) end |