Class: Google::Apis::ComputeBeta::CrossSiteNetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A resource that represents a cross-site network. You can use cross-site networks to connect your on-premises networks to each other through Interconnect connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetwork

Returns a new instance of CrossSiteNetwork.



8957
8958
8959
# File 'lib/google/apis/compute_beta/classes.rb', line 8957

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


8921
8922
8923
# File 'lib/google/apis/compute_beta/classes.rb', line 8921

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the cross-site network. Corresponds to the JSON property description

Returns:

  • (String)


8926
8927
8928
# File 'lib/google/apis/compute_beta/classes.rb', line 8926

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


8933
8934
8935
# File 'lib/google/apis/compute_beta/classes.rb', line 8933

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


8939
8940
8941
# File 'lib/google/apis/compute_beta/classes.rb', line 8939

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


8950
8951
8952
# File 'lib/google/apis/compute_beta/classes.rb', line 8950

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8955
8956
8957
# File 'lib/google/apis/compute_beta/classes.rb', line 8955

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8962
8963
8964
8965
8966
8967
8968
8969
# File 'lib/google/apis/compute_beta/classes.rb', line 8962

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
end