Class: Google::Apis::ComputeBeta::CustomErrorResponsePolicyCustomErrorResponseRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies the mapping between the response code that will be returned along with the custom error content and the response code returned by the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomErrorResponsePolicyCustomErrorResponseRule

Returns a new instance of CustomErrorResponsePolicyCustomErrorResponseRule.



10154
10155
10156
# File 'lib/google/apis/compute_beta/classes.rb', line 10154

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#match_response_codesArray<String>

Valid values include:

  • A number between 400 and 599: For example 401 or 503, in which case the load balancer applies the policy if the error code exactly matches this value.
  • 5xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 500 to 599.
  • 4xx: Load Balancer will apply the policy if the backend service responds with any response code in the range of 400 to 499. Values must be unique within matchResponseCodes and across allerrorResponseRules ofCustomErrorResponsePolicy. Corresponds to the JSON property matchResponseCodes

Returns:

  • (Array<String>)


10131
10132
10133
# File 'lib/google/apis/compute_beta/classes.rb', line 10131

def match_response_codes
  @match_response_codes
end

#override_response_codeFixnum

The HTTP status code returned with the response containing the custom error content. If overrideResponseCode is not supplied, the same response code returned by the original backend bucket or backend service is returned to the client. Corresponds to the JSON property overrideResponseCode

Returns:

  • (Fixnum)


10139
10140
10141
# File 'lib/google/apis/compute_beta/classes.rb', line 10139

def override_response_code
  @override_response_code
end

#pathString

The full path to a file within backendBucket . For example:/errors/ defaultError.html path must start with a leading slash. path cannot have trailing slashes. If the file is not available in backendBucket or the load balancer cannot reach the BackendBucket, a simpleNot Found Error is returned to the client. The value must be from 1 to 1024 characters Corresponds to the JSON property path

Returns:

  • (String)


10152
10153
10154
# File 'lib/google/apis/compute_beta/classes.rb', line 10152

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10159
10160
10161
10162
10163
# File 'lib/google/apis/compute_beta/classes.rb', line 10159

def update!(**args)
  @match_response_codes = args[:match_response_codes] if args.key?(:match_response_codes)
  @override_response_code = args[:override_response_code] if args.key?(:override_response_code)
  @path = args[:path] if args.key?(:path)
end