Class: Google::Apis::ComputeBeta::DeprecationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Deprecation status for a public resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeprecationStatus

Returns a new instance of DeprecationStatus.



10588
10589
10590
# File 'lib/google/apis/compute_beta/classes.rb', line 10588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deleted

Returns:

  • (String)


10546
10547
10548
# File 'lib/google/apis/compute_beta/classes.rb', line 10546

def deleted
  @deleted
end

#deprecatedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deprecated

Returns:

  • (String)


10554
10555
10556
# File 'lib/google/apis/compute_beta/classes.rb', line 10554

def deprecated
  @deprecated
end

#obsoleteString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property obsolete

Returns:

  • (String)


10562
10563
10564
# File 'lib/google/apis/compute_beta/classes.rb', line 10562

def obsolete
  @obsolete
end

#replacementString

The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource. Corresponds to the JSON property replacement

Returns:

  • (String)


10569
10570
10571
# File 'lib/google/apis/compute_beta/classes.rb', line 10569

def replacement
  @replacement
end

#stateString

The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Corresponds to the JSON property state

Returns:

  • (String)


10581
10582
10583
# File 'lib/google/apis/compute_beta/classes.rb', line 10581

def state
  @state
end

#state_overrideGoogle::Apis::ComputeBeta::RolloutPolicy

A rollout policy configuration. Corresponds to the JSON property stateOverride



10586
10587
10588
# File 'lib/google/apis/compute_beta/classes.rb', line 10586

def state_override
  @state_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10593
10594
10595
10596
10597
10598
10599
10600
# File 'lib/google/apis/compute_beta/classes.rb', line 10593

def update!(**args)
  @deleted = args[:deleted] if args.key?(:deleted)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @obsolete = args[:obsolete] if args.key?(:obsolete)
  @replacement = args[:replacement] if args.key?(:replacement)
  @state = args[:state] if args.key?(:state)
  @state_override = args[:state_override] if args.key?(:state_override)
end