Class: Google::Apis::ComputeBeta::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



11520
11521
11522
# File 'lib/google/apis/compute_beta/classes.rb', line 11520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11487
11488
11489
# File 'lib/google/apis/compute_beta/classes.rb', line 11487

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Disk>

A list of Disk resources. Corresponds to the JSON property items



11492
11493
11494
# File 'lib/google/apis/compute_beta/classes.rb', line 11492

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


11498
11499
11500
# File 'lib/google/apis/compute_beta/classes.rb', line 11498

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11508
11509
11510
# File 'lib/google/apis/compute_beta/classes.rb', line 11508

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11513
11514
11515
# File 'lib/google/apis/compute_beta/classes.rb', line 11513

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11518
11519
11520
# File 'lib/google/apis/compute_beta/classes.rb', line 11518

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11525
11526
11527
11528
11529
11530
11531
11532
# File 'lib/google/apis/compute_beta/classes.rb', line 11525

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end