Class: Google::Apis::ComputeBeta::DiskMoveRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskMoveRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#destination_zone ⇒ String
The URL of the destination zone to move the disk.
-
#target_disk ⇒ String
The URL of the target disk to move.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskMoveRequest
constructor
A new instance of DiskMoveRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskMoveRequest
Returns a new instance of DiskMoveRequest.
10438 10439 10440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#destination_zone ⇒ String
The URL of the destination zone to move the disk. This can be a full or partial URL. For example, the following are all valid URLs to a zone:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone
- projects/project/zones/zone
- zones/zone
Corresponds to the JSON property
destinationZone
10425 10426 10427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10425 def destination_zone @destination_zone end |
#target_disk ⇒ String
The URL of the target disk to move. This can be a full or partial URL. For example, the following are all valid URLs to a disk:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
Corresponds to the JSON property
targetDisk
10436 10437 10438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10436 def target_disk @target_disk end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10443 10444 10445 10446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10443 def update!(**args) @destination_zone = args[:destination_zone] if args.key?(:destination_zone) @target_disk = args[:target_disk] if args.key?(:target_disk) end |