Class: Google::Apis::ComputeBeta::DiskSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskSettings

Returns a new instance of DiskSettings.



10541
10542
10543
# File 'lib/google/apis/compute_beta/classes.rb', line 10541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_locationGoogle::Apis::ComputeBeta::DiskSettingsAccessLocation

AccessLocation is only used for regional snapshot. It contains which regions are allowed to create a regional snapshot from disks located in the given region/zone. It includes key-value pairs designed to store the following structure. The keys should match their corresponding values, which must be provided: access_location: locations us-central1 region: "us-central1" , asia-west2 region: "asia-west2" Corresponds to the JSON property accessLocation



10539
10540
10541
# File 'lib/google/apis/compute_beta/classes.rb', line 10539

def access_location
  @access_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10546
10547
10548
# File 'lib/google/apis/compute_beta/classes.rb', line 10546

def update!(**args)
  @access_location = args[:access_location] if args.key?(:access_location)
end