Class: Google::Apis::ComputeBeta::DiskSettingsAccessLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskSettingsAccessLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
AccessLocation is only used for regional snapshot. It contains which
regions are allowed to create a regional snapshot from disks located in the
given region/zone.
It includes key-value pairs designed to store the following structure. The
keys should match their corresponding values, which must be provided:
access_location:
locations
us-central1
region: "us-central1"
,
asia-west2
region: "asia-west2"
Instance Attribute Summary collapse
-
#locations ⇒ Hash<String,Google::Apis::ComputeBeta::DiskSettingsAccessLocationAccessLocationPreference>
List of regions that can create a regional snapshot from the current region Corresponds to the JSON property
locations. -
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskSettingsAccessLocation
constructor
A new instance of DiskSettingsAccessLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskSettingsAccessLocation
Returns a new instance of DiskSettingsAccessLocation.
10580 10581 10582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10580 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Hash<String,Google::Apis::ComputeBeta::DiskSettingsAccessLocationAccessLocationPreference>
List of regions that can create a regional
snapshot from the current region
Corresponds to the JSON property locations
10573 10574 10575 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10573 def locations @locations end |
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Corresponds to the JSON property policy
10578 10579 10580 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10578 def policy @policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10585 10586 10587 10588 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10585 def update!(**args) @locations = args[:locations] if args.key?(:locations) @policy = args[:policy] if args.key?(:policy) end |