Class: Google::Apis::ComputeBeta::ExchangedPeeringRoute
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ExchangedPeeringRoute
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#dest_range ⇒ String
The destination range of the route.
-
#imported ⇒ Boolean
(also: #imported?)
True if the peering route has been imported from a peer.
-
#next_hop_region ⇒ String
The region of peering route next hop, only applies to dynamic routes.
-
#priority ⇒ Fixnum
The priority of the peering route.
-
#type ⇒ String
The type of the peering route.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangedPeeringRoute
constructor
A new instance of ExchangedPeeringRoute.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangedPeeringRoute
Returns a new instance of ExchangedPeeringRoute.
12700 12701 12702 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_range ⇒ String
The destination range of the route.
Corresponds to the JSON property destRange
12673 12674 12675 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12673 def dest_range @dest_range end |
#imported ⇒ Boolean Also known as: imported?
True if the peering route has been imported from a peer. The actual import
happens if the field networkPeering.importCustomRoutes is true
for this network, and networkPeering.exportCustomRoutes is
true for the peer network, and the import does not result in a route
conflict.
Corresponds to the JSON property imported
12682 12683 12684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12682 def imported @imported end |
#next_hop_region ⇒ String
The region of peering route next hop, only applies to dynamic routes.
Corresponds to the JSON property nextHopRegion
12688 12689 12690 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12688 def next_hop_region @next_hop_region end |
#priority ⇒ Fixnum
The priority of the peering route.
Corresponds to the JSON property priority
12693 12694 12695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12693 def priority @priority end |
#type ⇒ String
The type of the peering route.
Corresponds to the JSON property type
12698 12699 12700 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12698 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12705 12706 12707 12708 12709 12710 12711 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12705 def update!(**args) @dest_range = args[:dest_range] if args.key?(:dest_range) @imported = args[:imported] if args.key?(:imported) @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region) @priority = args[:priority] if args.key?(:priority) @type = args[:type] if args.key?(:type) end |