Class: Google::Apis::ComputeBeta::ExternalVpnGatewayInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ExternalVpnGatewayInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The interface for the external VPN gateway.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
The numeric ID of this interface.
-
#ip_address ⇒ String
IP address of the interface in the external VPN gateway.
-
#ipv6_address ⇒ String
IPv6 address of the interface in the external VPN gateway.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayInterface
constructor
A new instance of ExternalVpnGatewayInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayInterface
Returns a new instance of ExternalVpnGatewayInterface.
11833 11834 11835 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
The numeric ID of this interface. The allowed input values for this id for different redundancy types of external VPN gateway:
- SINGLE_IP_INTERNALLY_REDUNDANT - 0
- TWO_IPS_REDUNDANCY - 0, 1
- FOUR_IPS_REDUNDANCY - 0, 1, 2, 3
Corresponds to the JSON property
id
11813 11814 11815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11813 def id @id end |
#ip_address ⇒ String
IP address of the interface in the external VPN gateway. Only IPv4 is
supported. This IP address can be either from your on-premise gateway or
another Cloud provider's VPN gateway, it cannot be an IP address from
Google Compute Engine.
Corresponds to the JSON property ipAddress
11821 11822 11823 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11821 def ip_address @ip_address end |
#ipv6_address ⇒ String
IPv6 address of the interface in the external VPN gateway. This IPv6
address can be either from your on-premise gateway or another Cloud
provider's VPN gateway, it cannot be an IP address from Google Compute
Engine. Must specify an IPv6 address (not IPV4-mapped) using any format
described in RFC 4291 (e.g. 2001:db8:0:0:2d9:51:0:0). The output format
is RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
Corresponds to the JSON property ipv6Address
11831 11832 11833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11831 def ipv6_address @ipv6_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11838 11839 11840 11841 11842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11838 def update!(**args) @id = args[:id] if args.key?(:id) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) end |