Class: Google::Apis::ComputeBeta::FirewallPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPoliciesScopedList

Returns a new instance of FirewallPoliciesScopedList.



13785
13786
13787
# File 'lib/google/apis/compute_beta/classes.rb', line 13785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policiesArray<Google::Apis::ComputeBeta::FirewallPolicy>

A list of firewall policies contained in this scope. Corresponds to the JSON property firewallPolicies



13777
13778
13779
# File 'lib/google/apis/compute_beta/classes.rb', line 13777

def firewall_policies
  @firewall_policies
end

#warningGoogle::Apis::ComputeBeta::FirewallPoliciesScopedList::Warning

Informational warning which replaces the list of firewall policies when the list is empty. Corresponds to the JSON property warning



13783
13784
13785
# File 'lib/google/apis/compute_beta/classes.rb', line 13783

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13790
13791
13792
13793
# File 'lib/google/apis/compute_beta/classes.rb', line 13790

def update!(**args)
  @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies)
  @warning = args[:warning] if args.key?(:warning)
end