Class: Google::Apis::ComputeBeta::FirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Firewall Policy resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicy

Returns a new instance of FirewallPolicy.



14014
14015
14016
# File 'lib/google/apis/compute_beta/classes.rb', line 14014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::ComputeBeta::FirewallPolicyAssociation>

A list of associations that belong to this firewall policy. Corresponds to the JSON property associations



13874
13875
13876
# File 'lib/google/apis/compute_beta/classes.rb', line 13874

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


13880
13881
13882
# File 'lib/google/apis/compute_beta/classes.rb', line 13880

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


13886
13887
13888
# File 'lib/google/apis/compute_beta/classes.rb', line 13886

def description
  @description
end

#display_nameString

Deprecated, please use short name instead. User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property displayName

Returns:

  • (String)


13901
13902
13903
# File 'lib/google/apis/compute_beta/classes.rb', line 13901

def display_name
  @display_name
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make get() request to the firewall policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


13914
13915
13916
# File 'lib/google/apis/compute_beta/classes.rb', line 13914

def fingerprint
  @fingerprint
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


13920
13921
13922
# File 'lib/google/apis/compute_beta/classes.rb', line 13920

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# firewallPolicyfor firewall policies Corresponds to the JSON property kind

Returns:

  • (String)


13926
13927
13928
# File 'lib/google/apis/compute_beta/classes.rb', line 13926

def kind
  @kind
end

#nameString

Name of the resource. For Organization Firewall Policies it's a [Output Only] numeric ID allocated by Google Cloud which uniquely identifies the Organization Firewall Policy. Corresponds to the JSON property name

Returns:

  • (String)


13933
13934
13935
# File 'lib/google/apis/compute_beta/classes.rb', line 13933

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeBeta::FirewallPolicyRule>

A list of packet mirroring rules that belong to this policy. Corresponds to the JSON property packetMirroringRules



13938
13939
13940
# File 'lib/google/apis/compute_beta/classes.rb', line 13938

def packet_mirroring_rules
  @packet_mirroring_rules
end

#parentString

Output only. [Output Only] The parent of the firewall policy. This field is not applicable to network firewall policies. Corresponds to the JSON property parent

Returns:

  • (String)


13944
13945
13946
# File 'lib/google/apis/compute_beta/classes.rb', line 13944

def parent
  @parent
end

#policy_sourceString

Indicates the source of this Firewall Policy. This field is optional on creation and defaults to USER_DEFINED. The USER_DEFINED value indicates a regular firewall policy. The SYSTEM value indicates a system-level policy managed by an internal service like GKE. This SYSTEM value is reserved for internal services and cannot be set by users during policy creation. Policies with a SYSTEM source cannot be modified or deleted by users. Corresponds to the JSON property policySource

Returns:

  • (String)


13956
13957
13958
# File 'lib/google/apis/compute_beta/classes.rb', line 13956

def policy_source
  @policy_source
end

#policy_typeString

The type of the firewall policy. This field can be one of VPC_POLICY, RDMA_ROCE_POLICY or ULL_POLICY. Note: if not specified then VPC_POLICY will be used. Corresponds to the JSON property policyType

Returns:

  • (String)


13963
13964
13965
# File 'lib/google/apis/compute_beta/classes.rb', line 13963

def policy_type
  @policy_type
end

#regionString

Output only. [Output Only] URL of the region where the regional firewall policy resides. This field is not applicable to global firewall policies. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


13972
13973
13974
# File 'lib/google/apis/compute_beta/classes.rb', line 13972

def region
  @region
end

#rule_tuple_countFixnum

Output only. [Output Only] Total count of all firewall policy rule tuples. A firewall policy can not exceed a set number of tuples. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


13979
13980
13981
# File 'lib/google/apis/compute_beta/classes.rb', line 13979

def rule_tuple_count
  @rule_tuple_count
end

#rulesArray<Google::Apis::ComputeBeta::FirewallPolicyRule>

A list of rules that belong to this policy. There must always be a default rule (rule with priority 2147483647 and match "*"). If no rules are provided when creating a firewall policy, a default rule with action "allow" will be added. Corresponds to the JSON property rules



13987
13988
13989
# File 'lib/google/apis/compute_beta/classes.rb', line 13987

def rules
  @rules
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13992
13993
13994
# File 'lib/google/apis/compute_beta/classes.rb', line 13992

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


13998
13999
14000
# File 'lib/google/apis/compute_beta/classes.rb', line 13998

def self_link_with_id
  @self_link_with_id
end

#short_nameString

User-provided name of the Organization firewall policy. The name should be unique in the organization in which the firewall policy is created. This field is not applicable to network firewall policies. This name must be set on creation and cannot be changed. The name must be 1-63 characters long, and comply with RFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property shortName

Returns:

  • (String)


14012
14013
14014
# File 'lib/google/apis/compute_beta/classes.rb', line 14012

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14019
14020
14021
14022
14023
14024
14025
14026
14027
14028
14029
14030
14031
14032
14033
14034
14035
14036
14037
14038
# File 'lib/google/apis/compute_beta/classes.rb', line 14019

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @parent = args[:parent] if args.key?(:parent)
  @policy_source = args[:policy_source] if args.key?(:policy_source)
  @policy_type = args[:policy_type] if args.key?(:policy_type)
  @region = args[:region] if args.key?(:region)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @short_name = args[:short_name] if args.key?(:short_name)
end