Class: Google::Apis::ComputeBeta::FixedOrPercent

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Encapsulates numeric value that can be either absolute or relative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FixedOrPercent

Returns a new instance of FixedOrPercent.



14559
14560
14561
# File 'lib/google/apis/compute_beta/classes.rb', line 14559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#calculatedFixnum

Output only. Absolute value of VM instances calculated based on the specific mode.

  • If the value is fixed, then the calculated value is equal to the fixed value.
  • If the value is a percent, then the calculated value is percent/100 * targetSize. For example, the calculated value of a 80% of a managed instance group with 150 instances would be (80/100 * 150) = 120 VM instances. If there is a remainder, the number is rounded. Corresponds to the JSON property calculated

Returns:

  • (Fixnum)


14546
14547
14548
# File 'lib/google/apis/compute_beta/classes.rb', line 14546

def calculated
  @calculated
end

#fixedFixnum

Specifies a fixed number of VM instances. This must be a positive integer. Corresponds to the JSON property fixed

Returns:

  • (Fixnum)


14551
14552
14553
# File 'lib/google/apis/compute_beta/classes.rb', line 14551

def fixed
  @fixed
end

#percentFixnum

Specifies a percentage of instances between 0 to 100%, inclusive. For example, specify 80 for 80%. Corresponds to the JSON property percent

Returns:

  • (Fixnum)


14557
14558
14559
# File 'lib/google/apis/compute_beta/classes.rb', line 14557

def percent
  @percent
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14564
14565
14566
14567
14568
# File 'lib/google/apis/compute_beta/classes.rb', line 14564

def update!(**args)
  @calculated = args[:calculated] if args.key?(:calculated)
  @fixed = args[:fixed] if args.key?(:fixed)
  @percent = args[:percent] if args.key?(:percent)
end