Class: Google::Apis::ComputeBeta::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FlexibleTimeRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
-
#end_time_not_earlier_than ⇒ String
Corresponds to the JSON property
endTimeNotEarlierThan. -
#end_time_not_later_than ⇒ String
Corresponds to the JSON property
endTimeNotLaterThan. -
#max_duration ⇒ String
Corresponds to the JSON property
maxDuration. -
#min_duration ⇒ String
Corresponds to the JSON property
minDuration. -
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property
startTimeNotEarlierThan. -
#start_time_not_later_than ⇒ String
Corresponds to the JSON property
startTimeNotLaterThan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleTimeRange
constructor
A new instance of FlexibleTimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleTimeRange
Returns a new instance of FlexibleTimeRange.
14683 14684 14685 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14683 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_not_earlier_than ⇒ String
Corresponds to the JSON property endTimeNotEarlierThan
14656 14657 14658 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14656 def end_time_not_earlier_than @end_time_not_earlier_than end |
#end_time_not_later_than ⇒ String
Corresponds to the JSON property endTimeNotLaterThan
14661 14662 14663 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14661 def end_time_not_later_than @end_time_not_later_than end |
#max_duration ⇒ String
Corresponds to the JSON property maxDuration
14666 14667 14668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14666 def max_duration @max_duration end |
#min_duration ⇒ String
Corresponds to the JSON property minDuration
14671 14672 14673 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14671 def min_duration @min_duration end |
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property startTimeNotEarlierThan
14676 14677 14678 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14676 def start_time_not_earlier_than @start_time_not_earlier_than end |
#start_time_not_later_than ⇒ String
Corresponds to the JSON property startTimeNotLaterThan
14681 14682 14683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14681 def start_time_not_later_than @start_time_not_later_than end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14688 14689 14690 14691 14692 14693 14694 14695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14688 def update!(**args) @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than) @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than) @max_duration = args[:max_duration] if args.key?(:max_duration) @min_duration = args[:min_duration] if args.key?(:min_duration) @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than) @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than) end |