Class: Google::Apis::ComputeBeta::ForwardingRuleList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of ForwardingRule resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ForwardingRule>
A list of ForwardingRule resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleList
constructor
A new instance of ForwardingRuleList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleList
Returns a new instance of ForwardingRuleList.
15560 15561 15562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15528 15529 15530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15528 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ForwardingRule>
A list of ForwardingRule resources.
Corresponds to the JSON property items
15533 15534 15535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15533 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
15538 15539 15540 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15538 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15548 15549 15550 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15548 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15553 15554 15555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15553 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15558 15559 15560 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15558 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15565 15566 15567 15568 15569 15570 15571 15572 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15565 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |