Class: Google::Apis::ComputeBeta::FutureReservationSpecificSkuProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationSpecificSkuProperties

Returns a new instance of FutureReservationSpecificSkuProperties.



15794
15795
15796
# File 'lib/google/apis/compute_beta/classes.rb', line 15794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_propertiesGoogle::Apis::ComputeBeta::AllocationSpecificSkuAllocationReservedInstanceProperties

Properties of the SKU instances being reserved. Next ID: 10 Corresponds to the JSON property instanceProperties



15780
15781
15782
# File 'lib/google/apis/compute_beta/classes.rb', line 15780

def instance_properties
  @instance_properties
end

#source_instance_templateString

The instance template that will be used to populate the ReservedInstanceProperties of the future reservation Corresponds to the JSON property sourceInstanceTemplate

Returns:

  • (String)


15786
15787
15788
# File 'lib/google/apis/compute_beta/classes.rb', line 15786

def source_instance_template
  @source_instance_template
end

#total_countFixnum

Total number of instances for which capacity assurance is requested at a future time period. Corresponds to the JSON property totalCount

Returns:

  • (Fixnum)


15792
15793
15794
# File 'lib/google/apis/compute_beta/classes.rb', line 15792

def total_count
  @total_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15799
15800
15801
15802
15803
# File 'lib/google/apis/compute_beta/classes.rb', line 15799

def update!(**args)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template)
  @total_count = args[:total_count] if args.key?(:total_count)
end