Class: Google::Apis::ComputeBeta::FutureReservationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output only] Represents status related to the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatus

Returns a new instance of FutureReservationStatus.



16203
16204
16205
# File 'lib/google/apis/compute_beta/classes.rb', line 16203

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amendment_statusString

Output only. [Output Only] The current status of the requested amendment. Corresponds to the JSON property amendmentStatus

Returns:

  • (String)


16146
16147
16148
# File 'lib/google/apis/compute_beta/classes.rb', line 16146

def amendment_status
  @amendment_status
end

#auto_created_reservationsArray<String>

Output only. Fully qualified urls of the automatically created reservations at start_time. Corresponds to the JSON property autoCreatedReservations

Returns:

  • (Array<String>)


16152
16153
16154
# File 'lib/google/apis/compute_beta/classes.rb', line 16152

def auto_created_reservations
  @auto_created_reservations
end

#exapool_provisioned_capacity_gbGoogle::Apis::ComputeBeta::StoragePoolExapoolProvisionedCapacityGb

Exapool provisioned capacities for each SKU type Corresponds to the JSON property exapoolProvisionedCapacityGb



16157
16158
16159
# File 'lib/google/apis/compute_beta/classes.rb', line 16157

def exapool_provisioned_capacity_gb
  @exapool_provisioned_capacity_gb
end

#existing_matching_usage_infoGoogle::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



16163
16164
16165
# File 'lib/google/apis/compute_beta/classes.rb', line 16163

def existing_matching_usage_info
  @existing_matching_usage_info
end

#fulfilled_countFixnum

Output only. This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations. Corresponds to the JSON property fulfilledCount

Returns:

  • (Fixnum)


16171
16172
16173
# File 'lib/google/apis/compute_beta/classes.rb', line 16171

def fulfilled_count
  @fulfilled_count
end

#last_known_good_stateGoogle::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState

The state that the future reservation will be reverted to should the amendment be declined. Corresponds to the JSON property lastKnownGoodState



16177
16178
16179
# File 'lib/google/apis/compute_beta/classes.rb', line 16177

def last_known_good_state
  @last_known_good_state
end

#lock_timeString

Output only. Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time. Corresponds to the JSON property lockTime

Returns:

  • (String)


16186
16187
16188
# File 'lib/google/apis/compute_beta/classes.rb', line 16186

def lock_time
  @lock_time
end

#procurement_statusString

Output only. Current state of this Future Reservation Corresponds to the JSON property procurementStatus

Returns:

  • (String)


16191
16192
16193
# File 'lib/google/apis/compute_beta/classes.rb', line 16191

def procurement_status
  @procurement_status
end

#specific_sku_propertiesGoogle::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties

Properties to be set for the Future Reservation. Corresponds to the JSON property specificSkuProperties



16196
16197
16198
# File 'lib/google/apis/compute_beta/classes.rb', line 16196

def specific_sku_properties
  @specific_sku_properties
end

#storage_pool_provisioned_capacityGoogle::Apis::ComputeBeta::FutureReservationStoragePoolProvisionedCapacity

Storage pool provisioned capacities for each SKU type. Corresponds to the JSON property storagePoolProvisionedCapacity



16201
16202
16203
# File 'lib/google/apis/compute_beta/classes.rb', line 16201

def storage_pool_provisioned_capacity
  @storage_pool_provisioned_capacity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16208
16209
16210
16211
16212
16213
16214
16215
16216
16217
16218
16219
# File 'lib/google/apis/compute_beta/classes.rb', line 16208

def update!(**args)
  @amendment_status = args[:amendment_status] if args.key?(:amendment_status)
  @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations)
  @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count)
  @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @storage_pool_provisioned_capacity = args[:storage_pool_provisioned_capacity] if args.key?(:storage_pool_provisioned_capacity)
end