Class: Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Represents the existing matching usage for the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusExistingMatchingUsageInfo

Returns a new instance of FutureReservationStatusExistingMatchingUsageInfo.



16238
16239
16240
# File 'lib/google/apis/compute_beta/classes.rb', line 16238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. Count to represent min(FR total_count, matching_reserved_capacity+matching_unreserved_instances) Corresponds to the JSON property count

Returns:

  • (Fixnum)


16231
16232
16233
# File 'lib/google/apis/compute_beta/classes.rb', line 16231

def count
  @count
end

#timestampString

Output only. Timestamp when the matching usage was calculated Corresponds to the JSON property timestamp

Returns:

  • (String)


16236
16237
16238
# File 'lib/google/apis/compute_beta/classes.rb', line 16236

def timestamp
  @timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16243
16244
16245
16246
# File 'lib/google/apis/compute_beta/classes.rb', line 16243

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @timestamp = args[:timestamp] if args.key?(:timestamp)
end