Class: Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The properties of the last known good state for the Future Reservation.
Instance Attribute Summary collapse
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationSpecificSkuProperties
Output only.
-
#time_window ⇒ Google::Apis::ComputeBeta::FutureReservationTimeWindow
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
constructor
A new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.
16181 16182 16183 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16181 def initialize(**args) update!(**args) end |
Instance Attribute Details
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
16168 16169 16170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16168 def share_settings @share_settings end |
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationSpecificSkuProperties
Output only. [Output Only] The previous instance related properties of the
Future Reservation.
Corresponds to the JSON property specificSkuProperties
16174 16175 16176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16174 def specific_sku_properties @specific_sku_properties end |
#time_window ⇒ Google::Apis::ComputeBeta::FutureReservationTimeWindow
Output only. [Output Only] The previous time window of the Future Reservation.
Corresponds to the JSON property timeWindow
16179 16180 16181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16179 def time_window @time_window end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16186 16187 16188 16189 16190 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16186 def update!(**args) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @time_window = args[:time_window] if args.key?(:time_window) end |