Class: Google::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Properties to be set for the Future Reservation.
Instance Attribute Summary collapse
-
#source_instance_template_id ⇒ String
ID of the instance template used to populate the Future Reservation properties.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusSpecificSkuProperties
constructor
A new instance of FutureReservationStatusSpecificSkuProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusSpecificSkuProperties
Returns a new instance of FutureReservationStatusSpecificSkuProperties.
14862 14863 14864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_instance_template_id ⇒ String
ID of the instance template used to populate the Future Reservation
properties.
Corresponds to the JSON property sourceInstanceTemplateId
14860 14861 14862 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14860 def source_instance_template_id @source_instance_template_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14867 14868 14869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14867 def update!(**args) @source_instance_template_id = args[:source_instance_template_id] if args.key?(:source_instance_template_id) end |