Class: Google::Apis::ComputeBeta::FutureReservationStoragePoolProvisionedCapacity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Storage pool provisioned capacities for each SKU type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStoragePoolProvisionedCapacity

Returns a new instance of FutureReservationStoragePoolProvisionedCapacity.



16409
16410
16411
# File 'lib/google/apis/compute_beta/classes.rb', line 16409

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#pool_provisioned_capacity_gbFixnum

Size of the storage pool in GiB. Corresponds to the JSON property poolProvisionedCapacityGb

Returns:

  • (Fixnum)


16395
16396
16397
# File 'lib/google/apis/compute_beta/classes.rb', line 16395

def pool_provisioned_capacity_gb
  @pool_provisioned_capacity_gb
end

#pool_provisioned_iopsFixnum

Provisioned IOPS of the storage pool. Only relevant if the storage pool type is hyperdisk-balanced. Corresponds to the JSON property poolProvisionedIops

Returns:

  • (Fixnum)


16401
16402
16403
# File 'lib/google/apis/compute_beta/classes.rb', line 16401

def pool_provisioned_iops
  @pool_provisioned_iops
end

#pool_provisioned_throughputFixnum

Provisioned throughput of the storage pool in MiB/s. Only relevant if the storage pool type is hyperdisk-balanced or hyperdisk-throughput. Corresponds to the JSON property poolProvisionedThroughput

Returns:

  • (Fixnum)


16407
16408
16409
# File 'lib/google/apis/compute_beta/classes.rb', line 16407

def pool_provisioned_throughput
  @pool_provisioned_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16414
16415
16416
16417
16418
# File 'lib/google/apis/compute_beta/classes.rb', line 16414

def update!(**args)
  @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb)
  @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops)
  @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput)
end