Class: Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



16507
16508
16509
# File 'lib/google/apis/compute_beta/classes.rb', line 16507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16463
16464
16465
# File 'lib/google/apis/compute_beta/classes.rb', line 16463

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16468
16469
16470
# File 'lib/google/apis/compute_beta/classes.rb', line 16468

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



16473
16474
16475
# File 'lib/google/apis/compute_beta/classes.rb', line 16473

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


16480
16481
16482
# File 'lib/google/apis/compute_beta/classes.rb', line 16480

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16490
16491
16492
# File 'lib/google/apis/compute_beta/classes.rb', line 16490

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16495
16496
16497
# File 'lib/google/apis/compute_beta/classes.rb', line 16495

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16500
16501
16502
# File 'lib/google/apis/compute_beta/classes.rb', line 16500

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16505
16506
16507
# File 'lib/google/apis/compute_beta/classes.rb', line 16505

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16512
16513
16514
16515
16516
16517
16518
16519
16520
16521
# File 'lib/google/apis/compute_beta/classes.rb', line 16512

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end