Class: Google::Apis::ComputeBeta::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
16461 16462 16463 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16461 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
16429 16430 16431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16429 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
16437 16438 16439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16437 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
16444 16445 16446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16444 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
16449 16450 16451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16449 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
16454 16455 16456 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16454 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
16459 16460 16461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16459 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16466 16467 16468 16469 16470 16471 16472 16473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16466 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |