Class: Google::Apis::ComputeBeta::FutureResourcesSpec

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesSpec

Returns a new instance of FutureResourcesSpec.



16942
16943
16944
# File 'lib/google/apis/compute_beta/classes.rb', line 16942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deployment_typeString

Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD). Defaults to DENSE. Corresponds to the JSON property deploymentType

Returns:

  • (String)


16923
16924
16925
# File 'lib/google/apis/compute_beta/classes.rb', line 16923

def deployment_type
  @deployment_type
end

#location_policyGoogle::Apis::ComputeBeta::FutureResourcesSpecLocationPolicy

Specification of locations to create resources in. Corresponds to the JSON property locationPolicy



16928
16929
16930
# File 'lib/google/apis/compute_beta/classes.rb', line 16928

def location_policy
  @location_policy
end

#target_resourcesGoogle::Apis::ComputeBeta::FutureResourcesSpecTargetResources

Specification of reserved resources. Corresponds to the JSON property targetResources



16933
16934
16935
# File 'lib/google/apis/compute_beta/classes.rb', line 16933

def target_resources
  @target_resources
end

#time_range_specGoogle::Apis::ComputeBeta::FlexibleTimeRange

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error. Corresponds to the JSON property timeRangeSpec



16940
16941
16942
# File 'lib/google/apis/compute_beta/classes.rb', line 16940

def time_range_spec
  @time_range_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16947
16948
16949
16950
16951
16952
# File 'lib/google/apis/compute_beta/classes.rb', line 16947

def update!(**args)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @location_policy = args[:location_policy] if args.key?(:location_policy)
  @target_resources = args[:target_resources] if args.key?(:target_resources)
  @time_range_spec = args[:time_range_spec] if args.key?(:time_range_spec)
end