Class: Google::Apis::ComputeBeta::GetVersionOperationMetadataSbomInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GetVersionOperationMetadataSbomInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other appropriate identifiers.
-
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate identifiers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
constructor
A new instance of GetVersionOperationMetadataSbomInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo
Returns a new instance of GetVersionOperationMetadataSbomInfo.
16866 16867 16868 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16866 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_component_versions ⇒ Hash<String,String>
A mapping of components to their currently-applied versions or other
appropriate identifiers.
Corresponds to the JSON property currentComponentVersions
16858 16859 16860 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16858 def current_component_versions @current_component_versions end |
#target_component_versions ⇒ Hash<String,String>
A mapping of components to their target versions or other appropriate
identifiers.
Corresponds to the JSON property targetComponentVersions
16864 16865 16866 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16864 def target_component_versions @target_component_versions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16871 16872 16873 16874 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16871 def update!(**args) @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions) @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions) end |