Class: Google::Apis::ComputeBeta::GlobalAddressesMoveRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GlobalAddressesMoveRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional destination address description if intended to be different from the source.
-
#destination_address ⇒ String
The URL of the destination address to move to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalAddressesMoveRequest
constructor
A new instance of GlobalAddressesMoveRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalAddressesMoveRequest
Returns a new instance of GlobalAddressesMoveRequest.
15715 15716 15717 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional destination address description if intended to be different
from the source.
Corresponds to the JSON property description
15701 15702 15703 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15701 def description @description end |
#destination_address ⇒ String
The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address:
- https://www.googleapis.com/compute/v1/projects/project/global/addresses/ address
- projects/project/global/addresses/address
Note that destination project must be different from the source project. So/
global/addresses/address is not valid partial url.
Corresponds to the JSON property
destinationAddress
15713 15714 15715 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15713 def destination_address @destination_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15720 15721 15722 15723 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15720 def update!(**args) @description = args[:description] if args.key?(:description) @destination_address = args[:destination_address] if args.key?(:destination_address) end |