Class: Google::Apis::ComputeBeta::GlobalOrganizationSetPolicyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GlobalOrganizationSetPolicyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#bindings ⇒ Array<Google::Apis::ComputeBeta::Binding>
Flatten Policy to create a backward compatible wire-format.
-
#etag ⇒ String
Flatten Policy to create a backward compatible wire-format.
-
#policy ⇒ Google::Apis::ComputeBeta::Policy
An Identity and Access Management (IAM) policy, which specifies access controls for Google Cloud resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalOrganizationSetPolicyRequest
constructor
A new instance of GlobalOrganizationSetPolicyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalOrganizationSetPolicyRequest
Returns a new instance of GlobalOrganizationSetPolicyRequest.
15850 15851 15852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15850 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bindings ⇒ Array<Google::Apis::ComputeBeta::Binding>
Flatten Policy to create a backward compatible wire-format.
Deprecated. Use 'policy' to specify bindings.
Corresponds to the JSON property bindings
15772 15773 15774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15772 def bindings @bindings end |
#etag ⇒ String
Flatten Policy to create a backward compatible wire-format.
Deprecated. Use 'policy' to specify the etag.
Corresponds to the JSON property etag
NOTE: Values are automatically base64 encoded/decoded in the client library.
15779 15780 15781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15779 def etag @etag end |
#policy ⇒ Google::Apis::ComputeBeta::Policy
An Identity and Access Management (IAM) policy, which specifies access
controls for Google Cloud resources.
A Policy is a collection of bindings. A binding binds one or more
members, or principals, to a single role. Principals can be user
accounts, service accounts, Google groups, and domains (such as G Suite). A
role is a named list of permissions; each role can be an IAM predefined
role or a user-created custom role.
For some types of Google Cloud resources, a binding can also specify a
condition, which is a logical expression that allows access to a resource
only if the expression evaluates to true. A condition can add constraints
based on attributes of the request, the resource, or both. To learn which
resources support conditions in their IAM policies, see the
IAM documentation.
JSON example:
`
"bindings": [
`
"role": "roles/resourcemanager.organizationAdmin",
"members": [
"user:mike@example.com",
"group:admins@example.com",
"domain:google.com",
"serviceAccount:my-project-id@appspot.gserviceaccount.com"
]
`,
`
"role": "roles/resourcemanager.organizationViewer",
"members": [
"user:eve@example.com"
],
"condition": `
"title": "expirable access",
"description": "Does not grant access after Sep 2020",
"expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')
",
`
`
],
"etag": "BwWWja0YfJA=",
"version": 3
`
YAML example:
bindings:
- members:
- user:mike@example.com
- group:admins@example.com
- domain:google.com
- serviceAccount:my-project-id@appspot.gserviceaccount.com
role: roles/resourcemanager.organizationAdmin
- members:
- user:eve@example.com
role: roles/resourcemanager.organizationViewer
condition:
title: expirable access
description: Does not grant access after Sep 2020
expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
etag: BwWWja0YfJA=
version: 3
For a description of IAM and its features, see the
IAM documentation.
Corresponds to the JSON property policy
15848 15849 15850 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15848 def policy @policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15855 15856 15857 15858 15859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15855 def update!(**args) @bindings = args[:bindings] if args.key?(:bindings) @etag = args[:etag] if args.key?(:etag) @policy = args[:policy] if args.key?(:policy) end |