Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



17820
17821
17822
# File 'lib/google/apis/compute_beta/classes.rb', line 17820

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


17778
17779
17780
# File 'lib/google/apis/compute_beta/classes.rb', line 17778

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17783
17784
17785
# File 'lib/google/apis/compute_beta/classes.rb', line 17783

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



17788
17789
17790
# File 'lib/google/apis/compute_beta/classes.rb', line 17788

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17793
17794
17795
# File 'lib/google/apis/compute_beta/classes.rb', line 17793

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17803
17804
17805
# File 'lib/google/apis/compute_beta/classes.rb', line 17803

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17808
17809
17810
# File 'lib/google/apis/compute_beta/classes.rb', line 17808

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17813
17814
17815
# File 'lib/google/apis/compute_beta/classes.rb', line 17813

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17818
17819
17820
# File 'lib/google/apis/compute_beta/classes.rb', line 17818

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17825
17826
17827
17828
17829
17830
17831
17832
17833
17834
# File 'lib/google/apis/compute_beta/classes.rb', line 17825

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end