Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadata.



18053
18054
18055
# File 'lib/google/apis/compute_beta/classes.rb', line 18053

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#location_rollout_statusHash<String,Google::Apis::ComputeBeta::GlobalVmExtensionPolicyRolloutOperationRolloutStatusRolloutMetadataLocationRolloutStatus>

Output only. [Output Only] The rollout status for each location. The list of the locations is the same as the list of locations in the rollout plan. Corresponds to the JSON property locationRolloutStatus



18033
18034
18035
# File 'lib/google/apis/compute_beta/classes.rb', line 18033

def location_rollout_status
  @location_rollout_status
end

#rolloutString

Output only. [Output Only] The name of the rollout. Ex. projects//locations/global/rollouts/. Corresponds to the JSON property rollout

Returns:

  • (String)


18039
18040
18041
# File 'lib/google/apis/compute_beta/classes.rb', line 18039

def rollout
  @rollout
end

#rollout_planString

Output only. [Output Only] The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/. Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


18046
18047
18048
# File 'lib/google/apis/compute_beta/classes.rb', line 18046

def rollout_plan
  @rollout_plan
end

#stateString

Output only. [Output Only] The overall state of the rollout. Corresponds to the JSON property state

Returns:

  • (String)


18051
18052
18053
# File 'lib/google/apis/compute_beta/classes.rb', line 18051

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18058
18059
18060
18061
18062
18063
# File 'lib/google/apis/compute_beta/classes.rb', line 18058

def update!(**args)
  @location_rollout_status = args[:location_rollout_status] if args.key?(:location_rollout_status)
  @rollout = args[:rollout] if args.key?(:rollout)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @state = args[:state] if args.key?(:state)
end