Class: Google::Apis::ComputeBeta::GuestOsFeature
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GuestOsFeature
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Guest OS features.
Instance Attribute Summary collapse
-
#type ⇒ String
The ID of a supported feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GuestOsFeature
constructor
A new instance of GuestOsFeature.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GuestOsFeature
Returns a new instance of GuestOsFeature.
16658 16659 16660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#type ⇒ String
The ID of a supported feature. To add multiple values, use commas to separate values. Set to one or more of the following values:
- VIRTIO_SCSI_MULTIQUEUE
- WINDOWS
- MULTI_IP_SUBNET
- UEFI_COMPATIBLE
- GVNIC
- SEV_CAPABLE
- SUSPEND_RESUME_COMPATIBLE
- SEV_LIVE_MIGRATABLE_V2
- SEV_SNP_CAPABLE
- TDX_CAPABLE
- IDPF
- SNP_SVSM_CAPABLE
For more information, see
Enabling guest operating system features.
Corresponds to the JSON property
type
16656 16657 16658 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16656 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16663 16664 16665 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16663 def update!(**args) @type = args[:type] if args.key?(:type) end |