Class: Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#health_aggregation_policies ⇒ Array<Google::Apis::ComputeBeta::HealthAggregationPolicy>
A list of HealthAggregationPolicys contained in this scope.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList::Warning
Informational warning which replaces the list of health aggregation policies when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPoliciesScopedList
constructor
A new instance of HealthAggregationPoliciesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPoliciesScopedList
Returns a new instance of HealthAggregationPoliciesScopedList.
17280 17281 17282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_aggregation_policies ⇒ Array<Google::Apis::ComputeBeta::HealthAggregationPolicy>
A list of HealthAggregationPolicys contained in this scope.
Corresponds to the JSON property healthAggregationPolicies
17272 17273 17274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17272 def health_aggregation_policies @health_aggregation_policies end |
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList::Warning
Informational warning which replaces the list of health aggregation
policies when the list is empty.
Corresponds to the JSON property warning
17278 17279 17280 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17278 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17285 17286 17287 17288 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17285 def update!(**args) @health_aggregation_policies = args[:health_aggregation_policies] if args.key?(:health_aggregation_policies) @warning = args[:warning] if args.key?(:warning) end |