Class: Google::Apis::ComputeBeta::HealthAggregationPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthAggregationPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a health aggregation policy. A health aggregation policy resource defines a policy to aggregate health. For more information, see Health checks overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#healthy_percent_threshold ⇒ Fixnum
Can only be set if the policyType field isBACKEND_SERVICE_POLICY.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#min_healthy_threshold ⇒ Fixnum
Can only be set if the policyType field isBACKEND_SERVICE_POLICY.
-
#name ⇒ String
Name of the resource.
-
#policy_type ⇒ String
Specifies the type of the healthAggregationPolicy.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicy
constructor
A new instance of HealthAggregationPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicy
Returns a new instance of HealthAggregationPolicy.
18776 18777 18778 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18776 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
18673 18674 18675 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18673 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
18679 18680 18681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18679 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthAggregationPolicy. An up-to-date fingerprint
must be provided in order to patch the HealthAggregationPolicy; Otherwise,
the request will fail with error 412 conditionNotMet. To see
the latest fingerprint, make a get() request to retrieve the
HealthAggregationPolicy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
18691 18692 18693 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18691 def fingerprint @fingerprint end |
#healthy_percent_threshold ⇒ Fixnum
Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies
the threshold (as a
percentage) of healthy endpoints required in order to consider the
aggregated health result HEALTHY. Defaults to 60. Must be in
range [0, 100]. Not applicable if the policyType field isDNB_PUBLIC_IP_POLICY.
Can be mutated. This field is optional,
and will be set to the default if unspecified. Note that both this
threshold and minHealthyThreshold must be satisfied in order
for HEALTHY to be the aggregated result. "Endpoints" refers to network
endpoints within a Network Endpoint Group or instances within an Instance
Group.
Corresponds to the JSON property healthyPercentThreshold
18706 18707 18708 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18706 def healthy_percent_threshold @healthy_percent_threshold end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
18713 18714 18715 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18713 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
18720 18721 18722 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18720 def kind @kind end |
#min_healthy_threshold ⇒ Fixnum
Can only be set if the policyType field isBACKEND_SERVICE_POLICY. Specifies
the minimum number of
healthy endpoints required in order to consider the aggregated health
result HEALTHY. Defaults to 1. Must be positive. Not
applicable if the policyType field isDNB_PUBLIC_IP_POLICY. Can be mutated.
This field is optional,
and will be set to the default if unspecified. Note that both this
threshold and healthyPercentThreshold must be satisfied in
order for HEALTHY to be the aggregated result. "Endpoints" refers to
network endpoints within a Network Endpoint Group or instances within an
Instance Group.
Corresponds to the JSON property minHealthyThreshold
18735 18736 18737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18735 def min_healthy_threshold @min_healthy_threshold end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
18746 18747 18748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18746 def name @name end |
#policy_type ⇒ String
Specifies the type of the healthAggregationPolicy. The only allowed value
for global resources is DNS_PUBLIC_IP_POLICY. The only allowed
value for regional resources is BACKEND_SERVICE_POLICY. Must
be specified when the healthAggregationPolicy is created, and cannot be
mutated.
Corresponds to the JSON property policyType
18755 18756 18757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18755 def policy_type @policy_type end |
#region ⇒ String
Output only. [Output Only] URL of the region where the health aggregation
policy
resides. This field applies only to the regional resource. You must specify
this field as part of the HTTP request URL. It is not settable as a field
in the request body.
Corresponds to the JSON property region
18764 18765 18766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18764 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
18769 18770 18771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18769 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
18774 18775 18776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18774 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18781 18782 18783 18784 18785 18786 18787 18788 18789 18790 18791 18792 18793 18794 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18781 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @healthy_percent_threshold = args[:healthy_percent_threshold] if args.key?(:healthy_percent_threshold) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @min_healthy_threshold = args[:min_healthy_threshold] if args.key?(:min_healthy_threshold) @name = args[:name] if args.key?(:name) @policy_type = args[:policy_type] if args.key?(:policy_type) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |