Class: Google::Apis::ComputeBeta::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



18968
18969
18970
# File 'lib/google/apis/compute_beta/classes.rb', line 18968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18934
18935
18936
# File 'lib/google/apis/compute_beta/classes.rb', line 18934

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



18939
18940
18941
# File 'lib/google/apis/compute_beta/classes.rb', line 18939

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


18946
18947
18948
# File 'lib/google/apis/compute_beta/classes.rb', line 18946

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18956
18957
18958
# File 'lib/google/apis/compute_beta/classes.rb', line 18956

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18961
18962
18963
# File 'lib/google/apis/compute_beta/classes.rb', line 18961

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18966
18967
18968
# File 'lib/google/apis/compute_beta/classes.rb', line 18966

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18973
18974
18975
18976
18977
18978
18979
18980
# File 'lib/google/apis/compute_beta/classes.rb', line 18973

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end