Class: Google::Apis::ComputeBeta::HealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthCheck>
A list of HealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckList
constructor
A new instance of HealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckList
Returns a new instance of HealthCheckList.
19282 19283 19284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19282 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19250 19251 19252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19250 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthCheck>
A list of HealthCheck resources.
Corresponds to the JSON property items
19255 19256 19257 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19255 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19260 19261 19262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19260 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19270 19271 19272 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19270 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19275 19276 19277 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19275 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19280 19281 19282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19280 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19287 19288 19289 19290 19291 19292 19293 19294 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19287 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |