Class: Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfo.



20176
20177
20178
# File 'lib/google/apis/compute_beta/classes.rb', line 20176

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backendsArray<Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfoBackendInfo>

Represents an instance group or network endpoint group behind the source backend service. Only used if the sourceType of the regionHealthSource is BACKEND_SERVICE. Corresponds to the JSON property backends



20162
20163
20164
# File 'lib/google/apis/compute_beta/classes.rb', line 20162

def backends
  @backends
end

#forwarding_ruleString

Fully qualified URL of the forwarding rule associated with the source resource if it is a L4ILB backend service. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


20168
20169
20170
# File 'lib/google/apis/compute_beta/classes.rb', line 20168

def forwarding_rule
  @forwarding_rule
end

#sourceString

Fully qualified URL of the associated source resource. This is always a backend service URL. Corresponds to the JSON property source

Returns:

  • (String)


20174
20175
20176
# File 'lib/google/apis/compute_beta/classes.rb', line 20174

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20181
20182
20183
20184
20185
# File 'lib/google/apis/compute_beta/classes.rb', line 20181

def update!(**args)
  @backends = args[:backends] if args.key?(:backends)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @source = args[:source] if args.key?(:source)
end