Class: Google::Apis::ComputeBeta::HostPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostPhysicalTopology

Returns a new instance of HostPhysicalTopology.



20771
20772
20773
# File 'lib/google/apis/compute_beta/classes.rb', line 20771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


20753
20754
20755
# File 'lib/google/apis/compute_beta/classes.rb', line 20753

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


20758
20759
20760
# File 'lib/google/apis/compute_beta/classes.rb', line 20758

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


20763
20764
20765
# File 'lib/google/apis/compute_beta/classes.rb', line 20763

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


20769
20770
20771
# File 'lib/google/apis/compute_beta/classes.rb', line 20769

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20776
20777
20778
20779
20780
20781
# File 'lib/google/apis/compute_beta/classes.rb', line 20776

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end