Class: Google::Apis::ComputeBeta::HttpFaultInjection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpFaultInjection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.
Instance Attribute Summary collapse
-
#abort ⇒ Google::Apis::ComputeBeta::HttpFaultAbort
Specification for how requests are aborted as part of fault injection.
-
#delay ⇒ Google::Apis::ComputeBeta::HttpFaultDelay
Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFaultInjection
constructor
A new instance of HttpFaultInjection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFaultInjection
Returns a new instance of HttpFaultInjection.
21169 21170 21171 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abort ⇒ Google::Apis::ComputeBeta::HttpFaultAbort
Specification for how requests are aborted as part of fault injection.
Corresponds to the JSON property abort
21161 21162 21163 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21161 def abort @abort end |
#delay ⇒ Google::Apis::ComputeBeta::HttpFaultDelay
Specifies the delay introduced by the load balancer before forwarding the
request to the backend service as part of fault injection.
Corresponds to the JSON property delay
21167 21168 21169 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21167 def delay @delay end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21174 21175 21176 21177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21174 def update!(**args) @abort = args[:abort] if args.key?(:abort) @delay = args[:delay] if args.key?(:delay) end |