Class: Google::Apis::ComputeBeta::HttpRedirectAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies settings for an HTTP redirect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRedirectAction

Returns a new instance of HttpRedirectAction.



21968
21969
21970
# File 'lib/google/apis/compute_beta/classes.rb', line 21968

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_redirectString

The host that is used in the redirect response instead of the one that was supplied in the request. The value must be from 1 to 255 characters. Corresponds to the JSON property hostRedirect

Returns:

  • (String)


21908
21909
21910
# File 'lib/google/apis/compute_beta/classes.rb', line 21908

def host_redirect
  @host_redirect
end

#https_redirectBoolean Also known as: https_redirect?

If set to true, the URL scheme in the redirected request is set to HTTPS. If set to false, the URL scheme of the redirected request remains the same as that of the request. This must only be set for URL maps used inTargetHttpProxys. Setting this true forTargetHttpsProxy is not permitted. The default is set to false. Corresponds to the JSON property httpsRedirect

Returns:

  • (Boolean)


21919
21920
21921
# File 'lib/google/apis/compute_beta/classes.rb', line 21919

def https_redirect
  @https_redirect
end

#path_redirectString

The path that is used in the redirect response instead of the one that was supplied in the request. pathRedirect cannot be supplied together withprefixRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters. Corresponds to the JSON property pathRedirect

Returns:

  • (String)


21930
21931
21932
# File 'lib/google/apis/compute_beta/classes.rb', line 21930

def path_redirect
  @path_redirect
end

#prefix_redirectString

The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request. prefixRedirect cannot be supplied together withpathRedirect. Supply one alone or neither. If neither is supplied, the path of the original request is used for the redirect. The value must be from 1 to 1024 characters. Corresponds to the JSON property prefixRedirect

Returns:

  • (String)


21941
21942
21943
# File 'lib/google/apis/compute_beta/classes.rb', line 21941

def prefix_redirect
  @prefix_redirect
end

#redirect_response_codeString

The HTTP Status code to use for this RedirectAction. Supported values are:

  • MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301.
  • FOUND, which corresponds to 302.
  • SEE_OTHER which corresponds to 303.
  • TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained.
  • PERMANENT_REDIRECT, which corresponds to 308. In this case, the request method is retained. Corresponds to the JSON property redirectResponseCode

Returns:

  • (String)


21956
21957
21958
# File 'lib/google/apis/compute_beta/classes.rb', line 21956

def redirect_response_code
  @redirect_response_code
end

#strip_queryBoolean Also known as: strip_query?

If set to true, any accompanying query portion of the original URL is removed before redirecting the request. If set to false, the query portion of the original URL is retained. The default is set to false. Corresponds to the JSON property stripQuery

Returns:

  • (Boolean)


21965
21966
21967
# File 'lib/google/apis/compute_beta/classes.rb', line 21965

def strip_query
  @strip_query
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21973
21974
21975
21976
21977
21978
21979
21980
# File 'lib/google/apis/compute_beta/classes.rb', line 21973

def update!(**args)
  @host_redirect = args[:host_redirect] if args.key?(:host_redirect)
  @https_redirect = args[:https_redirect] if args.key?(:https_redirect)
  @path_redirect = args[:path_redirect] if args.key?(:path_redirect)
  @prefix_redirect = args[:prefix_redirect] if args.key?(:prefix_redirect)
  @redirect_response_code = args[:redirect_response_code] if args.key?(:redirect_response_code)
  @strip_query = args[:strip_query] if args.key?(:strip_query)
end