Class: Google::Apis::ComputeBeta::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



22562
22563
22564
# File 'lib/google/apis/compute_beta/classes.rb', line 22562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22530
22531
22532
# File 'lib/google/apis/compute_beta/classes.rb', line 22530

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



22535
22536
22537
# File 'lib/google/apis/compute_beta/classes.rb', line 22535

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22540
22541
22542
# File 'lib/google/apis/compute_beta/classes.rb', line 22540

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22550
22551
22552
# File 'lib/google/apis/compute_beta/classes.rb', line 22550

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22555
22556
22557
# File 'lib/google/apis/compute_beta/classes.rb', line 22555

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22560
22561
22562
# File 'lib/google/apis/compute_beta/classes.rb', line 22560

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22567
22568
22569
22570
22571
22572
22573
22574
# File 'lib/google/apis/compute_beta/classes.rb', line 22567

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end