Class: Google::Apis::ComputeBeta::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
23123 23124 23125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23091 23092 23093 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23091 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
Corresponds to the JSON property items
23096 23097 23098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23096 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
23101 23102 23103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23101 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23111 23112 23113 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23111 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23116 23117 23118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23116 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23121 23122 23123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23121 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23128 23129 23130 23131 23132 23133 23134 23135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23128 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |