Class: Google::Apis::ComputeBeta::InstanceConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceConsumptionInfo

Returns a new instance of InstanceConsumptionInfo.



23639
23640
23641
# File 'lib/google/apis/compute_beta/classes.rb', line 23639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#guest_cpusFixnum

Output only. The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


23620
23621
23622
# File 'lib/google/apis/compute_beta/classes.rb', line 23620

def guest_cpus
  @guest_cpus
end

#local_ssd_gbFixnum

Output only. The amount of local SSD storage available to the instance, defined in GiB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


23626
23627
23628
# File 'lib/google/apis/compute_beta/classes.rb', line 23626

def local_ssd_gb
  @local_ssd_gb
end

#memory_mbFixnum

Output only. The amount of physical memory available to the instance, defined in MiB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


23632
23633
23634
# File 'lib/google/apis/compute_beta/classes.rb', line 23632

def memory_mb
  @memory_mb
end

#min_node_cpusFixnum

Output only. The minimal guaranteed number of virtual CPUs that are reserved. Corresponds to the JSON property minNodeCpus

Returns:

  • (Fixnum)


23637
23638
23639
# File 'lib/google/apis/compute_beta/classes.rb', line 23637

def min_node_cpus
  @min_node_cpus
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23644
23645
23646
23647
23648
23649
# File 'lib/google/apis/compute_beta/classes.rb', line 23644

def update!(**args)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @min_node_cpus = args[:min_node_cpus] if args.key?(:min_node_cpus)
end