Class: Google::Apis::ComputeBeta::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



24198
24199
24200
# File 'lib/google/apis/compute_beta/classes.rb', line 24198

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24158
24159
24160
# File 'lib/google/apis/compute_beta/classes.rb', line 24158

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



24163
24164
24165
# File 'lib/google/apis/compute_beta/classes.rb', line 24163

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24170
24171
24172
# File 'lib/google/apis/compute_beta/classes.rb', line 24170

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24181
24182
24183
# File 'lib/google/apis/compute_beta/classes.rb', line 24181

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24186
24187
24188
# File 'lib/google/apis/compute_beta/classes.rb', line 24186

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


24191
24192
24193
# File 'lib/google/apis/compute_beta/classes.rb', line 24191

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



24196
24197
24198
# File 'lib/google/apis/compute_beta/classes.rb', line 24196

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24203
24204
24205
24206
24207
24208
24209
24210
24211
# File 'lib/google/apis/compute_beta/classes.rb', line 24203

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end