Class: Google::Apis::ComputeBeta::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



24326
24327
24328
# File 'lib/google/apis/compute_beta/classes.rb', line 24326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24292
24293
24294
# File 'lib/google/apis/compute_beta/classes.rb', line 24292

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



24297
24298
24299
# File 'lib/google/apis/compute_beta/classes.rb', line 24297

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


24303
24304
24305
# File 'lib/google/apis/compute_beta/classes.rb', line 24303

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24314
24315
24316
# File 'lib/google/apis/compute_beta/classes.rb', line 24314

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24319
24320
24321
# File 'lib/google/apis/compute_beta/classes.rb', line 24319

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



24324
24325
24326
# File 'lib/google/apis/compute_beta/classes.rb', line 24324

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24331
24332
24333
24334
24335
24336
24337
24338
# File 'lib/google/apis/compute_beta/classes.rb', line 24331

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end