Class: Google::Apis::ComputeBeta::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



24679
24680
24681
# File 'lib/google/apis/compute_beta/classes.rb', line 24679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::InstanceGroupManagerAllInstancesConfig

Specifies configuration that overrides the instance template configuration for the group. Corresponds to the JSON property allInstancesConfig



24425
24426
24427
# File 'lib/google/apis/compute_beta/classes.rb', line 24425

def all_instances_config
  @all_instances_config
end

#auto_healing_policiesArray<Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



24431
24432
24433
# File 'lib/google/apis/compute_beta/classes.rb', line 24431

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format. When a VM is created in the group, the MIG appends a hyphen and a random four-character string to the base instance name. If you want the MIG to assign sequential numbers instead of a random string, then end the base instance name with a hyphen followed by one or more hash symbols. The hash symbols indicate the number of digits. For example, a base instance name of "vm-###" results in "vm-001" as a VM name. a-z Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


24446
24447
24448
# File 'lib/google/apis/compute_beta/classes.rb', line 24446

def base_instance_name
  @base_instance_name
end

#creation_timestampString

Output only. The creation timestamp for this managed instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


24452
24453
24454
# File 'lib/google/apis/compute_beta/classes.rb', line 24452

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeBeta::InstanceGroupManagerActionsSummary

Output only. The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



24459
24460
24461
# File 'lib/google/apis/compute_beta/classes.rb', line 24459

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


24464
24465
24466
# File 'lib/google/apis/compute_beta/classes.rb', line 24464

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeBeta::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



24470
24471
24472
# File 'lib/google/apis/compute_beta/classes.rb', line 24470

def distribution_policy
  @distribution_policy
end

#failover_actionString

The action to perform in case of zone failure. Only one value is supported, NO_FAILOVER. The default is NO_FAILOVER. Corresponds to the JSON property failoverAction

Returns:

  • (String)


24476
24477
24478
# File 'lib/google/apis/compute_beta/classes.rb', line 24476

def failover_action
  @failover_action
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


24487
24488
24489
# File 'lib/google/apis/compute_beta/classes.rb', line 24487

def fingerprint
  @fingerprint
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


24493
24494
24495
# File 'lib/google/apis/compute_beta/classes.rb', line 24493

def id
  @id
end

#instance_flexibility_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicy

Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration. Corresponds to the JSON property instanceFlexibilityPolicy



24501
24502
24503
# File 'lib/google/apis/compute_beta/classes.rb', line 24501

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_groupString

Output only. The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


24506
24507
24508
# File 'lib/google/apis/compute_beta/classes.rb', line 24506

def instance_group
  @instance_group
end

#instance_lifecycle_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerInstanceLifecyclePolicy

The repair policy for this managed instance group. Corresponds to the JSON property instanceLifecyclePolicy



24511
24512
24513
# File 'lib/google/apis/compute_beta/classes.rb', line 24511

def instance_lifecycle_policy
  @instance_lifecycle_policy
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


24520
24521
24522
# File 'lib/google/apis/compute_beta/classes.rb', line 24520

def instance_template
  @instance_template
end

#kindString

Output only. The resource type, which is alwayscompute#instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24526
24527
24528
# File 'lib/google/apis/compute_beta/classes.rb', line 24526

def kind
  @kind
end

#list_managed_instances_resultsString

Pagination behavior of the listManagedInstances API method for this managed instance group. Corresponds to the JSON property listManagedInstancesResults

Returns:

  • (String)


24532
24533
24534
# File 'lib/google/apis/compute_beta/classes.rb', line 24532

def list_managed_instances_results
  @list_managed_instances_results
end

#multi_migString

URL to the multi-MIG that this Managed Instance Group belongs to. Corresponds to the JSON property multiMig

Returns:

  • (String)


24537
24538
24539
# File 'lib/google/apis/compute_beta/classes.rb', line 24537

def multi_mig
  @multi_mig
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


24543
24544
24545
# File 'lib/google/apis/compute_beta/classes.rb', line 24543

def name
  @name
end

#named_portsArray<Google::Apis::ComputeBeta::NamedPort>

[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



24549
24550
24551
# File 'lib/google/apis/compute_beta/classes.rb', line 24549

def named_ports
  @named_ports
end

#paramsGoogle::Apis::ComputeBeta::InstanceGroupManagerParams

Input only additional params for instance group manager creation. Corresponds to the JSON property params



24554
24555
24556
# File 'lib/google/apis/compute_beta/classes.rb', line 24554

def params
  @params
end

#regionString

Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


24560
24561
24562
# File 'lib/google/apis/compute_beta/classes.rb', line 24560

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeBeta::InstanceGroupManagerResourcePolicies

Resource policies for this managed instance group. Corresponds to the JSON property resourcePolicies



24565
24566
24567
# File 'lib/google/apis/compute_beta/classes.rb', line 24565

def resource_policies
  @resource_policies
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


24570
24571
24572
# File 'lib/google/apis/compute_beta/classes.rb', line 24570

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


24576
24577
24578
# File 'lib/google/apis/compute_beta/classes.rb', line 24576

def satisfies_pzs
  @satisfies_pzs
end

Output only. The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


24583
24584
24585
# File 'lib/google/apis/compute_beta/classes.rb', line 24583

def self_link
  @self_link
end

#service_accountString

The service account to be used as credentials for all operations performed by the managed instance group on instances. The service accounts needs all permissions required to create and delete instances. By default, the service account projectNumber@cloudservices.gserviceaccount.com is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


24592
24593
24594
# File 'lib/google/apis/compute_beta/classes.rb', line 24592

def 
  @service_account
end

#standby_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy

Standby policy for stopped and suspended instances. Corresponds to the JSON property standbyPolicy



24597
24598
24599
# File 'lib/google/apis/compute_beta/classes.rb', line 24597

def standby_policy
  @standby_policy
end

#stateful_policyGoogle::Apis::ComputeBeta::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



24602
24603
24604
# File 'lib/google/apis/compute_beta/classes.rb', line 24602

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeBeta::InstanceGroupManagerStatus

Output only. The status of this managed instance group. Corresponds to the JSON property status



24607
24608
24609
# File 'lib/google/apis/compute_beta/classes.rb', line 24607

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


24614
24615
24616
# File 'lib/google/apis/compute_beta/classes.rb', line 24614

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


24622
24623
24624
# File 'lib/google/apis/compute_beta/classes.rb', line 24622

def target_size
  @target_size
end

#target_size_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerTargetSizePolicy

The policy that specifies how the MIG creates its VMs to achieve the target size. Corresponds to the JSON property targetSizePolicy



24628
24629
24630
# File 'lib/google/apis/compute_beta/classes.rb', line 24628

def target_size_policy
  @target_size_policy
end

#target_stopped_sizeFixnum

The target number of stopped instances for this managed instance group. This number changes when you:

  • Stop instance using the stopInstances method or start instances using the startInstances method.
  • Manually change the targetStoppedSize using the update method. Corresponds to the JSON property targetStoppedSize

Returns:

  • (Fixnum)


24640
24641
24642
# File 'lib/google/apis/compute_beta/classes.rb', line 24640

def target_stopped_size
  @target_stopped_size
end

#target_suspended_sizeFixnum

The target number of suspended instances for this managed instance group. This number changes when you:

  • Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
  • Manually change the targetSuspendedSize using the update method. Corresponds to the JSON property targetSuspendedSize

Returns:

  • (Fixnum)


24652
24653
24654
# File 'lib/google/apis/compute_beta/classes.rb', line 24652

def target_suspended_size
  @target_suspended_size
end

#update_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



24657
24658
24659
# File 'lib/google/apis/compute_beta/classes.rb', line 24657

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeBeta::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates. Corresponds to the JSON property versions



24671
24672
24673
# File 'lib/google/apis/compute_beta/classes.rb', line 24671

def versions
  @versions
end

#zoneString

Output only. The URL of azone where the managed instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


24677
24678
24679
# File 'lib/google/apis/compute_beta/classes.rb', line 24677

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24684
24685
24686
24687
24688
24689
24690
24691
24692
24693
24694
24695
24696
24697
24698
24699
24700
24701
24702
24703
24704
24705
24706
24707
24708
24709
24710
24711
24712
24713
24714
24715
24716
24717
24718
24719
24720
24721
24722
# File 'lib/google/apis/compute_beta/classes.rb', line 24684

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @failover_action = args[:failover_action] if args.key?(:failover_action)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results)
  @multi_mig = args[:multi_mig] if args.key?(:multi_mig)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_account = args[:service_account] if args.key?(:service_account)
  @standby_policy = args[:standby_policy] if args.key?(:standby_policy)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy)
  @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size)
  @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end