Class: Google::Apis::ComputeBeta::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



24687
24688
24689
# File 'lib/google/apis/compute_beta/classes.rb', line 24687

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24648
24649
24650
# File 'lib/google/apis/compute_beta/classes.rb', line 24648

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



24653
24654
24655
# File 'lib/google/apis/compute_beta/classes.rb', line 24653

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24660
24661
24662
# File 'lib/google/apis/compute_beta/classes.rb', line 24660

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24670
24671
24672
# File 'lib/google/apis/compute_beta/classes.rb', line 24670

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24675
24676
24677
# File 'lib/google/apis/compute_beta/classes.rb', line 24675

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


24680
24681
24682
# File 'lib/google/apis/compute_beta/classes.rb', line 24680

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



24685
24686
24687
# File 'lib/google/apis/compute_beta/classes.rb', line 24685

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24692
24693
24694
24695
24696
24697
24698
24699
24700
# File 'lib/google/apis/compute_beta/classes.rb', line 24692

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end