Class: Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#health_check ⇒ String
The URL for the health check that signals autohealing.
-
#initial_delay_sec ⇒ Fixnum
The initial delay is the number of seconds that a new VM takes to initialize and run its startup script.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerAutoHealingPolicy
constructor
A new instance of InstanceGroupManagerAutoHealingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerAutoHealingPolicy
Returns a new instance of InstanceGroupManagerAutoHealingPolicy.
22640 22641 22642 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22640 def initialize(**args) update!(**args) end |
Instance Attribute Details
#health_check ⇒ String
The URL for the health check that signals autohealing.
Corresponds to the JSON property healthCheck
22626 22627 22628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22626 def health_check @health_check end |
#initial_delay_sec ⇒ Fixnum
The initial delay is the number of seconds that a new VM takes to
initialize and run its startup script. During a VM's initial delay
period, the MIG ignores unsuccessful health checks because the VM might
be in the startup process. This prevents the MIG from prematurely
recreating a VM. If the health check receives a healthy response during
the initial delay, it indicates that the startup process is complete and
the VM is ready. The value of initial delay must be between 0 and 3600
seconds. The default value is 0.
Corresponds to the JSON property initialDelaySec
22638 22639 22640 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22638 def initial_delay_sec @initial_delay_sec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22645 22646 22647 22648 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22645 def update!(**args) @health_check = args[:health_check] if args.key?(:health_check) @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec) end |