Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



25481
25482
25483
# File 'lib/google/apis/compute_beta/classes.rb', line 25481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

This field is deprecated, please use resize_by instead. The count of instances to create as part of this resize request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


25392
25393
25394
# File 'lib/google/apis/compute_beta/classes.rb', line 25392

def count
  @count
end

#creation_timestampString

Output only. The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


25398
25399
25400
# File 'lib/google/apis/compute_beta/classes.rb', line 25398

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


25403
25404
25405
# File 'lib/google/apis/compute_beta/classes.rb', line 25403

def description
  @description
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25410
25411
25412
# File 'lib/google/apis/compute_beta/classes.rb', line 25410

def id
  @id
end

#instancesArray<Google::Apis::ComputeBeta::PerInstanceConfig>

The names of instances to be created by this resize request. The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'. Corresponds to the JSON property instances



25418
25419
25420
# File 'lib/google/apis/compute_beta/classes.rb', line 25418

def instances
  @instances
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


25424
25425
25426
# File 'lib/google/apis/compute_beta/classes.rb', line 25424

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


25430
25431
25432
# File 'lib/google/apis/compute_beta/classes.rb', line 25430

def name
  @name
end

#regionString

Output only. The URL of a region where the resize request is located. Populated only for regional resize requests. Corresponds to the JSON property region

Returns:

  • (String)


25437
25438
25439
# File 'lib/google/apis/compute_beta/classes.rb', line 25437

def region
  @region
end

#requested_run_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



25445
25446
25447
# File 'lib/google/apis/compute_beta/classes.rb', line 25445

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


25452
25453
25454
# File 'lib/google/apis/compute_beta/classes.rb', line 25452

def resize_by
  @resize_by
end

Output only. The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


25457
25458
25459
# File 'lib/google/apis/compute_beta/classes.rb', line 25457

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


25462
25463
25464
# File 'lib/google/apis/compute_beta/classes.rb', line 25462

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


25467
25468
25469
# File 'lib/google/apis/compute_beta/classes.rb', line 25467

def state
  @state
end

#statusGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus

Output only. Status of the request. Corresponds to the JSON property status



25472
25473
25474
# File 'lib/google/apis/compute_beta/classes.rb', line 25472

def status
  @status
end

#zoneString

Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


25479
25480
25481
# File 'lib/google/apis/compute_beta/classes.rb', line 25479

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25486
25487
25488
25489
25490
25491
25492
25493
25494
25495
25496
25497
25498
25499
25500
25501
25502
# File 'lib/google/apis/compute_beta/classes.rb', line 25486

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end