Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
25328 25329 25330 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
25306 25307 25308 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25306 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
25315 25316 25317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25315 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
25321 25322 25323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25321 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
25326 25327 25328 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25326 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25333 25334 25335 25336 25337 25338 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25333 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |