Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



25852
25853
25854
# File 'lib/google/apis/compute_beta/classes.rb', line 25852

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25818
25819
25820
# File 'lib/google/apis/compute_beta/classes.rb', line 25818

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



25823
25824
25825
# File 'lib/google/apis/compute_beta/classes.rb', line 25823

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


25830
25831
25832
# File 'lib/google/apis/compute_beta/classes.rb', line 25830

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25840
25841
25842
# File 'lib/google/apis/compute_beta/classes.rb', line 25840

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25845
25846
25847
# File 'lib/google/apis/compute_beta/classes.rb', line 25845

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



25850
25851
25852
# File 'lib/google/apis/compute_beta/classes.rb', line 25850

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25857
25858
25859
25860
25861
25862
25863
25864
# File 'lib/google/apis/compute_beta/classes.rb', line 25857

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end