Class: Google::Apis::ComputeBeta::InstanceGroupManagerResourcePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResourcePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#workload_policy ⇒ String
The URL of the workload policy that is specified for this managed instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResourcePolicies
constructor
A new instance of InstanceGroupManagerResourcePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResourcePolicies
Returns a new instance of InstanceGroupManagerResourcePolicies.
23568 23569 23570 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#workload_policy ⇒ String
The URL of the workload policy that is specified for this managed instance group. It can be a full or partial URL. For example, the following are all valid URLs to a workload policy:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ resourcePolicies/resourcePolicy
- projects/project/regions/region/resourcePolicies/resourcePolicy
- regions/region/resourcePolicies/resourcePolicy
Corresponds to the JSON property
workloadPolicy
23566 23567 23568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23566 def workload_policy @workload_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23573 23574 23575 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23573 def update!(**args) @workload_policy = args[:workload_policy] if args.key?(:workload_policy) end |