Class: Google::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy

Returns a new instance of InstanceGroupManagerStandbyPolicy.



25191
25192
25193
# File 'lib/google/apis/compute_beta/classes.rb', line 25191

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#initial_delay_secFixnum

Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created. The initial delay gives the initialization script the time to prepare your VM for a quick scale out. The value of initial delay must be between 0 and 3600 seconds. The default value is 0. Corresponds to the JSON property initialDelaySec

Returns:

  • (Fixnum)


25183
25184
25185
# File 'lib/google/apis/compute_beta/classes.rb', line 25183

def initial_delay_sec
  @initial_delay_sec
end

#modeString

Defines how a MIG resumes or starts VMs from a standby pool when the group scales out. The default mode is MANUAL. Corresponds to the JSON property mode

Returns:

  • (String)


25189
25190
25191
# File 'lib/google/apis/compute_beta/classes.rb', line 25189

def mode
  @mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25196
25197
25198
25199
# File 'lib/google/apis/compute_beta/classes.rb', line 25196

def update!(**args)
  @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec)
  @mode = args[:mode] if args.key?(:mode)
end