Class: Google::Apis::ComputeBeta::InstanceGroupManagerTargetSizePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerTargetSizePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#mode ⇒ String
The mode of target size policy based on which the MIG creates its VMs individually or all at once.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerTargetSizePolicy
constructor
A new instance of InstanceGroupManagerTargetSizePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerTargetSizePolicy
Returns a new instance of InstanceGroupManagerTargetSizePolicy.
23977 23978 23979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#mode ⇒ String
The mode of target size policy based on which the MIG creates its VMs
individually or all at once.
Corresponds to the JSON property mode
23975 23976 23977 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23975 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23982 23983 23984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23982 def update!(**args) @mode = args[:mode] if args.key?(:mode) end |