Class: Google::Apis::ComputeBeta::InstanceGroupManagersDeletePerInstanceConfigsReq
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersDeletePerInstanceConfigsReq
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
InstanceGroupManagers.deletePerInstanceConfigs
Instance Attribute Summary collapse
-
#names ⇒ Array<String>
The list of instance names for which we want to delete per-instance configs on this managed instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersDeletePerInstanceConfigsReq
constructor
A new instance of InstanceGroupManagersDeletePerInstanceConfigsReq.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersDeletePerInstanceConfigsReq
Returns a new instance of InstanceGroupManagersDeletePerInstanceConfigsReq.
24824 24825 24826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24824 def initialize(**args) update!(**args) end |
Instance Attribute Details
#names ⇒ Array<String>
The list of instance names for which we want to delete per-instance configs
on this managed instance group.
Corresponds to the JSON property names
24822 24823 24824 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24822 def names @names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24829 24830 24831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24829 def update!(**args) @names = args[:names] if args.key?(:names) end |