Class: Google::Apis::ComputeBeta::InstanceGroupManagersScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersScopedList

Returns a new instance of InstanceGroupManagersScopedList.



27295
27296
27297
# File 'lib/google/apis/compute_beta/classes.rb', line 27295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_group_managersArray<Google::Apis::ComputeBeta::InstanceGroupManager>

Output only. The list of managed instance groups that are contained in the specified project and zone. Corresponds to the JSON property instanceGroupManagers



27286
27287
27288
# File 'lib/google/apis/compute_beta/classes.rb', line 27286

def instance_group_managers
  @instance_group_managers
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagersScopedList::Warning

Output only. The warning that replaces the list of managed instance groups when the list is empty. Corresponds to the JSON property warning



27293
27294
27295
# File 'lib/google/apis/compute_beta/classes.rb', line 27293

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27300
27301
27302
27303
# File 'lib/google/apis/compute_beta/classes.rb', line 27300

def update!(**args)
  @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers)
  @warning = args[:warning] if args.key?(:warning)
end