Class: Google::Apis::ComputeBeta::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



28309
28310
28311
# File 'lib/google/apis/compute_beta/classes.rb', line 28309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28276
28277
28278
# File 'lib/google/apis/compute_beta/classes.rb', line 28276

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reference>

A list of Reference resources. Corresponds to the JSON property items



28281
28282
28283
# File 'lib/google/apis/compute_beta/classes.rb', line 28281

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


28287
28288
28289
# File 'lib/google/apis/compute_beta/classes.rb', line 28287

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28297
28298
28299
# File 'lib/google/apis/compute_beta/classes.rb', line 28297

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28302
28303
28304
# File 'lib/google/apis/compute_beta/classes.rb', line 28302

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28307
28308
28309
# File 'lib/google/apis/compute_beta/classes.rb', line 28307

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28314
28315
28316
28317
28318
28319
28320
28321
# File 'lib/google/apis/compute_beta/classes.rb', line 28314

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end