Class: Google::Apis::ComputeBeta::InstanceTemplatesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceTemplatesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#instance_templates ⇒ Array<Google::Apis::ComputeBeta::InstanceTemplate>
[Output Only] A list of instance templates that are contained within the specified project and zone.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplatesScopedList::Warning
[Output Only] An informational warning that replaces the list of instance templates when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplatesScopedList
constructor
A new instance of InstanceTemplatesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplatesScopedList
Returns a new instance of InstanceTemplatesScopedList.
27855 27856 27857 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27855 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_templates ⇒ Array<Google::Apis::ComputeBeta::InstanceTemplate>
[Output Only] A list of instance templates that are contained within
the specified project and zone.
Corresponds to the JSON property instanceTemplates
27847 27848 27849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27847 def instance_templates @instance_templates end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplatesScopedList::Warning
[Output Only] An informational warning that replaces the list of instance
templates when the list is empty.
Corresponds to the JSON property warning
27853 27854 27855 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27853 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27860 27861 27862 27863 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27860 def update!(**args) @instance_templates = args[:instance_templates] if args.key?(:instance_templates) @warning = args[:warning] if args.key?(:warning) end |