Class: Google::Apis::ComputeBeta::InstancesSetMachineResourcesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstancesSetMachineResourcesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesSetMachineResourcesRequest
constructor
A new instance of InstancesSetMachineResourcesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesSetMachineResourcesRequest
Returns a new instance of InstancesSetMachineResourcesRequest.
29515 29516 29517 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29515 def initialize(**args) update!(**args) end |
Instance Attribute Details
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
Corresponds to the JSON property guestAccelerators
29513 29514 29515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29513 def guest_accelerators @guest_accelerators end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29520 29521 29522 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29520 def update!(**args) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) end |