Class: Google::Apis::ComputeBeta::InstancesStartWithEncryptionKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesStartWithEncryptionKeyRequest

Returns a new instance of InstancesStartWithEncryptionKeyRequest.



29620
29621
29622
# File 'lib/google/apis/compute_beta/classes.rb', line 29620

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeBeta::CustomerEncryptionKeyProtectedDisk>

Array of disks associated with this instance that are protected with acustomer- supplied encryption key. In order to start the instance, the disk url and its corresponding key must be provided. If the disk is not protected with a customer-supplied encryption key it should not be specified. Corresponds to the JSON property disks



29618
29619
29620
# File 'lib/google/apis/compute_beta/classes.rb', line 29618

def disks
  @disks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29625
29626
29627
# File 'lib/google/apis/compute_beta/classes.rb', line 29625

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
end