Class: Google::Apis::ComputeBeta::InstantSnapshotGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an InstantSnapshotGroup resource. An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotGroup

Returns a new instance of InstantSnapshotGroup.



30375
30376
30377
# File 'lib/google/apis/compute_beta/classes.rb', line 30375

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


30299
30300
30301
# File 'lib/google/apis/compute_beta/classes.rb', line 30299

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


30306
30307
30308
# File 'lib/google/apis/compute_beta/classes.rb', line 30306

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30313
30314
30315
# File 'lib/google/apis/compute_beta/classes.rb', line 30313

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instantSnapshotGroup for InstantSnapshotGroup resources. Corresponds to the JSON property kind

Returns:

  • (String)


30320
30321
30322
# File 'lib/google/apis/compute_beta/classes.rb', line 30320

def kind
  @kind
end

#nameString

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


30332
30333
30334
# File 'lib/google/apis/compute_beta/classes.rb', line 30332

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


30340
30341
30342
# File 'lib/google/apis/compute_beta/classes.rb', line 30340

def region
  @region
end

#resource_statusGoogle::Apis::ComputeBeta::InstantSnapshotGroupResourceStatus

Corresponds to the JSON property resourceStatus



30345
30346
30347
# File 'lib/google/apis/compute_beta/classes.rb', line 30345

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30350
30351
30352
# File 'lib/google/apis/compute_beta/classes.rb', line 30350

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


30355
30356
30357
# File 'lib/google/apis/compute_beta/classes.rb', line 30355

def self_link_with_id
  @self_link_with_id
end

#source_consistency_groupString

Corresponds to the JSON property sourceConsistencyGroup

Returns:

  • (String)


30360
30361
30362
# File 'lib/google/apis/compute_beta/classes.rb', line 30360

def source_consistency_group
  @source_consistency_group
end

#statusString

Output only. [Output Only] Corresponds to the JSON property status

Returns:

  • (String)


30365
30366
30367
# File 'lib/google/apis/compute_beta/classes.rb', line 30365

def status
  @status
end

#zoneString

Output only. [Output Only] URL of the zone where the instant snapshot group resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


30373
30374
30375
# File 'lib/google/apis/compute_beta/classes.rb', line 30373

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30380
30381
30382
30383
30384
30385
30386
30387
30388
30389
30390
30391
30392
30393
# File 'lib/google/apis/compute_beta/classes.rb', line 30380

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_consistency_group = args[:source_consistency_group] if args.key?(:source_consistency_group)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end