Class: Google::Apis::ComputeBeta::InstantSnapshotGroupParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotGroupParameters

Returns a new instance of InstantSnapshotGroupParameters.



30076
30077
30078
# File 'lib/google/apis/compute_beta/classes.rb', line 30076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_instant_snapshot_groupString

The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


30074
30075
30076
# File 'lib/google/apis/compute_beta/classes.rb', line 30074

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30081
30082
30083
# File 'lib/google/apis/compute_beta/classes.rb', line 30081

def update!(**args)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
end