Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfigured

Returns a new instance of InterconnectAttachmentGroupConfigured.



28842
28843
28844
# File 'lib/google/apis/compute_beta/classes.rb', line 28842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_slaGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySla

[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements. Corresponds to the JSON property availabilitySla



28840
28841
28842
# File 'lib/google/apis/compute_beta/classes.rb', line 28840

def availability_sla
  @availability_sla
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28847
28848
28849
# File 'lib/google/apis/compute_beta/classes.rb', line 28847

def update!(**args)
  @availability_sla = args[:availability_sla] if args.key?(:availability_sla)
end