Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.



30715
30716
30717
# File 'lib/google/apis/compute_beta/classes.rb', line 30715

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


30671
30672
30673
# File 'lib/google/apis/compute_beta/classes.rb', line 30671

def attachments
  @attachments
end

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


30676
30677
30678
# File 'lib/google/apis/compute_beta/classes.rb', line 30676

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


30683
30684
30685
# File 'lib/google/apis/compute_beta/classes.rb', line 30683

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


30690
30691
30692
# File 'lib/google/apis/compute_beta/classes.rb', line 30690

def explanation
  @explanation
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


30698
30699
30700
# File 'lib/google/apis/compute_beta/classes.rb', line 30698

def metros
  @metros
end

#regionsArray<String>

Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others. Corresponds to the JSON property regions

Returns:

  • (Array<String>)


30706
30707
30708
# File 'lib/google/apis/compute_beta/classes.rb', line 30706

def regions
  @regions
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


30713
30714
30715
# File 'lib/google/apis/compute_beta/classes.rb', line 30713

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30720
30721
30722
30723
30724
30725
30726
30727
30728
# File 'lib/google/apis/compute_beta/classes.rb', line 30720

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metros = args[:metros] if args.key?(:metros)
  @regions = args[:regions] if args.key?(:regions)
  @zones = args[:zones] if args.key?(:zones)
end