Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



32385
32386
32387
# File 'lib/google/apis/compute_beta/classes.rb', line 32385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


32341
32342
32343
# File 'lib/google/apis/compute_beta/classes.rb', line 32341

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32346
32347
32348
# File 'lib/google/apis/compute_beta/classes.rb', line 32346

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



32351
32352
32353
# File 'lib/google/apis/compute_beta/classes.rb', line 32351

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


32356
32357
32358
# File 'lib/google/apis/compute_beta/classes.rb', line 32356

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32366
32367
32368
# File 'lib/google/apis/compute_beta/classes.rb', line 32366

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32371
32372
32373
# File 'lib/google/apis/compute_beta/classes.rb', line 32371

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


32378
32379
32380
# File 'lib/google/apis/compute_beta/classes.rb', line 32378

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32383
32384
32385
# File 'lib/google/apis/compute_beta/classes.rb', line 32383

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32390
32391
32392
32393
32394
32395
32396
32397
32398
32399
# File 'lib/google/apis/compute_beta/classes.rb', line 32390

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end