Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



32506
32507
32508
# File 'lib/google/apis/compute_beta/classes.rb', line 32506

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



32479
32480
32481
# File 'lib/google/apis/compute_beta/classes.rb', line 32479

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



32486
32487
32488
# File 'lib/google/apis/compute_beta/classes.rb', line 32486

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


32491
32492
32493
# File 'lib/google/apis/compute_beta/classes.rb', line 32491

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



32497
32498
32499
# File 'lib/google/apis/compute_beta/classes.rb', line 32497

def intent
  @intent
end

#operationalGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



32504
32505
32506
# File 'lib/google/apis/compute_beta/classes.rb', line 32504

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32511
32512
32513
32514
32515
32516
32517
# File 'lib/google/apis/compute_beta/classes.rb', line 32511

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end