Class: Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The inner VLAN-to-Appliance mapping.
Instance Attribute Summary collapse
-
#inner_appliance_ip_address ⇒ String
Required in this object.
-
#inner_vlan_tags ⇒ Array<String>
Required in this object.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
constructor
A new instance of InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping
Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping.
32680 32681 32682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#inner_appliance_ip_address ⇒ String
Required in this object. A single IPv4 or IPv6 address used as the
destination IP address for ingress packets that match on both VLAN
tags.
Corresponds to the JSON property innerApplianceIpAddress
32668 32669 32670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32668 def inner_appliance_ip_address @inner_appliance_ip_address end |
#inner_vlan_tags ⇒ Array<String>
Required in this object. Used to match the inner VLAN tag on the
packet. Each entry can be a single number or a range of numbers in
the range of 1 to 4094, e.g., ["1", "4001-4094"] is valid. Non-empty
and Non-overlapping VLAN tag ranges are enforced, and violating
operations will be rejected.
The inner VLAN tags must have an ethertype value of 0x8100.
Corresponds to the JSON property innerVlanTags
32678 32679 32680 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32678 def @inner_vlan_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32685 32686 32687 32688 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32685 def update!(**args) @inner_appliance_ip_address = args[:inner_appliance_ip_address] if args.key?(:inner_appliance_ip_address) @inner_vlan_tags = args[:inner_vlan_tags] if args.key?(:inner_vlan_tags) end |