Class: Google::Apis::ComputeBeta::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



32753
32754
32755
# File 'lib/google/apis/compute_beta/classes.rb', line 32753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32719
32720
32721
# File 'lib/google/apis/compute_beta/classes.rb', line 32719

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



32724
32725
32726
# File 'lib/google/apis/compute_beta/classes.rb', line 32724

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


32731
32732
32733
# File 'lib/google/apis/compute_beta/classes.rb', line 32731

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32741
32742
32743
# File 'lib/google/apis/compute_beta/classes.rb', line 32741

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32746
32747
32748
# File 'lib/google/apis/compute_beta/classes.rb', line 32746

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32751
32752
32753
# File 'lib/google/apis/compute_beta/classes.rb', line 32751

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32758
32759
32760
32761
32762
32763
32764
32765
# File 'lib/google/apis/compute_beta/classes.rb', line 32758

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end