Class: Google::Apis::ComputeBeta::InterconnectAttachmentPrivateInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentPrivateInfo

Returns a new instance of InterconnectAttachmentPrivateInfo.



31488
31489
31490
# File 'lib/google/apis/compute_beta/classes.rb', line 31488

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#tag8021qFixnum

[Output Only] 802.1q encapsulation tag to be used for traffic between Google and the customer, going to and from this network and region. Corresponds to the JSON property tag8021q

Returns:

  • (Fixnum)


31486
31487
31488
# File 'lib/google/apis/compute_beta/classes.rb', line 31486

def tag8021q
  @tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31493
31494
31495
# File 'lib/google/apis/compute_beta/classes.rb', line 31493

def update!(**args)
  @tag8021q = args[:tag8021q] if args.key?(:tag8021q)
end