Class: Google::Apis::ComputeBeta::InterconnectCircuitInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectCircuitInfo

Returns a new instance of InterconnectCircuitInfo.



32832
32833
32834
# File 'lib/google/apis/compute_beta/classes.rb', line 32832

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_demarc_idString

Customer-side demarc ID for this circuit. Corresponds to the JSON property customerDemarcId

Returns:

  • (String)


32819
32820
32821
# File 'lib/google/apis/compute_beta/classes.rb', line 32819

def customer_demarc_id
  @customer_demarc_id
end

#google_circuit_idString

Google-assigned unique ID for this circuit. Assigned at circuit turn-up. Corresponds to the JSON property googleCircuitId

Returns:

  • (String)


32824
32825
32826
# File 'lib/google/apis/compute_beta/classes.rb', line 32824

def google_circuit_id
  @google_circuit_id
end

#google_demarc_idString

Google-side demarc ID for this circuit. Assigned at circuit turn-up and provided by Google to the customer in the LOA. Corresponds to the JSON property googleDemarcId

Returns:

  • (String)


32830
32831
32832
# File 'lib/google/apis/compute_beta/classes.rb', line 32830

def google_demarc_id
  @google_demarc_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32837
32838
32839
32840
32841
# File 'lib/google/apis/compute_beta/classes.rb', line 32837

def update!(**args)
  @customer_demarc_id = args[:customer_demarc_id] if args.key?(:customer_demarc_id)
  @google_circuit_id = args[:google_circuit_id] if args.key?(:google_circuit_id)
  @google_demarc_id = args[:google_demarc_id] if args.key?(:google_demarc_id)
end