Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



33257
33258
33259
# File 'lib/google/apis/compute_beta/classes.rb', line 33257

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



33218
33219
33220
# File 'lib/google/apis/compute_beta/classes.rb', line 33218

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


33223
33224
33225
# File 'lib/google/apis/compute_beta/classes.rb', line 33223

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


33228
33229
33230
# File 'lib/google/apis/compute_beta/classes.rb', line 33228

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



33233
33234
33235
# File 'lib/google/apis/compute_beta/classes.rb', line 33233

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



33238
33239
33240
# File 'lib/google/apis/compute_beta/classes.rb', line 33238

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


33243
33244
33245
# File 'lib/google/apis/compute_beta/classes.rb', line 33243

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



33249
33250
33251
# File 'lib/google/apis/compute_beta/classes.rb', line 33249

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



33255
33256
33257
# File 'lib/google/apis/compute_beta/classes.rb', line 33255

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33262
33263
33264
33265
33266
33267
33268
33269
33270
33271
# File 'lib/google/apis/compute_beta/classes.rb', line 33262

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end