Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.



33315
33316
33317
# File 'lib/google/apis/compute_beta/classes.rb', line 33315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilityString

Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility. Corresponds to the JSON property facility

Returns:

  • (String)


33308
33309
33310
# File 'lib/google/apis/compute_beta/classes.rb', line 33308

def facility
  @facility
end

#zonesArray<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>

Corresponds to the JSON property zones



33313
33314
33315
# File 'lib/google/apis/compute_beta/classes.rb', line 33313

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33320
33321
33322
33323
# File 'lib/google/apis/compute_beta/classes.rb', line 33320

def update!(**args)
  @facility = args[:facility] if args.key?(:facility)
  @zones = args[:zones] if args.key?(:zones)
end