Class: Google::Apis::ComputeBeta::InterconnectGroupsGetOperationalStatusResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupsGetOperationalStatusResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response for the InterconnectGroupsGetOperationalStatusResponse.
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#result ⇒ Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatus
Request to get the status of the interconnect group with extra detail.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsGetOperationalStatusResponse
constructor
A new instance of InterconnectGroupsGetOperationalStatusResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsGetOperationalStatusResponse
Returns a new instance of InterconnectGroupsGetOperationalStatusResponse.
30646 30647 30648 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30646 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
30639 30640 30641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30639 def etag @etag end |
#result ⇒ Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatus
Request to get the status of the interconnect group with extra detail.
Corresponds to the JSON property result
30644 30645 30646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30644 def result @result end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30651 30652 30653 30654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30651 def update!(**args) @etag = args[:etag] if args.key?(:etag) @result = args[:result] if args.key?(:result) end |