Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



33921
33922
33923
# File 'lib/google/apis/compute_beta/classes.rb', line 33921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33878
33879
33880
# File 'lib/google/apis/compute_beta/classes.rb', line 33878

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33883
33884
33885
# File 'lib/google/apis/compute_beta/classes.rb', line 33883

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



33888
33889
33890
# File 'lib/google/apis/compute_beta/classes.rb', line 33888

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


33893
33894
33895
# File 'lib/google/apis/compute_beta/classes.rb', line 33893

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33903
33904
33905
# File 'lib/google/apis/compute_beta/classes.rb', line 33903

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33908
33909
33910
# File 'lib/google/apis/compute_beta/classes.rb', line 33908

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33914
33915
33916
# File 'lib/google/apis/compute_beta/classes.rb', line 33914

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33919
33920
33921
# File 'lib/google/apis/compute_beta/classes.rb', line 33919

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33926
33927
33928
33929
33930
33931
33932
33933
33934
33935
# File 'lib/google/apis/compute_beta/classes.rb', line 33926

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end