Class: Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatusInterconnectStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The status of one Interconnect in the group. The order is arbitrary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatusInterconnectStatus

Returns a new instance of InterconnectGroupsOperationalStatusInterconnectStatus.



32655
32656
32657
# File 'lib/google/apis/compute_beta/classes.rb', line 32655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. Whether the Interconnect is enabled. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


32634
32635
32636
# File 'lib/google/apis/compute_beta/classes.rb', line 32634

def admin_enabled
  @admin_enabled
end

#diagnosticsGoogle::Apis::ComputeBeta::InterconnectDiagnostics

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection. Corresponds to the JSON property diagnostics



32642
32643
32644
# File 'lib/google/apis/compute_beta/classes.rb', line 32642

def diagnostics
  @diagnostics
end

#interconnectString

Output only. The URL of the Interconnect being described. Corresponds to the JSON property interconnect

Returns:

  • (String)


32647
32648
32649
# File 'lib/google/apis/compute_beta/classes.rb', line 32647

def interconnect
  @interconnect
end

#is_activeString

Output only. Whether this interconnect is participating in the redundant configuration. Corresponds to the JSON property isActive

Returns:

  • (String)


32653
32654
32655
# File 'lib/google/apis/compute_beta/classes.rb', line 32653

def is_active
  @is_active
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32660
32661
32662
32663
32664
32665
# File 'lib/google/apis/compute_beta/classes.rb', line 32660

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @is_active = args[:is_active] if args.key?(:is_active)
end