Class: Google::Apis::ComputeBeta::InterconnectMacsec
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectMacsec
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router.
Instance Attribute Summary collapse
-
#fail_open ⇒ Boolean
(also: #fail_open?)
If set to true, the Interconnect connection is configured with ashould-secure MACsec security policy, that allows the Google router to fallback to cleartext traffic if the MKA session cannot be established.
-
#pre_shared_keys ⇒ Array<Google::Apis::ComputeBeta::InterconnectMacsecPreSharedKey>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectMacsec
constructor
A new instance of InterconnectMacsec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectMacsec
Returns a new instance of InterconnectMacsec.
31412 31413 31414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31412 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fail_open ⇒ Boolean Also known as: fail_open?
If set to true, the Interconnect connection is configured with ashould-secure
MACsec security policy, that allows the Google
router to fallback to cleartext traffic if the MKA session cannot be
established. By default, the Interconnect connection is configured with amust-
secure security policy that drops all traffic if the
MKA session cannot be established with your router.
Corresponds to the JSON property failOpen
31400 31401 31402 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31400 def fail_open @fail_open end |
#pre_shared_keys ⇒ Array<Google::Apis::ComputeBeta::InterconnectMacsecPreSharedKey>
Required. A keychain placeholder describing a set of named key objects
along with their start times. A MACsec CKN/CAK is generated for each
key in the key chain. Google router automatically picks the key with
the most recent startTime when establishing or re-establishing a MACsec
secure link.
Corresponds to the JSON property preSharedKeys
31410 31411 31412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31410 def pre_shared_keys @pre_shared_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31417 31418 31419 31420 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31417 def update!(**args) @fail_open = args[:fail_open] if args.key?(:fail_open) @pre_shared_keys = args[:pre_shared_keys] if args.key?(:pre_shared_keys) end |