Class: Google::Apis::ComputeBeta::InterconnectMacsecConfigPreSharedKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectMacsecConfigPreSharedKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
Instance Attribute Summary collapse
-
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
-
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
-
#name ⇒ String
User provided name for this pre-shared key.
-
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
constructor
A new instance of InterconnectMacsecConfigPreSharedKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
Returns a new instance of InterconnectMacsecConfigPreSharedKey.
34349 34350 34351 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
Corresponds to the JSON property cak
34332 34333 34334 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34332 def cak @cak end |
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
Corresponds to the JSON property ckn
34337 34338 34339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34337 def ckn @ckn end |
#name ⇒ String
User provided name for this pre-shared key.
Corresponds to the JSON property name
34342 34343 34344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34342 def name @name end |
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Corresponds to the JSON property startTime
34347 34348 34349 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34347 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34354 34355 34356 34357 34358 34359 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34354 def update!(**args) @cak = args[:cak] if args.key?(:cak) @ckn = args[:ckn] if args.key?(:ckn) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |