Class: Google::Apis::ComputeBeta::InterconnectMacsecPreSharedKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectMacsecPreSharedKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
Instance Attribute Summary collapse
-
#name ⇒ String
Required.
-
#start_time ⇒ String
A RFC3339 timestamp on or after which the key is valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectMacsecPreSharedKey
constructor
A new instance of InterconnectMacsecPreSharedKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectMacsecPreSharedKey
Returns a new instance of InterconnectMacsecPreSharedKey.
34726 34727 34728 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34726 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Required. A name for this pre-shared key.
The name must be 1-63 characters long, and comply withRFC1035. Specifically,
the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be
a dash.
Corresponds to the JSON property name
34714 34715 34716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34714 def name @name end |
#start_time ⇒ String
A RFC3339 timestamp on or after which the key is
valid. startTime can be in the future. If the keychain has a single
key, startTime can be omitted. If the keychain has multiple keys,
startTime is mandatory for each key. The start times of keys must be in
increasing order. The start times of two consecutive keys must be
at least 6 hours apart.
Corresponds to the JSON property startTime
34724 34725 34726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34724 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34731 34732 34733 34734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34731 def update!(**args) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |