Class: Google::Apis::ComputeBeta::InterconnectOutageNotification
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectOutageNotification
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Description of a planned outage on this Interconnect.
Instance Attribute Summary collapse
-
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
-
#description ⇒ String
A description about the purpose of the outage.
-
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix epoch).
-
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:.
-
#name ⇒ String
Unique identifier for this outage notification.
-
#source ⇒ String
The party that generated this notification, which can take the following value:.
-
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix epoch).
-
#state ⇒ String
State of this notification, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectOutageNotification
constructor
A new instance of InterconnectOutageNotification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectOutageNotification
Returns a new instance of InterconnectOutageNotification.
34469 34470 34471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34469 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit
IDs that will be affected.
Corresponds to the JSON property affectedCircuits
34408 34409 34410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34408 def affected_circuits @affected_circuits end |
#description ⇒ String
A description about the purpose of the outage.
Corresponds to the JSON property description
34413 34414 34415 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34413 def description @description end |
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property endTime
34419 34420 34421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34419 def end_time @end_time end |
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:
- OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
- PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
should remain up, but with reduced bandwidth.
Note that the versions of this enum prefixed with "IT_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
issueType
34432 34433 34434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34432 def issue_type @issue_type end |
#name ⇒ String
Unique identifier for this outage notification.
Corresponds to the JSON property name
34437 34438 34439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34437 def name @name end |
#source ⇒ String
The party that generated this notification, which can take the following value:
- GOOGLE: this notification as generated by Google.
Note that the value of NSRC_GOOGLE has been deprecated in favor of
GOOGLE.
Corresponds to the JSON property
source
34447 34448 34449 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34447 def source @source end |
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property startTime
34453 34454 34455 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34453 def start_time @start_time end |
#state ⇒ String
State of this notification, which can take one of the following values:
- ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
- CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
- COMPLETED: The outage associated with this notification is complete.
Note that the versions of this enum prefixed with "NS_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
state
34467 34468 34469 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34467 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34474 34475 34476 34477 34478 34479 34480 34481 34482 34483 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34474 def update!(**args) @affected_circuits = args[:affected_circuits] if args.key?(:affected_circuits) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @issue_type = args[:issue_type] if args.key?(:issue_type) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |