Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationConstraints
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectRemoteLocationConstraints
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#port_pair_remote_location ⇒ String
Output only.
-
#port_pair_vlan ⇒ String
Output only.
-
#subnet_length_range ⇒ Google::Apis::ComputeBeta::InterconnectRemoteLocationConstraintsSubnetLengthRange
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocationConstraints
constructor
A new instance of InterconnectRemoteLocationConstraints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocationConstraints
Returns a new instance of InterconnectRemoteLocationConstraints.
32844 32845 32846 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32844 def initialize(**args) update!(**args) end |
Instance Attribute Details
#port_pair_remote_location ⇒ String
Output only. [Output Only] Port pair remote location constraints, which can
take one
of the following values: PORT_PAIR_UNCONSTRAINED_REMOTE_LOCATION,
PORT_PAIR_MATCHING_REMOTE_LOCATION.
Google Cloud API refers only to individual ports, but the UI uses this
field when ordering a pair of ports, to prevent users from accidentally
ordering something that is incompatible with their cloud provider.
Specifically, when ordering a redundant pair of Cross-Cloud Interconnect
ports, and one of them uses a remote location with
portPairMatchingRemoteLocation set to matching, the UI requires that
both ports use the same remote location.
Corresponds to the JSON property portPairRemoteLocation
32820 32821 32822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32820 def port_pair_remote_location @port_pair_remote_location end |
#port_pair_vlan ⇒ String
Output only. [Output Only] Port pair VLAN constraints, which can take one of
the
following values: PORT_PAIR_UNCONSTRAINED_VLAN, PORT_PAIR_MATCHING_VLAN
Corresponds to the JSON property portPairVlan
32827 32828 32829 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32827 def port_pair_vlan @port_pair_vlan end |
#subnet_length_range ⇒ Google::Apis::ComputeBeta::InterconnectRemoteLocationConstraintsSubnetLengthRange
Output only. [Output Only]
[min-length, max-length]
The minimum and maximum value (inclusive) for the IPv4 subnet
length.
For example, an interconnectRemoteLocation for Azure has min: 30,
max:
30 because Azure requires /30 subnets.
This range specifies the values supported by both cloud providers.
Interconnect currently supports /29 and /30 IPv4 subnet lengths. If a
remote cloud has no constraint on IPv4 subnet length, the range would
thus be min: 29, max: 30.
Corresponds to the JSON property subnetLengthRange
32842 32843 32844 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32842 def subnet_length_range @subnet_length_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32849 32850 32851 32852 32853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32849 def update!(**args) @port_pair_remote_location = args[:port_pair_remote_location] if args.key?(:port_pair_remote_location) @port_pair_vlan = args[:port_pair_vlan] if args.key?(:port_pair_vlan) @subnet_length_range = args[:subnet_length_range] if args.key?(:subnet_length_range) end |