Class: Google::Apis::ComputeBeta::LicenseParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::LicenseParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Additional license params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicenseParams
constructor
A new instance of LicenseParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicenseParams
Returns a new instance of LicenseParams.
35729 35730 35731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the license. Tag keys and
values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
35727 35728 35729 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35727 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35734 35735 35736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35734 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |