Class: Google::Apis::ComputeBeta::LicenseResourceRequirements

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicenseResourceRequirements

Returns a new instance of LicenseResourceRequirements.



32462
32463
32464
# File 'lib/google/apis/compute_beta/classes.rb', line 32462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_guest_cpu_countFixnum

[Input Only] Deprecated. This field no longer reflects the minimum number of guest cpus required to use the Instance. Corresponds to the JSON property minGuestCpuCount

Returns:

  • (Fixnum)


32454
32455
32456
# File 'lib/google/apis/compute_beta/classes.rb', line 32454

def min_guest_cpu_count
  @min_guest_cpu_count
end

#min_memory_mbFixnum

[Input Only] Deprecated. This field no longer reflects the minimum memory required to use the Instance. Corresponds to the JSON property minMemoryMb

Returns:

  • (Fixnum)


32460
32461
32462
# File 'lib/google/apis/compute_beta/classes.rb', line 32460

def min_memory_mb
  @min_memory_mb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32467
32468
32469
32470
# File 'lib/google/apis/compute_beta/classes.rb', line 32467

def update!(**args)
  @min_guest_cpu_count = args[:min_guest_cpu_count] if args.key?(:min_guest_cpu_count)
  @min_memory_mb = args[:min_memory_mb] if args.key?(:min_memory_mb)
end