Class: Google::Apis::ComputeBeta::LocalDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocalDisk

Returns a new instance of LocalDisk.



35874
35875
35876
# File 'lib/google/apis/compute_beta/classes.rb', line 35874

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_countFixnum

Specifies the number of such disks. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


35859
35860
35861
# File 'lib/google/apis/compute_beta/classes.rb', line 35859

def disk_count
  @disk_count
end

#disk_size_gbFixnum

Specifies the size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


35864
35865
35866
# File 'lib/google/apis/compute_beta/classes.rb', line 35864

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Specifies the desired disk type on the node. This disk type must be a local storage type (e.g.: local-ssd). Note that for nodeTemplates, this should be the name of the disk type and not its URL. Corresponds to the JSON property diskType

Returns:

  • (String)


35872
35873
35874
# File 'lib/google/apis/compute_beta/classes.rb', line 35872

def disk_type
  @disk_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35879
35880
35881
35882
35883
# File 'lib/google/apis/compute_beta/classes.rb', line 35879

def update!(**args)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
end