Class: Google::Apis::ComputeBeta::LocalizedMessage
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::LocalizedMessage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
Instance Attribute Summary collapse
-
#locale ⇒ String
The locale used following the specification defined at https://www.rfc-editor.org/rfc/bcp/bcp47.txt.
-
#message ⇒ String
The localized error message in the above locale.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LocalizedMessage
constructor
A new instance of LocalizedMessage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LocalizedMessage
Returns a new instance of LocalizedMessage.
32642 32643 32644 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locale ⇒ String
The locale used following the specification defined at
https://www.rfc-editor.org/rfc/bcp/bcp47.txt.
Examples are: "en-US", "fr-CH", "es-MX"
Corresponds to the JSON property locale
32635 32636 32637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32635 def locale @locale end |
#message ⇒ String
The localized error message in the above locale.
Corresponds to the JSON property message
32640 32641 32642 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32640 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32647 32648 32649 32650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32647 def update!(**args) @locale = args[:locale] if args.key?(:locale) @message = args[:message] if args.key?(:message) end |