Class: Google::Apis::ComputeBeta::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



36594
36595
36596
# File 'lib/google/apis/compute_beta/classes.rb', line 36594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36561
36562
36563
# File 'lib/google/apis/compute_beta/classes.rb', line 36561

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



36566
36567
36568
# File 'lib/google/apis/compute_beta/classes.rb', line 36566

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


36572
36573
36574
# File 'lib/google/apis/compute_beta/classes.rb', line 36572

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36582
36583
36584
# File 'lib/google/apis/compute_beta/classes.rb', line 36582

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36587
36588
36589
# File 'lib/google/apis/compute_beta/classes.rb', line 36587

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36592
36593
36594
# File 'lib/google/apis/compute_beta/classes.rb', line 36592

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36599
36600
36601
36602
36603
36604
36605
36606
# File 'lib/google/apis/compute_beta/classes.rb', line 36599

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end