Class: Google::Apis::ComputeBeta::MachineType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.

Defined Under Namespace

Classes: Accelerator

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineType

Returns a new instance of MachineType.



36815
36816
36817
# File 'lib/google/apis/compute_beta/classes.rb', line 36815

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeBeta::MachineType::Accelerator>

[Output Only] A list of accelerator configurations assigned to this machine type. Corresponds to the JSON property accelerators



36729
36730
36731
# File 'lib/google/apis/compute_beta/classes.rb', line 36729

def accelerators
  @accelerators
end

#architectureString

[Output Only] The architecture of the machine type. Corresponds to the JSON property architecture

Returns:

  • (String)


36734
36735
36736
# File 'lib/google/apis/compute_beta/classes.rb', line 36734

def architecture
  @architecture
end

#bundled_local_ssdsGoogle::Apis::ComputeBeta::BundledLocalSsds

[Output Only] The configuration of bundled local SSD for the machine type. Corresponds to the JSON property bundledLocalSsds



36739
36740
36741
# File 'lib/google/apis/compute_beta/classes.rb', line 36739

def bundled_local_ssds
  @bundled_local_ssds
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


36745
36746
36747
# File 'lib/google/apis/compute_beta/classes.rb', line 36745

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeBeta::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



36750
36751
36752
# File 'lib/google/apis/compute_beta/classes.rb', line 36750

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


36755
36756
36757
# File 'lib/google/apis/compute_beta/classes.rb', line 36755

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the instance. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


36761
36762
36763
# File 'lib/google/apis/compute_beta/classes.rb', line 36761

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


36767
36768
36769
# File 'lib/google/apis/compute_beta/classes.rb', line 36767

def id
  @id
end

#is_shared_cpuBoolean Also known as: is_shared_cpu?

[Output Only] Whether this machine type has a shared CPU. SeeShared-core machine types for more information. Corresponds to the JSON property isSharedCpu

Returns:

  • (Boolean)


36774
36775
36776
# File 'lib/google/apis/compute_beta/classes.rb', line 36774

def is_shared_cpu
  @is_shared_cpu
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#machineType for machine types. Corresponds to the JSON property kind

Returns:

  • (String)


36781
36782
36783
# File 'lib/google/apis/compute_beta/classes.rb', line 36781

def kind
  @kind
end

#maximum_persistent_disksFixnum

[Output Only] Maximum persistent disks allowed. Corresponds to the JSON property maximumPersistentDisks

Returns:

  • (Fixnum)


36786
36787
36788
# File 'lib/google/apis/compute_beta/classes.rb', line 36786

def maximum_persistent_disks
  @maximum_persistent_disks
end

#maximum_persistent_disks_size_gbFixnum

[Output Only] Maximum total persistent disks size (GB) allowed. Corresponds to the JSON property maximumPersistentDisksSizeGb

Returns:

  • (Fixnum)


36791
36792
36793
# File 'lib/google/apis/compute_beta/classes.rb', line 36791

def maximum_persistent_disks_size_gb
  @maximum_persistent_disks_size_gb
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the instance, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


36797
36798
36799
# File 'lib/google/apis/compute_beta/classes.rb', line 36797

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


36802
36803
36804
# File 'lib/google/apis/compute_beta/classes.rb', line 36802

def name
  @name
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36807
36808
36809
# File 'lib/google/apis/compute_beta/classes.rb', line 36807

def self_link
  @self_link
end

#zoneString

[Output Only] The name of the zone where the machine type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


36813
36814
36815
# File 'lib/google/apis/compute_beta/classes.rb', line 36813

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36820
36821
36822
36823
36824
36825
36826
36827
36828
36829
36830
36831
36832
36833
36834
36835
36836
36837
# File 'lib/google/apis/compute_beta/classes.rb', line 36820

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @architecture = args[:architecture] if args.key?(:architecture)
  @bundled_local_ssds = args[:bundled_local_ssds] if args.key?(:bundled_local_ssds)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu)
  @kind = args[:kind] if args.key?(:kind)
  @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks)
  @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end