Class: Google::Apis::ComputeBeta::ManagedInstanceLastAttempt::Errors::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



37210
37211
37212
# File 'lib/google/apis/compute_beta/classes.rb', line 37210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


37188
37189
37190
# File 'lib/google/apis/compute_beta/classes.rb', line 37188

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeBeta::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



37197
37198
37199
# File 'lib/google/apis/compute_beta/classes.rb', line 37197

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


37203
37204
37205
# File 'lib/google/apis/compute_beta/classes.rb', line 37203

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


37208
37209
37210
# File 'lib/google/apis/compute_beta/classes.rb', line 37208

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37215
37216
37217
37218
37219
37220
# File 'lib/google/apis/compute_beta/classes.rb', line 37215

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end