Class: Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
List of disks to be attached to the instance.
-
#machine_type ⇒ String
Output only.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
-
#provisioning_model ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstancePropertiesFromFlexibilityPolicy
constructor
A new instance of ManagedInstancePropertiesFromFlexibilityPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstancePropertiesFromFlexibilityPolicy
Returns a new instance of ManagedInstancePropertiesFromFlexibilityPolicy.
36769 36770 36771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
List of disks to be attached to the instance.
Corresponds to the JSON property disks
36751 36752 36753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36751 def disks @disks end |
#machine_type ⇒ String
Output only. The machine type to be used for this instance.
Corresponds to the JSON property machineType
36756 36757 36758 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36756 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
36762 36763 36764 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36762 def min_cpu_platform @min_cpu_platform end |
#provisioning_model ⇒ String
Output only. The provisioning model to be used for this instance.
Corresponds to the JSON property provisioningModel
36767 36768 36769 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36767 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36774 36775 36776 36777 36778 36779 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36774 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |