Class: Google::Apis::ComputeBeta::MetadataFilterLabelMatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MetadataFilterLabelMatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of metadata label.
-
#value ⇒ String
The value of the label must match the specified value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataFilterLabelMatch
constructor
A new instance of MetadataFilterLabelMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataFilterLabelMatch
Returns a new instance of MetadataFilterLabelMatch.
38011 38012 38013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of metadata label.
The name can have a maximum length of 1024 characters and must be at
least 1 character long.
Corresponds to the JSON property name
38003 38004 38005 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38003 def name @name end |
#value ⇒ String
The value of the label must match the specified value.
value can have a maximum length of 1024 characters.
Corresponds to the JSON property value
38009 38010 38011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38009 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38016 38017 38018 38019 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38016 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |