Class: Google::Apis::ComputeBeta::Money
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Money
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Money
constructor
A new instance of Money.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Money
Returns a new instance of Money.
38047 38048 38049 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38047 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
38029 38030 38031 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38029 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
The value must be between -999,999,999 and +999,999,999 inclusive.
If units is positive, nanos must be positive or zero.
If units is zero, nanos can be positive, zero, or negative.
If units is negative, nanos must be negative or zero.
For example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
38039 38040 38041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38039 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount.
For example if currencyCode is "USD", then 1 unit is one US dollar.
Corresponds to the JSON property units
38045 38046 38047 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38045 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38052 38053 38054 38055 38056 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38052 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |