Class: Google::Apis::ComputeBeta::MultiMigStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigStatusAcceleratorTopology

Returns a new instance of MultiMigStatusAcceleratorTopology.



37961
37962
37963
# File 'lib/google/apis/compute_beta/classes.rb', line 37961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. [Output Only] Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


37948
37949
37950
# File 'lib/google/apis/compute_beta/classes.rb', line 37948

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_stateString

Output only. [Output Only] The state of the accelerator topology. Corresponds to the JSON property acceleratorTopologyState

Returns:

  • (String)


37953
37954
37955
# File 'lib/google/apis/compute_beta/classes.rb', line 37953

def accelerator_topology_state
  @accelerator_topology_state
end

#accelerator_topology_state_last_checkGoogle::Apis::ComputeBeta::MultiMigStatusAcceleratorTopologyAcceleratorTopologyStateLastCheck

Output only. [Output Only] The result of the latest accelerator topology state check. Corresponds to the JSON property acceleratorTopologyStateLastCheck



37959
37960
37961
# File 'lib/google/apis/compute_beta/classes.rb', line 37959

def accelerator_topology_state_last_check
  @accelerator_topology_state_last_check
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37966
37967
37968
37969
37970
# File 'lib/google/apis/compute_beta/classes.rb', line 37966

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_state = args[:accelerator_topology_state] if args.key?(:accelerator_topology_state)
  @accelerator_topology_state_last_check = args[:accelerator_topology_state_last_check] if args.key?(:accelerator_topology_state_last_check)
end