Class: Google::Apis::ComputeBeta::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



39412
39413
39414
# File 'lib/google/apis/compute_beta/classes.rb', line 39412

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39380
39381
39382
# File 'lib/google/apis/compute_beta/classes.rb', line 39380

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



39385
39386
39387
# File 'lib/google/apis/compute_beta/classes.rb', line 39385

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


39390
39391
39392
# File 'lib/google/apis/compute_beta/classes.rb', line 39390

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39400
39401
39402
# File 'lib/google/apis/compute_beta/classes.rb', line 39400

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39405
39406
39407
# File 'lib/google/apis/compute_beta/classes.rb', line 39405

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39410
39411
39412
# File 'lib/google/apis/compute_beta/classes.rb', line 39410

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39417
39418
39419
39420
39421
39422
39423
39424
# File 'lib/google/apis/compute_beta/classes.rb', line 39417

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end