Class: Google::Apis::ComputeBeta::NetworkEdgeSecurityService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Google Cloud Armor network edge security service resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityService

Returns a new instance of NetworkEdgeSecurityService.



39274
39275
39276
# File 'lib/google/apis/compute_beta/classes.rb', line 39274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


39204
39205
39206
# File 'lib/google/apis/compute_beta/classes.rb', line 39204

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


39210
39211
39212
# File 'lib/google/apis/compute_beta/classes.rb', line 39210

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a NetworkEdgeSecurityService. An up-to-date fingerprint must be provided in order to update the NetworkEdgeSecurityService, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a NetworkEdgeSecurityService. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


39222
39223
39224
# File 'lib/google/apis/compute_beta/classes.rb', line 39222

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


39229
39230
39231
# File 'lib/google/apis/compute_beta/classes.rb', line 39229

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# networkEdgeSecurityService for NetworkEdgeSecurityServices Corresponds to the JSON property kind

Returns:

  • (String)


39236
39237
39238
# File 'lib/google/apis/compute_beta/classes.rb', line 39236

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


39247
39248
39249
# File 'lib/google/apis/compute_beta/classes.rb', line 39247

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


39255
39256
39257
# File 'lib/google/apis/compute_beta/classes.rb', line 39255

def region
  @region
end

#security_policyString

The resource URL for the network edge security service associated with this network edge security service. Corresponds to the JSON property securityPolicy

Returns:

  • (String)


39261
39262
39263
# File 'lib/google/apis/compute_beta/classes.rb', line 39261

def security_policy
  @security_policy
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39266
39267
39268
# File 'lib/google/apis/compute_beta/classes.rb', line 39266

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


39272
39273
39274
# File 'lib/google/apis/compute_beta/classes.rb', line 39272

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39279
39280
39281
39282
39283
39284
39285
39286
39287
39288
39289
39290
# File 'lib/google/apis/compute_beta/classes.rb', line 39279

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end