Class: Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



39742
39743
39744
# File 'lib/google/apis/compute_beta/classes.rb', line 39742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39698
39699
39700
# File 'lib/google/apis/compute_beta/classes.rb', line 39698

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39703
39704
39705
# File 'lib/google/apis/compute_beta/classes.rb', line 39703

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



39708
39709
39710
# File 'lib/google/apis/compute_beta/classes.rb', line 39708

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


39715
39716
39717
# File 'lib/google/apis/compute_beta/classes.rb', line 39715

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39725
39726
39727
# File 'lib/google/apis/compute_beta/classes.rb', line 39725

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39730
39731
39732
# File 'lib/google/apis/compute_beta/classes.rb', line 39730

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39735
39736
39737
# File 'lib/google/apis/compute_beta/classes.rb', line 39735

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39740
39741
39742
# File 'lib/google/apis/compute_beta/classes.rb', line 39740

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39747
39748
39749
39750
39751
39752
39753
39754
39755
39756
# File 'lib/google/apis/compute_beta/classes.rb', line 39747

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end