Class: Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAppEngine

Returns a new instance of NetworkEndpointGroupAppEngine.



40380
40381
40382
# File 'lib/google/apis/compute_beta/classes.rb', line 40380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

Optional serving service. The service name is case-sensitive and must be 1-63 characters long. Example value: default, my-service. Corresponds to the JSON property service

Returns:

  • (String)


40354
40355
40356
# File 'lib/google/apis/compute_beta/classes.rb', line 40354

def service
  @service
end

#url_maskString

An URL mask is one of the main components of the Cloud Function. A template to parse service and version fields from a request URL. URL mask allows for routing to multiple App Engine services without having to create multiple Network Endpoint Groups and backend services. For example, the request URLsfoo1-dot-appname.appspot.com/v1 andfoo1-dot- appname.appspot.com/v2 can be backed by the same Serverless NEG with URL mask-dot-appname.appspot.com/. The URL mask will parse them to service = "foo1", version = "v1" and service = "foo1", version = "v2" respectively. Corresponds to the JSON property urlMask

Returns:

  • (String)


40370
40371
40372
# File 'lib/google/apis/compute_beta/classes.rb', line 40370

def url_mask
  @url_mask
end

#versionString

Optional serving version. The version name is case-sensitive and must be 1-100 characters long. Example value: v1, v2. Corresponds to the JSON property version

Returns:

  • (String)


40378
40379
40380
# File 'lib/google/apis/compute_beta/classes.rb', line 40378

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40385
40386
40387
40388
40389
# File 'lib/google/apis/compute_beta/classes.rb', line 40385

def update!(**args)
  @service = args[:service] if args.key?(:service)
  @url_mask = args[:url_mask] if args.key?(:url_mask)
  @version = args[:version] if args.key?(:version)
end