Class: Google::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#function ⇒ String
A user-defined name of the Cloud Function.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupCloudFunction
constructor
A new instance of NetworkEndpointGroupCloudFunction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupCloudFunction
Returns a new instance of NetworkEndpointGroupCloudFunction.
36388 36389 36390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#function ⇒ String
A user-defined name of the Cloud Function.
The function name is case-sensitive and must be 1-63
characters long.
Example value: func1.
Corresponds to the JSON property function
36372 36373 36374 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36372 def function @function end |
#url_mask ⇒ String
An URL
mask is one of the main components of the Cloud Function.
A template to parse function field from a request URL. URL
mask allows for routing to multiple Cloud Functions without having to
create multiple Network Endpoint Groups and backend services.
For example, request URLs mydomain.com/function1 andmydomain.com/function2 can
be backed by the same
Serverless NEG with URL mask /function = "function1" andfunction = "function2"
respectively.
Corresponds to the JSON property urlMask
36386 36387 36388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36386 def url_mask @url_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36393 36394 36395 36396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36393 def update!(**args) @function = args[:function] if args.key?(:function) @url_mask = args[:url_mask] if args.key?(:url_mask) end |