Class: Google::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Load balancing specific fields for network endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupLbNetworkEndpointGroup

Returns a new instance of NetworkEndpointGroupLbNetworkEndpointGroup.



40525
40526
40527
# File 'lib/google/apis/compute_beta/classes.rb', line 40525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_portFixnum

The default port used if the port number is not specified in the network endpoint. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified. [Deprecated] This field is deprecated. Corresponds to the JSON property defaultPort

Returns:

  • (Fixnum)


40496
40497
40498
# File 'lib/google/apis/compute_beta/classes.rb', line 40496

def default_port
  @default_port
end

#networkString

The URL of the network to which all network endpoints in the NEG belong. For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or NON_GCP_PRIVATE_IP_PORT, if this field is not specified, a default network will be used. This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or PRIVATE_SERVICE_CONNECT and for global NEGs. For all other network endpoint types, this field is required. [Deprecated] This field is deprecated. Corresponds to the JSON property network

Returns:

  • (String)


40509
40510
40511
# File 'lib/google/apis/compute_beta/classes.rb', line 40509

def network
  @network
end

#subnetworkString

Optional URL of the subnetwork to which all network endpoints in the NEG belong. [Deprecated] This field is deprecated. Corresponds to the JSON property subnetwork

Returns:

  • (String)


40516
40517
40518
# File 'lib/google/apis/compute_beta/classes.rb', line 40516

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the network endpoint group is located. [Deprecated] This field is deprecated. Corresponds to the JSON property zone

Returns:

  • (String)


40523
40524
40525
# File 'lib/google/apis/compute_beta/classes.rb', line 40523

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40530
40531
40532
40533
40534
40535
# File 'lib/google/apis/compute_beta/classes.rb', line 40530

def update!(**args)
  @default_port = args[:default_port] if args.key?(:default_port)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end