Class: Google::Apis::ComputeBeta::NetworkEndpointGroupPscData
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupPscData
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
Instance Attribute Summary collapse
-
#consumer_psc_address ⇒ String
Output only.
-
#producer_port ⇒ Fixnum
The psc producer port is used to connect PSC NEG with specific port on the PSC Producer side; should only be used for the PRIVATE_SERVICE_CONNECT NEG type Corresponds to the JSON property
producerPort. -
#psc_connection_id ⇒ Fixnum
Output only.
-
#psc_connection_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupPscData
constructor
A new instance of NetworkEndpointGroupPscData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupPscData
Returns a new instance of NetworkEndpointGroupPscData.
36657 36658 36659 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36657 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consumer_psc_address ⇒ String
Output only. [Output Only] Address allocated from given subnetwork for PSC.
This IP
address acts as a VIP for a PSC NEG, allowing it to act as an endpoint in
L7 PSC-XLB.
Corresponds to the JSON property consumerPscAddress
36636 36637 36638 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36636 def consumer_psc_address @consumer_psc_address end |
#producer_port ⇒ Fixnum
The psc producer port is used to connect PSC NEG with specific port on
the PSC Producer side; should only be used for the
PRIVATE_SERVICE_CONNECT NEG type
Corresponds to the JSON property producerPort
36643 36644 36645 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36643 def producer_port @producer_port end |
#psc_connection_id ⇒ Fixnum
Output only. [Output Only] The PSC connection id of the PSC Network Endpoint
Group
Consumer.
Corresponds to the JSON property pscConnectionId
36650 36651 36652 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36650 def psc_connection_id @psc_connection_id end |
#psc_connection_status ⇒ String
Output only. [Output Only] The connection status of the PSC Forwarding Rule.
Corresponds to the JSON property pscConnectionStatus
36655 36656 36657 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36655 def psc_connection_status @psc_connection_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36662 36663 36664 36665 36666 36667 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36662 def update!(**args) @consumer_psc_address = args[:consumer_psc_address] if args.key?(:consumer_psc_address) @producer_port = args[:producer_port] if args.key?(:producer_port) @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id) @psc_connection_status = args[:psc_connection_status] if args.key?(:psc_connection_status) end |