Class: Google::Apis::ComputeBeta::NetworkEndpointGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsScopedList

Returns a new instance of NetworkEndpointGroupsScopedList.



36964
36965
36966
# File 'lib/google/apis/compute_beta/classes.rb', line 36964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_endpoint_groupsArray<Google::Apis::ComputeBeta::NetworkEndpointGroup>

Output only. [Output Only] The list ofnetwork endpoint groups that are contained in this scope. Corresponds to the JSON property networkEndpointGroups



36955
36956
36957
# File 'lib/google/apis/compute_beta/classes.rb', line 36955

def network_endpoint_groups
  @network_endpoint_groups
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of network endpoint groups when the list is empty. Corresponds to the JSON property warning



36962
36963
36964
# File 'lib/google/apis/compute_beta/classes.rb', line 36962

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36969
36970
36971
36972
# File 'lib/google/apis/compute_beta/classes.rb', line 36969

def update!(**args)
  @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups)
  @warning = args[:warning] if args.key?(:warning)
end