Class: Google::Apis::ComputeBeta::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



41504
41505
41506
# File 'lib/google/apis/compute_beta/classes.rb', line 41504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41471
41472
41473
# File 'lib/google/apis/compute_beta/classes.rb', line 41471

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Network>

A list of Network resources. Corresponds to the JSON property items



41476
41477
41478
# File 'lib/google/apis/compute_beta/classes.rb', line 41476

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


41482
41483
41484
# File 'lib/google/apis/compute_beta/classes.rb', line 41482

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41492
41493
41494
# File 'lib/google/apis/compute_beta/classes.rb', line 41492

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41497
41498
41499
# File 'lib/google/apis/compute_beta/classes.rb', line 41497

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41502
41503
41504
# File 'lib/google/apis/compute_beta/classes.rb', line 41502

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41509
41510
41511
41512
41513
41514
41515
41516
# File 'lib/google/apis/compute_beta/classes.rb', line 41509

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end