Class: Google::Apis::ComputeBeta::NetworkPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPoliciesScopedList

Returns a new instance of NetworkPoliciesScopedList.



40059
40060
40061
# File 'lib/google/apis/compute_beta/classes.rb', line 40059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_policiesArray<Google::Apis::ComputeBeta::NetworkPolicy>

A list of network policies contained in this scope. Corresponds to the JSON property networkPolicies



40051
40052
40053
# File 'lib/google/apis/compute_beta/classes.rb', line 40051

def network_policies
  @network_policies
end

#warningGoogle::Apis::ComputeBeta::NetworkPoliciesScopedList::Warning

Informational warning which replaces the list of network policies when the list is empty. Corresponds to the JSON property warning



40057
40058
40059
# File 'lib/google/apis/compute_beta/classes.rb', line 40057

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40064
40065
40066
40067
# File 'lib/google/apis/compute_beta/classes.rb', line 40064

def update!(**args)
  @network_policies = args[:network_policies] if args.key?(:network_policies)
  @warning = args[:warning] if args.key?(:warning)
end