Class: Google::Apis::ComputeBeta::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



42126
42127
42128
# File 'lib/google/apis/compute_beta/classes.rb', line 42126

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42087
42088
42089
# File 'lib/google/apis/compute_beta/classes.rb', line 42087

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



42092
42093
42094
# File 'lib/google/apis/compute_beta/classes.rb', line 42092

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


42099
42100
42101
# File 'lib/google/apis/compute_beta/classes.rb', line 42099

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42109
42110
42111
# File 'lib/google/apis/compute_beta/classes.rb', line 42109

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42114
42115
42116
# File 'lib/google/apis/compute_beta/classes.rb', line 42114

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42119
42120
42121
# File 'lib/google/apis/compute_beta/classes.rb', line 42119

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42124
42125
42126
# File 'lib/google/apis/compute_beta/classes.rb', line 42124

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42131
42132
42133
42134
42135
42136
42137
42138
42139
# File 'lib/google/apis/compute_beta/classes.rb', line 42131

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end