Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a traffic classification rule that describes one or more match conditions along with the action to be taken when traffic matches this condition.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRule

Returns a new instance of NetworkPolicyTrafficClassificationRule.



42438
42439
42440
# File 'lib/google/apis/compute_beta/classes.rb', line 42438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionGoogle::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction

The Action to perform when the client connection triggers the rule. Corresponds to the JSON property action



42365
42366
42367
# File 'lib/google/apis/compute_beta/classes.rb', line 42365

def action
  @action
end

#descriptionString

An optional description for this resource. Corresponds to the JSON property description

Returns:

  • (String)


42370
42371
42372
# File 'lib/google/apis/compute_beta/classes.rb', line 42370

def description
  @description
end

#disabledBoolean Also known as: disabled?

Denotes whether the network policy rule is disabled. When set to true, the network policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the network policy rule will be enabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


42378
42379
42380
# File 'lib/google/apis/compute_beta/classes.rb', line 42378

def disabled
  @disabled
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# networkPolicyTrafficClassificationRule for network policy traffic classification rules Corresponds to the JSON property kind

Returns:

  • (String)


42386
42387
42388
# File 'lib/google/apis/compute_beta/classes.rb', line 42386

def kind
  @kind
end

#matchGoogle::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcher

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified. Corresponds to the JSON property match



42392
42393
42394
# File 'lib/google/apis/compute_beta/classes.rb', line 42392

def match
  @match
end

#priorityFixnum

An integer indicating the priority of a rule in the list. The priority must be a positive value between 1 and 2147482647. The priority values from 2147482648 to 2147483647 (1000) are reserved for system default network policy rules. Rules are evaluated from highest to lowest priority where 1 is the highest priority and 2147483647 is the lowest priority. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


42402
42403
42404
# File 'lib/google/apis/compute_beta/classes.rb', line 42402

def priority
  @priority
end

#rule_nameString

An optional name for the rule. This field is not a unique identifier and can be updated. Corresponds to the JSON property ruleName

Returns:

  • (String)


42408
42409
42410
# File 'lib/google/apis/compute_beta/classes.rb', line 42408

def rule_name
  @rule_name
end

#rule_tuple_countFixnum

Output only. [Output Only] Calculation of the complexity of a single network policy rule. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


42415
42416
42417
# File 'lib/google/apis/compute_beta/classes.rb', line 42415

def rule_tuple_count
  @rule_tuple_count
end

#target_secure_tagsArray<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleSecureTag>

A list of secure tags that controls which instances the traffic classification rule applies to. If targetSecureTag are specified, then the traffic classification rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the targetSecureTag are in INEFFECTIVE state, then this rule will be ignored. targetSecureTag may not be set at the same time as targetServiceAccounts. If neithertargetServiceAccounts nor targetSecureTag are specified, the traffic classification rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256. Corresponds to the JSON property targetSecureTags



42430
42431
42432
# File 'lib/google/apis/compute_beta/classes.rb', line 42430

def target_secure_tags
  @target_secure_tags
end

#target_service_accountsArray<String>

A list of service accounts indicating the sets of instances that are applied with this rule. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


42436
42437
42438
# File 'lib/google/apis/compute_beta/classes.rb', line 42436

def target_service_accounts
  @target_service_accounts
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42443
42444
42445
42446
42447
42448
42449
42450
42451
42452
42453
42454
# File 'lib/google/apis/compute_beta/classes.rb', line 42443

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @description = args[:description] if args.key?(:description)
  @disabled = args[:disabled] if args.key?(:disabled)
  @kind = args[:kind] if args.key?(:kind)
  @match = args[:match] if args.key?(:match)
  @priority = args[:priority] if args.key?(:priority)
  @rule_name = args[:rule_name] if args.key?(:rule_name)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @target_secure_tags = args[:target_secure_tags] if args.key?(:target_secure_tags)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
end