Class: Google::Apis::ComputeBeta::NetworksCancelRequestRemovePeeringRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworksCancelRequestRemovePeeringRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the peering, which should conform to RFC1035.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworksCancelRequestRemovePeeringRequest
constructor
A new instance of NetworksCancelRequestRemovePeeringRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworksCancelRequestRemovePeeringRequest
Returns a new instance of NetworksCancelRequestRemovePeeringRequest.
39201 39202 39203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39201 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the peering, which should conform to RFC1035.
Corresponds to the JSON property name
39199 39200 39201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39199 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39206 39207 39208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39206 def update!(**args) @name = args[:name] if args.key?(:name) end |