Class: Google::Apis::ComputeBeta::NetworksRequestRemovePeeringRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworksRequestRemovePeeringRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the peering, which should conform to RFC1035.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworksRequestRemovePeeringRequest
constructor
A new instance of NetworksRequestRemovePeeringRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworksRequestRemovePeeringRequest
Returns a new instance of NetworksRequestRemovePeeringRequest.
39359 39360 39361 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the peering, which should conform to RFC1035.
Corresponds to the JSON property name
39357 39358 39359 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39357 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39364 39365 39366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39364 def update!(**args) @name = args[:name] if args.key?(:name) end |