Class: Google::Apis::ComputeBeta::NetworksUpdatePeeringRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksUpdatePeeringRequest

Returns a new instance of NetworksUpdatePeeringRequest.



40768
40769
40770
# File 'lib/google/apis/compute_beta/classes.rb', line 40768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_peeringGoogle::Apis::ComputeBeta::NetworkPeering

A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering. Corresponds to the JSON property networkPeering



40766
40767
40768
# File 'lib/google/apis/compute_beta/classes.rb', line 40766

def network_peering
  @network_peering
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40773
40774
40775
# File 'lib/google/apis/compute_beta/classes.rb', line 40773

def update!(**args)
  @network_peering = args[:network_peering] if args.key?(:network_peering)
end