Class: Google::Apis::ComputeBeta::NodeGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroup

Returns a new instance of NodeGroup.



43569
43570
43571
# File 'lib/google/apis/compute_beta/classes.rb', line 43569

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_policyGoogle::Apis::ComputeBeta::NodeGroupAutoscalingPolicy

Specifies how autoscaling should behave. Corresponds to the JSON property autoscalingPolicy



43463
43464
43465
# File 'lib/google/apis/compute_beta/classes.rb', line 43463

def autoscaling_policy
  @autoscaling_policy
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


43469
43470
43471
# File 'lib/google/apis/compute_beta/classes.rb', line 43469

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


43475
43476
43477
# File 'lib/google/apis/compute_beta/classes.rb', line 43475

def description
  @description
end

#fingerprintString

Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


43481
43482
43483
# File 'lib/google/apis/compute_beta/classes.rb', line 43481

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


43488
43489
43490
# File 'lib/google/apis/compute_beta/classes.rb', line 43488

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup for node group. Corresponds to the JSON property kind

Returns:

  • (String)


43494
43495
43496
# File 'lib/google/apis/compute_beta/classes.rb', line 43494

def kind
  @kind
end

#location_hintString

An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate. Corresponds to the JSON property locationHint

Returns:

  • (String)


43503
43504
43505
# File 'lib/google/apis/compute_beta/classes.rb', line 43503

def location_hint
  @location_hint
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


43509
43510
43511
# File 'lib/google/apis/compute_beta/classes.rb', line 43509

def maintenance_interval
  @maintenance_interval
end

#maintenance_policyString

Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Corresponds to the JSON property maintenancePolicy

Returns:

  • (String)


43518
43519
43520
# File 'lib/google/apis/compute_beta/classes.rb', line 43518

def maintenance_policy
  @maintenance_policy
end

#maintenance_windowGoogle::Apis::ComputeBeta::NodeGroupMaintenanceWindow

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window. Corresponds to the JSON property maintenanceWindow



43524
43525
43526
# File 'lib/google/apis/compute_beta/classes.rb', line 43524

def maintenance_window
  @maintenance_window
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


43536
43537
43538
# File 'lib/google/apis/compute_beta/classes.rb', line 43536

def name
  @name
end

#node_templateString

URL of the node template to create the node group from. Corresponds to the JSON property nodeTemplate

Returns:

  • (String)


43541
43542
43543
# File 'lib/google/apis/compute_beta/classes.rb', line 43541

def node_template
  @node_template
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43546
43547
43548
# File 'lib/google/apis/compute_beta/classes.rb', line 43546

def self_link
  @self_link
end

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



43551
43552
43553
# File 'lib/google/apis/compute_beta/classes.rb', line 43551

def share_settings
  @share_settings
end

#sizeFixnum

Output only. [Output Only] The total number of nodes in the node group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


43556
43557
43558
# File 'lib/google/apis/compute_beta/classes.rb', line 43556

def size
  @size
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


43561
43562
43563
# File 'lib/google/apis/compute_beta/classes.rb', line 43561

def status
  @status
end

#zoneString

Output only. [Output Only] The name of the zone where the node group resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


43567
43568
43569
# File 'lib/google/apis/compute_beta/classes.rb', line 43567

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43574
43575
43576
43577
43578
43579
43580
43581
43582
43583
43584
43585
43586
43587
43588
43589
43590
43591
43592
# File 'lib/google/apis/compute_beta/classes.rb', line 43574

def update!(**args)
  @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @name = args[:name] if args.key?(:name)
  @node_template = args[:node_template] if args.key?(:node_template)
  @self_link = args[:self_link] if args.key?(:self_link)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size = args[:size] if args.key?(:size)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end