Class: Google::Apis::ComputeBeta::NodeGroupsSetNodeTemplateRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupsSetNodeTemplateRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#node_template ⇒ String
Full or partial URL of the node template resource to be updated for this node group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupsSetNodeTemplateRequest
constructor
A new instance of NodeGroupsSetNodeTemplateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupsSetNodeTemplateRequest
Returns a new instance of NodeGroupsSetNodeTemplateRequest.
42466 42467 42468 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#node_template ⇒ String
Full or partial URL of the node template resource to be updated for this
node group.
Corresponds to the JSON property nodeTemplate
42464 42465 42466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42464 def node_template @node_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42471 42472 42473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42471 def update!(**args) @node_template = args[:node_template] if args.key?(:node_template) end |