Class: Google::Apis::ComputeBeta::NodeType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeType

Returns a new instance of NodeType.



44944
44945
44946
# File 'lib/google/apis/compute_beta/classes.rb', line 44944

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_platformString

[Output Only] The CPU platform used by this node type. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


44875
44876
44877
# File 'lib/google/apis/compute_beta/classes.rb', line 44875

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


44881
44882
44883
# File 'lib/google/apis/compute_beta/classes.rb', line 44881

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeBeta::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



44886
44887
44888
# File 'lib/google/apis/compute_beta/classes.rb', line 44886

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


44891
44892
44893
# File 'lib/google/apis/compute_beta/classes.rb', line 44891

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the node type. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


44897
44898
44899
# File 'lib/google/apis/compute_beta/classes.rb', line 44897

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


44903
44904
44905
# File 'lib/google/apis/compute_beta/classes.rb', line 44903

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types. Corresponds to the JSON property kind

Returns:

  • (String)


44909
44910
44911
# File 'lib/google/apis/compute_beta/classes.rb', line 44909

def kind
  @kind
end

#local_ssd_gbFixnum

[Output Only] Local SSD available to the node type, defined in GB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


44914
44915
44916
# File 'lib/google/apis/compute_beta/classes.rb', line 44914

def local_ssd_gb
  @local_ssd_gb
end

#max_vmsFixnum

Output only. [Output Only] Maximum number of VMs that can be created for this node type. Corresponds to the JSON property maxVms

Returns:

  • (Fixnum)


44920
44921
44922
# File 'lib/google/apis/compute_beta/classes.rb', line 44920

def max_vms
  @max_vms
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the node type, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


44926
44927
44928
# File 'lib/google/apis/compute_beta/classes.rb', line 44926

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


44931
44932
44933
# File 'lib/google/apis/compute_beta/classes.rb', line 44931

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44936
44937
44938
# File 'lib/google/apis/compute_beta/classes.rb', line 44936

def self_link
  @self_link
end

#zoneString

Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


44942
44943
44944
# File 'lib/google/apis/compute_beta/classes.rb', line 44942

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44949
44950
44951
44952
44953
44954
44955
44956
44957
44958
44959
44960
44961
44962
44963
# File 'lib/google/apis/compute_beta/classes.rb', line 44949

def update!(**args)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @max_vms = args[:max_vms] if args.key?(:max_vms)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end