Class: Google::Apis::ComputeBeta::NotificationEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpoint

Returns a new instance of NotificationEndpoint.



45385
45386
45387
# File 'lib/google/apis/compute_beta/classes.rb', line 45385

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


45333
45334
45335
# File 'lib/google/apis/compute_beta/classes.rb', line 45333

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


45339
45340
45341
# File 'lib/google/apis/compute_beta/classes.rb', line 45339

def description
  @description
end

#grpc_settingsGoogle::Apis::ComputeBeta::NotificationEndpointGrpcSettings

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint. Corresponds to the JSON property grpcSettings



45345
45346
45347
# File 'lib/google/apis/compute_beta/classes.rb', line 45345

def grpc_settings
  @grpc_settings
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


45352
45353
45354
# File 'lib/google/apis/compute_beta/classes.rb', line 45352

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


45358
45359
45360
# File 'lib/google/apis/compute_beta/classes.rb', line 45358

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


45369
45370
45371
# File 'lib/google/apis/compute_beta/classes.rb', line 45369

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


45378
45379
45380
# File 'lib/google/apis/compute_beta/classes.rb', line 45378

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45383
45384
45385
# File 'lib/google/apis/compute_beta/classes.rb', line 45383

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45390
45391
45392
45393
45394
45395
45396
45397
45398
45399
# File 'lib/google/apis/compute_beta/classes.rb', line 45390

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @grpc_settings = args[:grpc_settings] if args.key?(:grpc_settings)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end