Class: Google::Apis::ComputeBeta::NotificationEndpointGrpcSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointGrpcSettings

Returns a new instance of NotificationEndpointGrpcSettings.



45173
45174
45175
# File 'lib/google/apis/compute_beta/classes.rb', line 45173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorityString

Optional. If specified, this field is used to set the authority header by the sender of notifications. See https://tools.ietf.org/html/rfc7540#section-8.1.2.3 Corresponds to the JSON property authority

Returns:

  • (String)


45144
45145
45146
# File 'lib/google/apis/compute_beta/classes.rb', line 45144

def authority
  @authority
end

#endpointString

Endpoint to which gRPC notifications are sent. This must be a valid gRPCLB DNS name. Corresponds to the JSON property endpoint

Returns:

  • (String)


45150
45151
45152
# File 'lib/google/apis/compute_beta/classes.rb', line 45150

def endpoint
  @endpoint
end

#payload_nameString

Optional. If specified, this field is used to populate the "name" field in gRPC requests. Corresponds to the JSON property payloadName

Returns:

  • (String)


45156
45157
45158
# File 'lib/google/apis/compute_beta/classes.rb', line 45156

def payload_name
  @payload_name
end

#resend_intervalGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property resendInterval



45164
45165
45166
# File 'lib/google/apis/compute_beta/classes.rb', line 45164

def resend_interval
  @resend_interval
end

#retry_duration_secFixnum

How much time (in seconds) is spent attempting notification retries until a successful response is received. Default is 30s. Limit is 20m (1200s). Must be a positive number. Corresponds to the JSON property retryDurationSec

Returns:

  • (Fixnum)


45171
45172
45173
# File 'lib/google/apis/compute_beta/classes.rb', line 45171

def retry_duration_sec
  @retry_duration_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45178
45179
45180
45181
45182
45183
45184
# File 'lib/google/apis/compute_beta/classes.rb', line 45178

def update!(**args)
  @authority = args[:authority] if args.key?(:authority)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @payload_name = args[:payload_name] if args.key?(:payload_name)
  @resend_interval = args[:resend_interval] if args.key?(:resend_interval)
  @retry_duration_sec = args[:retry_duration_sec] if args.key?(:retry_duration_sec)
end