Class: Google::Apis::ComputeBeta::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



45625
45626
45627
# File 'lib/google/apis/compute_beta/classes.rb', line 45625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45592
45593
45594
# File 'lib/google/apis/compute_beta/classes.rb', line 45592

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



45597
45598
45599
# File 'lib/google/apis/compute_beta/classes.rb', line 45597

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


45603
45604
45605
# File 'lib/google/apis/compute_beta/classes.rb', line 45603

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45613
45614
45615
# File 'lib/google/apis/compute_beta/classes.rb', line 45613

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45618
45619
45620
# File 'lib/google/apis/compute_beta/classes.rb', line 45618

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45623
45624
45625
# File 'lib/google/apis/compute_beta/classes.rb', line 45623

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45630
45631
45632
45633
45634
45635
45636
45637
# File 'lib/google/apis/compute_beta/classes.rb', line 45630

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end