Class: Google::Apis::ComputeBeta::Operation::Error::Error
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Operation::Error::Error
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: ErrorDetail
Instance Attribute Summary collapse
-
#code ⇒ String
[Output Only] The error type identifier for this error.
-
#error_details ⇒ Array<Google::Apis::ComputeBeta::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error details.
-
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
-
#message ⇒ String
[Output Only] An optional, human-readable error message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Error
constructor
A new instance of Error.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Error
Returns a new instance of Error.
41791 41792 41793 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41791 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
[Output Only] The error type identifier for this error.
Corresponds to the JSON property code
41769 41770 41771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41769 def code @code end |
#error_details ⇒ Array<Google::Apis::ComputeBeta::Operation::Error::Error::ErrorDetail>
[Output Only] An optional list of messages that contain the error
details. There is a set of defined message types to use for providing
details.The syntax depends on the error code. For example,
QuotaExceededInfo will have details when the error code is
QUOTA_EXCEEDED.
Corresponds to the JSON property errorDetails
41778 41779 41780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41778 def error_details @error_details end |
#location ⇒ String
[Output Only] Indicates the field in the request that caused the error.
This property is optional.
Corresponds to the JSON property location
41784 41785 41786 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41784 def location @location end |
#message ⇒ String
[Output Only] An optional, human-readable error message.
Corresponds to the JSON property message
41789 41790 41791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41789 def @message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41796 41797 41798 41799 41800 41801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41796 def update!(**args) @code = args[:code] if args.key?(:code) @error_details = args[:error_details] if args.key?(:error_details) @location = args[:location] if args.key?(:location) @message = args[:message] if args.key?(:message) end |