Class: Google::Apis::ComputeBeta::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



46278
46279
46280
# File 'lib/google/apis/compute_beta/classes.rb', line 46278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46239
46240
46241
# File 'lib/google/apis/compute_beta/classes.rb', line 46239

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



46244
46245
46246
# File 'lib/google/apis/compute_beta/classes.rb', line 46244

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


46251
46252
46253
# File 'lib/google/apis/compute_beta/classes.rb', line 46251

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46261
46262
46263
# File 'lib/google/apis/compute_beta/classes.rb', line 46261

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46266
46267
46268
# File 'lib/google/apis/compute_beta/classes.rb', line 46266

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46271
46272
46273
# File 'lib/google/apis/compute_beta/classes.rb', line 46271

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46276
46277
46278
# File 'lib/google/apis/compute_beta/classes.rb', line 46276

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46283
46284
46285
46286
46287
46288
46289
46290
46291
# File 'lib/google/apis/compute_beta/classes.rb', line 46283

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end