Class: Google::Apis::ComputeBeta::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



46633
46634
46635
# File 'lib/google/apis/compute_beta/classes.rb', line 46633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


46595
46596
46597
# File 'lib/google/apis/compute_beta/classes.rb', line 46595

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46600
46601
46602
# File 'lib/google/apis/compute_beta/classes.rb', line 46600

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



46605
46606
46607
# File 'lib/google/apis/compute_beta/classes.rb', line 46605

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46615
46616
46617
# File 'lib/google/apis/compute_beta/classes.rb', line 46615

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46620
46621
46622
# File 'lib/google/apis/compute_beta/classes.rb', line 46620

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46626
46627
46628
# File 'lib/google/apis/compute_beta/classes.rb', line 46626

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46631
46632
46633
# File 'lib/google/apis/compute_beta/classes.rb', line 46631

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46638
46639
46640
46641
46642
46643
46644
46645
46646
# File 'lib/google/apis/compute_beta/classes.rb', line 46638

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end