Class: Google::Apis::ComputeBeta::PacketIntervals
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketIntervals
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Next free: 7
Instance Attribute Summary collapse
-
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
-
#duration ⇒ String
From how long ago in the past these intervals were observed.
-
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
-
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
-
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
-
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketIntervals
constructor
A new instance of PacketIntervals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketIntervals
Returns a new instance of PacketIntervals.
46448 46449 46450 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46448 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
Corresponds to the JSON property avgMs
46421 46422 46423 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46421 def avg_ms @avg_ms end |
#duration ⇒ String
From how long ago in the past these intervals were observed.
Corresponds to the JSON property duration
46426 46427 46428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46426 def duration @duration end |
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
Corresponds to the JSON property maxMs
46431 46432 46433 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46431 def max_ms @max_ms end |
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
Corresponds to the JSON property minMs
46436 46437 46438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46436 def min_ms @min_ms end |
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
Corresponds to the JSON property numIntervals
46441 46442 46443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46441 def num_intervals @num_intervals end |
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Corresponds to the JSON property type
46446 46447 46448 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46446 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46453 46454 46455 46456 46457 46458 46459 46460 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46453 def update!(**args) @avg_ms = args[:avg_ms] if args.key?(:avg_ms) @duration = args[:duration] if args.key?(:duration) @max_ms = args[:max_ms] if args.key?(:max_ms) @min_ms = args[:min_ms] if args.key?(:min_ms) @num_intervals = args[:num_intervals] if args.key?(:num_intervals) @type = args[:type] if args.key?(:type) end |