Class: Google::Apis::ComputeBeta::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



47078
47079
47080
# File 'lib/google/apis/compute_beta/classes.rb', line 47078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47041
47042
47043
# File 'lib/google/apis/compute_beta/classes.rb', line 47041

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



47046
47047
47048
# File 'lib/google/apis/compute_beta/classes.rb', line 47046

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


47051
47052
47053
# File 'lib/google/apis/compute_beta/classes.rb', line 47051

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47061
47062
47063
# File 'lib/google/apis/compute_beta/classes.rb', line 47061

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47066
47067
47068
# File 'lib/google/apis/compute_beta/classes.rb', line 47066

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47071
47072
47073
# File 'lib/google/apis/compute_beta/classes.rb', line 47071

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47076
47077
47078
# File 'lib/google/apis/compute_beta/classes.rb', line 47076

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47083
47084
47085
47086
47087
47088
47089
47090
47091
# File 'lib/google/apis/compute_beta/classes.rb', line 47083

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end