Class: Google::Apis::ComputeBeta::PacketMirroringList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of PacketMirroring resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringList

Returns a new instance of PacketMirroringList.



46875
46876
46877
# File 'lib/google/apis/compute_beta/classes.rb', line 46875

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46842
46843
46844
# File 'lib/google/apis/compute_beta/classes.rb', line 46842

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PacketMirroring>

A list of PacketMirroring resources. Corresponds to the JSON property items



46847
46848
46849
# File 'lib/google/apis/compute_beta/classes.rb', line 46847

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


46853
46854
46855
# File 'lib/google/apis/compute_beta/classes.rb', line 46853

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46863
46864
46865
# File 'lib/google/apis/compute_beta/classes.rb', line 46863

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46868
46869
46870
# File 'lib/google/apis/compute_beta/classes.rb', line 46868

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PacketMirroringList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46873
46874
46875
# File 'lib/google/apis/compute_beta/classes.rb', line 46873

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46880
46881
46882
46883
46884
46885
46886
46887
# File 'lib/google/apis/compute_beta/classes.rb', line 46880

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end