Class: Google::Apis::ComputeBeta::PerInstanceConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PerInstanceConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Fingerprint of this per-instance config.
-
#name ⇒ String
The name of a per-instance configuration and its corresponding instance.
-
#preserved_state ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
-
#status ⇒ String
The status of applying this per-instance configuration on the corresponding managed instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PerInstanceConfig
constructor
A new instance of PerInstanceConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PerInstanceConfig
Returns a new instance of PerInstanceConfig.
47290 47291 47292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47290 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Fingerprint of this per-instance config. This field can be used in
optimistic locking. It is ignored when inserting a per-instance
config. An up-to-date fingerprint must be provided in order to update an
existing per-instance configuration or the field needs to be unset.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
47266 47267 47268 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47266 def fingerprint @fingerprint end |
#name ⇒ String
The name of a per-instance configuration and its corresponding instance.
Serves as a merge key during UpdatePerInstanceConfigs
operations, that is, if a per-instance configuration with the same name
exists then it will be updated, otherwise a new one will be created for the
VM instance with the same name. An attempt to create a per-instance
configuration for a VM instance that either doesn't exist or is not part
of the group will result in an error.
Corresponds to the JSON property name
47277 47278 47279 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47277 def name @name end |
#preserved_state ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedState
47282 47283 47284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47282 def preserved_state @preserved_state end |
#status ⇒ String
The status of applying this per-instance configuration on the corresponding
managed instance.
Corresponds to the JSON property status
47288 47289 47290 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47288 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47295 47296 47297 47298 47299 47300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47295 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @preserved_state = args[:preserved_state] if args.key?(:preserved_state) @status = args[:status] if args.key?(:status) end |