Class: Google::Apis::ComputeBeta::Policy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Policy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An Identity and Access Management (IAM) policy, which specifies access
controls for Google Cloud resources.
A Policy is a collection of bindings. A binding binds one or more
members, or principals, to a single role. Principals can be user
accounts, service accounts, Google groups, and domains (such as G Suite). A
role is a named list of permissions; each role can be an IAM predefined
role or a user-created custom role.
For some types of Google Cloud resources, a binding can also specify a
condition, which is a logical expression that allows access to a resource
only if the expression evaluates to true. A condition can add constraints
based on attributes of the request, the resource, or both. To learn which
resources support conditions in their IAM policies, see the
IAM documentation.
JSON example:
`
"bindings": [
`
"role": "roles/resourcemanager.organizationAdmin",
"members": [
"user:mike@example.com",
"group:admins@example.com",
"domain:google.com",
"serviceAccount:my-project-id@appspot.gserviceaccount.com"
]
`,
`
"role": "roles/resourcemanager.organizationViewer",
"members": [
"user:eve@example.com"
],
"condition": `
"title": "expirable access",
"description": "Does not grant access after Sep 2020",
"expression": "request.time < timestamp('2020-10-01T00:00:00.000Z')
",
`
`
],
"etag": "BwWWja0YfJA=",
"version": 3
`
YAML example:
bindings:
- members:
- user:mike@example.com
- group:admins@example.com
- domain:google.com
- serviceAccount:my-project-id@appspot.gserviceaccount.com
role: roles/resourcemanager.organizationAdmin
- members:
- user:eve@example.com
role: roles/resourcemanager.organizationViewer
condition:
title: expirable access
description: Does not grant access after Sep 2020
expression: request.time < timestamp('2020-10-01T00:00:00.000Z')
etag: BwWWja0YfJA=
version: 3
For a description of IAM and its features, see the IAM documentation.
Instance Attribute Summary collapse
-
#audit_configs ⇒ Array<Google::Apis::ComputeBeta::AuditConfig>
Specifies cloud audit logging configuration for this policy.
-
#bindings ⇒ Array<Google::Apis::ComputeBeta::Binding>
Associates a list of
members, or principals, with arole. -
#etag ⇒ String
etagis used for optimistic concurrency control as a way to help prevent simultaneous updates of a policy from overwriting each other. -
#version ⇒ Fixnum
Specifies the format of the policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Policy
constructor
A new instance of Policy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Policy
Returns a new instance of Policy.
43529 43530 43531 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43529 def initialize(**args) update!(**args) end |
Instance Attribute Details
#audit_configs ⇒ Array<Google::Apis::ComputeBeta::AuditConfig>
Specifies cloud audit logging configuration for this policy.
Corresponds to the JSON property auditConfigs
43475 43476 43477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43475 def audit_configs @audit_configs end |
#bindings ⇒ Array<Google::Apis::ComputeBeta::Binding>
Associates a list of members, or principals, with a role. Optionally,
may specify a condition that determines how and when the bindings are
applied. Each of the bindings must contain at least one principal.
The bindings in a Policy can refer to up to 1,500 principals; up to 250
of these principals can be Google groups. Each occurrence of a principal
counts towards these limits. For example, if the bindings grant 50
different roles to user:alice@example.com, and not to any other
principal, then you can add another 1,450 principals to the bindings in
the Policy.
Corresponds to the JSON property bindings
43488 43489 43490 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43488 def bindings @bindings end |
#etag ⇒ String
etag is used for optimistic concurrency control as a way to help
prevent simultaneous updates of a policy from overwriting each other.
It is strongly suggested that systems make use of the etag in the
read-modify-write cycle to perform policy updates in order to avoid race
conditions: An etag is returned in the response to getIamPolicy, and
systems are expected to put that etag in the request to setIamPolicy to
ensure that their change will be applied to the same version of the policy.
Important: If you use IAM Conditions, you must include the etag field
whenever you call setIamPolicy. If you omit this field, then IAM allows
you to overwrite a version 3 policy with a version 1 policy, and all of
the conditions in the version 3 policy are lost.
Corresponds to the JSON property etag
NOTE: Values are automatically base64 encoded/decoded in the client library.
43504 43505 43506 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43504 def etag @etag end |
#version ⇒ Fixnum
Specifies the format of the policy.
Valid values are 0, 1, and 3. Requests that specify an invalid value
are rejected.
Any operation that affects conditional role bindings must specify version
3. This requirement applies to the following operations:
- Getting a policy that includes a conditional role binding
- Adding a conditional role binding to a policy
- Changing a conditional role binding in a policy
- Removing any role binding, with or without a condition, from a policy
that includes conditions
Important: If you use IAM Conditions, you must include the
etagfield whenever you callsetIamPolicy. If you omit this field, then IAM allows you to overwrite a version3policy with a version1policy, and all of the conditions in the version3policy are lost. If a policy does not include any conditions, operations on that policy may specify any valid version or leave the field unset. To learn which resources support conditions in their IAM policies, see the IAM documentation. Corresponds to the JSON propertyversion
43527 43528 43529 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43527 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43534 43535 43536 43537 43538 43539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43534 def update!(**args) @audit_configs = args[:audit_configs] if args.key?(:audit_configs) @bindings = args[:bindings] if args.key?(:bindings) @etag = args[:etag] if args.key?(:etag) @version = args[:version] if args.key?(:version) end |