Class: Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreservedStatePreservedNetworkIp

Returns a new instance of PreservedStatePreservedNetworkIp.



48197
48198
48199
# File 'lib/google/apis/compute_beta/classes.rb', line 48197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful IPs will never be released during autohealing, update or VM instance recreate operations. This flag is used to configure if the IP reservation should be deleted after it is no longer used by the group, e.g. when the given instance or the whole group is deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


48190
48191
48192
# File 'lib/google/apis/compute_beta/classes.rb', line 48190

def auto_delete
  @auto_delete
end

#ip_addressGoogle::Apis::ComputeBeta::PreservedStatePreservedNetworkIpIpAddress

Ip address representation Corresponds to the JSON property ipAddress



48195
48196
48197
# File 'lib/google/apis/compute_beta/classes.rb', line 48195

def ip_address
  @ip_address
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48202
48203
48204
48205
# File 'lib/google/apis/compute_beta/classes.rb', line 48202

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
end