Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A public advertised prefix represents an aggregated IP prefix or netblock which customers bring to cloud. The IP prefix is a single unit of route advertisement and is announced globally to the internet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefix

Returns a new instance of PublicAdvertisedPrefix.



48995
48996
48997
# File 'lib/google/apis/compute_beta/classes.rb', line 48995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#byoip_api_versionString

Output only. [Output Only] The version of BYOIP API. Corresponds to the JSON property byoipApiVersion

Returns:

  • (String)


48874
48875
48876
# File 'lib/google/apis/compute_beta/classes.rb', line 48874

def byoip_api_version
  @byoip_api_version
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


48880
48881
48882
# File 'lib/google/apis/compute_beta/classes.rb', line 48880

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


48886
48887
48888
# File 'lib/google/apis/compute_beta/classes.rb', line 48886

def description
  @description
end

#dns_verification_ipString

The address to be used for reverse DNS verification. Corresponds to the JSON property dnsVerificationIp

Returns:

  • (String)


48891
48892
48893
# File 'lib/google/apis/compute_beta/classes.rb', line 48891

def dns_verification_ip
  @dns_verification_ip
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicAdvertisedPrefix. An up-to-date fingerprint must be provided in order to update thePublicAdvertisedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicAdvertisedPrefix. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


48904
48905
48906
# File 'lib/google/apis/compute_beta/classes.rb', line 48904

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


48911
48912
48913
# File 'lib/google/apis/compute_beta/classes.rb', line 48911

def id
  @id
end

#ip_cidr_rangeString

The address range, in CIDR format, represented by this public advertised prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


48917
48918
48919
# File 'lib/google/apis/compute_beta/classes.rb', line 48917

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

The internet access type for IPv6 Public Advertised Prefixes. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


48922
48923
48924
# File 'lib/google/apis/compute_beta/classes.rb', line 48922

def ipv6_access_type
  @ipv6_access_type
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


48928
48929
48930
# File 'lib/google/apis/compute_beta/classes.rb', line 48928

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


48939
48940
48941
# File 'lib/google/apis/compute_beta/classes.rb', line 48939

def name
  @name
end

#network_tierString

Network tier to be used for this prefix. All child delegated prefixes will inherit this field. If this field is not specified, it defaults to the network tier of the project that the PublicAdvertisedPrefix belongs to. Corresponds to the JSON property networkTier

Returns:

  • (String)


48946
48947
48948
# File 'lib/google/apis/compute_beta/classes.rb', line 48946

def network_tier
  @network_tier
end

#pdp_scopeString

Specifies how child public delegated prefix will be scoped. It could be one of following values:

  • REGIONAL: The public delegated prefix is regional only. The provisioning will take a few minutes.
  • GLOBAL: The public delegated prefix is global only. The provisioning will take ~4 weeks.
  • GLOBAL_AND_REGIONAL [output only]: The public delegated prefixes is BYOIP V1 legacy prefix. This is output only value and no longer supported in BYOIP V2. Corresponds to the JSON property pdpScope

Returns:

  • (String)


48961
48962
48963
# File 'lib/google/apis/compute_beta/classes.rb', line 48961

def pdp_scope
  @pdp_scope
end

#public_delegated_prefixsArray<Google::Apis::ComputeBeta::PublicAdvertisedPrefixPublicDelegatedPrefix>

Output only. [Output Only] The list of public delegated prefixes that exist for this public advertised prefix. Corresponds to the JSON property publicDelegatedPrefixs



48968
48969
48970
# File 'lib/google/apis/compute_beta/classes.rb', line 48968

def public_delegated_prefixs
  @public_delegated_prefixs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48973
48974
48975
# File 'lib/google/apis/compute_beta/classes.rb', line 48973

def self_link
  @self_link
end

#shared_secretString

[Output Only] The shared secret to be used for reverse DNS verification. Corresponds to the JSON property sharedSecret

Returns:

  • (String)


48978
48979
48980
# File 'lib/google/apis/compute_beta/classes.rb', line 48978

def shared_secret
  @shared_secret
end

#statusString

The status of the public advertised prefix. Possible values include:

  • INITIAL: RPKI validation is complete.
  • PTR_CONFIGURED: User has configured the PTR.
  • VALIDATED: Reverse DNS lookup is successful.
  • REVERSE_DNS_LOOKUP_FAILED: Reverse DNS lookup failed.
  • PREFIX_CONFIGURATION_IN_PROGRESS: The prefix is being configured.
  • PREFIX_CONFIGURATION_COMPLETE: The prefix is fully configured.
  • PREFIX_REMOVAL_IN_PROGRESS: The prefix is being removed. Corresponds to the JSON property status

Returns:

  • (String)


48993
48994
48995
# File 'lib/google/apis/compute_beta/classes.rb', line 48993

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49000
49001
49002
49003
49004
49005
49006
49007
49008
49009
49010
49011
49012
49013
49014
49015
49016
49017
# File 'lib/google/apis/compute_beta/classes.rb', line 49000

def update!(**args)
  @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dns_verification_ip = args[:dns_verification_ip] if args.key?(:dns_verification_ip)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network_tier = args[:network_tier] if args.key?(:network_tier)
  @pdp_scope = args[:pdp_scope] if args.key?(:pdp_scope)
  @public_delegated_prefixs = args[:public_delegated_prefixs] if args.key?(:public_delegated_prefixs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @shared_secret = args[:shared_secret] if args.key?(:shared_secret)
  @status = args[:status] if args.key?(:status)
end