Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixPublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a CIDR range which can be used to assign addresses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix

Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.



48780
48781
48782
# File 'lib/google/apis/compute_beta/classes.rb', line 48780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_rangeString

The IP address range of the public delegated prefix Corresponds to the JSON property ipRange

Returns:

  • (String)


48754
48755
48756
# File 'lib/google/apis/compute_beta/classes.rb', line 48754

def ip_range
  @ip_range
end

#nameString

The name of the public delegated prefix Corresponds to the JSON property name

Returns:

  • (String)


48759
48760
48761
# File 'lib/google/apis/compute_beta/classes.rb', line 48759

def name
  @name
end

#projectString

The project number of the public delegated prefix Corresponds to the JSON property project

Returns:

  • (String)


48764
48765
48766
# File 'lib/google/apis/compute_beta/classes.rb', line 48764

def project
  @project
end

#regionString

The region of the public delegated prefix if it is regional. If absent, the prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


48770
48771
48772
# File 'lib/google/apis/compute_beta/classes.rb', line 48770

def region
  @region
end

#statusString

The status of the public delegated prefix. Possible values are: INITIALIZING: The public delegated prefix is being initialized and addresses cannot be created yet. ANNOUNCED: The public delegated prefix is active. Corresponds to the JSON property status

Returns:

  • (String)


48778
48779
48780
# File 'lib/google/apis/compute_beta/classes.rb', line 48778

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48785
48786
48787
48788
48789
48790
48791
# File 'lib/google/apis/compute_beta/classes.rb', line 48785

def update!(**args)
  @ip_range = args[:ip_range] if args.key?(:ip_range)
  @name = args[:name] if args.key?(:name)
  @project = args[:project] if args.key?(:project)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end