Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



49568
49569
49570
# File 'lib/google/apis/compute_beta/classes.rb', line 49568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49534
49535
49536
# File 'lib/google/apis/compute_beta/classes.rb', line 49534

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



49539
49540
49541
# File 'lib/google/apis/compute_beta/classes.rb', line 49539

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


49546
49547
49548
# File 'lib/google/apis/compute_beta/classes.rb', line 49546

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49556
49557
49558
# File 'lib/google/apis/compute_beta/classes.rb', line 49556

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49561
49562
49563
# File 'lib/google/apis/compute_beta/classes.rb', line 49561

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49566
49567
49568
# File 'lib/google/apis/compute_beta/classes.rb', line 49566

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49573
49574
49575
49576
49577
49578
49579
49580
# File 'lib/google/apis/compute_beta/classes.rb', line 49573

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end