Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixPublicDelegatedSubPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a sub PublicDelegatedPrefix.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix

Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.



49729
49730
49731
# File 'lib/google/apis/compute_beta/classes.rb', line 49729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocatable_prefix_lengthFixnum

The allocatable prefix length supported by this PublicDelegatedSubPrefix. Corresponds to the JSON property allocatablePrefixLength

Returns:

  • (Fixnum)


49660
49661
49662
# File 'lib/google/apis/compute_beta/classes.rb', line 49660

def allocatable_prefix_length
  @allocatable_prefix_length
end

#delegatee_projectString

Name of the project scoping this PublicDelegatedSubPrefix. Corresponds to the JSON property delegateeProject

Returns:

  • (String)


49665
49666
49667
# File 'lib/google/apis/compute_beta/classes.rb', line 49665

def delegatee_project
  @delegatee_project
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


49671
49672
49673
# File 'lib/google/apis/compute_beta/classes.rb', line 49671

def description
  @description
end

#enable_enhanced_ipv4_allocationBoolean Also known as: enable_enhanced_ipv4_allocation?

Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only. Corresponds to the JSON property enableEnhancedIpv4Allocation

Returns:

  • (Boolean)


49677
49678
49679
# File 'lib/google/apis/compute_beta/classes.rb', line 49677

def enable_enhanced_ipv4_allocation
  @enable_enhanced_ipv4_allocation
end

#ip_cidr_rangeString

The IP address range, in CIDR format, represented by this sub public delegated prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


49684
49685
49686
# File 'lib/google/apis/compute_beta/classes.rb', line 49684

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

Output only. [Output Only] The internet access type for IPv6 Public Delegated Sub Prefixes. Inherited from parent prefix. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


49691
49692
49693
# File 'lib/google/apis/compute_beta/classes.rb', line 49691

def ipv6_access_type
  @ipv6_access_type
end

#is_addressBoolean Also known as: is_address?

Whether the sub prefix is delegated to create Address resources in the delegatee project. Corresponds to the JSON property isAddress

Returns:

  • (Boolean)


49697
49698
49699
# File 'lib/google/apis/compute_beta/classes.rb', line 49697

def is_address
  @is_address
end

#modeString

The PublicDelegatedSubPrefix mode for IPv6 only. Corresponds to the JSON property mode

Returns:

  • (String)


49703
49704
49705
# File 'lib/google/apis/compute_beta/classes.rb', line 49703

def mode
  @mode
end

#nameString

The name of the sub public delegated prefix. Corresponds to the JSON property name

Returns:

  • (String)


49708
49709
49710
# File 'lib/google/apis/compute_beta/classes.rb', line 49708

def name
  @name
end

#purposeString

Output only. [Output Only] The purpose of the sub public delegated prefix. Inherited from parent prefix. Corresponds to the JSON property purpose

Returns:

  • (String)


49715
49716
49717
# File 'lib/google/apis/compute_beta/classes.rb', line 49715

def purpose
  @purpose
end

#regionString

Output only. [Output Only] The region of the sub public delegated prefix if it is regional. If absent, the sub prefix is global. Corresponds to the JSON property region

Returns:

  • (String)


49722
49723
49724
# File 'lib/google/apis/compute_beta/classes.rb', line 49722

def region
  @region
end

#statusString

Output only. [Output Only] The status of the sub public delegated prefix. Corresponds to the JSON property status

Returns:

  • (String)


49727
49728
49729
# File 'lib/google/apis/compute_beta/classes.rb', line 49727

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49734
49735
49736
49737
49738
49739
49740
49741
49742
49743
49744
49745
49746
49747
# File 'lib/google/apis/compute_beta/classes.rb', line 49734

def update!(**args)
  @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length)
  @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project)
  @description = args[:description] if args.key?(:description)
  @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @is_address = args[:is_address] if args.key?(:is_address)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @status = args[:status] if args.key?(:status)
end