Class: Google::Apis::ComputeBeta::QuotaExceededInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Additional details for quota exceeded error for resource quota.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaExceededInfo

Returns a new instance of QuotaExceededInfo.



49921
49922
49923
# File 'lib/google/apis/compute_beta/classes.rb', line 49921

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dimensionsHash<String,String>

The map holding related quota dimensions. Corresponds to the JSON property dimensions

Returns:

  • (Hash<String,String>)


49892
49893
49894
# File 'lib/google/apis/compute_beta/classes.rb', line 49892

def dimensions
  @dimensions
end

#future_limitFloat

Future quota limit being rolled out. The limit's unit depends on the quota type or metric. Corresponds to the JSON property futureLimit

Returns:

  • (Float)


49898
49899
49900
# File 'lib/google/apis/compute_beta/classes.rb', line 49898

def future_limit
  @future_limit
end

#limitFloat

Current effective quota limit. The limit's unit depends on the quota type or metric. Corresponds to the JSON property limit

Returns:

  • (Float)


49904
49905
49906
# File 'lib/google/apis/compute_beta/classes.rb', line 49904

def limit
  @limit
end

#limit_nameString

The name of the quota limit. Corresponds to the JSON property limitName

Returns:

  • (String)


49909
49910
49911
# File 'lib/google/apis/compute_beta/classes.rb', line 49909

def limit_name
  @limit_name
end

#metric_nameString

The Compute Engine quota metric name. Corresponds to the JSON property metricName

Returns:

  • (String)


49914
49915
49916
# File 'lib/google/apis/compute_beta/classes.rb', line 49914

def metric_name
  @metric_name
end

#rollout_statusString

Rollout status of the future quota limit. Corresponds to the JSON property rolloutStatus

Returns:

  • (String)


49919
49920
49921
# File 'lib/google/apis/compute_beta/classes.rb', line 49919

def rollout_status
  @rollout_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49926
49927
49928
49929
49930
49931
49932
49933
# File 'lib/google/apis/compute_beta/classes.rb', line 49926

def update!(**args)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @future_limit = args[:future_limit] if args.key?(:future_limit)
  @limit = args[:limit] if args.key?(:limit)
  @limit_name = args[:limit_name] if args.key?(:limit_name)
  @metric_name = args[:metric_name] if args.key?(:metric_name)
  @rollout_status = args[:rollout_status] if args.key?(:rollout_status)
end