Class: Google::Apis::ComputeBeta::Reference

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reference to a resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reference

Returns a new instance of Reference.



49567
49568
49569
# File 'lib/google/apis/compute_beta/classes.rb', line 49567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of the resource. Always compute#reference for references. Corresponds to the JSON property kind

Returns:

  • (String)


49546
49547
49548
# File 'lib/google/apis/compute_beta/classes.rb', line 49546

def kind
  @kind
end

#reference_typeString

A description of the reference type with no implied semantics. Possible values include:

  1. MEMBER_OF Corresponds to the JSON property referenceType

Returns:

  • (String)


49555
49556
49557
# File 'lib/google/apis/compute_beta/classes.rb', line 49555

def reference_type
  @reference_type
end

#referrerString

URL of the resource which refers to the target. Corresponds to the JSON property referrer

Returns:

  • (String)


49560
49561
49562
# File 'lib/google/apis/compute_beta/classes.rb', line 49560

def referrer
  @referrer
end

#targetString

URL of the resource to which this reference points. Corresponds to the JSON property target

Returns:

  • (String)


49565
49566
49567
# File 'lib/google/apis/compute_beta/classes.rb', line 49565

def target
  @target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49572
49573
49574
49575
49576
49577
# File 'lib/google/apis/compute_beta/classes.rb', line 49572

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @reference_type = args[:reference_type] if args.key?(:reference_type)
  @referrer = args[:referrer] if args.key?(:referrer)
  @target = args[:target] if args.key?(:target)
end