Class: Google::Apis::ComputeBeta::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Region
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Classes: QuotaStatusWarning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ Google::Apis::ComputeBeta::Region::QuotaStatusWarning
Output only.
-
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
49621 49622 49623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49621 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
49558 49559 49560 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49558 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
49563 49564 49565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49563 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
49568 49569 49570 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49568 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
49574 49575 49576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49574 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#region for
regions.
Corresponds to the JSON property kind
49580 49581 49582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49580 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
49585 49586 49587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49585 def name @name end |
#quota_status_warning ⇒ Google::Apis::ComputeBeta::Region::QuotaStatusWarning
Output only. [Output Only] Warning of fetching the quotas field for this
region. This
field is populated only if fetching of the quotas field fails.
Corresponds to the JSON property quotaStatusWarning
49592 49593 49594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49592 def quota_status_warning @quota_status_warning end |
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
49597 49598 49599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49597 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
49602 49603 49604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49602 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
Corresponds to the JSON property status
49607 49608 49609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49607 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
49612 49613 49614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49612 def supports_pzs @supports_pzs end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
49619 49620 49621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49619 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49626 49627 49628 49629 49630 49631 49632 49633 49634 49635 49636 49637 49638 49639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49626 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) @zones = args[:zones] if args.key?(:zones) end |