Class: Google::Apis::ComputeBeta::Region::QuotaStatusWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Output only. [Output Only] Warning of fetching the quotas field for this region. This field is populated only if fetching of the quotas field fails.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ QuotaStatusWarning

Returns a new instance of QuotaStatusWarning.



49547
49548
49549
# File 'lib/google/apis/compute_beta/classes.rb', line 49547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


49529
49530
49531
# File 'lib/google/apis/compute_beta/classes.rb', line 49529

def code
  @code
end

#dataArray<Google::Apis::ComputeBeta::Region::QuotaStatusWarning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



49540
49541
49542
# File 'lib/google/apis/compute_beta/classes.rb', line 49540

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


49545
49546
49547
# File 'lib/google/apis/compute_beta/classes.rb', line 49545

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49552
49553
49554
49555
49556
# File 'lib/google/apis/compute_beta/classes.rb', line 49552

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end