Class: Google::Apis::ComputeBeta::RegionAddressesMoveRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionAddressesMoveRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional destination address description if intended to be different from the source.
-
#destination_address ⇒ String
The URL of the destination address to move to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAddressesMoveRequest
constructor
A new instance of RegionAddressesMoveRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAddressesMoveRequest
Returns a new instance of RegionAddressesMoveRequest.
45554 45555 45556 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45554 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional destination address description if intended to be different
from the source.
Corresponds to the JSON property description
45540 45541 45542 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45540 def description @description end |
#destination_address ⇒ String
The URL of the destination address to move to. This can be a full or partial URL. For example, the following are all valid URLs to a address:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ addresses/address
- projects/project/regions/region/addresses/address
Note that destination project must be different from the source project. So/
regions/region/addresses/address is not valid partial url.
Corresponds to the JSON property
destinationAddress
45552 45553 45554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45552 def destination_address @destination_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45559 45560 45561 45562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45559 def update!(**args) @description = args[:description] if args.key?(:description) @destination_address = args[:destination_address] if args.key?(:destination_address) end |