Class: Google::Apis::ComputeBeta::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



50267
50268
50269
# File 'lib/google/apis/compute_beta/classes.rb', line 50267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50235
50236
50237
# File 'lib/google/apis/compute_beta/classes.rb', line 50235

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



50240
50241
50242
# File 'lib/google/apis/compute_beta/classes.rb', line 50240

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


50245
50246
50247
# File 'lib/google/apis/compute_beta/classes.rb', line 50245

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50255
50256
50257
# File 'lib/google/apis/compute_beta/classes.rb', line 50255

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50260
50261
50262
# File 'lib/google/apis/compute_beta/classes.rb', line 50260

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50265
50266
50267
# File 'lib/google/apis/compute_beta/classes.rb', line 50265

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50272
50273
50274
50275
50276
50277
50278
50279
# File 'lib/google/apis/compute_beta/classes.rb', line 50272

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end