Class: Google::Apis::ComputeBeta::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



50215
50216
50217
# File 'lib/google/apis/compute_beta/classes.rb', line 50215

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50182
50183
50184
# File 'lib/google/apis/compute_beta/classes.rb', line 50182

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



50187
50188
50189
# File 'lib/google/apis/compute_beta/classes.rb', line 50187

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


50192
50193
50194
# File 'lib/google/apis/compute_beta/classes.rb', line 50192

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50203
50204
50205
# File 'lib/google/apis/compute_beta/classes.rb', line 50203

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50208
50209
50210
# File 'lib/google/apis/compute_beta/classes.rb', line 50208

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



50213
50214
50215
# File 'lib/google/apis/compute_beta/classes.rb', line 50213

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50220
50221
50222
50223
50224
50225
50226
50227
# File 'lib/google/apis/compute_beta/classes.rb', line 50220

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end