Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



50810
50811
50812
# File 'lib/google/apis/compute_beta/classes.rb', line 50810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50776
50777
50778
# File 'lib/google/apis/compute_beta/classes.rb', line 50776

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



50781
50782
50783
# File 'lib/google/apis/compute_beta/classes.rb', line 50781

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


50788
50789
50790
# File 'lib/google/apis/compute_beta/classes.rb', line 50788

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50798
50799
50800
# File 'lib/google/apis/compute_beta/classes.rb', line 50798

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50803
50804
50805
# File 'lib/google/apis/compute_beta/classes.rb', line 50803

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50808
50809
50810
# File 'lib/google/apis/compute_beta/classes.rb', line 50808

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50815
50816
50817
50818
50819
50820
50821
50822
# File 'lib/google/apis/compute_beta/classes.rb', line 50815

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end