Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



50967
50968
50969
# File 'lib/google/apis/compute_beta/classes.rb', line 50967

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50922
50923
50924
# File 'lib/google/apis/compute_beta/classes.rb', line 50922

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50927
50928
50929
# File 'lib/google/apis/compute_beta/classes.rb', line 50927

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



50932
50933
50934
# File 'lib/google/apis/compute_beta/classes.rb', line 50932

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


50939
50940
50941
# File 'lib/google/apis/compute_beta/classes.rb', line 50939

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50949
50950
50951
# File 'lib/google/apis/compute_beta/classes.rb', line 50949

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50954
50955
50956
# File 'lib/google/apis/compute_beta/classes.rb', line 50954

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50960
50961
50962
# File 'lib/google/apis/compute_beta/classes.rb', line 50960

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50965
50966
50967
# File 'lib/google/apis/compute_beta/classes.rb', line 50965

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50972
50973
50974
50975
50976
50977
50978
50979
50980
50981
# File 'lib/google/apis/compute_beta/classes.rb', line 50972

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end