Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagersStopInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupManagersStopInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#force_stop ⇒ Boolean
(also: #force_stop?)
If this flag is set to true, the Instance Group Manager will proceed to stop the instances, skipping initialization on them.
-
#instances ⇒ Array<String>
The URLs of one or more instances to stop.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagersStopInstancesRequest
constructor
A new instance of RegionInstanceGroupManagersStopInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagersStopInstancesRequest
Returns a new instance of RegionInstanceGroupManagersStopInstancesRequest.
49379 49380 49381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#force_stop ⇒ Boolean Also known as: force_stop?
If this flag is set to true, the Instance Group Manager will proceed to
stop the instances, skipping initialization on them.
Corresponds to the JSON property forceStop
49370 49371 49372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49370 def force_stop @force_stop end |
#instances ⇒ Array<String>
The URLs of one or more instances to stop. This can be a full URL or
a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
49377 49378 49379 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49377 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49384 49385 49386 49387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49384 def update!(**args) @force_stop = args[:force_stop] if args.key?(:force_stop) @instances = args[:instances] if args.key?(:instances) end |