Class: Google::Apis::ComputeBeta::RegionList::Warning::Datum
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionList::Warning::Datum
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Output Only] A key that provides more detail on the warning being returned.
-
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Datum
constructor
A new instance of Datum.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Datum
Returns a new instance of Datum.
51454 51455 51456 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51454 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Output Only] A key that provides more detail on the warning being
returned. For example, for warnings where there are no results in a list
request for a particular zone, this key might be scope and
the key value might be the zone name. Other examples might be a key
indicating a deprecated resource and a suggested replacement, or a
warning about invalid network settings (for example, if an instance
attempts to perform IP forwarding but is not enabled for IP forwarding).
Corresponds to the JSON property key
51447 51448 51449 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51447 def key @key end |
#value ⇒ String
[Output Only] A warning data value corresponding to the key.
Corresponds to the JSON property value
51452 51453 51454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51452 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51459 51460 51461 51462 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51459 def update!(**args) @key = args[:key] if args.key?(:key) @value = args[:value] if args.key?(:value) end |