Class: Google::Apis::ComputeBeta::RegionUrlMapsValidateRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionUrlMapsValidateRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#resource ⇒ Google::Apis::ComputeBeta::UrlMap
Represents a URL Map resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionUrlMapsValidateRequest
constructor
A new instance of RegionUrlMapsValidateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionUrlMapsValidateRequest
Returns a new instance of RegionUrlMapsValidateRequest.
47558 47559 47560 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47558 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource ⇒ Google::Apis::ComputeBeta::UrlMap
Represents a URL Map resource. Compute Engine has two URL Map resources:
- Global
- Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
- urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
- regionUrlMaps are used by internal Application Load Balancers,
regional external Application Load Balancers and regional internal
Application Load Balancers.
For a list of supported URL map features by the load balancer type, see the
Load balancing features: Routing and traffic management table.
For a list of supported URL map features for Traffic Director, see the
Traffic Director features: Routing and traffic management table.
This resource defines mappings from hostnames and URL paths to either a
backend service or a backend bucket.
To use the global urlMaps resource, the backend service must
have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or
INTERNAL_SELF_MANAGED. To use
the regionUrlMaps resource, the backend service must have aloadBalancingScheme
of INTERNAL_MANAGED. For more
information, read URL
Map Concepts.
Corresponds to the JSON property
resource
47556 47557 47558 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47556 def resource @resource end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47563 47564 47565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47563 def update!(**args) @resource = args[:resource] if args.key?(:resource) end |