Class: Google::Apis::ComputeBeta::ReliabilityRisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReliabilityRisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a ReliabilityRisk resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional textual description of the resource; provided when the resource is created.
-
#details ⇒ Google::Apis::ComputeBeta::RiskDetails
Detailed insights and metrics about a detected reliability risk.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#recommendation ⇒ Google::Apis::ComputeBeta::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisk
constructor
A new instance of ReliabilityRisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisk
Returns a new instance of ReliabilityRisk.
52342 52343 52344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52342 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
52295 52296 52297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52295 def @creation_timestamp end |
#description ⇒ String
An optional textual description of the resource; provided when the
resource is created.
Corresponds to the JSON property description
52301 52302 52303 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52301 def description @description end |
#details ⇒ Google::Apis::ComputeBeta::RiskDetails
Detailed insights and metrics about a detected reliability risk.
Corresponds to the JSON property details
52306 52307 52308 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52306 def details @details end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
52312 52313 52314 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52312 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#reliabilityRisk
for reliability risks.
Corresponds to the JSON property kind
52318 52319 52320 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52318 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long and
comply with RFC1035.
Corresponds to the JSON property name
52324 52325 52326 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52324 def name @name end |
#recommendation ⇒ Google::Apis::ComputeBeta::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
Corresponds to the JSON property recommendation
52329 52330 52331 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52329 def recommendation @recommendation end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
52334 52335 52336 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52334 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
52340 52341 52342 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52340 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52347 52348 52349 52350 52351 52352 52353 52354 52355 52356 52357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52347 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @recommendation = args[:recommendation] if args.key?(:recommendation) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |