Class: Google::Apis::ComputeBeta::ReliabilityRisksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response message for the List method of ReliabilityRisksService.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReliabilityRisksListResponse

Returns a new instance of ReliabilityRisksListResponse.



52405
52406
52407
# File 'lib/google/apis/compute_beta/classes.rb', line 52405

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

[Output Only] An ETag of the resource. Corresponds to the JSON property etag

Returns:

  • (String)


52367
52368
52369
# File 'lib/google/apis/compute_beta/classes.rb', line 52367

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52372
52373
52374
# File 'lib/google/apis/compute_beta/classes.rb', line 52372

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReliabilityRisk>

A list of ReliabilityRisk resources. Corresponds to the JSON property items



52377
52378
52379
# File 'lib/google/apis/compute_beta/classes.rb', line 52377

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52387
52388
52389
# File 'lib/google/apis/compute_beta/classes.rb', line 52387

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52392
52393
52394
# File 'lib/google/apis/compute_beta/classes.rb', line 52392

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52398
52399
52400
# File 'lib/google/apis/compute_beta/classes.rb', line 52398

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReliabilityRisksListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52403
52404
52405
# File 'lib/google/apis/compute_beta/classes.rb', line 52403

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52410
52411
52412
52413
52414
52415
52416
52417
52418
# File 'lib/google/apis/compute_beta/classes.rb', line 52410

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end