Class: Google::Apis::ComputeBeta::ReservationBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reservation block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlock

Returns a new instance of ReservationBlock.



53055
53056
53057
# File 'lib/google/apis/compute_beta/classes.rb', line 53055

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. [Output Only] The number of resources that are allocated in this reservation block. Corresponds to the JSON property count

Returns:

  • (Fixnum)


52961
52962
52963
# File 'lib/google/apis/compute_beta/classes.rb', line 52961

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52966
52967
52968
# File 'lib/google/apis/compute_beta/classes.rb', line 52966

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeBeta::ReservationBlockHealthInfo

Health information for the reservation block. Corresponds to the JSON property healthInfo



52971
52972
52973
# File 'lib/google/apis/compute_beta/classes.rb', line 52971

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52978
52979
52980
# File 'lib/google/apis/compute_beta/classes.rb', line 52978

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation block. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


52985
52986
52987
# File 'lib/google/apis/compute_beta/classes.rb', line 52985

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


52992
52993
52994
# File 'lib/google/apis/compute_beta/classes.rb', line 52992

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationBlock for reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


52998
52999
53000
# File 'lib/google/apis/compute_beta/classes.rb', line 52998

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


53006
53007
53008
# File 'lib/google/apis/compute_beta/classes.rb', line 53006

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeBeta::ReservationBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation block. Corresponds to the JSON property physicalTopology



53011
53012
53013
# File 'lib/google/apis/compute_beta/classes.rb', line 53011

def physical_topology
  @physical_topology
end

#reservation_maintenanceGoogle::Apis::ComputeBeta::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationMaintenance



53016
53017
53018
# File 'lib/google/apis/compute_beta/classes.rb', line 53016

def reservation_maintenance
  @reservation_maintenance
end

#reservation_sub_block_countFixnum

Output only. [Output Only] The number of reservation subBlocks associated with this reservation block. Corresponds to the JSON property reservationSubBlockCount

Returns:

  • (Fixnum)


53023
53024
53025
# File 'lib/google/apis/compute_beta/classes.rb', line 53023

def reservation_sub_block_count
  @reservation_sub_block_count
end

#reservation_sub_block_in_use_countFixnum

Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use. Corresponds to the JSON property reservationSubBlockInUseCount

Returns:

  • (Fixnum)


53031
53032
53033
# File 'lib/google/apis/compute_beta/classes.rb', line 53031

def reservation_sub_block_in_use_count
  @reservation_sub_block_in_use_count
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53037
53038
53039
# File 'lib/google/apis/compute_beta/classes.rb', line 53037

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


53043
53044
53045
# File 'lib/google/apis/compute_beta/classes.rb', line 53043

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation block. Corresponds to the JSON property status

Returns:

  • (String)


53048
53049
53050
# File 'lib/google/apis/compute_beta/classes.rb', line 53048

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation block resides. Corresponds to the JSON property zone

Returns:

  • (String)


53053
53054
53055
# File 'lib/google/apis/compute_beta/classes.rb', line 53053

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53060
53061
53062
53063
53064
53065
53066
53067
53068
53069
53070
53071
53072
53073
53074
53075
53076
53077
# File 'lib/google/apis/compute_beta/classes.rb', line 53060

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance)
  @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count)
  @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end