Class: Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



52681
52682
52683
# File 'lib/google/apis/compute_beta/classes.rb', line 52681

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


52669
52670
52671
# File 'lib/google/apis/compute_beta/classes.rb', line 52669

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


52674
52675
52676
# File 'lib/google/apis/compute_beta/classes.rb', line 52674

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



52679
52680
52681
# File 'lib/google/apis/compute_beta/classes.rb', line 52679

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52686
52687
52688
52689
52690
# File 'lib/google/apis/compute_beta/classes.rb', line 52686

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end