Class: Google::Apis::ComputeBeta::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
53158 53159 53160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53158 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
53101 53102 53103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53101 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
53108 53109 53110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53108 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
53114 53115 53116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53114 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
53119 53120 53121 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53119 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
53124 53125 53126 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53124 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
53130 53131 53132 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53130 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
53136 53137 53138 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53136 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
53141 53142 53143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53141 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
53146 53147 53148 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53146 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
53151 53152 53153 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53151 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
53156 53157 53158 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53156 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53163 53164 53165 53166 53167 53168 53169 53170 53171 53172 53173 53174 53175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53163 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |