Class: Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
constructor
A new instance of ReservationSlotPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotPhysicalTopology
Returns a new instance of ReservationSlotPhysicalTopology.
53602 53603 53604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53602 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
53584 53585 53586 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53584 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
53589 53590 53591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53589 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
53594 53595 53596 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53594 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
53600 53601 53602 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53600 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53607 53608 53609 53610 53611 53612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53607 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |