Class: Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Health information for the reservation subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlockHealthInfo

Returns a new instance of ReservationSubBlockHealthInfo.



53557
53558
53559
# File 'lib/google/apis/compute_beta/classes.rb', line 53557

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#degraded_host_countFixnum

The number of degraded hosts in the reservation subBlock. Corresponds to the JSON property degradedHostCount

Returns:

  • (Fixnum)


53533
53534
53535
# File 'lib/google/apis/compute_beta/classes.rb', line 53533

def degraded_host_count
  @degraded_host_count
end

#degraded_infra_countFixnum

The number of degraded infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property degradedInfraCount

Returns:

  • (Fixnum)


53539
53540
53541
# File 'lib/google/apis/compute_beta/classes.rb', line 53539

def degraded_infra_count
  @degraded_infra_count
end

#health_statusString

The health status of the reservation subBlock. Corresponds to the JSON property healthStatus

Returns:

  • (String)


53544
53545
53546
# File 'lib/google/apis/compute_beta/classes.rb', line 53544

def health_status
  @health_status
end

#healthy_host_countFixnum

The number of healthy hosts in the reservation subBlock. Corresponds to the JSON property healthyHostCount

Returns:

  • (Fixnum)


53549
53550
53551
# File 'lib/google/apis/compute_beta/classes.rb', line 53549

def healthy_host_count
  @healthy_host_count
end

#healthy_infra_countFixnum

The number of healthy infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property healthyInfraCount

Returns:

  • (Fixnum)


53555
53556
53557
# File 'lib/google/apis/compute_beta/classes.rb', line 53555

def healthy_infra_count
  @healthy_infra_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53562
53563
53564
53565
53566
53567
53568
# File 'lib/google/apis/compute_beta/classes.rb', line 53562

def update!(**args)
  @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count)
  @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count)
  @health_status = args[:health_status] if args.key?(:health_status)
  @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count)
  @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count)
end