Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



54210
54211
54212
# File 'lib/google/apis/compute_beta/classes.rb', line 54210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


54203
54204
54205
# File 'lib/google/apis/compute_beta/classes.rb', line 54203

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


54208
54209
54210
# File 'lib/google/apis/compute_beta/classes.rb', line 54208

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54215
54216
54217
54218
# File 'lib/google/apis/compute_beta/classes.rb', line 54215

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end