Class: Google::Apis::ComputeBeta::ReservationsBlocksPerformMaintenanceRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationsBlocksPerformMaintenanceRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#maintenance_scope ⇒ String
Specifies if all, running or unused hosts are in scope for this request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationsBlocksPerformMaintenanceRequest
constructor
A new instance of ReservationsBlocksPerformMaintenanceRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationsBlocksPerformMaintenanceRequest
Returns a new instance of ReservationsBlocksPerformMaintenanceRequest.
52679 52680 52681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52679 def initialize(**args) update!(**args) end |
Instance Attribute Details
#maintenance_scope ⇒ String
Specifies if all, running or unused hosts are in scope for this request.
Corresponds to the JSON property maintenanceScope
52677 52678 52679 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52677 def maintenance_scope @maintenance_scope end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52684 52685 52686 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52684 def update!(**args) @maintenance_scope = args[:maintenance_scope] if args.key?(:maintenance_scope) end |