Class: Google::Apis::ComputeBeta::ResourcePolicyHourlyCycle

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Time window specified for hourly operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyHourlyCycle

Returns a new instance of ResourcePolicyHourlyCycle.



54457
54458
54459
# File 'lib/google/apis/compute_beta/classes.rb', line 54457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario. Corresponds to the JSON property duration

Returns:

  • (String)


54443
54444
54445
# File 'lib/google/apis/compute_beta/classes.rb', line 54443

def duration
  @duration
end

#hours_in_cycleFixnum

Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle. Corresponds to the JSON property hoursInCycle

Returns:

  • (Fixnum)


54449
54450
54451
# File 'lib/google/apis/compute_beta/classes.rb', line 54449

def hours_in_cycle
  @hours_in_cycle
end

#start_timeString

Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT. Corresponds to the JSON property startTime

Returns:

  • (String)


54455
54456
54457
# File 'lib/google/apis/compute_beta/classes.rb', line 54455

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54462
54463
54464
54465
54466
# File 'lib/google/apis/compute_beta/classes.rb', line 54462

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @hours_in_cycle = args[:hours_in_cycle] if args.key?(:hours_in_cycle)
  @start_time = args[:start_time] if args.key?(:start_time)
end