Class: Google::Apis::ComputeBeta::ResourcePolicyResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyResourceStatus

Returns a new instance of ResourcePolicyResourceStatus.



55161
55162
55163
# File 'lib/google/apis/compute_beta/classes.rb', line 55161

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_schedule_policyGoogle::Apis::ComputeBeta::ResourcePolicyResourceStatusInstanceSchedulePolicyStatus

Output only. [Output Only] Specifies a set of output values reffering to the instance_schedule_policy system status. This field should have the same name as corresponding policy field. Corresponds to the JSON property instanceSchedulePolicy



55159
55160
55161
# File 'lib/google/apis/compute_beta/classes.rb', line 55159

def instance_schedule_policy
  @instance_schedule_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55166
55167
55168
# File 'lib/google/apis/compute_beta/classes.rb', line 55166

def update!(**args)
  @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy)
end