Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicy

Returns a new instance of ResourcePolicySnapshotSchedulePolicy.



55221
55222
55223
# File 'lib/google/apis/compute_beta/classes.rb', line 55221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_policyGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Policy for retention of scheduled snapshots. Corresponds to the JSON property retentionPolicy



55208
55209
55210
# File 'lib/google/apis/compute_beta/classes.rb', line 55208

def retention_policy
  @retention_policy
end

#scheduleGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySchedule

A schedule for disks where the schedueled operations are performed. Corresponds to the JSON property schedule



55213
55214
55215
# File 'lib/google/apis/compute_beta/classes.rb', line 55213

def schedule
  @schedule
end

#snapshot_propertiesGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Specified snapshot properties for scheduled snapshots created by this policy. Corresponds to the JSON property snapshotProperties



55219
55220
55221
# File 'lib/google/apis/compute_beta/classes.rb', line 55219

def snapshot_properties
  @snapshot_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55226
55227
55228
55229
55230
# File 'lib/google/apis/compute_beta/classes.rb', line 55226

def update!(**args)
  @retention_policy = args[:retention_policy] if args.key?(:retention_policy)
  @schedule = args[:schedule] if args.key?(:schedule)
  @snapshot_properties = args[:snapshot_properties] if args.key?(:snapshot_properties)
end