Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Policy for retention of scheduled snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Returns a new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.



55248
55249
55250
# File 'lib/google/apis/compute_beta/classes.rb', line 55248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_retention_daysFixnum

Maximum age of the snapshot that is allowed to be kept. Corresponds to the JSON property maxRetentionDays

Returns:

  • (Fixnum)


55240
55241
55242
# File 'lib/google/apis/compute_beta/classes.rb', line 55240

def max_retention_days
  @max_retention_days
end

#on_source_disk_deleteString

Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Corresponds to the JSON property onSourceDiskDelete

Returns:

  • (String)


55246
55247
55248
# File 'lib/google/apis/compute_beta/classes.rb', line 55246

def on_source_disk_delete
  @on_source_disk_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55253
55254
55255
55256
# File 'lib/google/apis/compute_beta/classes.rb', line 55253

def update!(**args)
  @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days)
  @on_source_disk_delete = args[:on_source_disk_delete] if args.key?(:on_source_disk_delete)
end