Class: Google::Apis::ComputeBeta::ResourcePolicyWeeklyCycleDayOfWeek
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyWeeklyCycleDayOfWeek
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#day ⇒ String
Defines a schedule that runs on specific days of the week.
-
#duration ⇒ String
Output only.
-
#start_time ⇒ String
Time within the window to start the operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
constructor
A new instance of ResourcePolicyWeeklyCycleDayOfWeek.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWeeklyCycleDayOfWeek
Returns a new instance of ResourcePolicyWeeklyCycleDayOfWeek.
50077 50078 50079 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50077 def initialize(**args) update!(**args) end |
Instance Attribute Details
#day ⇒ String
Defines a schedule that runs on specific days of the week. Specify
one or more days. The following options are available:
MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY, SATURDAY, SUNDAY.
Corresponds to the JSON property day
50062 50063 50064 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50062 def day @day end |
#duration ⇒ String
Output only. [Output only] Duration of the time window, automatically chosen
to be
smallest possible in the given scenario.
Corresponds to the JSON property duration
50069 50070 50071 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50069 def duration @duration end |
#start_time ⇒ String
Time within the window to start the operations.
It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT.
Corresponds to the JSON property startTime
50075 50076 50077 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50075 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50082 50083 50084 50085 50086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50082 def update!(**args) @day = args[:day] if args.key?(:day) @duration = args[:duration] if args.key?(:duration) @start_time = args[:start_time] if args.key?(:start_time) end |