Class: Google::Apis::ComputeBeta::ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatus

Returns a new instance of ResourceStatus.



55477
55478
55479
# File 'lib/google/apis/compute_beta/classes.rb', line 55477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_instance_metadataGoogle::Apis::ComputeBeta::ResourceStatusEffectiveInstanceMetadata

Effective values of predefined metadata keys for an instance. Corresponds to the JSON property effectiveInstanceMetadata



55440
55441
55442
# File 'lib/google/apis/compute_beta/classes.rb', line 55440

def 
  @effective_instance_metadata
end

#physical_hostString

Output only. [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId. Corresponds to the JSON property physicalHost

Returns:

  • (String)


55448
55449
55450
# File 'lib/google/apis/compute_beta/classes.rb', line 55448

def physical_host
  @physical_host
end

#physical_host_topologyGoogle::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology

Represents the physical host topology of the host on which the VM is running. Corresponds to the JSON property physicalHostTopology



55454
55455
55456
# File 'lib/google/apis/compute_beta/classes.rb', line 55454

def physical_host_topology
  @physical_host_topology
end

#reservation_consumption_infoGoogle::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo

Reservation consumption information that the instance is consuming from. Corresponds to the JSON property reservationConsumptionInfo



55459
55460
55461
# File 'lib/google/apis/compute_beta/classes.rb', line 55459

def reservation_consumption_info
  @reservation_consumption_info
end

#schedulingGoogle::Apis::ComputeBeta::ResourceStatusScheduling

Corresponds to the JSON property scheduling



55464
55465
55466
# File 'lib/google/apis/compute_beta/classes.rb', line 55464

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeBeta::ResourceStatusShutdownDetails

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



55470
55471
55472
# File 'lib/google/apis/compute_beta/classes.rb', line 55470

def shutdown_details
  @shutdown_details
end

#upcoming_maintenanceGoogle::Apis::ComputeBeta::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



55475
55476
55477
# File 'lib/google/apis/compute_beta/classes.rb', line 55475

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55482
55483
55484
55485
55486
55487
55488
55489
55490
# File 'lib/google/apis/compute_beta/classes.rb', line 55482

def update!(**args)
  @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata)
  @physical_host = args[:physical_host] if args.key?(:physical_host)
  @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology)
  @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end