Class: Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo

Returns a new instance of ResourceStatusReservationConsumptionInfo.



55216
55217
55218
# File 'lib/google/apis/compute_beta/classes.rb', line 55216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


55200
55201
55202
# File 'lib/google/apis/compute_beta/classes.rb', line 55200

def consumed_reservation
  @consumed_reservation
end

#consumed_reservation_blockString

Output only. [Output Only] The full resource name of the reservation block that this instance is consuming from. Corresponds to the JSON property consumedReservationBlock

Returns:

  • (String)


55207
55208
55209
# File 'lib/google/apis/compute_beta/classes.rb', line 55207

def consumed_reservation_block
  @consumed_reservation_block
end

#consumed_reservation_sub_blockString

Output only. [Output Only] The full resource name of the reservation sub-block that this instance is consuming from. Corresponds to the JSON property consumedReservationSubBlock

Returns:

  • (String)


55214
55215
55216
# File 'lib/google/apis/compute_beta/classes.rb', line 55214

def consumed_reservation_sub_block
  @consumed_reservation_sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55221
55222
55223
55224
55225
# File 'lib/google/apis/compute_beta/classes.rb', line 55221

def update!(**args)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
  @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block)
  @consumed_reservation_sub_block = args[:consumed_reservation_sub_block] if args.key?(:consumed_reservation_sub_block)
end