Class: Google::Apis::ComputeBeta::RiskDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RiskDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Detailed insights and metrics about a detected reliability risk.
Instance Attribute Summary collapse
-
#duration ⇒ String
The duration of the risk since it was detected.
-
#global_dns_insight ⇒ Google::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight
Detailed insights for a global DNS reliability risk.
-
#last_update_timestamp ⇒ String
The last time the risk was updated.
-
#severity ⇒ String
The severity of the risk.
-
#type ⇒ String
The type of risk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RiskDetails
constructor
A new instance of RiskDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RiskDetails
Returns a new instance of RiskDetails.
55792 55793 55794 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55792 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ String
The duration of the risk since it was detected.
Corresponds to the JSON property duration
55770 55771 55772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55770 def duration @duration end |
#global_dns_insight ⇒ Google::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight
Detailed insights for a global DNS reliability risk.
Corresponds to the JSON property globalDnsInsight
55775 55776 55777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55775 def global_dns_insight @global_dns_insight end |
#last_update_timestamp ⇒ String
The last time the risk was updated.
Corresponds to the JSON property lastUpdateTimestamp
55780 55781 55782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55780 def @last_update_timestamp end |
#severity ⇒ String
The severity of the risk.
Corresponds to the JSON property severity
55785 55786 55787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55785 def severity @severity end |
#type ⇒ String
The type of risk.
Corresponds to the JSON property type
55790 55791 55792 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55790 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55797 55798 55799 55800 55801 55802 55803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55797 def update!(**args) @duration = args[:duration] if args.key?(:duration) @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight) @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp) @severity = args[:severity] if args.key?(:severity) @type = args[:type] if args.key?(:type) end |