Class: Google::Apis::ComputeBeta::RolloutPlanWave
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlanWave
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A single wave in a rollout plan.
Instance Attribute Summary collapse
-
#display_name ⇒ String
Optional.
-
#number ⇒ Fixnum
Output only.
-
#orchestration_options ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions
Options to control the pace of orchestration of a wave.
-
#selectors ⇒ Array<Google::Apis::ComputeBeta::RolloutPlanWaveSelector>
Required.
-
#validation ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveValidation
The validation to be performed before progressing to the next wave.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWave
constructor
A new instance of RolloutPlanWave.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWave
Returns a new instance of RolloutPlanWave.
56121 56122 56123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#display_name ⇒ String
Optional. The display name of this wave of the rollout plan.
Corresponds to the JSON property displayName
56094 56095 56096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56094 def display_name @display_name end |
#number ⇒ Fixnum
Output only. The wave number.
Corresponds to the JSON property number
56099 56100 56101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56099 def number @number end |
#orchestration_options ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions
Options to control the pace of orchestration of a wave. These options are
required only if the resource being rolled out follows the Orchestrated
pattern.
Corresponds to the JSON property orchestrationOptions
56106 56107 56108 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56106 def @orchestration_options end |
#selectors ⇒ Array<Google::Apis::ComputeBeta::RolloutPlanWaveSelector>
Required. The selectors for this wave. There is a logical AND between each
selector
defined in a wave, so a resource must satisfy the criteria of all the
specified selectors to be in scope for the wave.
Corresponds to the JSON property selectors
56114 56115 56116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56114 def selectors @selectors end |
#validation ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveValidation
The validation to be performed before progressing to the next wave.
Corresponds to the JSON property validation
56119 56120 56121 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56119 def validation @validation end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56126 56127 56128 56129 56130 56131 56132 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56126 def update!(**args) @display_name = args[:display_name] if args.key?(:display_name) @number = args[:number] if args.key?(:number) @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options) @selectors = args[:selectors] if args.key?(:selectors) @validation = args[:validation] if args.key?(:validation) end |