Class: Google::Apis::ComputeBeta::RolloutPlanWaveSelector
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlanWaveSelector
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A selector which specifies what resource(s) are included in a given wave.
Instance Attribute Summary collapse
-
#location_selector ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveSelectorLocationSelector
Roll out to resources by location.
-
#resource_hierarchy_selector ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveSelectorResourceHierarchySelector
Roll out to resources by Cloud Resource Manager resource hierarchy nodes such as projects, folders, orgs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveSelector
constructor
A new instance of RolloutPlanWaveSelector.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveSelector
Returns a new instance of RolloutPlanWaveSelector.
50734 50735 50736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50734 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location_selector ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveSelectorLocationSelector
Roll out to resources by location.
Corresponds to the JSON property locationSelector
50726 50727 50728 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50726 def location_selector @location_selector end |
#resource_hierarchy_selector ⇒ Google::Apis::ComputeBeta::RolloutPlanWaveSelectorResourceHierarchySelector
Roll out to resources by Cloud Resource Manager resource hierarchy
nodes such as projects, folders, orgs.
Corresponds to the JSON property resourceHierarchySelector
50732 50733 50734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50732 def resource_hierarchy_selector @resource_hierarchy_selector end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50739 50740 50741 50742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50739 def update!(**args) @location_selector = args[:location_selector] if args.key?(:location_selector) @resource_hierarchy_selector = args[:resource_hierarchy_selector] if args.key?(:resource_hierarchy_selector) end |