Class: Google::Apis::ComputeBeta::RolloutRolloutEntity
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutRolloutEntity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifications of the resource to roll out.
Instance Attribute Summary collapse
-
#orchestrated_entity ⇒ Google::Apis::ComputeBeta::RolloutRolloutEntityOrchestratedEntity
This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutRolloutEntity
constructor
A new instance of RolloutRolloutEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutRolloutEntity
Returns a new instance of RolloutRolloutEntity.
53909 53910 53911 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53909 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_entity ⇒ Google::Apis::ComputeBeta::RolloutRolloutEntityOrchestratedEntity
This message is used if the resource type follows the Orchestrated
integration model with ProgressiveRollout.
Corresponds to the JSON property orchestratedEntity
53907 53908 53909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53907 def orchestrated_entity @orchestrated_entity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53914 53915 53916 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53914 def update!(**args) @orchestrated_entity = args[:orchestrated_entity] if args.key?(:orchestrated_entity) end |