Class: Google::Apis::ComputeBeta::RolloutRolloutEntityOrchestratedEntity

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutRolloutEntityOrchestratedEntity

Returns a new instance of RolloutRolloutEntityOrchestratedEntity.



52800
52801
52802
# File 'lib/google/apis/compute_beta/classes.rb', line 52800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflict_behaviorString

Required. Specifies the behavior of the Rollout if an out of band update is detected in a project during a Rollout. It can be one of the following values: 1) overwrite : Overwrite the local value with the rollout value. 2) no_overwrite : Do not overwrite the local value with the rollout value. Corresponds to the JSON property conflictBehavior

Returns:

  • (String)


52775
52776
52777
# File 'lib/google/apis/compute_beta/classes.rb', line 52775

def conflict_behavior
  @conflict_behavior
end

#orchestration_actionString

Required. Orchestration action during the Rollout. It can be one of the following values: 1) "update": Resources will be updated by the rollout. 2) "delete": Resources will be deleted by the rollout. Corresponds to the JSON property orchestrationAction

Returns:

  • (String)


52784
52785
52786
# File 'lib/google/apis/compute_beta/classes.rb', line 52784

def orchestration_action
  @orchestration_action
end

#orchestration_sourceString

Required. Fully qualified resource name of the resource which contains the source of truth of the configuration being rolled out across locations/projects. For example, in the case of a global Rollout which is applied across regions, this contains the name of the global resource created by the user which contains a payload for a resource that is orchestrated across regions. This follows the following format: //.googleapis.com/projects//locations/global// e.g. //osconfig.googleapis.com/projects/1/locations/global/policyOrchestrators/po1 Corresponds to the JSON property orchestrationSource

Returns:

  • (String)


52798
52799
52800
# File 'lib/google/apis/compute_beta/classes.rb', line 52798

def orchestration_source
  @orchestration_source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52805
52806
52807
52808
52809
# File 'lib/google/apis/compute_beta/classes.rb', line 52805

def update!(**args)
  @conflict_behavior = args[:conflict_behavior] if args.key?(:conflict_behavior)
  @orchestration_action = args[:orchestration_action] if args.key?(:orchestration_action)
  @orchestration_source = args[:orchestration_source] if args.key?(:orchestration_source)
end