Class: Google::Apis::ComputeBeta::RolloutWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Additional metadata about the status of each wave provided by the server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetails

Returns a new instance of RolloutWaveDetails.



56194
56195
56196
# File 'lib/google/apis/compute_beta/classes.rb', line 56194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#orchestrated_wave_detailsGoogle::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetails

Details of the wave for products using the Orchestrated integration model. Corresponds to the JSON property orchestratedWaveDetails



56181
56182
56183
# File 'lib/google/apis/compute_beta/classes.rb', line 56181

def orchestrated_wave_details
  @orchestrated_wave_details
end

#wave_display_nameString

Output only. Wave name. Ex. wave1 Corresponds to the JSON property waveDisplayName

Returns:

  • (String)


56187
56188
56189
# File 'lib/google/apis/compute_beta/classes.rb', line 56187

def wave_display_name
  @wave_display_name
end

#wave_numberFixnum

Output only. System generated number for the wave. Corresponds to the JSON property waveNumber

Returns:

  • (Fixnum)


56192
56193
56194
# File 'lib/google/apis/compute_beta/classes.rb', line 56192

def wave_number
  @wave_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56199
56200
56201
56202
56203
# File 'lib/google/apis/compute_beta/classes.rb', line 56199

def update!(**args)
  @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details)
  @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name)
  @wave_number = args[:wave_number] if args.key?(:wave_number)
end