Class: Google::Apis::ComputeBeta::RouteAsPath

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteAsPath

Returns a new instance of RouteAsPath.



51634
51635
51636
# File 'lib/google/apis/compute_beta/classes.rb', line 51634

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#as_listsArray<Fixnum>

[Output Only] The AS numbers of the AS Path. Corresponds to the JSON property asLists

Returns:

  • (Array<Fixnum>)


51616
51617
51618
# File 'lib/google/apis/compute_beta/classes.rb', line 51616

def as_lists
  @as_lists
end

#path_segment_typeString

[Output Only] The type of the AS Path, which can be one of the following values:

  • 'AS_SET': unordered set of autonomous systems that the route in has traversed
  • 'AS_SEQUENCE': ordered set of autonomous systems that the route has traversed
  • 'AS_CONFED_SEQUENCE': ordered set of Member Autonomous Systems in the local confederation that the route has traversed
  • 'AS_CONFED_SET': unordered set of Member Autonomous Systems in the local confederation that the route has traversed Corresponds to the JSON property pathSegmentType

Returns:

  • (String)


51632
51633
51634
# File 'lib/google/apis/compute_beta/classes.rb', line 51632

def path_segment_type
  @path_segment_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51639
51640
51641
51642
# File 'lib/google/apis/compute_beta/classes.rb', line 51639

def update!(**args)
  @as_lists = args[:as_lists] if args.key?(:as_lists)
  @path_segment_type = args[:path_segment_type] if args.key?(:path_segment_type)
end