Class: Google::Apis::ComputeBeta::RouteParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouteParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Additional route parameters.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Tag keys/values directly bound to this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteParams
constructor
A new instance of RouteParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteParams
Returns a new instance of RouteParams.
51789 51790 51791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51789 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Tag keys/values directly bound to this resource.
Tag keys and values have the same definition as resource
manager tags. The field is allowed for INSERT
only. The keys/values to set on the resource should be specified in
either ID : or Namespaced format
:.
For example the following are valid inputs:
"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456""123/environment" : "production", "345/abc" : "xyz"Note:- Invalid combinations of ID & namespaced format is not supported. For
instance:
"123/environment" : "tagValues/444"is invalid. Corresponds to the JSON propertyresourceManagerTags
51787 51788 51789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51787 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51794 51795 51796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51794 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |