Class: Google::Apis::ComputeBeta::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Router resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouterList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
58237 58238 58239 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
58204 58205 58206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58204 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of Router resources.
Corresponds to the JSON property items
58209 58210 58211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58209 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
58215 58216 58217 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58215 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58225 58226 58227 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58225 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58230 58231 58232 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58230 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RouterList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58235 58236 58237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58235 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58242 58243 58244 58245 58246 58247 58248 58249 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58242 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |