Class: Google::Apis::ComputeBeta::RouterNatRuleAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatRuleAction

Returns a new instance of RouterNatRuleAction.



58701
58702
58703
# File 'lib/google/apis/compute_beta/classes.rb', line 58701

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_nat_active_ipsArray<String>

A list of URLs of the IP resources used for this NAT rule. These IP addresses must be valid static external IP addresses assigned to the project. This field is used for public NAT. Corresponds to the JSON property sourceNatActiveIps

Returns:

  • (Array<String>)


58675
58676
58677
# File 'lib/google/apis/compute_beta/classes.rb', line 58675

def source_nat_active_ips
  @source_nat_active_ips
end

#source_nat_active_rangesArray<String>

A list of URLs of the subnetworks used as source ranges for this NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT. This field is used for private NAT. Corresponds to the JSON property sourceNatActiveRanges

Returns:

  • (Array<String>)


58682
58683
58684
# File 'lib/google/apis/compute_beta/classes.rb', line 58682

def source_nat_active_ranges
  @source_nat_active_ranges
end

#source_nat_drain_ipsArray<String>

A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT rule only. This field is used for public NAT. Corresponds to the JSON property sourceNatDrainIps

Returns:

  • (Array<String>)


58690
58691
58692
# File 'lib/google/apis/compute_beta/classes.rb', line 58690

def source_nat_drain_ips
  @source_nat_drain_ips
end

#source_nat_drain_rangesArray<String>

A list of URLs of subnetworks representing source ranges to be drained. This is only supported on patch/update, and these subnetworks must have previously been used as active ranges in this NAT Rule. This field is used for private NAT. Corresponds to the JSON property sourceNatDrainRanges

Returns:

  • (Array<String>)


58699
58700
58701
# File 'lib/google/apis/compute_beta/classes.rb', line 58699

def source_nat_drain_ranges
  @source_nat_drain_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58706
58707
58708
58709
58710
58711
# File 'lib/google/apis/compute_beta/classes.rb', line 58706

def update!(**args)
  @source_nat_active_ips = args[:source_nat_active_ips] if args.key?(:source_nat_active_ips)
  @source_nat_active_ranges = args[:source_nat_active_ranges] if args.key?(:source_nat_active_ranges)
  @source_nat_drain_ips = args[:source_nat_drain_ips] if args.key?(:source_nat_drain_ips)
  @source_nat_drain_ranges = args[:source_nat_drain_ranges] if args.key?(:source_nat_drain_ranges)
end