Class: Google::Apis::ComputeBeta::RouterNatSubnetworkToNat
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterNatSubnetworkToNat
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Defines the IP ranges that want to use NAT for a subnetwork.
Instance Attribute Summary collapse
-
#name ⇒ String
URL for the subnetwork resource that will use NAT.
-
#secondary_ip_range_names ⇒ Array<String>
A list of the secondary ranges of the Subnetwork that are allowed to use NAT.
-
#source_ip_ranges_to_nat ⇒ Array<String>
Specify the options for NAT ranges in the Subnetwork.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatSubnetworkToNat
constructor
A new instance of RouterNatSubnetworkToNat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatSubnetworkToNat
Returns a new instance of RouterNatSubnetworkToNat.
53205 53206 53207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
URL for the subnetwork resource that will use NAT.
Corresponds to the JSON property name
53186 53187 53188 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53186 def name @name end |
#secondary_ip_range_names ⇒ Array<String>
A list of the secondary ranges of the Subnetwork that are allowed to
use NAT. This can be populated only if "LIST_OF_SECONDARY_IP_RANGES"
is one of the values in source_ip_ranges_to_nat.
Corresponds to the JSON property secondaryIpRangeNames
53193 53194 53195 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53193 def secondary_ip_range_names @secondary_ip_range_names end |
#source_ip_ranges_to_nat ⇒ Array<String>
Specify the options for NAT ranges in the Subnetwork. All
options of a single value are valid except
NAT_IP_RANGE_OPTION_UNSPECIFIED.
The only valid option with multiple values is: ["PRIMARY_IP_RANGE",
"LIST_OF_SECONDARY_IP_RANGES"]
Default: [ALL_IP_RANGES]
Corresponds to the JSON property sourceIpRangesToNat
53203 53204 53205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53203 def source_ip_ranges_to_nat @source_ip_ranges_to_nat end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53210 53211 53212 53213 53214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53210 def update!(**args) @name = args[:name] if args.key?(:name) @secondary_ip_range_names = args[:secondary_ip_range_names] if args.key?(:secondary_ip_range_names) @source_ip_ranges_to_nat = args[:source_ip_ranges_to_nat] if args.key?(:source_ip_ranges_to_nat) end |