Class: Google::Apis::ComputeBeta::RoutersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#routers ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of routers contained in this scope.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersScopedList::Warning
Informational warning which replaces the list of routers when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersScopedList
constructor
A new instance of RoutersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersScopedList
Returns a new instance of RoutersScopedList.
59660 59661 59662 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59660 def initialize(**args) update!(**args) end |
Instance Attribute Details
#routers ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of routers contained in this scope.
Corresponds to the JSON property routers
59652 59653 59654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59652 def routers @routers end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersScopedList::Warning
Informational warning which replaces the list of routers when
the list is empty.
Corresponds to the JSON property warning
59658 59659 59660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59658 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59665 59666 59667 59668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59665 def update!(**args) @routers = args[:routers] if args.key?(:routers) @warning = args[:warning] if args.key?(:warning) end |