Class: Google::Apis::ComputeBeta::SavedAttachedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SavedAttachedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.
Instance Attribute Summary collapse
-
#auto_delete ⇒ Boolean
(also: #auto_delete?)
Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance).
-
#boot ⇒ Boolean
(also: #boot?)
Indicates that this is a boot disk.
-
#device_name ⇒ String
Specifies the name of the disk attached to the source instance.
-
#disk_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
The encryption key for the disk.
-
#disk_size_gb ⇒ Fixnum
The size of the disk in base-2 GB.
-
#disk_type ⇒ String
Output only.
-
#guest_os_features ⇒ Array<Google::Apis::ComputeBeta::GuestOsFeature>
A list of features to enable on the guest operating system.
-
#index ⇒ Fixnum
Output only.
-
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
-
#kind ⇒ String
Output only.
-
#licenses ⇒ Array<String>
Output only.
-
#mode ⇒ String
The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY.
-
#source ⇒ String
Specifies a URL of the disk attached to the source instance.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
-
#type ⇒ String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedAttachedDisk
constructor
A new instance of SavedAttachedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedAttachedDisk
Returns a new instance of SavedAttachedDisk.
59928 59929 59930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59928 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ Boolean Also known as: auto_delete?
Specifies whether the disk will be auto-deleted when the instance is
deleted (but not when the disk is detached from the instance).
Corresponds to the JSON property autoDelete
59832 59833 59834 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59832 def auto_delete @auto_delete end |
#boot ⇒ Boolean Also known as: boot?
Indicates that this is a boot disk. The virtual machine will use the first
partition of the disk for its root filesystem.
Corresponds to the JSON property boot
59839 59840 59841 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59839 def boot @boot end |
#device_name ⇒ String
Specifies the name of the disk attached to the source instance.
Corresponds to the JSON property deviceName
59845 59846 59847 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59845 def device_name @device_name end |
#disk_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
The encryption key for the disk.
Corresponds to the JSON property diskEncryptionKey
59850 59851 59852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59850 def disk_encryption_key @disk_encryption_key end |
#disk_size_gb ⇒ Fixnum
The size of the disk in base-2 GB.
Corresponds to the JSON property diskSizeGb
59855 59856 59857 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59855 def disk_size_gb @disk_size_gb end |
#disk_type ⇒ String
Output only. [Output Only] URL of the disk type resource. For example:projects/
project/zones/zone/diskTypes/pd-standard or
pd-ssd
Corresponds to the JSON property diskType
59862 59863 59864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59862 def disk_type @disk_type end |
#guest_os_features ⇒ Array<Google::Apis::ComputeBeta::GuestOsFeature>
A list of features to enable on the guest operating system. Applicable only
for bootable images. Read
Enabling guest operating system features to see a list of available
options.
Corresponds to the JSON property guestOsFeatures
59870 59871 59872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59870 def guest_os_features @guest_os_features end |
#index ⇒ Fixnum
Output only. Specifies zero-based index of the disk that is attached to the
source
instance.
Corresponds to the JSON property index
59877 59878 59879 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59877 def index @index end |
#interface ⇒ String
Specifies the disk interface to use for attaching this disk, which is
either SCSI or NVME.
Corresponds to the JSON property interface
59883 59884 59885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59883 def interface @interface end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk
for attached disks.
Corresponds to the JSON property kind
59889 59890 59891 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59889 def kind @kind end |
#licenses ⇒ Array<String>
Output only. [Output Only] Any valid publicly visible licenses.
Corresponds to the JSON property licenses
59894 59895 59896 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59894 def licenses @licenses end |
#mode ⇒ String
The mode in which this disk is attached to the source instance,
eitherREAD_WRITE or READ_ONLY.
Corresponds to the JSON property mode
59900 59901 59902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59900 def mode @mode end |
#source ⇒ String
Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property source
59905 59906 59907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59905 def source @source end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] A size of the storage used by the disk's snapshot
by this
machine image.
Corresponds to the JSON property storageBytes
59912 59913 59914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59912 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
59921 59922 59923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59921 def storage_bytes_status @storage_bytes_status end |
#type ⇒ String
Specifies the type of the attached disk, either SCRATCH orPERSISTENT.
Corresponds to the JSON property type
59926 59927 59928 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59926 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59933 59934 59935 59936 59937 59938 59939 59940 59941 59942 59943 59944 59945 59946 59947 59948 59949 59950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59933 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @boot = args[:boot] if args.key?(:boot) @device_name = args[:device_name] if args.key?(:device_name) @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key) @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb) @disk_type = args[:disk_type] if args.key?(:disk_type) @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features) @index = args[:index] if args.key?(:index) @interface = args[:interface] if args.key?(:interface) @kind = args[:kind] if args.key?(:kind) @licenses = args[:licenses] if args.key?(:licenses) @mode = args[:mode] if args.key?(:mode) @source = args[:source] if args.key?(:source) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) @type = args[:type] if args.key?(:type) end |