Class: Google::Apis::ComputeBeta::ScalingScheduleStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ScalingScheduleStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#last_start_time ⇒ String
[Output Only] The last time the scaling schedule became active.
-
#next_start_time ⇒ String
[Output Only] The next time the scaling schedule is to become active.
-
#state ⇒ String
[Output Only] The current state of a scaling schedule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ScalingScheduleStatus
constructor
A new instance of ScalingScheduleStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ScalingScheduleStatus
Returns a new instance of ScalingScheduleStatus.
54324 54325 54326 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54324 def initialize(**args) update!(**args) end |
Instance Attribute Details
#last_start_time ⇒ String
[Output Only] The last time the scaling schedule became active.
Note: this is a timestamp when a schedule actually became active, not when
it was planned to do so.
The timestamp is in RFC3339
text format.
Corresponds to the JSON property lastStartTime
54308 54309 54310 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54308 def last_start_time @last_start_time end |
#next_start_time ⇒ String
[Output Only] The next time the scaling schedule is to become active.
Note: this is a timestamp when a schedule is planned to run, but the actual
time might be slightly different.
The timestamp is in RFC3339
text format.
Corresponds to the JSON property nextStartTime
54317 54318 54319 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54317 def next_start_time @next_start_time end |
#state ⇒ String
[Output Only] The current state of a scaling schedule.
Corresponds to the JSON property state
54322 54323 54324 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54322 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54329 54330 54331 54332 54333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54329 def update!(**args) @last_start_time = args[:last_start_time] if args.key?(:last_start_time) @next_start_time = args[:next_start_time] if args.key?(:next_start_time) @state = args[:state] if args.key?(:state) end |