Class: Google::Apis::ComputeBeta::SchedulingGracefulShutdown

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The configuration for gracefully shutting down the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingGracefulShutdown

Returns a new instance of SchedulingGracefulShutdown.



60228
60229
60230
# File 'lib/google/apis/compute_beta/classes.rb', line 60228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Opts-in for graceful shutdown. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


60217
60218
60219
# File 'lib/google/apis/compute_beta/classes.rb', line 60217

def enabled
  @enabled
end

#max_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



60226
60227
60228
# File 'lib/google/apis/compute_beta/classes.rb', line 60226

def max_duration
  @max_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60233
60234
60235
60236
# File 'lib/google/apis/compute_beta/classes.rb', line 60233

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
end