Class: Google::Apis::ComputeBeta::SecurityPoliciesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Informational warning which replaces the list of security policies when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



60024
60025
60026
# File 'lib/google/apis/compute_beta/classes.rb', line 60024

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


60006
60007
60008
# File 'lib/google/apis/compute_beta/classes.rb', line 60006

def code
  @code
end

#dataArray<Google::Apis::ComputeBeta::SecurityPoliciesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



60017
60018
60019
# File 'lib/google/apis/compute_beta/classes.rb', line 60017

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


60022
60023
60024
# File 'lib/google/apis/compute_beta/classes.rb', line 60022

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60029
60030
60031
60032
60033
# File 'lib/google/apis/compute_beta/classes.rb', line 60029

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end