Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration options for L7 DDoS detection. This field is only supported in Global Security Policies of type CLOUD_ARMOR.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
If set to true, enables CAAP for L7 DDoS detection.
-
#rule_visibility ⇒ String
Rule visibility can be one of the following: STANDARD - opaque rules.
-
#threshold_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>
Configuration options for layer7 adaptive protection for various customizable thresholds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfig.
55209 55210 55211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
If set to true, enables CAAP for L7 DDoS detection.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property enable
55191 55192 55193 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55191 def enable @enable end |
#rule_visibility ⇒ String
Rule visibility can be one of the following:
STANDARD - opaque rules. (default)
PREMIUM - transparent rules.
This field is only supported in Global Security Policies of type
CLOUD_ARMOR.
Corresponds to the JSON property ruleVisibility
55201 55202 55203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55201 def rule_visibility @rule_visibility end |
#threshold_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig>
Configuration options for layer7 adaptive protection for various
customizable thresholds.
Corresponds to the JSON property thresholdConfigs
55207 55208 55209 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55207 def threshold_configs @threshold_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55214 55215 55216 55217 55218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55214 def update!(**args) @enable = args[:enable] if args.key?(:enable) @rule_visibility = args[:rule_visibility] if args.key?(:rule_visibility) @threshold_configs = args[:threshold_configs] if args.key?(:threshold_configs) end |