Class: Google::Apis::ComputeBeta::SecurityPolicyDdosProtectionConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyDdosProtectionConfig

Returns a new instance of SecurityPolicyDdosProtectionConfig.



61200
61201
61202
# File 'lib/google/apis/compute_beta/classes.rb', line 61200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ddos_adaptive_protectionString

Corresponds to the JSON property ddosAdaptiveProtection

Returns:

  • (String)


61175
61176
61177
# File 'lib/google/apis/compute_beta/classes.rb', line 61175

def ddos_adaptive_protection
  @ddos_adaptive_protection
end

#ddos_impacted_baseline_thresholdFloat

DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage. It quantifies this as the fraction of a non-abuse baseline that's inadvertently blocked. Rules whose collateral damage exceeds ddosImpactedBaselineThreshold will not be deployed. Using a lower value will prioritize keeping collateral damage low, possibly at the cost of its effectiveness in rate limiting some or all of the attack. It should typically be unset, so Advanced DDoS (and Adaptive Protection) uses the best mitigation it can find. Setting the threshold is advised if there are logs for false positive detections with high collateral damage, and will cause Advanced DDoS to attempt to find a less aggressive rule that satisfies the constraint. If a suitable rule cannot be found, the system falls back to either no mitigation for smaller attacks or broader network throttles for larger ones. Corresponds to the JSON property ddosImpactedBaselineThreshold

Returns:

  • (Float)


61193
61194
61195
# File 'lib/google/apis/compute_beta/classes.rb', line 61193

def ddos_impacted_baseline_threshold
  @ddos_impacted_baseline_threshold
end

#ddos_protectionString

Corresponds to the JSON property ddosProtection

Returns:

  • (String)


61198
61199
61200
# File 'lib/google/apis/compute_beta/classes.rb', line 61198

def ddos_protection
  @ddos_protection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61205
61206
61207
61208
61209
# File 'lib/google/apis/compute_beta/classes.rb', line 61205

def update!(**args)
  @ddos_adaptive_protection = args[:ddos_adaptive_protection] if args.key?(:ddos_adaptive_protection)
  @ddos_impacted_baseline_threshold = args[:ddos_impacted_baseline_threshold] if args.key?(:ddos_impacted_baseline_threshold)
  @ddos_protection = args[:ddos_protection] if args.key?(:ddos_protection)
end