Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfigLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig
constructor
A new instance of SecurityPolicyRuleMatcherConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfig
Returns a new instance of SecurityPolicyRuleMatcherConfig.
60740 60741 60742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property destIpRanges
60725 60726 60727 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60725 def dest_ip_ranges @dest_ip_ranges end |
#layer4_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfigLayer4Config>
Pairs of IP protocols and ports that the rule should match.
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property layer4Configs
60732 60733 60734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60732 def layer4_configs @layer4_configs end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of src_ip_ranges allowed is 10.
Corresponds to the JSON property srcIpRanges
60738 60739 60740 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60738 def src_ip_ranges @src_ip_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60745 60746 60747 60748 60749 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60745 def update!(**args) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) end |