Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfigLayer4Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfigLayer4Config

Returns a new instance of SecurityPolicyRuleMatcherConfigLayer4Config.



61716
61717
61718
# File 'lib/google/apis/compute_beta/classes.rb', line 61716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp,udp, icmp, esp,ah, ipip, sctp), or the IP protocol number. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


61703
61704
61705
# File 'lib/google/apis/compute_beta/classes.rb', line 61703

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"],["80","443"], and ["12345-12349"]. This field may only be specified when versioned_expr is set to FIREWALL. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


61714
61715
61716
# File 'lib/google/apis/compute_beta/classes.rb', line 61714

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61721
61722
61723
61724
# File 'lib/google/apis/compute_beta/classes.rb', line 61721

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end