Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#action_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA action-tokens.
-
#session_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA session-tokens.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.
59958 59959 59960 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA
action-tokens. The provided site keys need to be created from
reCAPTCHA API under the same project where the security policy is
created.
Corresponds to the JSON property actionTokenSiteKeys
59948 59949 59950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59948 def action_token_site_keys @action_token_site_keys end |
#session_token_site_keys ⇒ Array<String>
A list of site keys to be used during the validation of reCAPTCHA
session-tokens. The provided site keys need to be created from
reCAPTCHA API under the same project where the security policy is
created.
Corresponds to the JSON property sessionTokenSiteKeys
59956 59957 59958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59956 def session_token_site_keys @session_token_site_keys end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59963 59964 59965 59966 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59963 def update!(**args) @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys) @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys) end |