Class: Google::Apis::ComputeBeta::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#enforce_on_key_name ⇒ String
Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value.
-
#enforce_on_key_type ⇒ String
Determines the key to enforce the rate_limit_threshold on.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
constructor
A new instance of SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig
Returns a new instance of SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig.
56456 56457 56458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56456 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enforce_on_key_name ⇒ String
Rate limit key name applicable only for the following key types:
HTTP_HEADER -- Name of the HTTP header whose value is taken as the
key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is
taken as the key value.
Corresponds to the JSON property enforceOnKeyName
56411 56412 56413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56411 def enforce_on_key_name @enforce_on_key_name end |
#enforce_on_key_type ⇒ String
Determines the key to enforce the rate_limit_threshold on. Possible values are:
- ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKeyConfigs" is not configured.
- IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
- HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
- XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
- HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
- HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
- SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
- REGION_CODE: The country/region from which the request originates.
- TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
- USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.
- TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the
client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the
key type defaults to ALL.
Corresponds to the JSON property
enforceOnKeyType
56454 56455 56456 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56454 def enforce_on_key_type @enforce_on_key_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56461 56462 56463 56464 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56461 def update!(**args) @enforce_on_key_name = args[:enforce_on_key_name] if args.key?(:enforce_on_key_name) @enforce_on_key_type = args[:enforce_on_key_type] if args.key?(:enforce_on_key_type) end |