Class: Google::Apis::ComputeBeta::ServiceAttachmentTunnelingConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ServiceAttachmentTunnelingConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Use to configure this PSC connection in tunneling mode. In tunneling mode traffic from consumer to producer will be encapsulated as it crosses the VPC boundary and traffic from producer to consumer will be decapsulated in the same manner.
Instance Attribute Summary collapse
-
#encapsulation_profile ⇒ String
Specify the encapsulation protocol and what metadata to include in incoming encapsulated packet headers.
-
#routing_mode ⇒ String
How this Service Attachment will treat traffic sent to the tunnel_ip, destined for the consumer network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentTunnelingConfig
constructor
A new instance of ServiceAttachmentTunnelingConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentTunnelingConfig
Returns a new instance of ServiceAttachmentTunnelingConfig.
63053 63054 63055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#encapsulation_profile ⇒ String
Specify the encapsulation protocol and what metadata to include in
incoming encapsulated packet headers.
Corresponds to the JSON property encapsulationProfile
63045 63046 63047 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63045 def encapsulation_profile @encapsulation_profile end |
#routing_mode ⇒ String
How this Service Attachment will treat traffic sent to the tunnel_ip,
destined for the consumer network.
Corresponds to the JSON property routingMode
63051 63052 63053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63051 def routing_mode @routing_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63058 63059 63060 63061 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63058 def update!(**args) @encapsulation_profile = args[:encapsulation_profile] if args.key?(:encapsulation_profile) @routing_mode = args[:routing_mode] if args.key?(:routing_mode) end |