Class: Google::Apis::ComputeBeta::ShareSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The share setting for reservations and sole tenancy node groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShareSettings

Returns a new instance of ShareSettings.



62738
62739
62740
# File 'lib/google/apis/compute_beta/classes.rb', line 62738

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folder_mapHash<String,Google::Apis::ComputeBeta::ShareSettingsFolderConfig>

A map of folder id and folder config to specify consumer projects for this shared-reservation. This is only valid when share_type's value is DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id should be a string of number, and without "folders/" prefix. Corresponds to the JSON property folderMap



62718
62719
62720
# File 'lib/google/apis/compute_beta/classes.rb', line 62718

def folder_map
  @folder_map
end

#project_mapHash<String,Google::Apis::ComputeBeta::ShareSettingsProjectConfig>

A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS. Corresponds to the JSON property projectMap



62724
62725
62726
# File 'lib/google/apis/compute_beta/classes.rb', line 62724

def project_map
  @project_map
end

#projectsArray<String>

A List of Project names to specify consumer projects for this shared-reservation. This is only valid when share_type's value is SPECIFIC_PROJECTS. Corresponds to the JSON property projects

Returns:

  • (Array<String>)


62731
62732
62733
# File 'lib/google/apis/compute_beta/classes.rb', line 62731

def projects
  @projects
end

#share_typeString

Type of sharing for this shared-reservation Corresponds to the JSON property shareType

Returns:

  • (String)


62736
62737
62738
# File 'lib/google/apis/compute_beta/classes.rb', line 62736

def share_type
  @share_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62743
62744
62745
62746
62747
62748
# File 'lib/google/apis/compute_beta/classes.rb', line 62743

def update!(**args)
  @folder_map = args[:folder_map] if args.key?(:folder_map)
  @project_map = args[:project_map] if args.key?(:project_map)
  @projects = args[:projects] if args.key?(:projects)
  @share_type = args[:share_type] if args.key?(:share_type)
end