Class: Google::Apis::ComputeBeta::ShareSettingsFolderConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Config for each folder in the share settings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShareSettingsFolderConfig

Returns a new instance of ShareSettingsFolderConfig.



62298
62299
62300
# File 'lib/google/apis/compute_beta/classes.rb', line 62298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folder_idString

The folder ID, should be same as the key of this folder config in the parent map. Folder id should be a string of number, and without "folders/" prefix. Corresponds to the JSON property folderId

Returns:

  • (String)


62296
62297
62298
# File 'lib/google/apis/compute_beta/classes.rb', line 62296

def folder_id
  @folder_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62303
62304
62305
# File 'lib/google/apis/compute_beta/classes.rb', line 62303

def update!(**args)
  @folder_id = args[:folder_id] if args.key?(:folder_id)
end