Class: Google::Apis::ComputeBeta::ShieldedInstanceIntegrityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The policy describes the baseline against which Instance boot integrity is measured.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShieldedInstanceIntegrityPolicy

Returns a new instance of ShieldedInstanceIntegrityPolicy.



61630
61631
61632
# File 'lib/google/apis/compute_beta/classes.rb', line 61630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#update_auto_learn_policyBoolean Also known as: update_auto_learn_policy?

Updates the integrity policy baseline using the measurements from the VM instance's most recent boot. Corresponds to the JSON property updateAutoLearnPolicy

Returns:

  • (Boolean)


61627
61628
61629
# File 'lib/google/apis/compute_beta/classes.rb', line 61627

def update_auto_learn_policy
  @update_auto_learn_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61635
61636
61637
# File 'lib/google/apis/compute_beta/classes.rb', line 61635

def update!(**args)
  @update_auto_learn_policy = args[:update_auto_learn_policy] if args.key?(:update_auto_learn_policy)
end