Class: Google::Apis::ComputeBeta::SignedUrlKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SignedUrlKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a customer-supplied Signing Key used by Cloud CDN Signed URLs
Instance Attribute Summary collapse
-
#key_name ⇒ String
Name of the key.
-
#key_value ⇒ String
128-bit key value used for signing the URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SignedUrlKey
constructor
A new instance of SignedUrlKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SignedUrlKey
Returns a new instance of SignedUrlKey.
57808 57809 57810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57808 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key_name ⇒ String
Name of the key. The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property keyName
57800 57801 57802 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57800 def key_name @key_name end |
#key_value ⇒ String
128-bit key value used for signing the URL. The key value must be a validRFC
4648 Section 5 base64url encoded string.
Corresponds to the JSON property keyValue
57806 57807 57808 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57806 def key_value @key_value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57813 57814 57815 57816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57813 def update!(**args) @key_name = args[:key_name] if args.key?(:key_name) @key_value = args[:key_value] if args.key?(:key_value) end |