Class: Google::Apis::ComputeBeta::SnapshotGroupParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotGroupParameters

Returns a new instance of SnapshotGroupParameters.



63797
63798
63799
# File 'lib/google/apis/compute_beta/classes.rb', line 63797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#replica_zonesArray<String>

URLs of the zones where disks should be replicated to. Only applicable for regional resources. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


63774
63775
63776
# File 'lib/google/apis/compute_beta/classes.rb', line 63774

def replica_zones
  @replica_zones
end

#source_snapshot_groupString

The source snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


63787
63788
63789
# File 'lib/google/apis/compute_beta/classes.rb', line 63787

def source_snapshot_group
  @source_snapshot_group
end

#typeString

URL of the disk type resource describing which disk type to use to create disks. Provide this when creating the disk. For example:projects/project/zones/ zone/diskTypes/pd-ssd. See Persistent disk types. Corresponds to the JSON property type

Returns:

  • (String)


63795
63796
63797
# File 'lib/google/apis/compute_beta/classes.rb', line 63795

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63802
63803
63804
63805
63806
# File 'lib/google/apis/compute_beta/classes.rb', line 63802

def update!(**args)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @source_snapshot_group = args[:source_snapshot_group] if args.key?(:source_snapshot_group)
  @type = args[:type] if args.key?(:type)
end