Class: Google::Apis::ComputeBeta::SnapshotSettingsAccessLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettingsAccessLocation

Returns a new instance of SnapshotSettingsAccessLocation.



62602
62603
62604
# File 'lib/google/apis/compute_beta/classes.rb', line 62602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationsHash<String,Google::Apis::ComputeBeta::SnapshotSettingsAccessLocationAccessLocationPreference>

List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property locations



62595
62596
62597
# File 'lib/google/apis/compute_beta/classes.rb', line 62595

def locations
  @locations
end

#policyString

Policy of which location is allowed to access snapshot. Corresponds to the JSON property policy

Returns:

  • (String)


62600
62601
62602
# File 'lib/google/apis/compute_beta/classes.rb', line 62600

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62607
62608
62609
62610
# File 'lib/google/apis/compute_beta/classes.rb', line 62607

def update!(**args)
  @locations = args[:locations] if args.key?(:locations)
  @policy = args[:policy] if args.key?(:policy)
end