Class: Google::Apis::ComputeBeta::SslCertificate
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslCertificate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an SSL certificate resource. Google Compute Engine has two SSL certificate resources:
- Global
Regional The global SSL certificates (sslCertificates) are used by:
Global external Application Load Balancers
Classic Application Load Balancers
Proxy Network Load Balancers (with target SSL proxies) The regional SSL certificates (regionSslCertificates) are used by:
Regional external Application Load Balancers
Regional internal Application Load Balancers Optionally, certificate file contents that you upload can contain a set of up to five PEM-encoded certificates. The API call creates an object (sslCertificate) that holds this data. You can use SSL keys and certificates to secure connections to a load balancer. For more information, read Creating and using SSL certificates,SSL certificates quotas and limits, and Troubleshooting SSL certificates.
Instance Attribute Summary collapse
-
#certificate ⇒ String
A value read into memory from a certificate file.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#description ⇒ String
An optional description of this resource.
-
#expire_time ⇒ String
Output only.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#managed ⇒ Google::Apis::ComputeBeta::SslCertificateManagedSslCertificate
Configuration and status of a managed SSL certificate.
-
#name ⇒ String
Name of the resource.
-
#private_key ⇒ String
A value read into memory from a write-only private key file.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output only] Server-defined URL for the resource.
-
#self_managed ⇒ Google::Apis::ComputeBeta::SslCertificateSelfManagedSslCertificate
Configuration and status of a self-managed SSL certificate.
-
#subject_alternative_names ⇒ Array<String>
Output only.
-
#type ⇒ String
(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or "MANAGED".
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificate
constructor
A new instance of SslCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificate
Returns a new instance of SslCertificate.
58971 58972 58973 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate ⇒ String
A value read into memory from a certificate file. The certificate file must
be in PEM format. The certificate chain must be no greater than 5 certs
long. The chain must include at least one intermediate cert.
Corresponds to the JSON property certificate
58887 58888 58889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58887 def certificate @certificate end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
58893 58894 58895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58893 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
58899 58900 58901 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58899 def description @description end |
#expire_time ⇒ String
Output only. [Output Only] Expire time of the certificate. RFC3339
Corresponds to the JSON property expireTime
58904 58905 58906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58904 def expire_time @expire_time end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58910 58911 58912 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58910 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#sslCertificate
for SSL certificates.
Corresponds to the JSON property kind
58916 58917 58918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58916 def kind @kind end |
#managed ⇒ Google::Apis::ComputeBeta::SslCertificateManagedSslCertificate
Configuration and status of a managed SSL certificate.
Corresponds to the JSON property managed
58921 58922 58923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58921 def managed @managed end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
58932 58933 58934 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58932 def name @name end |
#private_key ⇒ String
A value read into memory from a write-only private key file. The private
key file must be in PEM format. For security, only insert
requests include this field.
Corresponds to the JSON property privateKey
58939 58940 58941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58939 def private_key @private_key end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional SSL
Certificate
resides. This field is not applicable to global SSL Certificate.
Corresponds to the JSON property region
58946 58947 58948 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58946 def region @region end |
#self_link ⇒ String
[Output only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
58951 58952 58953 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58951 def self_link @self_link end |
#self_managed ⇒ Google::Apis::ComputeBeta::SslCertificateSelfManagedSslCertificate
Configuration and status of a self-managed SSL certificate.
Corresponds to the JSON property selfManaged
58956 58957 58958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58956 def self_managed @self_managed end |
#subject_alternative_names ⇒ Array<String>
Output only. [Output Only] Domains associated with the certificate via Subject
Alternative Name.
Corresponds to the JSON property subjectAlternativeNames
58962 58963 58964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58962 def subject_alternative_names @subject_alternative_names end |
#type ⇒ String
(Optional) Specifies the type of SSL certificate, either "SELF_MANAGED" or
"MANAGED". If not specified, the certificate is self-managed and the
fieldscertificate and private_key are used.
Corresponds to the JSON property type
58969 58970 58971 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58969 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58976 58977 58978 58979 58980 58981 58982 58983 58984 58985 58986 58987 58988 58989 58990 58991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58976 def update!(**args) @certificate = args[:certificate] if args.key?(:certificate) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @expire_time = args[:expire_time] if args.key?(:expire_time) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @managed = args[:managed] if args.key?(:managed) @name = args[:name] if args.key?(:name) @private_key = args[:private_key] if args.key?(:private_key) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_managed = args[:self_managed] if args.key?(:self_managed) @subject_alternative_names = args[:subject_alternative_names] if args.key?(:subject_alternative_names) @type = args[:type] if args.key?(:type) end |