Class: Google::Apis::ComputeBeta::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



65022
65023
65024
# File 'lib/google/apis/compute_beta/classes.rb', line 65022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64983
64984
64985
# File 'lib/google/apis/compute_beta/classes.rb', line 64983

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



64988
64989
64990
# File 'lib/google/apis/compute_beta/classes.rb', line 64988

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


64995
64996
64997
# File 'lib/google/apis/compute_beta/classes.rb', line 64995

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65005
65006
65007
# File 'lib/google/apis/compute_beta/classes.rb', line 65005

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65010
65011
65012
# File 'lib/google/apis/compute_beta/classes.rb', line 65010

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65015
65016
65017
# File 'lib/google/apis/compute_beta/classes.rb', line 65015

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65020
65021
65022
# File 'lib/google/apis/compute_beta/classes.rb', line 65020

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65027
65028
65029
65030
65031
65032
65033
65034
65035
# File 'lib/google/apis/compute_beta/classes.rb', line 65027

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end