Class: Google::Apis::ComputeBeta::SslCertificateManagedSslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration and status of a managed SSL certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateManagedSslCertificate

Returns a new instance of SslCertificateManagedSslCertificate.



59274
59275
59276
# File 'lib/google/apis/compute_beta/classes.rb', line 59274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domain_statusHash<String,String>

Output only. [Output only] Detailed statuses of the domains specified for managed certificate resource. Corresponds to the JSON property domainStatus

Returns:

  • (Hash<String,String>)


59259
59260
59261
# File 'lib/google/apis/compute_beta/classes.rb', line 59259

def domain_status
  @domain_status
end

#domainsArray<String>

The domains for which a managed SSL certificate will be generated. Each Google-managed SSL certificate supports up to the maximum number of domains per Google-managed SSL certificate. Corresponds to the JSON property domains

Returns:

  • (Array<String>)


59267
59268
59269
# File 'lib/google/apis/compute_beta/classes.rb', line 59267

def domains
  @domains
end

#statusString

Output only. [Output only] Status of the managed certificate resource. Corresponds to the JSON property status

Returns:

  • (String)


59272
59273
59274
# File 'lib/google/apis/compute_beta/classes.rb', line 59272

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59279
59280
59281
59282
59283
# File 'lib/google/apis/compute_beta/classes.rb', line 59279

def update!(**args)
  @domain_status = args[:domain_status] if args.key?(:domain_status)
  @domains = args[:domains] if args.key?(:domains)
  @status = args[:status] if args.key?(:status)
end