Class: Google::Apis::ComputeBeta::SslCertificateSelfManagedSslCertificate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration and status of a self-managed SSL certificate.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateSelfManagedSslCertificate

Returns a new instance of SslCertificateSelfManagedSslCertificate.



64807
64808
64809
# File 'lib/google/apis/compute_beta/classes.rb', line 64807

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificateString

A local certificate file. The certificate must be in PEM format. The certificate chain must be no greater than 5 certs long. The chain must include at least one intermediate cert. Corresponds to the JSON property certificate

Returns:

  • (String)


64799
64800
64801
# File 'lib/google/apis/compute_beta/classes.rb', line 64799

def certificate
  @certificate
end

#private_keyString

A write-only private key in PEM format. Only insert requests will include this field. Corresponds to the JSON property privateKey

Returns:

  • (String)


64805
64806
64807
# File 'lib/google/apis/compute_beta/classes.rb', line 64805

def private_key
  @private_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64812
64813
64814
64815
# File 'lib/google/apis/compute_beta/classes.rb', line 64812

def update!(**args)
  @certificate = args[:certificate] if args.key?(:certificate)
  @private_key = args[:private_key] if args.key?(:private_key)
end