Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



66374
66375
66376
# File 'lib/google/apis/compute_beta/classes.rb', line 66374

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


66330
66331
66332
# File 'lib/google/apis/compute_beta/classes.rb', line 66330

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66335
66336
66337
# File 'lib/google/apis/compute_beta/classes.rb', line 66335

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



66340
66341
66342
# File 'lib/google/apis/compute_beta/classes.rb', line 66340

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


66347
66348
66349
# File 'lib/google/apis/compute_beta/classes.rb', line 66347

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66357
66358
66359
# File 'lib/google/apis/compute_beta/classes.rb', line 66357

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66362
66363
66364
# File 'lib/google/apis/compute_beta/classes.rb', line 66362

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66367
66368
66369
# File 'lib/google/apis/compute_beta/classes.rb', line 66367

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66372
66373
66374
# File 'lib/google/apis/compute_beta/classes.rb', line 66372

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66379
66380
66381
66382
66383
66384
66385
66386
66387
66388
# File 'lib/google/apis/compute_beta/classes.rb', line 66379

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end