Class: Google::Apis::ComputeBeta::StoragePoolExapoolProvisionedCapacityGb

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Exapool provisioned capacities for each SKU type

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolExapoolProvisionedCapacityGb

Returns a new instance of StoragePoolExapoolProvisionedCapacityGb.



60562
60563
60564
# File 'lib/google/apis/compute_beta/classes.rb', line 60562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#capacity_optimizedFixnum

Output only. Size, in GiB, of provisioned capacity-optimized capacity for this Exapool Corresponds to the JSON property capacityOptimized

Returns:

  • (Fixnum)


60548
60549
60550
# File 'lib/google/apis/compute_beta/classes.rb', line 60548

def capacity_optimized
  @capacity_optimized
end

#read_optimizedFixnum

Output only. Size, in GiB, of provisioned read-optimized capacity for this Exapool Corresponds to the JSON property readOptimized

Returns:

  • (Fixnum)


60554
60555
60556
# File 'lib/google/apis/compute_beta/classes.rb', line 60554

def read_optimized
  @read_optimized
end

#write_optimizedFixnum

Output only. Size, in GiB, of provisioned write-optimized capacity for this Exapool Corresponds to the JSON property writeOptimized

Returns:

  • (Fixnum)


60560
60561
60562
# File 'lib/google/apis/compute_beta/classes.rb', line 60560

def write_optimized
  @write_optimized
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60567
60568
60569
60570
60571
# File 'lib/google/apis/compute_beta/classes.rb', line 60567

def update!(**args)
  @capacity_optimized = args[:capacity_optimized] if args.key?(:capacity_optimized)
  @read_optimized = args[:read_optimized] if args.key?(:read_optimized)
  @write_optimized = args[:write_optimized] if args.key?(:write_optimized)
end