Class: Google::Apis::ComputeBeta::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



66766
66767
66768
# File 'lib/google/apis/compute_beta/classes.rb', line 66766

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


66719
66720
66721
# File 'lib/google/apis/compute_beta/classes.rb', line 66719

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66725
66726
66727
# File 'lib/google/apis/compute_beta/classes.rb', line 66725

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



66730
66731
66732
# File 'lib/google/apis/compute_beta/classes.rb', line 66730

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


66737
66738
66739
# File 'lib/google/apis/compute_beta/classes.rb', line 66737

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66748
66749
66750
# File 'lib/google/apis/compute_beta/classes.rb', line 66748

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66753
66754
66755
# File 'lib/google/apis/compute_beta/classes.rb', line 66753

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66759
66760
66761
# File 'lib/google/apis/compute_beta/classes.rb', line 66759

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



66764
66765
66766
# File 'lib/google/apis/compute_beta/classes.rb', line 66764

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66771
66772
66773
66774
66775
66776
66777
66778
66779
66780
# File 'lib/google/apis/compute_beta/classes.rb', line 66771

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end