Class: Google::Apis::ComputeBeta::StoragePoolResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolResourceStatus

Returns a new instance of StoragePoolResourceStatus.



66966
66967
66968
# File 'lib/google/apis/compute_beta/classes.rb', line 66966

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_countFixnum

[Output Only] Number of disks used. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


66886
66887
66888
# File 'lib/google/apis/compute_beta/classes.rb', line 66886

def disk_count
  @disk_count
end

#exapool_max_read_iopsFixnum

Output only. [Output Only] Maximum allowed read IOPS for this Exapool. Corresponds to the JSON property exapoolMaxReadIops

Returns:

  • (Fixnum)


66891
66892
66893
# File 'lib/google/apis/compute_beta/classes.rb', line 66891

def exapool_max_read_iops
  @exapool_max_read_iops
end

#exapool_max_read_throughputFixnum

Output only. [Output Only] Maximum allowed read throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxReadThroughput

Returns:

  • (Fixnum)


66897
66898
66899
# File 'lib/google/apis/compute_beta/classes.rb', line 66897

def exapool_max_read_throughput
  @exapool_max_read_throughput
end

#exapool_max_write_iopsFixnum

Output only. [Output Only] Maximum allowed write IOPS for this Exapool. Corresponds to the JSON property exapoolMaxWriteIops

Returns:

  • (Fixnum)


66902
66903
66904
# File 'lib/google/apis/compute_beta/classes.rb', line 66902

def exapool_max_write_iops
  @exapool_max_write_iops
end

#exapool_max_write_throughputFixnum

Output only. [Output Only] Maximum allowed write throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxWriteThroughput

Returns:

  • (Fixnum)


66908
66909
66910
# File 'lib/google/apis/compute_beta/classes.rb', line 66908

def exapool_max_write_throughput
  @exapool_max_write_throughput
end

#last_resize_timestampString

Output only. [Output Only] Timestamp of the last successful resize inRFC3339 text format. Corresponds to the JSON property lastResizeTimestamp

Returns:

  • (String)


66914
66915
66916
# File 'lib/google/apis/compute_beta/classes.rb', line 66914

def last_resize_timestamp
  @last_resize_timestamp
end

#max_total_provisioned_disk_capacity_gbFixnum

[Output Only] Maximum allowed aggregate disk size in GiB. Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


66919
66920
66921
# File 'lib/google/apis/compute_beta/classes.rb', line 66919

def max_total_provisioned_disk_capacity_gb
  @max_total_provisioned_disk_capacity_gb
end

#pool_used_capacity_bytesFixnum

[Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks. Corresponds to the JSON property poolUsedCapacityBytes

Returns:

  • (Fixnum)


66926
66927
66928
# File 'lib/google/apis/compute_beta/classes.rb', line 66926

def pool_used_capacity_bytes
  @pool_used_capacity_bytes
end

#pool_used_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolUsedIops

Returns:

  • (Fixnum)


66934
66935
66936
# File 'lib/google/apis/compute_beta/classes.rb', line 66934

def pool_used_iops
  @pool_used_iops
end

#pool_used_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s. Corresponds to the JSON property poolUsedThroughput

Returns:

  • (Fixnum)


66939
66940
66941
# File 'lib/google/apis/compute_beta/classes.rb', line 66939

def pool_used_throughput
  @pool_used_throughput
end

#pool_user_written_bytesFixnum

[Output Only] Amount of data written into the pool, before it is compacted. Corresponds to the JSON property poolUserWrittenBytes

Returns:

  • (Fixnum)


66945
66946
66947
# File 'lib/google/apis/compute_beta/classes.rb', line 66945

def pool_user_written_bytes
  @pool_user_written_bytes
end

#total_provisioned_disk_capacity_gbFixnum

[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity. Corresponds to the JSON property totalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


66952
66953
66954
# File 'lib/google/apis/compute_beta/classes.rb', line 66952

def total_provisioned_disk_capacity_gb
  @total_provisioned_disk_capacity_gb
end

#total_provisioned_disk_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS. Corresponds to the JSON property totalProvisionedDiskIops

Returns:

  • (Fixnum)


66957
66958
66959
# File 'lib/google/apis/compute_beta/classes.rb', line 66957

def total_provisioned_disk_iops
  @total_provisioned_disk_iops
end

#total_provisioned_disk_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity. Corresponds to the JSON property totalProvisionedDiskThroughput

Returns:

  • (Fixnum)


66964
66965
66966
# File 'lib/google/apis/compute_beta/classes.rb', line 66964

def total_provisioned_disk_throughput
  @total_provisioned_disk_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66971
66972
66973
66974
66975
66976
66977
66978
66979
66980
66981
66982
66983
66984
66985
66986
# File 'lib/google/apis/compute_beta/classes.rb', line 66971

def update!(**args)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops)
  @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput)
  @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops)
  @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput)
  @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp)
  @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb)
  @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes)
  @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops)
  @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput)
  @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes)
  @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb)
  @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops)
  @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput)
end