Class: Google::Apis::ComputeBeta::StoragePoolShareSettingsProjectConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolShareSettingsProjectConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Config for each project in the share settings.
Instance Attribute Summary collapse
-
#project_id ⇒ String
The project ID, should be same as the key of this project config in the parent map.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolShareSettingsProjectConfig
constructor
A new instance of StoragePoolShareSettingsProjectConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolShareSettingsProjectConfig
Returns a new instance of StoragePoolShareSettingsProjectConfig.
66615 66616 66617 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66615 def initialize(**args) update!(**args) end |
Instance Attribute Details
#project_id ⇒ String
The project ID, should be same as the key of this project config in the
parent map.
Corresponds to the JSON property projectId
66613 66614 66615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66613 def project_id @project_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66620 66621 66622 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66620 def update!(**args) @project_id = args[:project_id] if args.key?(:project_id) end |