Class: Google::Apis::ComputeBeta::StructuredEntries
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StructuredEntries
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#entries ⇒ Hash<String,Object>
Map of a partner metadata that belong to the same subdomain.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StructuredEntries
constructor
A new instance of StructuredEntries.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StructuredEntries
Returns a new instance of StructuredEntries.
61565 61566 61567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entries ⇒ Hash<String,Object>
Map of a partner metadata that belong to the same subdomain.
It accepts any value including google.protobuf.Struct.
Corresponds to the JSON property entries
61563 61564 61565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61563 def entries @entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61570 61571 61572 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61570 def update!(**args) @entries = args[:entries] if args.key?(:entries) end |