Class: Google::Apis::ComputeBeta::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



67571
67572
67573
# File 'lib/google/apis/compute_beta/classes.rb', line 67571

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


67564
67565
67566
# File 'lib/google/apis/compute_beta/classes.rb', line 67564

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeBeta::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



67569
67570
67571
# File 'lib/google/apis/compute_beta/classes.rb', line 67569

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67576
67577
67578
67579
# File 'lib/google/apis/compute_beta/classes.rb', line 67576

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end