Class: Google::Apis::ComputeBeta::Subsetting

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Subsetting configuration for this BackendService. Currently this is applicable only for Internal TCP/UDP load balancing, Internal HTTP(S) load balancing and Traffic Director.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subsetting

Returns a new instance of Subsetting.



68328
68329
68330
# File 'lib/google/apis/compute_beta/classes.rb', line 68328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#policyString

Corresponds to the JSON property policy

Returns:

  • (String)


68309
68310
68311
# File 'lib/google/apis/compute_beta/classes.rb', line 68309

def policy
  @policy
end

#subset_sizeFixnum

The number of backends per backend group assigned to each proxy instance or each service mesh client. An input parameter to the CONSISTENT_HASH_SUBSETTING algorithm. Can only be set if policy is set to CONSISTENT_HASH_SUBSETTING. Can only be set if load balancing scheme is INTERNAL_MANAGED or INTERNAL_SELF_MANAGED. subset_size is optional for Internal HTTP(S) load balancing and required for Traffic Director. If you do not provide this value, Cloud Load Balancing will calculate it dynamically to optimize the number of proxies/clients visible to each backend and vice versa. Must be greater than 0. If subset_size is larger than the number of backends/endpoints, then subsetting is disabled. Corresponds to the JSON property subsetSize

Returns:

  • (Fixnum)


68326
68327
68328
# File 'lib/google/apis/compute_beta/classes.rb', line 68326

def subset_size
  @subset_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68333
68334
68335
68336
# File 'lib/google/apis/compute_beta/classes.rb', line 68333

def update!(**args)
  @policy = args[:policy] if args.key?(:policy)
  @subset_size = args[:subset_size] if args.key?(:subset_size)
end