Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



70431
70432
70433
# File 'lib/google/apis/compute_beta/classes.rb', line 70431

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70394
70395
70396
# File 'lib/google/apis/compute_beta/classes.rb', line 70394

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



70399
70400
70401
# File 'lib/google/apis/compute_beta/classes.rb', line 70399

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70404
70405
70406
# File 'lib/google/apis/compute_beta/classes.rb', line 70404

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70414
70415
70416
# File 'lib/google/apis/compute_beta/classes.rb', line 70414

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70419
70420
70421
# File 'lib/google/apis/compute_beta/classes.rb', line 70419

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70424
70425
70426
# File 'lib/google/apis/compute_beta/classes.rb', line 70424

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70429
70430
70431
# File 'lib/google/apis/compute_beta/classes.rb', line 70429

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70436
70437
70438
70439
70440
70441
70442
70443
70444
# File 'lib/google/apis/compute_beta/classes.rb', line 70436

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end