Class: Google::Apis::ComputeBeta::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



70157
70158
70159
# File 'lib/google/apis/compute_beta/classes.rb', line 70157

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70125
70126
70127
# File 'lib/google/apis/compute_beta/classes.rb', line 70125

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



70130
70131
70132
# File 'lib/google/apis/compute_beta/classes.rb', line 70130

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70135
70136
70137
# File 'lib/google/apis/compute_beta/classes.rb', line 70135

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70145
70146
70147
# File 'lib/google/apis/compute_beta/classes.rb', line 70145

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70150
70151
70152
# File 'lib/google/apis/compute_beta/classes.rb', line 70150

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70155
70156
70157
# File 'lib/google/apis/compute_beta/classes.rb', line 70155

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70162
70163
70164
70165
70166
70167
70168
70169
# File 'lib/google/apis/compute_beta/classes.rb', line 70162

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end