Class: Google::Apis::ComputeBeta::TargetInstancesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstancesScopedList

Returns a new instance of TargetInstancesScopedList.



70101
70102
70103
# File 'lib/google/apis/compute_beta/classes.rb', line 70101

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_instancesArray<Google::Apis::ComputeBeta::TargetInstance>

A list of target instances contained in this scope. Corresponds to the JSON property targetInstances



70093
70094
70095
# File 'lib/google/apis/compute_beta/classes.rb', line 70093

def target_instances
  @target_instances
end

#warningGoogle::Apis::ComputeBeta::TargetInstancesScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



70099
70100
70101
# File 'lib/google/apis/compute_beta/classes.rb', line 70099

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70106
70107
70108
70109
# File 'lib/google/apis/compute_beta/classes.rb', line 70106

def update!(**args)
  @target_instances = args[:target_instances] if args.key?(:target_instances)
  @warning = args[:warning] if args.key?(:warning)
end