Class: Google::Apis::ComputeBeta::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



70927
70928
70929
# File 'lib/google/apis/compute_beta/classes.rb', line 70927

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70888
70889
70890
# File 'lib/google/apis/compute_beta/classes.rb', line 70888

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



70893
70894
70895
# File 'lib/google/apis/compute_beta/classes.rb', line 70893

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


70900
70901
70902
# File 'lib/google/apis/compute_beta/classes.rb', line 70900

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70910
70911
70912
# File 'lib/google/apis/compute_beta/classes.rb', line 70910

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70915
70916
70917
# File 'lib/google/apis/compute_beta/classes.rb', line 70915

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70920
70921
70922
# File 'lib/google/apis/compute_beta/classes.rb', line 70920

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70925
70926
70927
# File 'lib/google/apis/compute_beta/classes.rb', line 70925

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70932
70933
70934
70935
70936
70937
70938
70939
70940
# File 'lib/google/apis/compute_beta/classes.rb', line 70932

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end