Class: Google::Apis::ComputeBeta::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



71080
71081
71082
# File 'lib/google/apis/compute_beta/classes.rb', line 71080

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71047
71048
71049
# File 'lib/google/apis/compute_beta/classes.rb', line 71047

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



71052
71053
71054
# File 'lib/google/apis/compute_beta/classes.rb', line 71052

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


71058
71059
71060
# File 'lib/google/apis/compute_beta/classes.rb', line 71058

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71068
71069
71070
# File 'lib/google/apis/compute_beta/classes.rb', line 71068

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71073
71074
71075
# File 'lib/google/apis/compute_beta/classes.rb', line 71073

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71078
71079
71080
# File 'lib/google/apis/compute_beta/classes.rb', line 71078

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71085
71086
71087
71088
71089
71090
71091
71092
# File 'lib/google/apis/compute_beta/classes.rb', line 71085

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end