Class: Google::Apis::ComputeBeta::TargetSslProxiesSetCertificateMapRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetSslProxiesSetCertificateMapRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#certificate_map ⇒ String
URL of the Certificate Map to associate with this TargetSslProxy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxiesSetCertificateMapRequest
constructor
A new instance of TargetSslProxiesSetCertificateMapRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxiesSetCertificateMapRequest
Returns a new instance of TargetSslProxiesSetCertificateMapRequest.
68641 68642 68643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate_map ⇒ String
URL of the Certificate Map to associate with this TargetSslProxy.
Accepted format is//certificatemanager.googleapis.com/projects/project/
locations/location/certificateMaps/resourceName.
Corresponds to the JSON property certificateMap
68639 68640 68641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68639 def certificate_map @certificate_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68646 68647 68648 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68646 def update!(**args) @certificate_map = args[:certificate_map] if args.key?(:certificate_map) end |