Class: Google::Apis::ComputeBeta::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



71693
71694
71695
# File 'lib/google/apis/compute_beta/classes.rb', line 71693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71661
71662
71663
# File 'lib/google/apis/compute_beta/classes.rb', line 71661

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



71666
71667
71668
# File 'lib/google/apis/compute_beta/classes.rb', line 71666

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


71671
71672
71673
# File 'lib/google/apis/compute_beta/classes.rb', line 71671

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71681
71682
71683
# File 'lib/google/apis/compute_beta/classes.rb', line 71681

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71686
71687
71688
# File 'lib/google/apis/compute_beta/classes.rb', line 71686

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71691
71692
71693
# File 'lib/google/apis/compute_beta/classes.rb', line 71691

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71698
71699
71700
71701
71702
71703
71704
71705
# File 'lib/google/apis/compute_beta/classes.rb', line 71698

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end