Class: Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetVpnGatewaysScopedList>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayAggregatedList
constructor
A new instance of TargetVpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayAggregatedList
Returns a new instance of TargetVpnGatewayAggregatedList.
72354 72355 72356 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72354 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72316 72317 72318 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72316 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetVpnGatewaysScopedList>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
72321 72322 72323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72321 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
72327 72328 72329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72327 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72337 72338 72339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72337 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72342 72343 72344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72342 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
72347 72348 72349 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72347 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72352 72353 72354 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72352 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72359 72360 72361 72362 72363 72364 72365 72366 72367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72359 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |