Class: Google::Apis::ComputeBeta::TargetVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetVpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayList

Returns a new instance of TargetVpnGatewayList.



72480
72481
72482
# File 'lib/google/apis/compute_beta/classes.rb', line 72480

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72447
72448
72449
# File 'lib/google/apis/compute_beta/classes.rb', line 72447

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetVpnGateway>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



72452
72453
72454
# File 'lib/google/apis/compute_beta/classes.rb', line 72452

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


72458
72459
72460
# File 'lib/google/apis/compute_beta/classes.rb', line 72458

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72468
72469
72470
# File 'lib/google/apis/compute_beta/classes.rb', line 72468

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72473
72474
72475
# File 'lib/google/apis/compute_beta/classes.rb', line 72473

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72478
72479
72480
# File 'lib/google/apis/compute_beta/classes.rb', line 72478

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72485
72486
72487
72488
72489
72490
72491
72492
# File 'lib/google/apis/compute_beta/classes.rb', line 72485

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end