Class: Google::Apis::ComputeBeta::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



72749
72750
72751
# File 'lib/google/apis/compute_beta/classes.rb', line 72749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


72702
72703
72704
# File 'lib/google/apis/compute_beta/classes.rb', line 72702

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


72708
72709
72710
# File 'lib/google/apis/compute_beta/classes.rb', line 72708

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


72714
72715
72716
# File 'lib/google/apis/compute_beta/classes.rb', line 72714

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


72720
72721
72722
# File 'lib/google/apis/compute_beta/classes.rb', line 72720

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


72726
72727
72728
# File 'lib/google/apis/compute_beta/classes.rb', line 72726

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


72732
72733
72734
# File 'lib/google/apis/compute_beta/classes.rb', line 72732

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeBeta::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



72737
72738
72739
# File 'lib/google/apis/compute_beta/classes.rb', line 72737

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


72742
72743
72744
# File 'lib/google/apis/compute_beta/classes.rb', line 72742

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


72747
72748
72749
# File 'lib/google/apis/compute_beta/classes.rb', line 72747

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72754
72755
72756
72757
72758
72759
72760
72761
72762
72763
72764
# File 'lib/google/apis/compute_beta/classes.rb', line 72754

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end