Class: Google::Apis::ComputeBeta::UrlMapQuotaUsage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message representing the quota usage for a UrlMap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapQuotaUsage

Returns a new instance of UrlMapQuotaUsage.



72843
72844
72845
# File 'lib/google/apis/compute_beta/classes.rb', line 72843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarding_rulesFixnum

Output only. The number of forwarding rules that uses this UrlMap. Corresponds to the JSON property forwardingRules

Returns:

  • (Fixnum)


72836
72837
72838
# File 'lib/google/apis/compute_beta/classes.rb', line 72836

def forwarding_rules
  @forwarding_rules
end

#unitsFixnum

Output only. The number of quota units calculated for this UrlMap. Corresponds to the JSON property units

Returns:

  • (Fixnum)


72841
72842
72843
# File 'lib/google/apis/compute_beta/classes.rb', line 72841

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72848
72849
72850
72851
# File 'lib/google/apis/compute_beta/classes.rb', line 72848

def update!(**args)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @units = args[:units] if args.key?(:units)
end