Class: Google::Apis::ComputeBeta::UrlMapValidationResult
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapValidationResult
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Message representing the validation result for a UrlMap.
Instance Attribute Summary collapse
-
#load_errors ⇒ Array<String>
Corresponds to the JSON property
loadErrors. -
#load_succeeded ⇒ Boolean
(also: #load_succeeded?)
Whether the given UrlMap can be successfully loaded.
-
#quota_usage ⇒ Google::Apis::ComputeBeta::UrlMapQuotaUsage
Message representing the quota usage for a UrlMap.
-
#test_failures ⇒ Array<Google::Apis::ComputeBeta::TestFailure>
Corresponds to the JSON property
testFailures. -
#test_passed ⇒ Boolean
(also: #test_passed?)
If successfully loaded, this field indicates whether the test passed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapValidationResult
constructor
A new instance of UrlMapValidationResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapValidationResult
Returns a new instance of UrlMapValidationResult.
72404 72405 72406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72404 def initialize(**args) update!(**args) end |
Instance Attribute Details
#load_errors ⇒ Array<String>
Corresponds to the JSON property loadErrors
72378 72379 72380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72378 def load_errors @load_errors end |
#load_succeeded ⇒ Boolean Also known as: load_succeeded?
Whether the given UrlMap can be successfully loaded.
If false, 'loadErrors' indicates the reasons.
Corresponds to the JSON property loadSucceeded
72384 72385 72386 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72384 def load_succeeded @load_succeeded end |
#quota_usage ⇒ Google::Apis::ComputeBeta::UrlMapQuotaUsage
Message representing the quota usage for a UrlMap.
Corresponds to the JSON property quotaUsage
72390 72391 72392 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72390 def quota_usage @quota_usage end |
#test_failures ⇒ Array<Google::Apis::ComputeBeta::TestFailure>
Corresponds to the JSON property testFailures
72395 72396 72397 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72395 def test_failures @test_failures end |
#test_passed ⇒ Boolean Also known as: test_passed?
If successfully loaded, this field indicates whether the test passed.
If false, 'testFailures's indicate the reason of failure.
Corresponds to the JSON property testPassed
72401 72402 72403 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72401 def test_passed @test_passed end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72409 72410 72411 72412 72413 72414 72415 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72409 def update!(**args) @load_errors = args[:load_errors] if args.key?(:load_errors) @load_succeeded = args[:load_succeeded] if args.key?(:load_succeeded) @quota_usage = args[:quota_usage] if args.key?(:quota_usage) @test_failures = args[:test_failures] if args.key?(:test_failures) @test_passed = args[:test_passed] if args.key?(:test_passed) end |