Class: Google::Apis::ComputeBeta::UrlRewrite
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlRewrite
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The spec for modifying the path before sending the request to the matched backend service.
Instance Attribute Summary collapse
-
#host_rewrite ⇒ String
Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite.
-
#path_prefix_rewrite ⇒ String
Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced bypathPrefixRewrite.
-
#path_template_rewrite ⇒ String
If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax.
-
#regex_rewrite ⇒ Google::Apis::ComputeBeta::RegexRewrite
The spec for modifying the path using a regular expression.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlRewrite
constructor
A new instance of UrlRewrite.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlRewrite
Returns a new instance of UrlRewrite.
73280 73281 73282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73280 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_rewrite ⇒ String
Before forwarding the request to the selected service, the request's
host header is replaced with contents of hostRewrite.
The value must be from 1 to 255 characters.
Corresponds to the JSON property hostRewrite
73240 73241 73242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73240 def host_rewrite @host_rewrite end |
#path_prefix_rewrite ⇒ String
Before forwarding the request to the selected backend service, the
matching portion of the request's path is replaced bypathPrefixRewrite.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property pathPrefixRewrite
73247 73248 73249 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73247 def path_prefix_rewrite @path_prefix_rewrite end |
#path_template_rewrite ⇒ String
If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax. A corresponding path_template_match must be specified. Any template variables must exist in the path_template_match field.
- -At least one variable must be specified in the path_template_match field
- You can omit variables from the rewritten URL
- The * and ** operators cannot be matched
unless they have a corresponding variable name - e.g.
format=*orvar=**. For example, a path_template_match of /static/format=**could be rewritten as /static/content/formatto prefix/content to the URL. Variables can also be re-ordered in a rewrite, so that /country/format/suffix=**can be rewritten as /content/format/country/suffix. At least one non-empty routeRules[].matchRules[].path_template_match is required. Only one of path_prefix_rewrite orpath_template_rewrite may be specified. Corresponds to the JSON propertypathTemplateRewrite
73273 73274 73275 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73273 def path_template_rewrite @path_template_rewrite end |
#regex_rewrite ⇒ Google::Apis::ComputeBeta::RegexRewrite
The spec for modifying the path using a regular expression.
Corresponds to the JSON property regexRewrite
73278 73279 73280 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73278 def regex_rewrite @regex_rewrite end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73285 73286 73287 73288 73289 73290 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73285 def update!(**args) @host_rewrite = args[:host_rewrite] if args.key?(:host_rewrite) @path_prefix_rewrite = args[:path_prefix_rewrite] if args.key?(:path_prefix_rewrite) @path_template_rewrite = args[:path_template_rewrite] if args.key?(:path_template_rewrite) @regex_rewrite = args[:regex_rewrite] if args.key?(:regex_rewrite) end |