Class: Google::Apis::ComputeBeta::UsableSubnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Subnetwork which the current user has compute.subnetworks.use permission on.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetwork

Returns a new instance of UsableSubnetwork.



73483
73484
73485
# File 'lib/google/apis/compute_beta/classes.rb', line 73483

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_ipv6_prefixString

Output only. [Output Only] The external IPv6 address range that is assigned to this subnetwork. Corresponds to the JSON property externalIpv6Prefix

Returns:

  • (String)


73422
73423
73424
# File 'lib/google/apis/compute_beta/classes.rb', line 73422

def external_ipv6_prefix
  @external_ipv6_prefix
end

#internal_ipv6_prefixString

Output only. [Output Only] The internal IPv6 address range that is assigned to this subnetwork. Corresponds to the JSON property internalIpv6Prefix

Returns:

  • (String)


73429
73430
73431
# File 'lib/google/apis/compute_beta/classes.rb', line 73429

def internal_ipv6_prefix
  @internal_ipv6_prefix
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


73434
73435
73436
# File 'lib/google/apis/compute_beta/classes.rb', line 73434

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


73441
73442
73443
# File 'lib/google/apis/compute_beta/classes.rb', line 73441

def ipv6_access_type
  @ipv6_access_type
end

#networkString

Network URL. Corresponds to the JSON property network

Returns:

  • (String)


73446
73447
73448
# File 'lib/google/apis/compute_beta/classes.rb', line 73446

def network
  @network
end

#purposeString

Corresponds to the JSON property purpose

Returns:

  • (String)


73451
73452
73453
# File 'lib/google/apis/compute_beta/classes.rb', line 73451

def purpose
  @purpose
end

#roleString

The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Corresponds to the JSON property role

Returns:

  • (String)


73462
73463
73464
# File 'lib/google/apis/compute_beta/classes.rb', line 73462

def role
  @role
end

#secondary_ip_rangesArray<Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange>

Secondary IP ranges. Corresponds to the JSON property secondaryIpRanges



73467
73468
73469
# File 'lib/google/apis/compute_beta/classes.rb', line 73467

def secondary_ip_ranges
  @secondary_ip_ranges
end

#stack_typeString

The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated usingpatch. Corresponds to the JSON property stackType

Returns:

  • (String)


73476
73477
73478
# File 'lib/google/apis/compute_beta/classes.rb', line 73476

def stack_type
  @stack_type
end

#subnetworkString

Subnetwork URL. Corresponds to the JSON property subnetwork

Returns:

  • (String)


73481
73482
73483
# File 'lib/google/apis/compute_beta/classes.rb', line 73481

def subnetwork
  @subnetwork
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73488
73489
73490
73491
73492
73493
73494
73495
73496
73497
73498
73499
# File 'lib/google/apis/compute_beta/classes.rb', line 73488

def update!(**args)
  @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix)
  @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @network = args[:network] if args.key?(:network)
  @purpose = args[:purpose] if args.key?(:purpose)
  @role = args[:role] if args.key?(:role)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
end