Class: Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Secondary IP range of a usable subnetwork.
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
-
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworkSecondaryRange
constructor
A new instance of UsableSubnetworkSecondaryRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworkSecondaryRange
Returns a new instance of UsableSubnetworkSecondaryRange.
72045 72046 72047 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72045 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
Can be Ipv4 or Ipv6 range.
Corresponds to the JSON property ipCidrRange
72035 72036 72037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72035 def ip_cidr_range @ip_cidr_range end |
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding
an alias IP range to a VM instance.
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the subnetwork.
Corresponds to the JSON property rangeName
72043 72044 72045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72043 def range_name @range_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72050 72051 72052 72053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72050 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @range_name = args[:range_name] if args.key?(:range_name) end |