Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



73992
73993
73994
# File 'lib/google/apis/compute_beta/classes.rb', line 73992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73943
73944
73945
# File 'lib/google/apis/compute_beta/classes.rb', line 73943

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



73948
73949
73950
# File 'lib/google/apis/compute_beta/classes.rb', line 73948

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


73955
73956
73957
# File 'lib/google/apis/compute_beta/classes.rb', line 73955

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73968
73969
73970
# File 'lib/google/apis/compute_beta/classes.rb', line 73968

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeBeta::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



73975
73976
73977
# File 'lib/google/apis/compute_beta/classes.rb', line 73975

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73980
73981
73982
# File 'lib/google/apis/compute_beta/classes.rb', line 73980

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73985
73986
73987
# File 'lib/google/apis/compute_beta/classes.rb', line 73985

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73990
73991
73992
# File 'lib/google/apis/compute_beta/classes.rb', line 73990

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73997
73998
73999
74000
74001
74002
74003
74004
74005
74006
# File 'lib/google/apis/compute_beta/classes.rb', line 73997

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end