Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



75147
75148
75149
# File 'lib/google/apis/compute_beta/classes.rb', line 75147

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75109
75110
75111
# File 'lib/google/apis/compute_beta/classes.rb', line 75109

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



75114
75115
75116
# File 'lib/google/apis/compute_beta/classes.rb', line 75114

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


75120
75121
75122
# File 'lib/google/apis/compute_beta/classes.rb', line 75120

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75130
75131
75132
# File 'lib/google/apis/compute_beta/classes.rb', line 75130

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75135
75136
75137
# File 'lib/google/apis/compute_beta/classes.rb', line 75135

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75140
75141
75142
# File 'lib/google/apis/compute_beta/classes.rb', line 75140

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75145
75146
75147
# File 'lib/google/apis/compute_beta/classes.rb', line 75145

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75152
75153
75154
75155
75156
75157
75158
75159
75160
# File 'lib/google/apis/compute_beta/classes.rb', line 75152

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end