Class: Google::Apis::ComputeBeta::VpnGatewayStatusVpnConnection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayStatusVpnConnection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
Instance Attribute Summary collapse
-
#peer_external_gateway ⇒ String
Output only.
-
#peer_gcp_gateway ⇒ String
Output only.
-
#state ⇒ Google::Apis::ComputeBeta::VpnGatewayStatusHighAvailabilityRequirementState
Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
-
#tunnels ⇒ Array<Google::Apis::ComputeBeta::VpnGatewayStatusTunnel>
List of VPN tunnels that are in this VPN connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayStatusVpnConnection
constructor
A new instance of VpnGatewayStatusVpnConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayStatusVpnConnection
Returns a new instance of VpnGatewayStatusVpnConnection.
74471 74472 74473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74471 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peer_external_gateway ⇒ String
Output only. URL reference to the peer external VPN gateways to which the VPN
tunnels
in this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
Corresponds to the JSON property peerExternalGateway
74450 74451 74452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74450 def peer_external_gateway @peer_external_gateway end |
#peer_gcp_gateway ⇒ String
Output only. URL reference to the peer side VPN gateways to which the VPN
tunnels in
this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
Corresponds to the JSON property peerGcpGateway
74458 74459 74460 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74458 def peer_gcp_gateway @peer_gcp_gateway end |
#state ⇒ Google::Apis::ComputeBeta::VpnGatewayStatusHighAvailabilityRequirementState
Describes the high availability requirement state for the VPN connection
between this Cloud VPN gateway and a peer gateway.
Corresponds to the JSON property state
74464 74465 74466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74464 def state @state end |
#tunnels ⇒ Array<Google::Apis::ComputeBeta::VpnGatewayStatusTunnel>
List of VPN tunnels that are in this VPN connection.
Corresponds to the JSON property tunnels
74469 74470 74471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74469 def tunnels @tunnels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74476 74477 74478 74479 74480 74481 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74476 def update!(**args) @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway) @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway) @state = args[:state] if args.key?(:state) @tunnels = args[:tunnels] if args.key?(:tunnels) end |