Class: Google::Apis::ComputeBeta::VpnGatewayVpnGatewayInterface
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayVpnGatewayInterface
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A VPN gateway interface.
Instance Attribute Summary collapse
-
#id ⇒ Fixnum
Output only.
-
#interconnect_attachment ⇒ String
URL of the VLAN attachment (interconnectAttachment) resource for this VPN gateway interface.
-
#ip_address ⇒ String
Output only.
-
#ipv6_address ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayVpnGatewayInterface
constructor
A new instance of VpnGatewayVpnGatewayInterface.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayVpnGatewayInterface
Returns a new instance of VpnGatewayVpnGatewayInterface.
75563 75564 75565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75563 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ Fixnum
Output only. [Output Only] Numeric identifier for this VPN interface
associated with
the VPN gateway.
Corresponds to the JSON property id
75527 75528 75529 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75527 def id @id end |
#interconnect_attachment ⇒ String
URL of the VLAN attachment (interconnectAttachment) resource for this
VPN gateway interface. When the value of this field is present, the VPN
gateway is used for HA VPN over Cloud Interconnect; all egress
or ingress traffic for this VPN gateway interface goes through the
specified VLAN attachment resource.
Corresponds to the JSON property interconnectAttachment
75536 75537 75538 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75536 def @interconnect_attachment end |
#ip_address ⇒ String
Output only. [Output Only] IP address for this VPN interface associated with
the VPN
gateway.
The IP address could be either a regional external IP address or
a regional internal IP address. The two IP addresses for a VPN gateway
must be all regional external or regional internal IP addresses. There
cannot be a mix of regional external IP addresses and regional internal
IP addresses. For HA VPN over Cloud Interconnect, the IP addresses
for both interfaces could either be regional internal IP addresses or
regional external IP addresses. For regular (non HA VPN over Cloud
Interconnect) HA VPN tunnels, the IP address must be a regional external
IP address.
Corresponds to the JSON property ipAddress
75552 75553 75554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75552 def ip_address @ip_address end |
#ipv6_address ⇒ String
Output only. [Output Only] IPv6 address for this VPN interface associated with
the VPN
gateway.
The IPv6 address must be a regional external IPv6 address. The format is
RFC 5952 format (e.g. 2001:db8::2d9:51:0:0).
Corresponds to the JSON property ipv6Address
75561 75562 75563 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75561 def ipv6_address @ipv6_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75568 75569 75570 75571 75572 75573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75568 def update!(**args) @id = args[:id] if args.key?(:id) @interconnect_attachment = args[:interconnect_attachment] if args.key?(:interconnect_attachment) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) end |