Class: Google::Apis::ComputeBeta::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



76001
76002
76003
# File 'lib/google/apis/compute_beta/classes.rb', line 76001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75963
75964
75965
# File 'lib/google/apis/compute_beta/classes.rb', line 75963

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



75968
75969
75970
# File 'lib/google/apis/compute_beta/classes.rb', line 75968

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


75974
75975
75976
# File 'lib/google/apis/compute_beta/classes.rb', line 75974

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75984
75985
75986
# File 'lib/google/apis/compute_beta/classes.rb', line 75984

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75989
75990
75991
# File 'lib/google/apis/compute_beta/classes.rb', line 75989

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75994
75995
75996
# File 'lib/google/apis/compute_beta/classes.rb', line 75994

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75999
76000
76001
# File 'lib/google/apis/compute_beta/classes.rb', line 75999

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76006
76007
76008
76009
76010
76011
76012
76013
76014
# File 'lib/google/apis/compute_beta/classes.rb', line 76006

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end