Class: Google::Apis::ComputeBeta::VpnTunnelList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnTunnelList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of VpnTunnel resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VpnTunnel>
A list of VpnTunnel resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnTunnelList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelList
constructor
A new instance of VpnTunnelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelList
Returns a new instance of VpnTunnelList.
76152 76153 76154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76152 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76119 76120 76121 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76119 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VpnTunnel>
A list of VpnTunnel resources.
Corresponds to the JSON property items
76124 76125 76126 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76124 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
76130 76131 76132 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76130 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76140 76141 76142 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76140 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76145 76146 76147 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76145 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::VpnTunnelList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76150 76151 76152 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76150 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76157 76158 76159 76160 76161 76162 76163 76164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76157 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |