Class: Google::Apis::ComputeBeta::WafExpressionSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WafExpressionSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of alternate IDs.
-
#expressions ⇒ Array<Google::Apis::ComputeBeta::WafExpressionSetExpression>
List of available expressions.
-
#id ⇒ String
Google specified expression set ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WafExpressionSet
constructor
A new instance of WafExpressionSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WafExpressionSet
Returns a new instance of WafExpressionSet.
75904 75905 75906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aliases ⇒ Array<String>
A list of alternate IDs. The format should be:
- E.g. XSS-stable
Generic suffix like "stable" is particularly useful if a policy
likes to avail newer set of expressions without having to change
the policy.
A given alias name can't be used for more than one entity set.
Corresponds to the JSON property
aliases
75890 75891 75892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75890 def aliases @aliases end |
#expressions ⇒ Array<Google::Apis::ComputeBeta::WafExpressionSetExpression>
List of available expressions.
Corresponds to the JSON property expressions
75895 75896 75897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75895 def expressions @expressions end |
#id ⇒ String
Google specified expression set ID. The format should be:
- E.g. XSS-20170329
required
Corresponds to the JSON property
id
75902 75903 75904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75902 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75909 75910 75911 75912 75913 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75909 def update!(**args) @aliases = args[:aliases] if args.key?(:aliases) @expressions = args[:expressions] if args.key?(:expressions) @id = args[:id] if args.key?(:id) end |