Class: Google::Apis::ComputeBeta::WireGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A resource that represents a group of redundant wires.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroup

Returns a new instance of WireGroup.



76317
76318
76319
# File 'lib/google/apis/compute_beta/classes.rb', line 76317

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


76237
76238
76239
# File 'lib/google/apis/compute_beta/classes.rb', line 76237

def admin_enabled
  @admin_enabled
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


76244
76245
76246
# File 'lib/google/apis/compute_beta/classes.rb', line 76244

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the wire group. Corresponds to the JSON property description

Returns:

  • (String)


76249
76250
76251
# File 'lib/google/apis/compute_beta/classes.rb', line 76249

def description
  @description
end

#endpointsHash<String,Google::Apis::ComputeBeta::WireGroupEndpoint>

A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object. Corresponds to the JSON property endpoints


76258
76259
76260
# File 'lib/google/apis/compute_beta/classes.rb', line 76258

def endpoints
  @endpoints
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


76265
76266
76267
# File 'lib/google/apis/compute_beta/classes.rb', line 76265

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


76271
76272
76273
# File 'lib/google/apis/compute_beta/classes.rb', line 76271

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


76282
76283
76284
# File 'lib/google/apis/compute_beta/classes.rb', line 76282

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. [Output Only] Indicates whether there are wire changes yet to be processed. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


76288
76289
76290
# File 'lib/google/apis/compute_beta/classes.rb', line 76288

def reconciling
  @reconciling
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76294
76295
76296
# File 'lib/google/apis/compute_beta/classes.rb', line 76294

def self_link
  @self_link
end

#topologyGoogle::Apis::ComputeBeta::WireGroupTopology

Topology details for the wire group. Corresponds to the JSON property topology



76299
76300
76301
# File 'lib/google/apis/compute_beta/classes.rb', line 76299

def topology
  @topology
end

#wire_group_propertiesGoogle::Apis::ComputeBeta::WireGroupProperties

The properties of a wire group. These properties determine how a group of redundant wires are created and managed. Corresponds to the JSON property wireGroupProperties



76305
76306
76307
# File 'lib/google/apis/compute_beta/classes.rb', line 76305

def wire_group_properties
  @wire_group_properties
end

#wire_propertiesGoogle::Apis::ComputeBeta::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



76310
76311
76312
# File 'lib/google/apis/compute_beta/classes.rb', line 76310

def wire_properties
  @wire_properties
end

#wiresArray<Google::Apis::ComputeBeta::Wire>

Output only. The single/redundant wire(s) managed by the wire group. Corresponds to the JSON property wires



76315
76316
76317
# File 'lib/google/apis/compute_beta/classes.rb', line 76315

def wires
  @wires
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76322
76323
76324
76325
76326
76327
76328
76329
76330
76331
76332
76333
76334
76335
76336
# File 'lib/google/apis/compute_beta/classes.rb', line 76322

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @topology = args[:topology] if args.key?(:topology)
  @wire_group_properties = args[:wire_group_properties] if args.key?(:wire_group_properties)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
  @wires = args[:wires] if args.key?(:wires)
end