Class: Google::Apis::ComputeBeta::WireGroupEndpointInterconnect

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The redundant Interconnect connections for this endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupEndpointInterconnect

Returns a new instance of WireGroupEndpointInterconnect.



72751
72752
72753
# File 'lib/google/apis/compute_beta/classes.rb', line 72751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnectString

Required. An Interconnect connection. You can specify the connection as a partial or full URL. If the connection is in a different project from the cross-site network, use a format that specifies the project. See the following examples of partial and full URLs:

global/interconnects/NAME

projects/PROJECT_ID/global/interconnects/NAME

- https://compute.googleapis.com/compute/projects/PROJECT_ID/global/ interconnects/NAME Corresponds to the JSON property interconnect

Returns:

  • (String)


72730
72731
72732
# File 'lib/google/apis/compute_beta/classes.rb', line 72730

def interconnect
  @interconnect
end

#vlan_tagsArray<Fixnum>

Required. To configure the wire group for VLAN mode, enter a VLAN tag, which is a number from 2 to 4093. You can autoallocate a tag by entering 0. To configure the wire group for port mode, enter -1. Review the following guidelines:

  • A VLAN tag must be unique for an Interconnect connection across all attachments and wire groups.
  • Both endpoints of a wire must use the same VLAN tag value.
  • Single wire and redundant type wire groups must have only one VLAN tag.
  • Port mode pseudowires must have a single VLAN tag with a value of -1 for both endpoints.
  • Box and cross type wire groups must have two VLAN tags. The first is for the same-zone pseudowire, and the second is for the cross-zone pseudowire. Corresponds to the JSON property vlanTags

Returns:

  • (Array<Fixnum>)


72749
72750
72751
# File 'lib/google/apis/compute_beta/classes.rb', line 72749

def vlan_tags
  @vlan_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72756
72757
72758
72759
# File 'lib/google/apis/compute_beta/classes.rb', line 72756

def update!(**args)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @vlan_tags = args[:vlan_tags] if args.key?(:vlan_tags)
end