Class: Google::Apis::ComputeBeta::XpnHostList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ XpnHostList

Returns a new instance of XpnHostList.



77151
77152
77153
# File 'lib/google/apis/compute_beta/classes.rb', line 77151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


77118
77119
77120
# File 'lib/google/apis/compute_beta/classes.rb', line 77118

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Project>

[Output Only] A list of shared VPC host project URLs. Corresponds to the JSON property items



77123
77124
77125
# File 'lib/google/apis/compute_beta/classes.rb', line 77123

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#xpnHostList for lists of shared VPC hosts. Corresponds to the JSON property kind

Returns:

  • (String)


77129
77130
77131
# File 'lib/google/apis/compute_beta/classes.rb', line 77129

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


77139
77140
77141
# File 'lib/google/apis/compute_beta/classes.rb', line 77139

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


77144
77145
77146
# File 'lib/google/apis/compute_beta/classes.rb', line 77144

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::XpnHostList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



77149
77150
77151
# File 'lib/google/apis/compute_beta/classes.rb', line 77149

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



77156
77157
77158
77159
77160
77161
77162
77163
# File 'lib/google/apis/compute_beta/classes.rb', line 77156

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end