Class: Google::Apis::ComputeBeta::Zone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Zone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.
Instance Attribute Summary collapse
-
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
-
#resource_status ⇒ Google::Apis::ComputeBeta::ZoneResourceStatus
Corresponds to the JSON property
resourceStatus. -
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Zone
constructor
A new instance of Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Zone
Returns a new instance of Zone.
76931 76932 76933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
Corresponds to the JSON property availableCpuPlatforms
76870 76871 76872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76870 def available_cpu_platforms @available_cpu_platforms end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
76876 76877 76878 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76876 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
76881 76882 76883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76881 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
76886 76887 76888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76886 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
76892 76893 76894 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76892 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#zone for
zones.
Corresponds to the JSON property kind
76898 76899 76900 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76898 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
76903 76904 76905 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76903 def name @name end |
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
Corresponds to the JSON property region
76908 76909 76910 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76908 def region @region end |
#resource_status ⇒ Google::Apis::ComputeBeta::ZoneResourceStatus
Corresponds to the JSON property resourceStatus
76913 76914 76915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76913 def resource_status @resource_status end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
76918 76919 76920 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76918 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
Corresponds to the JSON property status
76923 76924 76925 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76923 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
76928 76929 76930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76928 def supports_pzs @supports_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76936 76937 76938 76939 76940 76941 76942 76943 76944 76945 76946 76947 76948 76949 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76936 def update!(**args) @available_cpu_platforms = args[:available_cpu_platforms] if args.key?(:available_cpu_platforms) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) end |