Class: Google::Apis::ComputeBeta::AcceleratorConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AcceleratorConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A specification of the type and number of accelerator cards attached to the instance.
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
The number of the guest accelerator cards exposed to this instance.
-
#accelerator_type ⇒ String
Full or partial URL of the accelerator type resource to attach to this instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AcceleratorConfig
constructor
A new instance of AcceleratorConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AcceleratorConfig
Returns a new instance of AcceleratorConfig.
93 94 95 |
# File 'lib/google/apis/compute_beta/classes.rb', line 93 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
The number of the guest accelerator cards exposed to this instance.
Corresponds to the JSON property acceleratorCount
80 81 82 |
# File 'lib/google/apis/compute_beta/classes.rb', line 80 def accelerator_count @accelerator_count end |
#accelerator_type ⇒ String
Full or partial URL of the accelerator type resource to attach to this
instance. For example:projects/my-project/zones/us-central1-c/acceleratorTypes/
nvidia-tesla-p100
If you are creating an instance template, specify only the
accelerator name.
See GPUs on Compute Engine
for a full list of accelerator types.
Corresponds to the JSON property acceleratorType
91 92 93 |
# File 'lib/google/apis/compute_beta/classes.rb', line 91 def accelerator_type @accelerator_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
98 99 100 101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 98 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @accelerator_type = args[:accelerator_type] if args.key?(:accelerator_type) end |