Class: Google::Apis::ComputeBeta::AddressAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AddressAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::AddressesScopedList>
A list of AddressesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::AddressAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AddressAggregatedList
constructor
A new instance of AddressAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AddressAggregatedList
Returns a new instance of AddressAggregatedList.
984 985 986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 984 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
945 946 947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 945 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::AddressesScopedList>
A list of AddressesScopedList resources.
Corresponds to the JSON property items
950 951 952 |
# File 'lib/google/apis/compute_beta/classes.rb', line 950 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
addressAggregatedList for aggregated lists of
addresses.
Corresponds to the JSON property kind
957 958 959 |
# File 'lib/google/apis/compute_beta/classes.rb', line 957 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
967 968 969 |
# File 'lib/google/apis/compute_beta/classes.rb', line 967 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
972 973 974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 972 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
977 978 979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 977 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::AddressAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
982 983 984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 982 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
989 990 991 992 993 994 995 996 997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 989 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |