Class: Google::Apis::ComputeBeta::AliasIpRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AliasIpRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An alias IP range attached to an instance's network interface.
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The IP alias ranges to allocate for this interface.
-
#subnetwork_range_name ⇒ String
The name of a subnetwork secondary IP range from which to allocate an IP alias range.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AliasIpRange
constructor
A new instance of AliasIpRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AliasIpRange
Returns a new instance of AliasIpRange.
1378 1379 1380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1378 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The IP alias ranges to allocate for this interface. This IP CIDR range
must belong to the specified subnetwork and cannot contain IP addresses
reserved by system or used by other network interfaces. This range may be
a single IP address (such as 10.2.3.4), a netmask (such as/24) or a CIDR-
formatted string (such as10.1.2.0/24).
Corresponds to the JSON property ipCidrRange
1370 1371 1372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1370 def ip_cidr_range @ip_cidr_range end |
#subnetwork_range_name ⇒ String
The name of a subnetwork secondary IP range from which to allocate an IP
alias range. If not specified, the primary range of the subnetwork is used.
Corresponds to the JSON property subnetworkRangeName
1376 1377 1378 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1376 def subnetwork_range_name @subnetwork_range_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1383 1384 1385 1386 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1383 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @subnetwork_range_name = args[:subnetwork_range_name] if args.key?(:subnetwork_range_name) end |