Class: Google::Apis::ComputeBeta::AllocationAggregateReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationAggregateReservation

Returns a new instance of AllocationAggregateReservation.



1434
1435
1436
# File 'lib/google/apis/compute_beta/classes.rb', line 1434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_countFixnum

Count of reserved hosts of specified VM family. The host has fixed number of accelerators based on the accelerator/vm-family selected. Corresponds to the JSON property hostCount

Returns:

  • (Fixnum)


1399
1400
1401
# File 'lib/google/apis/compute_beta/classes.rb', line 1399

def host_count
  @host_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


1406
1407
1408
# File 'lib/google/apis/compute_beta/classes.rb', line 1406

def in_use_host_count
  @in_use_host_count
end

#in_use_instance_countFixnum

Output only. Number of instances currently in use in this reservation. Corresponds to the JSON property inUseInstanceCount

Returns:

  • (Fixnum)


1411
1412
1413
# File 'lib/google/apis/compute_beta/classes.rb', line 1411

def in_use_instance_count
  @in_use_instance_count
end

#in_use_resourcesArray<Google::Apis::ComputeBeta::AllocationAggregateReservationReservedResourceInfo>

Output only. [Output only] List of resources currently in use. Corresponds to the JSON property inUseResources



1416
1417
1418
# File 'lib/google/apis/compute_beta/classes.rb', line 1416

def in_use_resources
  @in_use_resources
end

#reserved_resourcesArray<Google::Apis::ComputeBeta::AllocationAggregateReservationReservedResourceInfo>

List of reserved resources (CPUs, memory, accelerators). Corresponds to the JSON property reservedResources



1421
1422
1423
# File 'lib/google/apis/compute_beta/classes.rb', line 1421

def reserved_resources
  @reserved_resources
end

#vm_familyString

The VM family that all instances scheduled against this reservation must belong to. Corresponds to the JSON property vmFamily

Returns:

  • (String)


1427
1428
1429
# File 'lib/google/apis/compute_beta/classes.rb', line 1427

def vm_family
  @vm_family
end

#workload_typeString

The workload type of the instances that will target this reservation. Corresponds to the JSON property workloadType

Returns:

  • (String)


1432
1433
1434
# File 'lib/google/apis/compute_beta/classes.rb', line 1432

def workload_type
  @workload_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1439
1440
1441
1442
1443
1444
1445
1446
1447
# File 'lib/google/apis/compute_beta/classes.rb', line 1439

def update!(**args)
  @host_count = args[:host_count] if args.key?(:host_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @in_use_instance_count = args[:in_use_instance_count] if args.key?(:in_use_instance_count)
  @in_use_resources = args[:in_use_resources] if args.key?(:in_use_resources)
  @reserved_resources = args[:reserved_resources] if args.key?(:reserved_resources)
  @vm_family = args[:vm_family] if args.key?(:vm_family)
  @workload_type = args[:workload_type] if args.key?(:workload_type)
end