Class: Google::Apis::ComputeBeta::AllocationResourceStatusSpecificSkuAllocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains Properties set for the reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AllocationResourceStatusSpecificSkuAllocation

Returns a new instance of AllocationResourceStatusSpecificSkuAllocation.



1606
1607
1608
# File 'lib/google/apis/compute_beta/classes.rb', line 1606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_instance_template_idString

ID of the instance template used to populate reservation properties. Corresponds to the JSON property sourceInstanceTemplateId

Returns:

  • (String)


1598
1599
1600
# File 'lib/google/apis/compute_beta/classes.rb', line 1598

def source_instance_template_id
  @source_instance_template_id
end

#utilizationsHash<String,Fixnum>

Per service utilization breakdown. The Key is the Google Cloud managed service name. Corresponds to the JSON property utilizations

Returns:

  • (Hash<String,Fixnum>)


1604
1605
1606
# File 'lib/google/apis/compute_beta/classes.rb', line 1604

def utilizations
  @utilizations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1611
1612
1613
1614
# File 'lib/google/apis/compute_beta/classes.rb', line 1611

def update!(**args)
  @source_instance_template_id = args[:source_instance_template_id] if args.key?(:source_instance_template_id)
  @utilizations = args[:utilizations] if args.key?(:utilizations)
end