Class: Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationReservedInstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationReservedInstanceProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Properties of the SKU instances being reserved. Next ID: 10
Instance Attribute Summary collapse
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
Specifies accelerator type and count.
-
#local_ssds ⇒ Array<Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk>
Specifies amount of local ssd to reserve with each instance.
-
#location_hint ⇒ String
An opaque location hint used to place the allocation close to other resources.
-
#machine_type ⇒ String
Specifies type of machine (name only) which has fixed number of vCPUs and fixed amount of memory.
-
#maintenance_freeze_duration_hours ⇒ Fixnum
Specifies the number of hours after reservation creation where instances using the reservation won't be scheduled for maintenance.
-
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events.
-
#min_cpu_platform ⇒ String
Minimum cpu platform the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuAllocationReservedInstanceProperties
constructor
A new instance of AllocationSpecificSkuAllocationReservedInstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuAllocationReservedInstanceProperties
Returns a new instance of AllocationSpecificSkuAllocationReservedInstanceProperties.
1691 1692 1693 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1691 def initialize(**args) update!(**args) end |
Instance Attribute Details
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
Specifies accelerator type and count.
Corresponds to the JSON property guestAccelerators
1652 1653 1654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1652 def guest_accelerators @guest_accelerators end |
#local_ssds ⇒ Array<Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationAllocatedInstancePropertiesReservedDisk>
Specifies amount of local ssd to reserve with each instance. The type
of disk is local-ssd.
Corresponds to the JSON property localSsds
1658 1659 1660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1658 def local_ssds @local_ssds end |
#location_hint ⇒ String
An opaque location hint used to place the allocation close to other
resources.
This field is for use by internal tools that use the public API.
Corresponds to the JSON property locationHint
1665 1666 1667 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1665 def location_hint @location_hint end |
#machine_type ⇒ String
Specifies type of machine (name only) which has fixed number of vCPUs
and fixed amount of memory. This also includes specifying custom
machine type following custom-NUMBER_OF_CPUS-AMOUNT_OF_MEMORY pattern.
Corresponds to the JSON property machineType
1672 1673 1674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1672 def machine_type @machine_type end |
#maintenance_freeze_duration_hours ⇒ Fixnum
Specifies the number of hours after reservation creation where
instances using the reservation won't be scheduled for maintenance.
Corresponds to the JSON property maintenanceFreezeDurationHours
1678 1679 1680 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1678 def maintenance_freeze_duration_hours @maintenance_freeze_duration_hours end |
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events. The accepted
values are: PERIODIC.
Corresponds to the JSON property maintenanceInterval
1684 1685 1686 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1684 def maintenance_interval @maintenance_interval end |
#min_cpu_platform ⇒ String
Minimum cpu platform the reservation.
Corresponds to the JSON property minCpuPlatform
1689 1690 1691 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1689 def min_cpu_platform @min_cpu_platform end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1696 1697 1698 1699 1700 1701 1702 1703 1704 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1696 def update!(**args) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @local_ssds = args[:local_ssds] if args.key?(:local_ssds) @location_hint = args[:location_hint] if args.key?(:location_hint) @machine_type = args[:machine_type] if args.key?(:machine_type) @maintenance_freeze_duration_hours = args[:maintenance_freeze_duration_hours] if args.key?(:maintenance_freeze_duration_hours) @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) end |