Class: Google::Apis::ComputeBeta::AllocationSpecificSkuReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AllocationSpecificSkuReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
This reservation type allows to pre allocate specific instance configuration.
Instance Attribute Summary collapse
-
#assured_count ⇒ Fixnum
Output only.
-
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
-
#in_use_count ⇒ Fixnum
Output only.
-
#instance_properties ⇒ Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
-
#source_instance_template ⇒ String
Specifies the instance template to create the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AllocationSpecificSkuReservation
constructor
A new instance of AllocationSpecificSkuReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AllocationSpecificSkuReservation
Returns a new instance of AllocationSpecificSkuReservation.
1739 1740 1741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#assured_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are actually usable
currently.
Corresponds to the JSON property assuredCount
1707 1708 1709 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1707 def assured_count @assured_count end |
#count ⇒ Fixnum
Specifies the number of resources that are allocated.
Corresponds to the JSON property count
1712 1713 1714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1712 def count @count end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] Indicates how many instances are in use.
Corresponds to the JSON property inUseCount
1717 1718 1719 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1717 def in_use_count @in_use_count end |
#instance_properties ⇒ Google::Apis::ComputeBeta::AllocationSpecificSkuAllocationReservedInstanceProperties
Properties of the SKU instances being reserved.
Next ID: 9
Corresponds to the JSON property instanceProperties
1723 1724 1725 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1723 def instance_properties @instance_properties end |
#source_instance_template ⇒ String
Specifies the instance template to create the reservation. If you use this field, you must exclude the instanceProperties field. This field is optional, and it can be a full or partial URL. For example, the following are all valid URLs to an instance template:
- https://www.googleapis.com/compute/v1/projects/project/global/ instanceTemplates/instanceTemplate
- projects/project/global/instanceTemplates/instanceTemplate
- global/instanceTemplates/instanceTemplate
Corresponds to the JSON property
sourceInstanceTemplate
1737 1738 1739 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1737 def source_instance_template @source_instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1744 1745 1746 1747 1748 1749 1750 |
# File 'lib/google/apis/compute_beta/classes.rb', line 1744 def update!(**args) @assured_count = args[:assured_count] if args.key?(:assured_count) @count = args[:count] if args.key?(:count) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @source_instance_template = args[:source_instance_template] if args.key?(:source_instance_template) end |