Class: Google::Apis::ComputeBeta::AttachedDiskInitializeParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Input Only] Specifies the parameters for a new disk that will be created alongside the new instance. Use initialization parameters to create boot disks or local SSDs attached to the new instance. This field is persisted and returned for instanceTemplate and not returned in the context of instance. This property is mutually exclusive with the source property; you can only define one or the other, but not both.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AttachedDiskInitializeParams

Returns a new instance of AttachedDiskInitializeParams.



2172
2173
2174
# File 'lib/google/apis/compute_beta/classes.rb', line 2172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

The architecture of the attached disk. Valid values are arm64 or x86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


1979
1980
1981
# File 'lib/google/apis/compute_beta/classes.rb', line 1979

def architecture
  @architecture
end

#descriptionString

An optional description. Provide this property when creating the disk. Corresponds to the JSON property description

Returns:

  • (String)


1984
1985
1986
# File 'lib/google/apis/compute_beta/classes.rb', line 1984

def description
  @description
end

#disk_nameString

Specifies the disk name. If not specified, the default is to use the name of the instance. If a disk with the same name already exists in the given region, the existing disk is attached to the new instance and the new disk is not created. Corresponds to the JSON property diskName

Returns:

  • (String)


1992
1993
1994
# File 'lib/google/apis/compute_beta/classes.rb', line 1992

def disk_name
  @disk_name
end

#disk_size_gbFixnum

Specifies the size of the disk in base-2 GB. The size must be at least 10 GB. If you specify a sourceImage, which is required for boot disks, the default size is the size of the sourceImage. If you do not specify a sourceImage, the default disk size is 500 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


2001
2002
2003
# File 'lib/google/apis/compute_beta/classes.rb', line 2001

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Corresponds to the JSON property diskType

Returns:

  • (String)


2006
2007
2008
# File 'lib/google/apis/compute_beta/classes.rb', line 2006

def disk_type
  @disk_type
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Whether this disk is using confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


2011
2012
2013
# File 'lib/google/apis/compute_beta/classes.rb', line 2011

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Guest OS features are applied by merginginitializeParams.guestOsFeatures anddisks.guestOsFeatures Corresponds to the JSON property guestOsFeatures



2022
2023
2024
# File 'lib/google/apis/compute_beta/classes.rb', line 2022

def guest_os_features
  @guest_os_features
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by thedisks. setLabels method. This field is only applicable for persistent disks. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2029
2030
2031
# File 'lib/google/apis/compute_beta/classes.rb', line 2029

def labels
  @labels
end

#licensesArray<String>

A list of publicly visible licenses. Reserved for Google's use. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


2034
2035
2036
# File 'lib/google/apis/compute_beta/classes.rb', line 2034

def licenses
  @licenses
end

#multi_writerBoolean Also known as: multi_writer?

Indicates whether or not the disk can be read/write attached to more than one instance. Corresponds to the JSON property multiWriter

Returns:

  • (Boolean)


2040
2041
2042
# File 'lib/google/apis/compute_beta/classes.rb', line 2040

def multi_writer
  @multi_writer
end

#on_update_actionString

Specifies which action to take on instance update with this disk. Default is to use the existing disk. Corresponds to the JSON property onUpdateAction

Returns:

  • (String)


2047
2048
2049
# File 'lib/google/apis/compute_beta/classes.rb', line 2047

def on_update_action
  @on_update_action
end

#provisioned_iopsFixnum

Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


2055
2056
2057
# File 'lib/google/apis/compute_beta/classes.rb', line 2055

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must greater than or equal to 1. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


2062
2063
2064
# File 'lib/google/apis/compute_beta/classes.rb', line 2062

def provisioned_throughput
  @provisioned_throughput
end

#replica_zonesArray<String>

Required for each regional disk associated with the instance. Specify the URLs of the zones where the disk should be replicated to. You must provide exactly two replica zones, and one zone must be the same as the instance zone. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


2070
2071
2072
# File 'lib/google/apis/compute_beta/classes.rb', line 2070

def replica_zones
  @replica_zones
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the disk. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


2081
2082
2083
# File 'lib/google/apis/compute_beta/classes.rb', line 2081

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies applied to this disk for automatic snapshot creations. Specified using the full or partial URL. For instance template, specify only the resource policy name. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


2088
2089
2090
# File 'lib/google/apis/compute_beta/classes.rb', line 2088

def resource_policies
  @resource_policies
end

#source_imageString

The source image to create this disk. When creating a new instance boot disk, one of initializeParams.sourceImage orinitializeParams.sourceSnapshot or disks.source is required. To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/ debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family If the source image is deleted later, this field will not be set. Corresponds to the JSON property sourceImage

Returns:

  • (String)


2110
2111
2112
# File 'lib/google/apis/compute_beta/classes.rb', line 2110

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. InstanceTemplate and InstancePropertiesPatch do not storecustomer-supplied encryption keys, so you cannot create disks for instances in a managed instance group if the source images are encrypted with your own keys. Corresponds to the JSON property sourceImageEncryptionKey



2121
2122
2123
# File 'lib/google/apis/compute_beta/classes.rb', line 2121

def source_image_encryption_key
  @source_image_encryption_key
end

#source_instant_snapshotString

The source instant-snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot or initializeParams.sourceInstantSnapshotinitializeParams.sourceImage or disks. source is required. To create a disk with a snapshot that you created, specify the snapshot name in the following format: us-central1-a/instantSnapshots/my-backup If the source instant-snapshot is deleted later, this field will not be set. Corresponds to the JSON property sourceInstantSnapshot

Returns:

  • (String)


2135
2136
2137
# File 'lib/google/apis/compute_beta/classes.rb', line 2135

def source_instant_snapshot
  @source_instant_snapshot
end

#source_snapshotString

The source snapshot to create this disk. When creating a new instance boot disk, one of initializeParams.sourceSnapshot orinitializeParams. sourceImage or disks.source is required. To create a disk with a snapshot that you created, specify the snapshot name in the following format: global/snapshots/my-backup If the source snapshot is deleted later, this field will not be set. Note: You cannot create VMs in bulk using a snapshot as the source. Use an image instead when you create VMs using the bulk insert method. Corresponds to the JSON property sourceSnapshot

Returns:

  • (String)


2151
2152
2153
# File 'lib/google/apis/compute_beta/classes.rb', line 2151

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source snapshot. Corresponds to the JSON property sourceSnapshotEncryptionKey



2157
2158
2159
# File 'lib/google/apis/compute_beta/classes.rb', line 2157

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#storage_poolString

The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


2170
2171
2172
# File 'lib/google/apis/compute_beta/classes.rb', line 2170

def storage_pool
  @storage_pool
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2177
2178
2179
2180
2181
2182
2183
2184
2185
2186
2187
2188
2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
2200
# File 'lib/google/apis/compute_beta/classes.rb', line 2177

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @description = args[:description] if args.key?(:description)
  @disk_name = args[:disk_name] if args.key?(:disk_name)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @labels = args[:labels] if args.key?(:labels)
  @licenses = args[:licenses] if args.key?(:licenses)
  @multi_writer = args[:multi_writer] if args.key?(:multi_writer)
  @on_update_action = args[:on_update_action] if args.key?(:on_update_action)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
end