Class: Google::Apis::ComputeBeta::Autoscaler

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Autoscaler resource. Google Compute Engine has two Autoscaler resources:

  • Zonal
  • Regional Use autoscalers to automatically add or delete instances from a managed instance group according to your defined autoscaling policy. For more information, read Autoscaling Groups of Instances. For zonal managed instance groups resource, use the autoscaler resource. For regional managed instance groups, use theregionAutoscalers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Autoscaler

Returns a new instance of Autoscaler.



2438
2439
2440
# File 'lib/google/apis/compute_beta/classes.rb', line 2438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_policyGoogle::Apis::ComputeBeta::AutoscalingPolicy

Cloud Autoscaler policy. Corresponds to the JSON property autoscalingPolicy



2335
2336
2337
# File 'lib/google/apis/compute_beta/classes.rb', line 2335

def autoscaling_policy
  @autoscaling_policy
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


2341
2342
2343
# File 'lib/google/apis/compute_beta/classes.rb', line 2341

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/compute_beta/classes.rb', line 2347

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


2354
2355
2356
# File 'lib/google/apis/compute_beta/classes.rb', line 2354

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#autoscaler for autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2360
2361
2362
# File 'lib/google/apis/compute_beta/classes.rb', line 2360

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


2371
2372
2373
# File 'lib/google/apis/compute_beta/classes.rb', line 2371

def name
  @name
end

Output only. [Output Only] Target recommended MIG size (number of instances) computed by autoscaler. Autoscaler calculates the recommended MIG size even when the autoscaling policy mode is different from ON. This field is empty when autoscaler is not connected to an existing managed instance group or autoscaler did not generate its prediction. Corresponds to the JSON property recommendedSize

Returns:

  • (Fixnum)


2381
2382
2383
# File 'lib/google/apis/compute_beta/classes.rb', line 2381

def recommended_size
  @recommended_size
end

#regionString

Output only. [Output Only] URL of theregion where the instance group resides (for autoscalers living in regional scope). Corresponds to the JSON property region

Returns:

  • (String)


2388
2389
2390
# File 'lib/google/apis/compute_beta/classes.rb', line 2388

def region
  @region
end

#scaling_schedule_statusHash<String,Google::Apis::ComputeBeta::ScalingScheduleStatus>

Output only. [Output Only] Status information of existing scaling schedules. Corresponds to the JSON property scalingScheduleStatus



2393
2394
2395
# File 'lib/google/apis/compute_beta/classes.rb', line 2393

def scaling_schedule_status
  @scaling_schedule_status
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2398
2399
2400
# File 'lib/google/apis/compute_beta/classes.rb', line 2398

def self_link
  @self_link
end

#statusString

[Output Only] The status of the autoscaler configuration. Current set of possible values:

  • PENDING: Autoscaler backend hasn't read new/updated configuration.
  • DELETING: Configuration is being deleted.
  • ACTIVE: Configuration is acknowledged to be effective. Some warnings might be present in the statusDetails field.
  • ERROR: Configuration has errors. Actionable for users. Details are present in the statusDetails field. New values might be added in the future. Corresponds to the JSON property status

Returns:

  • (String)


2416
2417
2418
# File 'lib/google/apis/compute_beta/classes.rb', line 2416

def status
  @status
end

#status_detailsArray<Google::Apis::ComputeBeta::AutoscalerStatusDetails>

[Output Only] Human-readable details about the current state of the autoscaler. Read the documentation forCommonly returned status messages for examples of status messages you might encounter. Corresponds to the JSON property statusDetails



2424
2425
2426
# File 'lib/google/apis/compute_beta/classes.rb', line 2424

def status_details
  @status_details
end

#targetString

URL of the managed instance group that this autoscaler will scale. This field is required when creating an autoscaler. Corresponds to the JSON property target

Returns:

  • (String)


2430
2431
2432
# File 'lib/google/apis/compute_beta/classes.rb', line 2430

def target
  @target
end

#zoneString

Output only. [Output Only] URL of thezone where the instance group resides (for autoscalers living in zonal scope). Corresponds to the JSON property zone

Returns:

  • (String)


2436
2437
2438
# File 'lib/google/apis/compute_beta/classes.rb', line 2436

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2443
2444
2445
2446
2447
2448
2449
2450
2451
2452
2453
2454
2455
2456
2457
2458
# File 'lib/google/apis/compute_beta/classes.rb', line 2443

def update!(**args)
  @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @recommended_size = args[:recommended_size] if args.key?(:recommended_size)
  @region = args[:region] if args.key?(:region)
  @scaling_schedule_status = args[:scaling_schedule_status] if args.key?(:scaling_schedule_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
  @status_details = args[:status_details] if args.key?(:status_details)
  @target = args[:target] if args.key?(:target)
  @zone = args[:zone] if args.key?(:zone)
end