Class: Google::Apis::ComputeBeta::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



2508
2509
2510
# File 'lib/google/apis/compute_beta/classes.rb', line 2508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2468
2469
2470
# File 'lib/google/apis/compute_beta/classes.rb', line 2468

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2473
2474
2475
# File 'lib/google/apis/compute_beta/classes.rb', line 2473

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2480
2481
2482
# File 'lib/google/apis/compute_beta/classes.rb', line 2480

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2490
2491
2492
# File 'lib/google/apis/compute_beta/classes.rb', line 2490

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2495
2496
2497
# File 'lib/google/apis/compute_beta/classes.rb', line 2495

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2501
2502
2503
# File 'lib/google/apis/compute_beta/classes.rb', line 2501

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2506
2507
2508
# File 'lib/google/apis/compute_beta/classes.rb', line 2506

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2513
2514
2515
2516
2517
2518
2519
2520
2521
# File 'lib/google/apis/compute_beta/classes.rb', line 2513

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end