Class: Google::Apis::ComputeBeta::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



2499
2500
2501
# File 'lib/google/apis/compute_beta/classes.rb', line 2499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2459
2460
2461
# File 'lib/google/apis/compute_beta/classes.rb', line 2459

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2464
2465
2466
# File 'lib/google/apis/compute_beta/classes.rb', line 2464

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2471
2472
2473
# File 'lib/google/apis/compute_beta/classes.rb', line 2471

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2481
2482
2483
# File 'lib/google/apis/compute_beta/classes.rb', line 2481

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2486
2487
2488
# File 'lib/google/apis/compute_beta/classes.rb', line 2486

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2492
2493
2494
# File 'lib/google/apis/compute_beta/classes.rb', line 2492

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2497
2498
2499
# File 'lib/google/apis/compute_beta/classes.rb', line 2497

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2504
2505
2506
2507
2508
2509
2510
2511
2512
# File 'lib/google/apis/compute_beta/classes.rb', line 2504

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end