Class: Google::Apis::ComputeBeta::AutoscalerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AutoscalerAggregatedList

Returns a new instance of AutoscalerAggregatedList.



2525
2526
2527
# File 'lib/google/apis/compute_beta/classes.rb', line 2525

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


2485
2486
2487
# File 'lib/google/apis/compute_beta/classes.rb', line 2485

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::AutoscalersScopedList>

A list of AutoscalersScopedList resources. Corresponds to the JSON property items



2490
2491
2492
# File 'lib/google/apis/compute_beta/classes.rb', line 2490

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# autoscalerAggregatedList for aggregated lists of autoscalers. Corresponds to the JSON property kind

Returns:

  • (String)


2497
2498
2499
# File 'lib/google/apis/compute_beta/classes.rb', line 2497

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


2507
2508
2509
# File 'lib/google/apis/compute_beta/classes.rb', line 2507

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


2512
2513
2514
# File 'lib/google/apis/compute_beta/classes.rb', line 2512

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


2518
2519
2520
# File 'lib/google/apis/compute_beta/classes.rb', line 2518

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::AutoscalerAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



2523
2524
2525
# File 'lib/google/apis/compute_beta/classes.rb', line 2523

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2530
2531
2532
2533
2534
2535
2536
2537
2538
# File 'lib/google/apis/compute_beta/classes.rb', line 2530

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end