Class: Google::Apis::ComputeBeta::AutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Autoscaler resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::AutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalerList
constructor
A new instance of AutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalerList
Returns a new instance of AutoscalerList.
2651 2652 2653 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2651 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
2618 2619 2620 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2618 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
2623 2624 2625 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2623 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#autoscalerList
for lists of autoscalers.
Corresponds to the JSON property kind
2629 2630 2631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2629 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
2639 2640 2641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2639 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
2644 2645 2646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2644 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::AutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
2649 2650 2651 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2649 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2656 2657 2658 2659 2660 2661 2662 2663 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2656 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |