Class: Google::Apis::ComputeBeta::AutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::AutoscalingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Cloud Autoscaler policy.
Instance Attribute Summary collapse
-
#cool_down_period_sec ⇒ Fixnum
The number of seconds that your application takes to initialize on a VM instance.
-
#cpu_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyCpuUtilization
CPU utilization policy.
-
#custom_metric_utilizations ⇒ Array<Google::Apis::ComputeBeta::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
-
#load_balancing_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancing.
-
#max_num_replicas ⇒ Fixnum
The maximum number of instances that the autoscaler can scale out to.
-
#min_num_replicas ⇒ Fixnum
The minimum number of replicas that the autoscaler can scale in to.
-
#mode ⇒ String
Defines the operating mode for this policy.
-
#scale_down_control ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyScaleDownControl
Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
-
#scale_in_control ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyScaleInControl
Configuration that allows for slower scale in so that even if Autoscaler recommends an abrupt scale in of a MIG, it will be throttled as specified by the parameters below.
-
#scaling_schedules ⇒ Hash<String,Google::Apis::ComputeBeta::AutoscalingPolicyScalingSchedule>
Scaling schedules defined for an autoscaler.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AutoscalingPolicy
constructor
A new instance of AutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AutoscalingPolicy
Returns a new instance of AutoscalingPolicy.
2995 2996 2997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cool_down_period_sec ⇒ Fixnum
The number of seconds that your application takes to initialize on a VM
instance. This is referred to as the
initialization period.
Specifying an accurate initialization period improves
autoscaler decisions. For example, when scaling out, the autoscaler ignores
data from VMs that are still initializing because those VMs might not yet
represent normal usage of your application. The default initialization
period is 60 seconds.
Initialization periods might vary because of numerous
factors. We recommend that you test how long your application takes to
initialize. To do this, create a VM and time your application's startup
process.
Corresponds to the JSON property coolDownPeriodSec
2927 2928 2929 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2927 def cool_down_period_sec @cool_down_period_sec end |
#cpu_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyCpuUtilization
CPU utilization policy.
Corresponds to the JSON property cpuUtilization
2932 2933 2934 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2932 def cpu_utilization @cpu_utilization end |
#custom_metric_utilizations ⇒ Array<Google::Apis::ComputeBeta::AutoscalingPolicyCustomMetricUtilization>
Configuration parameters of autoscaling based on a custom metric.
Corresponds to the JSON property customMetricUtilizations
2937 2938 2939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2937 def custom_metric_utilizations @custom_metric_utilizations end |
#load_balancing_utilization ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyLoadBalancingUtilization
Configuration parameters of autoscaling based on load balancing.
Corresponds to the JSON property loadBalancingUtilization
2942 2943 2944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2942 def load_balancing_utilization @load_balancing_utilization end |
#max_num_replicas ⇒ Fixnum
The maximum number of instances that the autoscaler can scale out to. This
is required when creating or updating an autoscaler. The maximum number
of replicas must not be lower than minimal number of replicas.
Corresponds to the JSON property maxNumReplicas
2949 2950 2951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2949 def max_num_replicas @max_num_replicas end |
#min_num_replicas ⇒ Fixnum
The minimum number of replicas that the autoscaler can scale in to.
This cannot be less than 0. If not provided, autoscaler chooses a
default value depending on maximum number of instances allowed.
Corresponds to the JSON property minNumReplicas
2956 2957 2958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2956 def min_num_replicas @min_num_replicas end |
#mode ⇒ String
Defines the operating mode for this policy. The following modes are available:
- OFF: Disables the autoscaler but maintains its configuration.
- ONLY_SCALE_OUT: Restricts the autoscaler to add VM instances only.
- ON: Enables all autoscaler activities according to its
policy.
For more information, see
"Turning off or restricting an autoscaler"
Corresponds to the JSON property
mode
2971 2972 2973 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2971 def mode @mode end |
#scale_down_control ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyScaleDownControl
Configuration that allows for slower scale in so that even if Autoscaler
recommends an abrupt scale in of a MIG, it will be throttled as specified
by the parameters below.
Corresponds to the JSON property scaleDownControl
2978 2979 2980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2978 def scale_down_control @scale_down_control end |
#scale_in_control ⇒ Google::Apis::ComputeBeta::AutoscalingPolicyScaleInControl
Configuration that allows for slower scale in so that even if Autoscaler
recommends an abrupt scale in of a MIG, it will be throttled as specified
by the parameters below.
Corresponds to the JSON property scaleInControl
2985 2986 2987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2985 def scale_in_control @scale_in_control end |
#scaling_schedules ⇒ Hash<String,Google::Apis::ComputeBeta::AutoscalingPolicyScalingSchedule>
Scaling schedules defined for an autoscaler. Multiple schedules
can be set on an autoscaler, and they can overlap. During overlapping
periods the greatest min_required_replicas of all scaling schedules is
applied. Up to 128 scaling schedules are allowed.
Corresponds to the JSON property scalingSchedules
2993 2994 2995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 2993 def scaling_schedules @scaling_schedules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3000 3001 3002 3003 3004 3005 3006 3007 3008 3009 3010 3011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 3000 def update!(**args) @cool_down_period_sec = args[:cool_down_period_sec] if args.key?(:cool_down_period_sec) @cpu_utilization = args[:cpu_utilization] if args.key?(:cpu_utilization) @custom_metric_utilizations = args[:custom_metric_utilizations] if args.key?(:custom_metric_utilizations) @load_balancing_utilization = args[:load_balancing_utilization] if args.key?(:load_balancing_utilization) @max_num_replicas = args[:max_num_replicas] if args.key?(:max_num_replicas) @min_num_replicas = args[:min_num_replicas] if args.key?(:min_num_replicas) @mode = args[:mode] if args.key?(:mode) @scale_down_control = args[:scale_down_control] if args.key?(:scale_down_control) @scale_in_control = args[:scale_in_control] if args.key?(:scale_in_control) @scaling_schedules = args[:scaling_schedules] if args.key?(:scaling_schedules) end |