Class: Google::Apis::ComputeBeta::BackendBackendOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A message containing information about the resource or system that manages the backend.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBackendOrchestrationInfo

Returns a new instance of BackendBackendOrchestrationInfo.



3530
3531
3532
# File 'lib/google/apis/compute_beta/classes.rb', line 3530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The URI of the resource or system that manages the backend. Corresponds to the JSON property resourceUri

Returns:

  • (String)


3528
3529
3530
# File 'lib/google/apis/compute_beta/classes.rb', line 3528

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3535
3536
3537
# File 'lib/google/apis/compute_beta/classes.rb', line 3535

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end