Class: Google::Apis::ComputeBeta::BackendBucket

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Cloud Storage Bucket resource. This Cloud Storage bucket resource is referenced by a URL map of a load balancer. For more information, readBackend Buckets.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucket

Returns a new instance of BackendBucket.



3600
3601
3602
# File 'lib/google/apis/compute_beta/classes.rb', line 3600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucket_nameString

Cloud Storage bucket name. Corresponds to the JSON property bucketName

Returns:

  • (String)


3505
3506
3507
# File 'lib/google/apis/compute_beta/classes.rb', line 3505

def bucket_name
  @bucket_name
end

#cdn_policyGoogle::Apis::ComputeBeta::BackendBucketCdnPolicy

Message containing Cloud CDN configuration for a backend bucket. Corresponds to the JSON property cdnPolicy



3510
3511
3512
# File 'lib/google/apis/compute_beta/classes.rb', line 3510

def cdn_policy
  @cdn_policy
end

#compression_modeString

Compress text responses using Brotli or gzip compression, based on the client's Accept-Encoding header. Corresponds to the JSON property compressionMode

Returns:

  • (String)


3516
3517
3518
# File 'lib/google/apis/compute_beta/classes.rb', line 3516

def compression_mode
  @compression_mode
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


3522
3523
3524
# File 'lib/google/apis/compute_beta/classes.rb', line 3522

def creation_timestamp
  @creation_timestamp
end

#custom_response_headersArray<String>

Headers that the Application Load Balancer should add to proxied responses. Corresponds to the JSON property customResponseHeaders

Returns:

  • (Array<String>)


3527
3528
3529
# File 'lib/google/apis/compute_beta/classes.rb', line 3527

def custom_response_headers
  @custom_response_headers
end

#descriptionString

An optional textual description of the resource; provided by the client when the resource is created. Corresponds to the JSON property description

Returns:

  • (String)


3533
3534
3535
# File 'lib/google/apis/compute_beta/classes.rb', line 3533

def description
  @description
end

#edge_security_policyString

[Output Only] The resource URL for the edge security policy associated with this backend bucket. Corresponds to the JSON property edgeSecurityPolicy

Returns:

  • (String)


3539
3540
3541
# File 'lib/google/apis/compute_beta/classes.rb', line 3539

def edge_security_policy
  @edge_security_policy
end

#enable_cdnBoolean Also known as: enable_cdn?

If true, enable Cloud CDN for this BackendBucket. Corresponds to the JSON property enableCdn

Returns:

  • (Boolean)


3544
3545
3546
# File 'lib/google/apis/compute_beta/classes.rb', line 3544

def enable_cdn
  @enable_cdn
end

#idFixnum

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


3550
3551
3552
# File 'lib/google/apis/compute_beta/classes.rb', line 3550

def id
  @id
end

#kindString

Output only. Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


3555
3556
3557
# File 'lib/google/apis/compute_beta/classes.rb', line 3555

def kind
  @kind
end

#load_balancing_schemeString

The value can only be INTERNAL_MANAGED for cross-region internal layer 7 load balancer. If loadBalancingScheme is not specified, the backend bucket can be used by classic global external load balancers, or global application external load balancers, or both. Corresponds to the JSON property loadBalancingScheme

Returns:

  • (String)


3564
3565
3566
# File 'lib/google/apis/compute_beta/classes.rb', line 3564

def load_balancing_scheme
  @load_balancing_scheme
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


3575
3576
3577
# File 'lib/google/apis/compute_beta/classes.rb', line 3575

def name
  @name
end

#paramsGoogle::Apis::ComputeBeta::BackendBucketParams

Additional Backend Bucket parameters. Corresponds to the JSON property params



3580
3581
3582
# File 'lib/google/apis/compute_beta/classes.rb', line 3580

def params
  @params
end

#regionString

Output only. [Output Only] URL of the region where the regional backend bucket resides. This field is not applicable to global backend buckets. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


3588
3589
3590
# File 'lib/google/apis/compute_beta/classes.rb', line 3588

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


3593
3594
3595
# File 'lib/google/apis/compute_beta/classes.rb', line 3593

def self_link
  @self_link
end

#used_byArray<Google::Apis::ComputeBeta::BackendBucketUsedBy>

Output only. [Output Only] List of resources referencing that backend bucket. Corresponds to the JSON property usedBy



3598
3599
3600
# File 'lib/google/apis/compute_beta/classes.rb', line 3598

def used_by
  @used_by
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3605
3606
3607
3608
3609
3610
3611
3612
3613
3614
3615
3616
3617
3618
3619
3620
3621
3622
# File 'lib/google/apis/compute_beta/classes.rb', line 3605

def update!(**args)
  @bucket_name = args[:bucket_name] if args.key?(:bucket_name)
  @cdn_policy = args[:cdn_policy] if args.key?(:cdn_policy)
  @compression_mode = args[:compression_mode] if args.key?(:compression_mode)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @custom_response_headers = args[:custom_response_headers] if args.key?(:custom_response_headers)
  @description = args[:description] if args.key?(:description)
  @edge_security_policy = args[:edge_security_policy] if args.key?(:edge_security_policy)
  @enable_cdn = args[:enable_cdn] if args.key?(:enable_cdn)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @used_by = args[:used_by] if args.key?(:used_by)
end