Class: Google::Apis::ComputeBeta::BackendBucketCdnPolicyNegativeCachingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendBucketCdnPolicyNegativeCachingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specify CDN TTLs for response error codes.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The HTTP status code to define a TTL against.
-
#ttl ⇒ Fixnum
The TTL (in seconds) for which to cache responses with the corresponding status code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketCdnPolicyNegativeCachingPolicy
constructor
A new instance of BackendBucketCdnPolicyNegativeCachingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketCdnPolicyNegativeCachingPolicy
Returns a new instance of BackendBucketCdnPolicyNegativeCachingPolicy.
4012 4013 4014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4012 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The HTTP status code to define a TTL against. Only HTTP status codes
300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be
specified as values, and you cannot specify a status code more than
once.
Corresponds to the JSON property code
4001 4002 4003 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4001 def code @code end |
#ttl ⇒ Fixnum
The TTL (in seconds) for which to cache responses with the
corresponding status code.
The maximum allowed value is 1800s (30 minutes), noting that
infrequently accessed objects may be evicted from the cache before the
defined TTL.
Corresponds to the JSON property ttl
4010 4011 4012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4010 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4017 4018 4019 4020 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4017 def update!(**args) @code = args[:code] if args.key?(:code) @ttl = args[:ttl] if args.key?(:ttl) end |