Class: Google::Apis::ComputeBeta::BackendBucketList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of BackendBucket resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketList

Returns a new instance of BackendBucketList.



4044
4045
4046
# File 'lib/google/apis/compute_beta/classes.rb', line 4044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4012
4013
4014
# File 'lib/google/apis/compute_beta/classes.rb', line 4012

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4017
4018
4019
# File 'lib/google/apis/compute_beta/classes.rb', line 4017

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


4022
4023
4024
# File 'lib/google/apis/compute_beta/classes.rb', line 4022

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4032
4033
4034
# File 'lib/google/apis/compute_beta/classes.rb', line 4032

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4037
4038
4039
# File 'lib/google/apis/compute_beta/classes.rb', line 4037

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendBucketList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4042
4043
4044
# File 'lib/google/apis/compute_beta/classes.rb', line 4042

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4049
4050
4051
4052
4053
4054
4055
4056
# File 'lib/google/apis/compute_beta/classes.rb', line 4049

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end