Class: Google::Apis::ComputeBeta::BackendBucketListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendBucketListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketListUsable
constructor
A new instance of BackendBucketListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketListUsable
Returns a new instance of BackendBucketListUsable.
4249 4250 4251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4215 4216 4217 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4215 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4220 4221 4222 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4220 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendBucketList for lists of usable backend
buckets.
Corresponds to the JSON property kind
4227 4228 4229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4227 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4237 4238 4239 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4237 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4242 4243 4244 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4242 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4247 4248 4249 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4247 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4254 4255 4256 4257 4258 4259 4260 4261 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4254 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |