Class: Google::Apis::ComputeBeta::BackendBucketListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendBucketListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketListUsable
constructor
A new instance of BackendBucketListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketListUsable
Returns a new instance of BackendBucketListUsable.
4206 4207 4208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4172 4173 4174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4172 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4177 4178 4179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4177 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendBucketList for lists of usable backend
buckets.
Corresponds to the JSON property kind
4184 4185 4186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4184 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4194 4195 4196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4194 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4199 4200 4201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4199 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4204 4205 4206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4204 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4211 4212 4213 4214 4215 4216 4217 4218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4211 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |