Class: Google::Apis::ComputeBeta::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4197
4198
4199
# File 'lib/google/apis/compute_beta/classes.rb', line 4197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4163
4164
4165
# File 'lib/google/apis/compute_beta/classes.rb', line 4163

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4168
4169
4170
# File 'lib/google/apis/compute_beta/classes.rb', line 4168

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4175
4176
4177
# File 'lib/google/apis/compute_beta/classes.rb', line 4175

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4185
4186
4187
# File 'lib/google/apis/compute_beta/classes.rb', line 4185

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4190
4191
4192
# File 'lib/google/apis/compute_beta/classes.rb', line 4190

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4195
4196
4197
# File 'lib/google/apis/compute_beta/classes.rb', line 4195

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4202
4203
4204
4205
4206
4207
4208
4209
# File 'lib/google/apis/compute_beta/classes.rb', line 4202

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end