Class: Google::Apis::ComputeBeta::BackendBucketListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendBucketListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendBucketListUsable
constructor
A new instance of BackendBucketListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendBucketListUsable
Returns a new instance of BackendBucketListUsable.
4214 4215 4216 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4214 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
4180 4181 4182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4180 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendBucket>
A list of BackendBucket resources.
Corresponds to the JSON property items
4185 4186 4187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4185 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendBucketList for lists of usable backend
buckets.
Corresponds to the JSON property kind
4192 4193 4194 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4192 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
4202 4203 4204 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4202 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
4207 4208 4209 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4207 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendBucketListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
4212 4213 4214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4212 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4219 4220 4221 4222 4223 4224 4225 4226 |
# File 'lib/google/apis/compute_beta/classes.rb', line 4219 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |