Class: Google::Apis::ComputeBeta::BackendBucketListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendBucketListUsable

Returns a new instance of BackendBucketListUsable.



4170
4171
4172
# File 'lib/google/apis/compute_beta/classes.rb', line 4170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


4136
4137
4138
# File 'lib/google/apis/compute_beta/classes.rb', line 4136

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendBucket>

A list of BackendBucket resources. Corresponds to the JSON property items



4141
4142
4143
# File 'lib/google/apis/compute_beta/classes.rb', line 4141

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendBucketList for lists of usable backend buckets. Corresponds to the JSON property kind

Returns:

  • (String)


4148
4149
4150
# File 'lib/google/apis/compute_beta/classes.rb', line 4148

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4158
4159
4160
# File 'lib/google/apis/compute_beta/classes.rb', line 4158

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


4163
4164
4165
# File 'lib/google/apis/compute_beta/classes.rb', line 4163

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendBucketListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



4168
4169
4170
# File 'lib/google/apis/compute_beta/classes.rb', line 4168

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4175
4176
4177
4178
4179
4180
4181
4182
# File 'lib/google/apis/compute_beta/classes.rb', line 4175

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end