Class: Google::Apis::ComputeBeta::BackendServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of BackendServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceAggregatedList

Returns a new instance of BackendServiceAggregatedList.



5120
5121
5122
# File 'lib/google/apis/compute_beta/classes.rb', line 5120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5083
5084
5085
# File 'lib/google/apis/compute_beta/classes.rb', line 5083

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::BackendServicesScopedList>

A list of BackendServicesScopedList resources. Corresponds to the JSON property items



5088
5089
5090
# File 'lib/google/apis/compute_beta/classes.rb', line 5088

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


5093
5094
5095
# File 'lib/google/apis/compute_beta/classes.rb', line 5093

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5103
5104
5105
# File 'lib/google/apis/compute_beta/classes.rb', line 5103

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5108
5109
5110
# File 'lib/google/apis/compute_beta/classes.rb', line 5108

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


5113
5114
5115
# File 'lib/google/apis/compute_beta/classes.rb', line 5113

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::BackendServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5118
5119
5120
# File 'lib/google/apis/compute_beta/classes.rb', line 5118

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5125
5126
5127
5128
5129
5130
5131
5132
5133
# File 'lib/google/apis/compute_beta/classes.rb', line 5125

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end