Class: Google::Apis::ComputeBeta::BackendServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of BackendServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceAggregatedList
constructor
A new instance of BackendServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceAggregatedList
Returns a new instance of BackendServiceAggregatedList.
5102 5103 5104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5065 5066 5067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5065 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::BackendServicesScopedList>
A list of BackendServicesScopedList resources.
Corresponds to the JSON property items
5070 5071 5072 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5070 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
5075 5076 5077 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5075 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5085 5086 5087 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5085 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
5090 5091 5092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5090 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
5095 5096 5097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5095 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
5100 5101 5102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5100 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5107 5108 5109 5110 5111 5112 5113 5114 5115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5107 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |