Class: Google::Apis::ComputeBeta::BackendServiceCdnPolicyNegativeCachingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceCdnPolicyNegativeCachingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specify CDN TTLs for response error codes.
Instance Attribute Summary collapse
-
#code ⇒ Fixnum
The HTTP status code to define a TTL against.
-
#ttl ⇒ Fixnum
The TTL (in seconds) for which to cache responses with the corresponding status code.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceCdnPolicyNegativeCachingPolicy
constructor
A new instance of BackendServiceCdnPolicyNegativeCachingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceCdnPolicyNegativeCachingPolicy
Returns a new instance of BackendServiceCdnPolicyNegativeCachingPolicy.
5431 5432 5433 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ Fixnum
The HTTP status code to define a TTL against. Only HTTP status codes
300, 301, 302, 307, 308, 404, 405, 410, 421, 451 and 501 can be
specified as values, and you cannot specify a status code more than
once.
Corresponds to the JSON property code
5420 5421 5422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5420 def code @code end |
#ttl ⇒ Fixnum
The TTL (in seconds) for which to cache responses with the
corresponding status code.
The maximum allowed value is 1800s (30 minutes), noting that
infrequently accessed objects may be evicted from the cache before the
defined TTL.
Corresponds to the JSON property ttl
5429 5430 5431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5429 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5436 5437 5438 5439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5436 def update!(**args) @code = args[:code] if args.key?(:code) @ttl = args[:ttl] if args.key?(:ttl) end |