Class: Google::Apis::ComputeBeta::BackendServiceCustomMetric
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceCustomMetric
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Custom Metrics are used for WEIGHTED_ROUND_ROBIN locality_lb_policy.
Instance Attribute Summary collapse
-
#dry_run ⇒ Boolean
(also: #dry_run?)
If true, the metric data is not used for load balancing.
-
#name ⇒ String
Name of a custom utilization signal.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceCustomMetric
constructor
A new instance of BackendServiceCustomMetric.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceCustomMetric
Returns a new instance of BackendServiceCustomMetric.
5499 5500 5501 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dry_run ⇒ Boolean Also known as: dry_run?
If true, the metric data is not used for load balancing.
Corresponds to the JSON property dryRun
5482 5483 5484 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5482 def dry_run @dry_run end |
#name ⇒ String
Name of a custom utilization signal. The name must be 1-64 characters
long and match the regular expression
[a-z]([-_.a-z0-9]*[a-z0-9])? which means that the
first character must be a lowercase letter, and all following
characters must be a dash, period, underscore, lowercase letter, or
digit, except the last character, which cannot be a dash, period, or
underscore. For usage guidelines, see Custom Metrics balancing mode. This
field can only be used for a global or regional backend service with the
loadBalancingScheme set to EXTERNAL_MANAGED,INTERNAL_MANAGED
INTERNAL_SELF_MANAGED.
Corresponds to the JSON property name
5497 5498 5499 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5497 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5504 5505 5506 5507 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5504 def update!(**args) @dry_run = args[:dry_run] if args.key?(:dry_run) @name = args[:name] if args.key?(:name) end |