Class: Google::Apis::ComputeBeta::BackendServiceDynamicForwarding
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceDynamicForwarding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Defines a dynamic forwarding configuration for the backend service.
Instance Attribute Summary collapse
-
#forward_proxy ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwardingForwardProxy
Defines Dynamic Forwarding Proxy configuration.
-
#ip_port_selection ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwardingIpPortSelection
Defines a IP:PORT based dynamic forwarding configuration for the backend service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceDynamicForwarding
constructor
A new instance of BackendServiceDynamicForwarding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceDynamicForwarding
Returns a new instance of BackendServiceDynamicForwarding.
5565 5566 5567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forward_proxy ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwardingForwardProxy
Defines Dynamic Forwarding Proxy configuration.
Corresponds to the JSON property forwardProxy
5556 5557 5558 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5556 def forward_proxy @forward_proxy end |
#ip_port_selection ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwardingIpPortSelection
Defines a IP:PORT based dynamic forwarding configuration for the backend
service. Some ranges are restricted: Restricted
ranges.
Corresponds to the JSON property ipPortSelection
5563 5564 5565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5563 def ip_port_selection @ip_port_selection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5570 5571 5572 5573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5570 def update!(**args) @forward_proxy = args[:forward_proxy] if args.key?(:forward_proxy) @ip_port_selection = args[:ip_port_selection] if args.key?(:ip_port_selection) end |