Class: Google::Apis::ComputeBeta::BackendServiceDynamicForwarding

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Defines a dynamic forwarding configuration for the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceDynamicForwarding

Returns a new instance of BackendServiceDynamicForwarding.



5546
5547
5548
# File 'lib/google/apis/compute_beta/classes.rb', line 5546

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_port_selectionGoogle::Apis::ComputeBeta::BackendServiceDynamicForwardingIpPortSelection

Defines a IP:PORT based dynamic forwarding configuration for the backend service. Some ranges are restricted: Restricted ranges. Corresponds to the JSON property ipPortSelection



5544
5545
5546
# File 'lib/google/apis/compute_beta/classes.rb', line 5544

def ip_port_selection
  @ip_port_selection
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5551
5552
5553
# File 'lib/google/apis/compute_beta/classes.rb', line 5551

def update!(**args)
  @ip_port_selection = args[:ip_port_selection] if args.key?(:ip_port_selection)
end