Class: Google::Apis::ComputeBeta::BackendServiceDynamicForwarding
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceDynamicForwarding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Defines a dynamic forwarding configuration for the backend service.
Instance Attribute Summary collapse
-
#ip_port_selection ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwardingIpPortSelection
Defines a IP:PORT based dynamic forwarding configuration for the backend service.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceDynamicForwarding
constructor
A new instance of BackendServiceDynamicForwarding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceDynamicForwarding
Returns a new instance of BackendServiceDynamicForwarding.
5521 5522 5523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_port_selection ⇒ Google::Apis::ComputeBeta::BackendServiceDynamicForwardingIpPortSelection
Defines a IP:PORT based dynamic forwarding configuration for the backend
service. Some ranges are restricted: Restricted
ranges.
Corresponds to the JSON property ipPortSelection
5519 5520 5521 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5519 def ip_port_selection @ip_port_selection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5526 5527 5528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5526 def update!(**args) @ip_port_selection = args[:ip_port_selection] if args.key?(:ip_port_selection) end |