Class: Google::Apis::ComputeBeta::BackendServiceGroupHealth

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceGroupHealth

Returns a new instance of BackendServiceGroupHealth.



5722
5723
5724
# File 'lib/google/apis/compute_beta/classes.rb', line 5722

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations on the network endpoint group. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


5707
5708
5709
# File 'lib/google/apis/compute_beta/classes.rb', line 5707

def annotations
  @annotations
end

#health_statusArray<Google::Apis::ComputeBeta::HealthStatus>

Health state of the backend instances or endpoints in requested instance or network endpoint group, determined based on configured health checks. Corresponds to the JSON property healthStatus



5713
5714
5715
# File 'lib/google/apis/compute_beta/classes.rb', line 5713

def health_status
  @health_status
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# backendServiceGroupHealth for the health of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5720
5721
5722
# File 'lib/google/apis/compute_beta/classes.rb', line 5720

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5727
5728
5729
5730
5731
# File 'lib/google/apis/compute_beta/classes.rb', line 5727

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @health_status = args[:health_status] if args.key?(:health_status)
  @kind = args[:kind] if args.key?(:kind)
end