Class: Google::Apis::ComputeBeta::BackendServiceHaPolicyLeader

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceHaPolicyLeader

Returns a new instance of BackendServiceHaPolicyLeader.



5858
5859
5860
# File 'lib/google/apis/compute_beta/classes.rb', line 5858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_groupString

A fully-qualified URL (starting with https://www.googleapis.com/) of the zonal Network Endpoint Group (NEG) with GCE_VM_IP endpoints that the leader is attached to. The leader's backendGroup must already be specified as a backend of this backend service. Removing a backend that is designated as the leader's backendGroup is not permitted. Corresponds to the JSON property backendGroup

Returns:

  • (String)


5847
5848
5849
# File 'lib/google/apis/compute_beta/classes.rb', line 5847

def backend_group
  @backend_group
end

#network_endpointGoogle::Apis::ComputeBeta::BackendServiceHaPolicyLeaderNetworkEndpoint

The network endpoint within the leader.backendGroup that is designated as the leader. This network endpoint cannot be detached from the NEG specified in the haPolicy.leader.backendGroup until the leader is updated with another network endpoint, or the leader is removed from the haPolicy. Corresponds to the JSON property networkEndpoint



5856
5857
5858
# File 'lib/google/apis/compute_beta/classes.rb', line 5856

def network_endpoint
  @network_endpoint
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5863
5864
5865
5866
# File 'lib/google/apis/compute_beta/classes.rb', line 5863

def update!(**args)
  @backend_group = args[:backend_group] if args.key?(:backend_group)
  @network_endpoint = args[:network_endpoint] if args.key?(:network_endpoint)
end