Class: Google::Apis::ComputeBeta::BackendServiceHttpCookie

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The HTTP cookie used for stateful session affinity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceHttpCookie

Returns a new instance of BackendServiceHttpCookie.



5962
5963
5964
# File 'lib/google/apis/compute_beta/classes.rb', line 5962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the cookie. Corresponds to the JSON property name

Returns:

  • (String)


5947
5948
5949
# File 'lib/google/apis/compute_beta/classes.rb', line 5947

def name
  @name
end

#pathString

Path to set for the cookie. Corresponds to the JSON property path

Returns:

  • (String)


5952
5953
5954
# File 'lib/google/apis/compute_beta/classes.rb', line 5952

def path
  @path
end

#ttlGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property ttl



5960
5961
5962
# File 'lib/google/apis/compute_beta/classes.rb', line 5960

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5967
5968
5969
5970
5971
# File 'lib/google/apis/compute_beta/classes.rb', line 5967

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @ttl = args[:ttl] if args.key?(:ttl)
end