Class: Google::Apis::ComputeBeta::BackendServiceHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The HTTP cookie used for stateful session affinity.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceHttpCookie
constructor
A new instance of BackendServiceHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceHttpCookie
Returns a new instance of BackendServiceHttpCookie.
5840 5841 5842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
5825 5826 5827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5825 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
5830 5831 5832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5830 def path @path end |
#ttl ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
5838 5839 5840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5838 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5845 5846 5847 5848 5849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5845 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |