Class: Google::Apis::ComputeBeta::BackendServiceIap

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Identity-Aware Proxy

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceIap

Returns a new instance of BackendServiceIap.



5908
5909
5910
# File 'lib/google/apis/compute_beta/classes.rb', line 5908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Whether the serving infrastructure will authenticate and authorize all incoming requests. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


5885
5886
5887
# File 'lib/google/apis/compute_beta/classes.rb', line 5885

def enabled
  @enabled
end

#oauth2_client_idString

OAuth2 client ID to use for the authentication flow. Corresponds to the JSON property oauth2ClientId

Returns:

  • (String)


5891
5892
5893
# File 'lib/google/apis/compute_beta/classes.rb', line 5891

def oauth2_client_id
  @oauth2_client_id
end

#oauth2_client_secretString

OAuth2 client secret to use for the authentication flow. For security reasons, this value cannot be retrieved via the API. Instead, the SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field. Corresponds to the JSON property oauth2ClientSecret

Returns:

  • (String)


5900
5901
5902
# File 'lib/google/apis/compute_beta/classes.rb', line 5900

def oauth2_client_secret
  @oauth2_client_secret
end

#oauth2_client_secret_sha256String

Output only. [Output Only] SHA256 hash value for the field oauth2_client_secret above. Corresponds to the JSON property oauth2ClientSecretSha256

Returns:

  • (String)


5906
5907
5908
# File 'lib/google/apis/compute_beta/classes.rb', line 5906

def oauth2_client_secret_sha256
  @oauth2_client_secret_sha256
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5913
5914
5915
5916
5917
5918
# File 'lib/google/apis/compute_beta/classes.rb', line 5913

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @oauth2_client_id = args[:oauth2_client_id] if args.key?(:oauth2_client_id)
  @oauth2_client_secret = args[:oauth2_client_secret] if args.key?(:oauth2_client_secret)
  @oauth2_client_secret_sha256 = args[:oauth2_client_secret_sha256] if args.key?(:oauth2_client_secret_sha256)
end