Class: Google::Apis::ComputeBeta::BackendServiceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceList
constructor
A new instance of BackendServiceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceList
Returns a new instance of BackendServiceList.
6076 6077 6078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
6043 6044 6045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6043 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
6048 6049 6050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6048 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList
for lists of backend services.
Corresponds to the JSON property kind
6054 6055 6056 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6054 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6064 6065 6066 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6064 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6069 6070 6071 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6069 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6074 6075 6076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6074 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6081 6082 6083 6084 6085 6086 6087 6088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6081 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |