Class: Google::Apis::ComputeBeta::BackendServiceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceList
constructor
A new instance of BackendServiceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceList
Returns a new instance of BackendServiceList.
6058 6059 6060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
6025 6026 6027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6025 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
6030 6031 6032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6030 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList
for lists of backend services.
Corresponds to the JSON property kind
6036 6037 6038 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6036 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6046 6047 6048 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6046 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6051 6052 6053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6051 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6056 6057 6058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6056 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6063 6064 6065 6066 6067 6068 6069 6070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6063 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |