Class: Google::Apis::ComputeBeta::BackendServiceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceList
constructor
A new instance of BackendServiceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceList
Returns a new instance of BackendServiceList.
6011 6012 6013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
5978 5979 5980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5978 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
5983 5984 5985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5983 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList
for lists of backend services.
Corresponds to the JSON property kind
5989 5990 5991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5989 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
5999 6000 6001 |
# File 'lib/google/apis/compute_beta/classes.rb', line 5999 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6004 6005 6006 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6004 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6009 6010 6011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6009 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6016 6017 6018 6019 6020 6021 6022 6023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6016 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |