Class: Google::Apis::ComputeBeta::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



6002
6003
6004
# File 'lib/google/apis/compute_beta/classes.rb', line 6002

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5969
5970
5971
# File 'lib/google/apis/compute_beta/classes.rb', line 5969

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



5974
5975
5976
# File 'lib/google/apis/compute_beta/classes.rb', line 5974

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5980
5981
5982
# File 'lib/google/apis/compute_beta/classes.rb', line 5980

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5990
5991
5992
# File 'lib/google/apis/compute_beta/classes.rb', line 5990

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5995
5996
5997
# File 'lib/google/apis/compute_beta/classes.rb', line 5995

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6000
6001
6002
# File 'lib/google/apis/compute_beta/classes.rb', line 6000

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6007
6008
6009
6010
6011
6012
6013
6014
# File 'lib/google/apis/compute_beta/classes.rb', line 6007

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end