Class: Google::Apis::ComputeBeta::BackendServiceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceList

Returns a new instance of BackendServiceList.



5961
5962
5963
# File 'lib/google/apis/compute_beta/classes.rb', line 5961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


5928
5929
5930
# File 'lib/google/apis/compute_beta/classes.rb', line 5928

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



5933
5934
5935
# File 'lib/google/apis/compute_beta/classes.rb', line 5933

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#backendServiceList for lists of backend services. Corresponds to the JSON property kind

Returns:

  • (String)


5939
5940
5941
# File 'lib/google/apis/compute_beta/classes.rb', line 5939

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


5949
5950
5951
# File 'lib/google/apis/compute_beta/classes.rb', line 5949

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


5954
5955
5956
# File 'lib/google/apis/compute_beta/classes.rb', line 5954

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendServiceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



5959
5960
5961
# File 'lib/google/apis/compute_beta/classes.rb', line 5959

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5966
5967
5968
5969
5970
5971
5972
5973
# File 'lib/google/apis/compute_beta/classes.rb', line 5966

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end