Class: Google::Apis::ComputeBeta::BackendServiceListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of usable BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceListUsable
constructor
A new instance of BackendServiceListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceListUsable
Returns a new instance of BackendServiceListUsable.
6202 6203 6204 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
6168 6169 6170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6168 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
6173 6174 6175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6173 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendServiceList for lists of usable backend
services.
Corresponds to the JSON property kind
6180 6181 6182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6180 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6190 6191 6192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6190 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6195 6196 6197 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6195 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6200 6201 6202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6200 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6207 6208 6209 6210 6211 6212 6213 6214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6207 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |