Class: Google::Apis::ComputeBeta::BackendServiceListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of usable BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceListUsable
constructor
A new instance of BackendServiceListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceListUsable
Returns a new instance of BackendServiceListUsable.
6184 6185 6186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
6150 6151 6152 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6150 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
6155 6156 6157 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6155 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendServiceList for lists of usable backend
services.
Corresponds to the JSON property kind
6162 6163 6164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6162 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6172 6173 6174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6172 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6177 6178 6179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6177 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6182 6183 6184 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6182 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6189 6190 6191 6192 6193 6194 6195 6196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6189 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |