Class: Google::Apis::ComputeBeta::BackendServiceListUsable
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BackendServiceListUsable
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of usable BackendService resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BackendServiceListUsable
constructor
A new instance of BackendServiceListUsable.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BackendServiceListUsable
Returns a new instance of BackendServiceListUsable.
6128 6129 6130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6128 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
6094 6095 6096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6094 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::BackendService>
A list of BackendService resources.
Corresponds to the JSON property items
6099 6100 6101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6099 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableBackendServiceList for lists of usable backend
services.
Corresponds to the JSON property kind
6106 6107 6108 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6106 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
6116 6117 6118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6116 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
6121 6122 6123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6121 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::BackendServiceListUsable::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
6126 6127 6128 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6126 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6133 6134 6135 6136 6137 6138 6139 6140 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6133 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |