Class: Google::Apis::ComputeBeta::BackendServiceListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of usable BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceListUsable

Returns a new instance of BackendServiceListUsable.



6145
6146
6147
# File 'lib/google/apis/compute_beta/classes.rb', line 6145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6111
6112
6113
# File 'lib/google/apis/compute_beta/classes.rb', line 6111

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6116
6117
6118
# File 'lib/google/apis/compute_beta/classes.rb', line 6116

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendServiceList for lists of usable backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6123
6124
6125
# File 'lib/google/apis/compute_beta/classes.rb', line 6123

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6133
6134
6135
# File 'lib/google/apis/compute_beta/classes.rb', line 6133

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6138
6139
6140
# File 'lib/google/apis/compute_beta/classes.rb', line 6138

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendServiceListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6143
6144
6145
# File 'lib/google/apis/compute_beta/classes.rb', line 6143

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6150
6151
6152
6153
6154
6155
6156
6157
# File 'lib/google/apis/compute_beta/classes.rb', line 6150

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end