Class: Google::Apis::ComputeBeta::BackendServiceListUsable

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of usable BackendService resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceListUsable

Returns a new instance of BackendServiceListUsable.



6062
6063
6064
# File 'lib/google/apis/compute_beta/classes.rb', line 6062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


6028
6029
6030
# File 'lib/google/apis/compute_beta/classes.rb', line 6028

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::BackendService>

A list of BackendService resources. Corresponds to the JSON property items



6033
6034
6035
# File 'lib/google/apis/compute_beta/classes.rb', line 6033

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableBackendServiceList for lists of usable backend services. Corresponds to the JSON property kind

Returns:

  • (String)


6040
6041
6042
# File 'lib/google/apis/compute_beta/classes.rb', line 6040

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


6050
6051
6052
# File 'lib/google/apis/compute_beta/classes.rb', line 6050

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


6055
6056
6057
# File 'lib/google/apis/compute_beta/classes.rb', line 6055

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::BackendServiceListUsable::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



6060
6061
6062
# File 'lib/google/apis/compute_beta/classes.rb', line 6060

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6067
6068
6069
6070
6071
6072
6073
6074
# File 'lib/google/apis/compute_beta/classes.rb', line 6067

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end