Class: Google::Apis::ComputeBeta::BackendServiceLocalityLoadBalancingPolicyConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Container for either a built-in LB policy supported by gRPC or Envoy or a custom one implemented by the end user.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfig

Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfig.



6188
6189
6190
# File 'lib/google/apis/compute_beta/classes.rb', line 6188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_policyGoogle::Apis::ComputeBeta::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

The configuration for a custom policy implemented by the user and deployed with the client. Corresponds to the JSON property customPolicy



6181
6182
6183
# File 'lib/google/apis/compute_beta/classes.rb', line 6181

def custom_policy
  @custom_policy
end

#policyGoogle::Apis::ComputeBeta::BackendServiceLocalityLoadBalancingPolicyConfigPolicy

The configuration for a built-in load balancing policy. Corresponds to the JSON property policy



6186
6187
6188
# File 'lib/google/apis/compute_beta/classes.rb', line 6186

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6193
6194
6195
6196
# File 'lib/google/apis/compute_beta/classes.rb', line 6193

def update!(**args)
  @custom_policy = args[:custom_policy] if args.key?(:custom_policy)
  @policy = args[:policy] if args.key?(:policy)
end