Class: Google::Apis::ComputeBeta::BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The configuration for a custom policy implemented by the user and deployed with the client.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy

Returns a new instance of BackendServiceLocalityLoadBalancingPolicyConfigCustomPolicy.



6264
6265
6266
# File 'lib/google/apis/compute_beta/classes.rb', line 6264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dataString

An optional, arbitrary JSON object with configuration data, understood by a locally installed custom policy implementation. Corresponds to the JSON property data

Returns:

  • (String)


6249
6250
6251
# File 'lib/google/apis/compute_beta/classes.rb', line 6249

def data
  @data
end

#nameString

Identifies the custom policy. The value should match the name of a custom implementation registered on the gRPC clients. It should follow protocol buffer message naming conventions and include the full path (for example, myorg.CustomLbPolicy). The maximum length is 256 characters. Do not specify the same custom policy more than once for a backend. If you do, the configuration is rejected. For an example of how to use this field, seeUse a custom policy. Corresponds to the JSON property name

Returns:

  • (String)


6262
6263
6264
# File 'lib/google/apis/compute_beta/classes.rb', line 6262

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6269
6270
6271
6272
# File 'lib/google/apis/compute_beta/classes.rb', line 6269

def update!(**args)
  @data = args[:data] if args.key?(:data)
  @name = args[:name] if args.key?(:name)
end