Class: Google::Apis::ComputeBeta::BackendServiceLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The available logging options for the load balancer traffic served by this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLogConfig

Returns a new instance of BackendServiceLogConfig.



6346
6347
6348
# File 'lib/google/apis/compute_beta/classes.rb', line 6346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


6307
6308
6309
# File 'lib/google/apis/compute_beta/classes.rb', line 6307

def enable
  @enable
end

#logging_http_request_headersArray<Google::Apis::ComputeBeta::BackendServiceLogConfigLoggingHttpHeader>

The list of request headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpRequestHeaders



6313
6314
6315
# File 'lib/google/apis/compute_beta/classes.rb', line 6313

def logging_http_request_headers
  @logging_http_request_headers
end

#logging_http_response_headersArray<Google::Apis::ComputeBeta::BackendServiceLogConfigLoggingHttpHeader>

The list of response headers that will be logged to Stackdriver. Corresponds to the JSON property loggingHttpResponseHeaders



6318
6319
6320
# File 'lib/google/apis/compute_beta/classes.rb', line 6318

def logging_http_response_headers
  @logging_http_response_headers
end

#optional_fieldsArray<String>

This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace Corresponds to the JSON property optionalFields

Returns:

  • (Array<String>)


6327
6328
6329
# File 'lib/google/apis/compute_beta/classes.rb', line 6327

def optional_fields
  @optional_fields
end

#optional_modeString

This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Corresponds to the JSON property optionalMode

Returns:

  • (String)


6335
6336
6337
# File 'lib/google/apis/compute_beta/classes.rb', line 6335

def optional_mode
  @optional_mode
end

#sample_rateFloat

This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


6344
6345
6346
# File 'lib/google/apis/compute_beta/classes.rb', line 6344

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6351
6352
6353
6354
6355
6356
6357
6358
# File 'lib/google/apis/compute_beta/classes.rb', line 6351

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @logging_http_request_headers = args[:logging_http_request_headers] if args.key?(:logging_http_request_headers)
  @logging_http_response_headers = args[:logging_http_response_headers] if args.key?(:logging_http_response_headers)
  @optional_fields = args[:optional_fields] if args.key?(:optional_fields)
  @optional_mode = args[:optional_mode] if args.key?(:optional_mode)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end