Class: Google::Apis::ComputeBeta::BackendServiceLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The available logging options for the load balancer traffic served by this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceLogConfig

Returns a new instance of BackendServiceLogConfig.



6295
6296
6297
# File 'lib/google/apis/compute_beta/classes.rb', line 6295

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Denotes whether to enable logging for the load balancer traffic served by this backend service. The default value is false. Corresponds to the JSON property enable

Returns:

  • (Boolean)


6266
6267
6268
# File 'lib/google/apis/compute_beta/classes.rb', line 6266

def enable
  @enable
end

#optional_fieldsArray<String>

This field can only be specified if logging is enabled for this backend service and "logConfig.optionalMode" was set to CUSTOM. Contains a list of optional fields you want to include in the logs. For example: serverInstance, serverGkeDetails.cluster, serverGkeDetails.pod.podNamespace Corresponds to the JSON property optionalFields

Returns:

  • (Array<String>)


6276
6277
6278
# File 'lib/google/apis/compute_beta/classes.rb', line 6276

def optional_fields
  @optional_fields
end

#optional_modeString

This field can only be specified if logging is enabled for this backend service. Configures whether all, none or a subset of optional fields should be added to the reported logs. One of [INCLUDE_ALL_OPTIONAL, EXCLUDE_ALL_OPTIONAL, CUSTOM]. Default is EXCLUDE_ALL_OPTIONAL. Corresponds to the JSON property optionalMode

Returns:

  • (String)


6284
6285
6286
# File 'lib/google/apis/compute_beta/classes.rb', line 6284

def optional_mode
  @optional_mode
end

#sample_rateFloat

This field can only be specified if logging is enabled for this backend service. The value of the field must be in [0, 1]. This configures the sampling rate of requests to the load balancer where 1.0 means all logged requests are reported and 0.0 means no logged requests are reported. The default value is 1.0. Corresponds to the JSON property sampleRate

Returns:

  • (Float)


6293
6294
6295
# File 'lib/google/apis/compute_beta/classes.rb', line 6293

def sample_rate
  @sample_rate
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6300
6301
6302
6303
6304
6305
# File 'lib/google/apis/compute_beta/classes.rb', line 6300

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @optional_fields = args[:optional_fields] if args.key?(:optional_fields)
  @optional_mode = args[:optional_mode] if args.key?(:optional_mode)
  @sample_rate = args[:sample_rate] if args.key?(:sample_rate)
end