Class: Google::Apis::ComputeBeta::BackendServiceOrchestrationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A message containing information about the resource or system that manages the backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BackendServiceOrchestrationInfo

Returns a new instance of BackendServiceOrchestrationInfo.



6433
6434
6435
# File 'lib/google/apis/compute_beta/classes.rb', line 6433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_uriString

The resource URI of the resource or system that manages the backend service. Corresponds to the JSON property resourceUri

Returns:

  • (String)


6431
6432
6433
# File 'lib/google/apis/compute_beta/classes.rb', line 6431

def resource_uri
  @resource_uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6438
6439
6440
# File 'lib/google/apis/compute_beta/classes.rb', line 6438

def update!(**args)
  @resource_uri = args[:resource_uri] if args.key?(:resource_uri)
end