Class: Google::Apis::ComputeBeta::BfdPacket
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BfdPacket
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#authentication_present ⇒ Boolean
(also: #authentication_present?)
The Authentication Present bit of the BFD packet.
-
#control_plane_independent ⇒ Boolean
(also: #control_plane_independent?)
The Control Plane Independent bit of the BFD packet.
-
#demand ⇒ Boolean
(also: #demand?)
The demand bit of the BFD packet.
-
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#final ⇒ Boolean
(also: #final?)
The Final bit of the BFD packet.
-
#length ⇒ Fixnum
The length of the BFD Control packet in bytes.
-
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet.
-
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet.
-
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet.
-
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet.
-
#multipoint ⇒ Boolean
(also: #multipoint?)
The multipoint bit of the BFD packet.
-
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet.
-
#poll ⇒ Boolean
(also: #poll?)
The Poll bit of the BFD packet.
-
#state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
-
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdPacket
constructor
A new instance of BfdPacket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdPacket
Returns a new instance of BfdPacket.
6924 6925 6926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6924 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication_present ⇒ Boolean Also known as: authentication_present?
The Authentication Present bit of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property authenticationPresent
6828 6829 6830 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6828 def authentication_present @authentication_present end |
#control_plane_independent ⇒ Boolean Also known as: control_plane_independent?
The Control Plane Independent bit of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property controlPlaneIndependent
6835 6836 6837 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6835 def control_plane_independent @control_plane_independent end |
#demand ⇒ Boolean Also known as: demand?
The demand bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property demand
6841 6842 6843 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6841 def demand @demand end |
#diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property diagnostic
6850 6851 6852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6850 def diagnostic @diagnostic end |
#final ⇒ Boolean Also known as: final?
The Final bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property final
6855 6856 6857 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6855 def final @final end |
#length ⇒ Fixnum
The length of the BFD Control packet in bytes. This is specified in section
4.1 ofRFC5880
Corresponds to the JSON property length
6862 6863 6864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6862 def length @length end |
#min_echo_rx_interval_ms ⇒ Fixnum
The Required Min Echo RX Interval value in the BFD packet. This is
specified in section 4.1 ofRFC5880
Corresponds to the JSON property minEchoRxIntervalMs
6868 6869 6870 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6868 def min_echo_rx_interval_ms @min_echo_rx_interval_ms end |
#min_rx_interval_ms ⇒ Fixnum
The Required Min RX Interval value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property minRxIntervalMs
6874 6875 6876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6874 def min_rx_interval_ms @min_rx_interval_ms end |
#min_tx_interval_ms ⇒ Fixnum
The Desired Min TX Interval value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property minTxIntervalMs
6880 6881 6882 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6880 def min_tx_interval_ms @min_tx_interval_ms end |
#multiplier ⇒ Fixnum
The detection time multiplier of the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property multiplier
6886 6887 6888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6886 def multiplier @multiplier end |
#multipoint ⇒ Boolean Also known as: multipoint?
The multipoint bit of the BFD packet. This is specified in section 4.1
ofRFC5880
Corresponds to the JSON property multipoint
6892 6893 6894 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6892 def multipoint @multipoint end |
#my_discriminator ⇒ Fixnum
The My Discriminator value in the BFD packet. This is specified in section
4.1 ofRFC5880
Corresponds to the JSON property myDiscriminator
6899 6900 6901 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6899 def my_discriminator @my_discriminator end |
#poll ⇒ Boolean Also known as: poll?
The Poll bit of the BFD packet. This is specified in section 4.1 ofRFC5880
Corresponds to the JSON property poll
6904 6905 6906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6904 def poll @poll end |
#state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property state
6911 6912 6913 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6911 def state @state end |
#version ⇒ Fixnum
The version number of the BFD protocol, as specified in section 4.1 ofRFC5880.
Corresponds to the JSON property version
6916 6917 6918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6916 def version @version end |
#your_discriminator ⇒ Fixnum
The Your Discriminator value in the BFD packet. This is specified in
section 4.1 ofRFC5880
Corresponds to the JSON property yourDiscriminator
6922 6923 6924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6922 def your_discriminator @your_discriminator end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 6945 6946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6929 def update!(**args) @authentication_present = args[:authentication_present] if args.key?(:authentication_present) @control_plane_independent = args[:control_plane_independent] if args.key?(:control_plane_independent) @demand = args[:demand] if args.key?(:demand) @diagnostic = args[:diagnostic] if args.key?(:diagnostic) @final = args[:final] if args.key?(:final) @length = args[:length] if args.key?(:length) @min_echo_rx_interval_ms = args[:min_echo_rx_interval_ms] if args.key?(:min_echo_rx_interval_ms) @min_rx_interval_ms = args[:min_rx_interval_ms] if args.key?(:min_rx_interval_ms) @min_tx_interval_ms = args[:min_tx_interval_ms] if args.key?(:min_tx_interval_ms) @multiplier = args[:multiplier] if args.key?(:multiplier) @multipoint = args[:multipoint] if args.key?(:multipoint) @my_discriminator = args[:my_discriminator] if args.key?(:my_discriminator) @poll = args[:poll] if args.key?(:poll) @state = args[:state] if args.key?(:state) @version = args[:version] if args.key?(:version) @your_discriminator = args[:your_discriminator] if args.key?(:your_discriminator) end |