Class: Google::Apis::ComputeBeta::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeBeta::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeBeta::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#rx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
6941 6942 6943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6941 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
6890 6891 6892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6890 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
6895 6896 6897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6895 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeBeta::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
6900 6901 6902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6900 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeBeta::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
6905 6906 6907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6905 def control_packet_intervals @control_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
6913 6914 6915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6913 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
6919 6920 6921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6919 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
6924 6925 6926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6924 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
6929 6930 6931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6929 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
6934 6935 6936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6934 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
6939 6940 6941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6939 def uptime_ms @uptime_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6946 6947 6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6946 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) end |