Class: Google::Apis::ComputeBeta::BfdStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::BfdStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Next free: 15
Instance Attribute Summary collapse
-
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
-
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
-
#control_packet_counts ⇒ Google::Apis::ComputeBeta::BfdStatusPacketCounts
Control packet counts for the current BFD session.
-
#control_packet_intervals ⇒ Array<Google::Apis::ComputeBeta::PacketIntervals>
Inter-packet time interval statistics for control packets.
-
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change in session state.
-
#local_state ⇒ String
The current BFD session state as seen by the transmitting system.
-
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
-
#rx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Rx control packet for this BFD session.
-
#tx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Tx control packet for this BFD session.
-
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds.
Instance Method Summary collapse
-
#initialize(**args) ⇒ BfdStatus
constructor
A new instance of BfdStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ BfdStatus
Returns a new instance of BfdStatus.
6837 6838 6839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6837 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bfd_session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer.
Corresponds to the JSON property bfdSessionInitializationMode
6786 6787 6788 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6786 def bfd_session_initialization_mode @bfd_session_initialization_mode end |
#config_update_timestamp_micros ⇒ Fixnum
Unix timestamp of the most recent config update.
Corresponds to the JSON property configUpdateTimestampMicros
6791 6792 6793 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6791 def @config_update_timestamp_micros end |
#control_packet_counts ⇒ Google::Apis::ComputeBeta::BfdStatusPacketCounts
Control packet counts for the current BFD session.
Corresponds to the JSON property controlPacketCounts
6796 6797 6798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6796 def control_packet_counts @control_packet_counts end |
#control_packet_intervals ⇒ Array<Google::Apis::ComputeBeta::PacketIntervals>
Inter-packet time interval statistics for control packets.
Corresponds to the JSON property controlPacketIntervals
6801 6802 6803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6801 def control_packet_intervals @control_packet_intervals end |
#local_diagnostic ⇒ String
The diagnostic code specifies the local system's reason for the last change
in session state. This allows remote systems to determine the reason that
the previous session failed, for example. These diagnostic codes are
specified in section 4.1 ofRFC5880
Corresponds to the JSON property localDiagnostic
6809 6810 6811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6809 def local_diagnostic @local_diagnostic end |
#local_state ⇒ String
The current BFD session state as seen by the transmitting system. These
states are specified in section 4.1 ofRFC5880
Corresponds to the JSON property localState
6815 6816 6817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6815 def local_state @local_state end |
#negotiated_local_control_tx_interval_ms ⇒ Fixnum
Negotiated transmit interval for control packets.
Corresponds to the JSON property negotiatedLocalControlTxIntervalMs
6820 6821 6822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6820 def negotiated_local_control_tx_interval_ms @negotiated_local_control_tx_interval_ms end |
#rx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Rx control packet for this BFD session.
Corresponds to the JSON property rxPacket
6825 6826 6827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6825 def rx_packet @rx_packet end |
#tx_packet ⇒ Google::Apis::ComputeBeta::BfdPacket
The most recent Tx control packet for this BFD session.
Corresponds to the JSON property txPacket
6830 6831 6832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6830 def tx_packet @tx_packet end |
#uptime_ms ⇒ Fixnum
Session uptime in milliseconds. Value will be 0 if session is not up.
Corresponds to the JSON property uptimeMs
6835 6836 6837 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6835 def uptime_ms @uptime_ms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 6842 def update!(**args) @bfd_session_initialization_mode = args[:bfd_session_initialization_mode] if args.key?(:bfd_session_initialization_mode) @config_update_timestamp_micros = args[:config_update_timestamp_micros] if args.key?(:config_update_timestamp_micros) @control_packet_counts = args[:control_packet_counts] if args.key?(:control_packet_counts) @control_packet_intervals = args[:control_packet_intervals] if args.key?(:control_packet_intervals) @local_diagnostic = args[:local_diagnostic] if args.key?(:local_diagnostic) @local_state = args[:local_state] if args.key?(:local_state) @negotiated_local_control_tx_interval_ms = args[:negotiated_local_control_tx_interval_ms] if args.key?(:negotiated_local_control_tx_interval_ms) @rx_packet = args[:rx_packet] if args.key?(:rx_packet) @tx_packet = args[:tx_packet] if args.key?(:tx_packet) @uptime_ms = args[:uptime_ms] if args.key?(:uptime_ms) end |