Class: Google::Apis::ComputeBeta::BfdStatusPacketCounts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatusPacketCounts

Returns a new instance of BfdStatusPacketCounts.



7058
7059
7060
# File 'lib/google/apis/compute_beta/classes.rb', line 7058

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_rxFixnum

Number of packets received since the beginning of the current BFD session. Corresponds to the JSON property numRx

Returns:

  • (Fixnum)


7038
7039
7040
# File 'lib/google/apis/compute_beta/classes.rb', line 7038

def num_rx
  @num_rx
end

#num_rx_rejectedFixnum

Number of packets received that were rejected because of errors since the beginning of the current BFD session. Corresponds to the JSON property numRxRejected

Returns:

  • (Fixnum)


7044
7045
7046
# File 'lib/google/apis/compute_beta/classes.rb', line 7044

def num_rx_rejected
  @num_rx_rejected
end

#num_rx_successfulFixnum

Number of packets received that were successfully processed since the beginning of the current BFD session. Corresponds to the JSON property numRxSuccessful

Returns:

  • (Fixnum)


7050
7051
7052
# File 'lib/google/apis/compute_beta/classes.rb', line 7050

def num_rx_successful
  @num_rx_successful
end

#num_txFixnum

Number of packets transmitted since the beginning of the current BFD session. Corresponds to the JSON property numTx

Returns:

  • (Fixnum)


7056
7057
7058
# File 'lib/google/apis/compute_beta/classes.rb', line 7056

def num_tx
  @num_tx
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7063
7064
7065
7066
7067
7068
# File 'lib/google/apis/compute_beta/classes.rb', line 7063

def update!(**args)
  @num_rx = args[:num_rx] if args.key?(:num_rx)
  @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected)
  @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful)
  @num_tx = args[:num_tx] if args.key?(:num_tx)
end