Class: Google::Apis::ComputeBeta::BfdStatusPacketCounts

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BfdStatusPacketCounts

Returns a new instance of BfdStatusPacketCounts.



6930
6931
6932
# File 'lib/google/apis/compute_beta/classes.rb', line 6930

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#num_rxFixnum

Number of packets received since the beginning of the current BFD session. Corresponds to the JSON property numRx

Returns:

  • (Fixnum)


6910
6911
6912
# File 'lib/google/apis/compute_beta/classes.rb', line 6910

def num_rx
  @num_rx
end

#num_rx_rejectedFixnum

Number of packets received that were rejected because of errors since the beginning of the current BFD session. Corresponds to the JSON property numRxRejected

Returns:

  • (Fixnum)


6916
6917
6918
# File 'lib/google/apis/compute_beta/classes.rb', line 6916

def num_rx_rejected
  @num_rx_rejected
end

#num_rx_successfulFixnum

Number of packets received that were successfully processed since the beginning of the current BFD session. Corresponds to the JSON property numRxSuccessful

Returns:

  • (Fixnum)


6922
6923
6924
# File 'lib/google/apis/compute_beta/classes.rb', line 6922

def num_rx_successful
  @num_rx_successful
end

#num_txFixnum

Number of packets transmitted since the beginning of the current BFD session. Corresponds to the JSON property numTx

Returns:

  • (Fixnum)


6928
6929
6930
# File 'lib/google/apis/compute_beta/classes.rb', line 6928

def num_tx
  @num_tx
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6935
6936
6937
6938
6939
6940
# File 'lib/google/apis/compute_beta/classes.rb', line 6935

def update!(**args)
  @num_rx = args[:num_rx] if args.key?(:num_rx)
  @num_rx_rejected = args[:num_rx_rejected] if args.key?(:num_rx_rejected)
  @num_rx_successful = args[:num_rx_successful] if args.key?(:num_rx_successful)
  @num_tx = args[:num_tx] if args.key?(:num_tx)
end