Class: Google::Apis::ComputeBeta::Binding
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Binding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Associates members, or principals, with a role.
Instance Attribute Summary collapse
-
#condition ⇒ Google::Apis::ComputeBeta::Expr
Represents a textual expression in the Common Expression Language (CEL) syntax.
-
#members ⇒ Array<String>
Specifies the principals requesting access for a Google Cloud resource.
-
#role ⇒ String
Role that is assigned to the list of
members, or principals.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Binding
constructor
A new instance of Binding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Binding
Returns a new instance of Binding.
7115 7116 7117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#condition ⇒ Google::Apis::ComputeBeta::Expr
Represents a textual expression in the Common Expression Language (CEL)
syntax. CEL is a C-like expression language. The syntax and semantics of CEL
are documented at https://github.com/google/cel-spec.
Example (Comparison):
title: "Summary size limit"
description: "Determines if a summary is less than 100 chars"
expression: "document.summary.size() < 100"
Example (Equality):
title: "Requestor is owner"
description: "Determines if requestor is the document owner"
expression: "document.owner == request.auth.claims.email"
Example (Logic):
title: "Public documents"
description: "Determine whether the document should be publicly visible"
expression: "document.type != 'private' && document.type != 'internal'"
Example (Data Manipulation):
title: "Notification string"
description: "Create a notification string with a timestamp."
expression: "'New message received at ' + string(document.create_time)"
The exact variables and functions that may be referenced within an expression
are determined by the service that evaluates it. See the service
documentation for additional information.
Corresponds to the JSON property condition
7029 7030 7031 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7029 def condition @condition end |
#members ⇒ Array<String>
Specifies the principals requesting access for a Google Cloud resource.
members can have the following values:
allUsers: A special identifier that represents anyone who is on the internet; with or without a Google account.allAuthenticatedUsers: A special identifier that represents anyone who is authenticated with a Google account or a service account. Does not include identities that come from external identity providers (IdPs) through identity federation.user:emailid`: An email address that represents a specific Google account. For example,alice@example.com` .serviceAccount:emailid`: An email address that represents a Google service account. For example,my-other-app@appspot.gserviceaccount.com`.serviceAccount:projectid.svc.id.goog[namespace/kubernetes-sa]: An identifier for a Kubernetes service account. For example,my-project.svc.id.goog[my-namespace/my-kubernetes-sa].group:emailid`: An email address that represents a Google group. For example,admins@example.com`.domain:domain`: The G Suite domain (primary) that represents all the users of that domain. For example,google.comorexample.com`.principal://iam.googleapis.com/locations/global/workforcePools/pool_id/ subject/subject_attribute_value``: A single identity in a workforce identity pool.principalSet://iam.googleapis.com/locations/global/workforcePools/pool_id/ group/group_id``: All workforce identities in a group.principalSet://iam.googleapis.com/locations/global/workforcePools/pool_id/ attribute.attribute_name/attribute_value``: All workforce identities with a specific attribute value.principalSet://iam.googleapis.com/locations/global/workforcePools/pool_id/ *: All identities in a workforce identity pool.principal://iam.googleapis.com/projects/project_number/locations/global/ workloadIdentityPools/pool_id/subject/subject_attribute_value``: A single identity in a workload identity pool.principalSet://iam.googleapis.com/projects/project_number/locations/ global/workloadIdentityPools/pool_id/group/group_id``: A workload identity pool group.principalSet://iam.googleapis.com/projects/project_number/locations/ global/workloadIdentityPools/pool_id/attribute.attribute_name/attribute_value``: All identities in a workload identity pool with a certain attribute.principalSet://iam.googleapis.com/projects/project_number/locations/ global/workloadIdentityPools/pool_id/*: All identities in a workload identity pool.deleted:user:emailid?uid=uniqueid: An email address (plus unique identifier) representing a user that has been recently deleted. For example, `alice@example.com?uid=123456789012345678901`. If the user is recovered, this value reverts to `user:`emailidand the recovered user retains the role in the binding.deleted:serviceAccount:emailid?uid=uniqueid: An email address (plus unique identifier) representing a service account that has been recently deleted. For example, `my-other-app@appspot.gserviceaccount.com?uid=123456789012345678901`. If the service account is undeleted, this value reverts to `serviceAccount:`emailidand the undeleted service account retains the role in the binding.deleted:group:emailid?uid=uniqueid: An email address (plus unique identifier) representing a Google group that has been recently deleted. For example, `admins@example.com?uid=123456789012345678901`. If the group is recovered, this value reverts to `group:`emailidand the recovered group retains the role in the binding.deleted:principal://iam.googleapis.com/locations/global/workforcePools/pool_id/subject/subject_attribute_value`: Deleted single identity in a workforce identity pool. For example,deleted:principal://iam.googleapis.com/locations/global/workforcePools/my- pool-id/subject/my-subject-attribute-value. Corresponds to the JSON propertymembers`
7103 7104 7105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7103 def members @members end |
#role ⇒ String
Role that is assigned to the list of members, or principals.
For example, roles/viewer, roles/editor, or roles/owner.
For an overview of the IAM roles and permissions, see the
IAM documentation. For
a list of the available pre-defined roles, see
here.
Corresponds to the JSON property role
7113 7114 7115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7113 def role @role end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7120 7121 7122 7123 7124 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7120 def update!(**args) @condition = args[:condition] if args.key?(:condition) @members = args[:members] if args.key?(:members) @role = args[:role] if args.key?(:role) end |