Class: Google::Apis::ComputeBeta::BulkSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkSetLabelsRequest

Returns a new instance of BulkSetLabelsRequest.



7449
7450
7451
# File 'lib/google/apis/compute_beta/classes.rb', line 7449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You may optionally provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


7442
7443
7444
# File 'lib/google/apis/compute_beta/classes.rb', line 7442

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

The labels to set for this resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7447
7448
7449
# File 'lib/google/apis/compute_beta/classes.rb', line 7447

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7454
7455
7456
7457
# File 'lib/google/apis/compute_beta/classes.rb', line 7454

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end