Class: Google::Apis::ComputeBeta::BulkSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ BulkSetLabelsRequest

Returns a new instance of BulkSetLabelsRequest.



7343
7344
7345
# File 'lib/google/apis/compute_beta/classes.rb', line 7343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You may optionally provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


7336
7337
7338
# File 'lib/google/apis/compute_beta/classes.rb', line 7336

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

The labels to set for this resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


7341
7342
7343
# File 'lib/google/apis/compute_beta/classes.rb', line 7341

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7348
7349
7350
7351
# File 'lib/google/apis/compute_beta/classes.rb', line 7348

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end