Class: Google::Apis::ComputeBeta::CacheInvalidationRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CacheInvalidationRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#cache_tags ⇒ Array<String>
A list of cache tags used to identify cached objects.
-
#host ⇒ String
If set, this invalidation rule will only apply to requests with a Host header matching host.
-
#path ⇒ String
Corresponds to the JSON property
path.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CacheInvalidationRule
constructor
A new instance of CacheInvalidationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CacheInvalidationRule
Returns a new instance of CacheInvalidationRule.
7426 7427 7428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cache_tags ⇒ Array<String>
A list of cache tags used to identify cached objects.
- Cache tags are specified when the response is first cached, by setting
the
Cache-Tagresponse header at the origin. - Multiple cache tags in the same invalidation request are treated as
Boolean
OR- for example,tag1 OR tag2 OR tag3. - If other fields are also specified, these are treated as Boolean
ANDwith any tags. Up to 10 tags can be specified in a single invalidation request. Corresponds to the JSON propertycacheTags
7413 7414 7415 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7413 def @cache_tags end |
#host ⇒ String
If set, this invalidation rule will only apply to requests with a Host
header matching host.
Corresponds to the JSON property host
7419 7420 7421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7419 def host @host end |
#path ⇒ String
Corresponds to the JSON property path
7424 7425 7426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7424 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7431 7432 7433 7434 7435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7431 def update!(**args) @cache_tags = args[:cache_tags] if args.key?(:cache_tags) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |