Class: Google::Apis::ComputeBeta::CacheKeyPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CacheKeyPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Message containing what to include in the cache key for a request for Cloud CDN.
Instance Attribute Summary collapse
-
#include_host ⇒ Boolean
(also: #include_host?)
If true, requests to different hosts will be cached separately.
-
#include_http_headers ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
-
#include_named_cookies ⇒ Array<String>
Allows HTTP cookies (by name) to be used in the cache key.
-
#include_protocol ⇒ Boolean
(also: #include_protocol?)
If true, http and https requests will be cached separately.
-
#include_query_string ⇒ Boolean
(also: #include_query_string?)
If true, include query string parameters in the cache key according to query_string_whitelist and query_string_blacklist.
-
#query_string_blacklist ⇒ Array<String>
Names of query string parameters to exclude in cache keys.
-
#query_string_whitelist ⇒ Array<String>
Names of query string parameters to include in cache keys.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CacheKeyPolicy
constructor
A new instance of CacheKeyPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CacheKeyPolicy
Returns a new instance of CacheKeyPolicy.
7614 7615 7616 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7614 def initialize(**args) update!(**args) end |
Instance Attribute Details
#include_host ⇒ Boolean Also known as: include_host?
If true, requests to different hosts will be cached separately.
Corresponds to the JSON property includeHost
7569 7570 7571 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7569 def include_host @include_host end |
#include_http_headers ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
Corresponds to the JSON property includeHttpHeaders
7575 7576 7577 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7575 def include_http_headers @include_http_headers end |
#include_named_cookies ⇒ Array<String>
Allows HTTP cookies (by name) to be used in the cache key.
The name=value pair will be used in the cache key Cloud CDN generates.
Corresponds to the JSON property includeNamedCookies
7581 7582 7583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7581 def @include_named_cookies end |
#include_protocol ⇒ Boolean Also known as: include_protocol?
If true, http and https requests will be cached separately.
Corresponds to the JSON property includeProtocol
7586 7587 7588 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7586 def include_protocol @include_protocol end |
#include_query_string ⇒ Boolean Also known as: include_query_string?
If true, include query string parameters in the cache key according to
query_string_whitelist and query_string_blacklist. If neither is set, the
entire query string will be included. If false, the query string will be
excluded from the cache key entirely.
Corresponds to the JSON property includeQueryString
7595 7596 7597 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7595 def include_query_string @include_query_string end |
#query_string_blacklist ⇒ Array<String>
Names of query string parameters to exclude in cache keys. All other
parameters will be included. Either specify query_string_whitelist or
query_string_blacklist, not both. '&' and '=' will be percent encoded and
not treated as delimiters.
Corresponds to the JSON property queryStringBlacklist
7604 7605 7606 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7604 def query_string_blacklist @query_string_blacklist end |
#query_string_whitelist ⇒ Array<String>
Names of query string parameters to include in cache keys. All other
parameters will be excluded. Either specify query_string_whitelist or
query_string_blacklist, not both. '&' and '=' will be percent encoded and
not treated as delimiters.
Corresponds to the JSON property queryStringWhitelist
7612 7613 7614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7612 def query_string_whitelist @query_string_whitelist end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7619 7620 7621 7622 7623 7624 7625 7626 7627 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7619 def update!(**args) @include_host = args[:include_host] if args.key?(:include_host) @include_http_headers = args[:include_http_headers] if args.key?(:include_http_headers) @include_named_cookies = args[:include_named_cookies] if args.key?(:include_named_cookies) @include_protocol = args[:include_protocol] if args.key?(:include_protocol) @include_query_string = args[:include_query_string] if args.key?(:include_query_string) @query_string_blacklist = args[:query_string_blacklist] if args.key?(:query_string_blacklist) @query_string_whitelist = args[:query_string_whitelist] if args.key?(:query_string_whitelist) end |