Class: Google::Apis::ComputeBeta::CachePolicyCacheKeyPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CachePolicyCacheKeyPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Message containing what to include in the cache key for a request for Cache Policy defined on Route Action.
Instance Attribute Summary collapse
-
#excluded_query_parameters ⇒ Array<String>
Names of query string parameters to exclude in cache keys.
-
#include_host ⇒ Boolean
(also: #include_host?)
If true, requests to different hosts will be cached separately.
-
#include_protocol ⇒ Boolean
(also: #include_protocol?)
If true, http and https requests will be cached separately.
-
#include_query_string ⇒ Boolean
(also: #include_query_string?)
If true, include query string parameters in the cache key according to
includedQueryParametersandexcludedQueryParameters. -
#included_cookie_names ⇒ Array<String>
Allows HTTP cookies (by name) to be used in the cache key.
-
#included_header_names ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
-
#included_query_parameters ⇒ Array<String>
Names of query string parameters to include in cache keys.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CachePolicyCacheKeyPolicy
constructor
A new instance of CachePolicyCacheKeyPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CachePolicyCacheKeyPolicy
Returns a new instance of CachePolicyCacheKeyPolicy.
7893 7894 7895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#excluded_query_parameters ⇒ Array<String>
Names of query string parameters to exclude in cache keys. All other
parameters will be included. Either specify excludedQueryParameters
or includedQueryParameters, not both. '&' and '=' will be percent
encoded and not treated as delimiters.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
Corresponds to the JSON property excludedQueryParameters
7831 7832 7833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7831 def excluded_query_parameters @excluded_query_parameters end |
#include_host ⇒ Boolean Also known as: include_host?
If true, requests to different hosts will be cached separately.
Note: This setting is only applicable to routes that use a Backend
Service. It does not affect requests served by a Backend Bucket, as the
host is never included in a Backend Bucket's cache key. Attempting to set
it on a route that points exclusively to Backend Buckets will result in a
configuration error.
Corresponds to the JSON property includeHost
7841 7842 7843 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7841 def include_host @include_host end |
#include_protocol ⇒ Boolean Also known as: include_protocol?
If true, http and https requests will be cached separately.
Note: This setting is only applicable to routes that use a Backend
Service. It does not affect requests served by a Backend Bucket, as the
protocol is never included in a Backend Bucket's cache key. Attempting to
set on a route that points exclusively to Backend Buckets will result in
a configuration error.
Corresponds to the JSON property includeProtocol
7852 7853 7854 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7852 def include_protocol @include_protocol end |
#include_query_string ⇒ Boolean Also known as: include_query_string?
If true, include query string parameters in the cache key according to
includedQueryParameters and excludedQueryParameters. If neither
is set, the entire query string will be included. If false, the query
string will be excluded from the cache key entirely.
Note: This field applies to routes that use backend services. Attempting
to set it on a route that points exclusively to Backend Buckets will
result in a configuration error. For routes that point to a Backend
Bucket, use includedQueryParameters to define which parameters should
be part of the cache key.
Corresponds to the JSON property includeQueryString
7866 7867 7868 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7866 def include_query_string @include_query_string end |
#included_cookie_names ⇒ Array<String>
Allows HTTP cookies (by name) to be used in the cache key.
The name=value pair will be used in the cache key Cloud CDN generates.
Note: This setting is only applicable to routes that use a Backend
Service. It does not affect requests served by a Backend Bucket.
Attempting to set it on a route that points exclusively to Backend
Buckets will result in a configuration error. Up to 5 cookie names can be
specified.
Corresponds to the JSON property includedCookieNames
7878 7879 7880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7878 def @included_cookie_names end |
#included_header_names ⇒ Array<String>
Allows HTTP request headers (by name) to be used in the cache key.
Corresponds to the JSON property includedHeaderNames
7883 7884 7885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7883 def included_header_names @included_header_names end |
#included_query_parameters ⇒ Array<String>
Names of query string parameters to include in cache keys. All other
parameters will be excluded. Either specify includedQueryParameters
or excludedQueryParameters, not both. '&' and '=' will be percent
encoded and not treated as delimiters.
Corresponds to the JSON property includedQueryParameters
7891 7892 7893 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7891 def included_query_parameters @included_query_parameters end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7898 7899 7900 7901 7902 7903 7904 7905 7906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7898 def update!(**args) @excluded_query_parameters = args[:excluded_query_parameters] if args.key?(:excluded_query_parameters) @include_host = args[:include_host] if args.key?(:include_host) @include_protocol = args[:include_protocol] if args.key?(:include_protocol) @include_query_string = args[:include_query_string] if args.key?(:include_query_string) @included_cookie_names = args[:included_cookie_names] if args.key?(:included_cookie_names) @included_header_names = args[:included_header_names] if args.key?(:included_header_names) @included_query_parameters = args[:included_query_parameters] if args.key?(:included_query_parameters) end |