Class: Google::Apis::ComputeBeta::CalendarModeAdviceRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A request to recommend the best way to consume the specified resources in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeAdviceRequest

Returns a new instance of CalendarModeAdviceRequest.



7520
7521
7522
# File 'lib/google/apis/compute_beta/classes.rb', line 7520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#future_resources_specsHash<String,Google::Apis::ComputeBeta::FutureResourcesSpec>

Specification of resources to create in the future. The key of the map is an arbitrary string specified by the caller. Value of the map is a specification of required resources and their constraints. Currently only one value is allowed in this map. Corresponds to the JSON property futureResourcesSpecs



7518
7519
7520
# File 'lib/google/apis/compute_beta/classes.rb', line 7518

def future_resources_specs
  @future_resources_specs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7525
7526
7527
# File 'lib/google/apis/compute_beta/classes.rb', line 7525

def update!(**args)
  @future_resources_specs = args[:future_resources_specs] if args.key?(:future_resources_specs)
end