Class: Google::Apis::ComputeBeta::CalendarModeAdviceResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CalendarModeAdviceResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.
Instance Attribute Summary collapse
-
#recommendations ⇒ Array<Google::Apis::ComputeBeta::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CalendarModeAdviceResponse
constructor
A new instance of CalendarModeAdviceResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CalendarModeAdviceResponse
Returns a new instance of CalendarModeAdviceResponse.
7919 7920 7921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recommendations ⇒ Array<Google::Apis::ComputeBeta::CalendarModeRecommendation>
Recommendations where, how and when to create the requested resources
in order to maximize their obtainability and minimize cost.
Corresponds to the JSON property recommendations
7917 7918 7919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7917 def recommendations @recommendations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7924 7925 7926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 7924 def update!(**args) @recommendations = args[:recommendations] if args.key?(:recommendations) end |