Class: Google::Apis::ComputeBeta::CalendarModeAdviceResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A response containing the recommended way of creating the specified resources in the future. It contains (will contain) multiple recommendations that can be analyzed by the customer and the best one can be picked.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeAdviceResponse

Returns a new instance of CalendarModeAdviceResponse.



7888
7889
7890
# File 'lib/google/apis/compute_beta/classes.rb', line 7888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendationsArray<Google::Apis::ComputeBeta::CalendarModeRecommendation>

Recommendations where, how and when to create the requested resources in order to maximize their obtainability and minimize cost. Corresponds to the JSON property recommendations



7886
7887
7888
# File 'lib/google/apis/compute_beta/classes.rb', line 7886

def recommendations
  @recommendations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7893
7894
7895
# File 'lib/google/apis/compute_beta/classes.rb', line 7893

def update!(**args)
  @recommendations = args[:recommendations] if args.key?(:recommendations)
end