Class: Google::Apis::ComputeBeta::CalendarModeRecommendation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A single recommendation to create requested resources. Contains detailed recommendations for every future resources specification specified in CalendarModeAdviceRequest.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CalendarModeRecommendation

Returns a new instance of CalendarModeRecommendation.



7911
7912
7913
# File 'lib/google/apis/compute_beta/classes.rb', line 7911

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#recommendations_per_specHash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendation>

Recommendations for every future resource specification passed in CalendarModeAdviceRequest. Keys of the map correspond to keys specified in the request. Corresponds to the JSON property recommendationsPerSpec



7909
7910
7911
# File 'lib/google/apis/compute_beta/classes.rb', line 7909

def recommendations_per_spec
  @recommendations_per_spec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7916
7917
7918
# File 'lib/google/apis/compute_beta/classes.rb', line 7916

def update!(**args)
  @recommendations_per_spec = args[:recommendations_per_spec] if args.key?(:recommendations_per_spec)
end