Class: Google::Apis::ComputeBeta::CapacityAdviceResponseRecommendationScores

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Groups information about a shard of capacity.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityAdviceResponseRecommendationScores

Returns a new instance of CapacityAdviceResponseRecommendationScores.



8200
8201
8202
# File 'lib/google/apis/compute_beta/classes.rb', line 8200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#estimated_uptimeString

The estimated run time of the majority of Spot VMs in the request before preemption. The estimate is best-effort only. It is based on historical data and current conditions. Corresponds to the JSON property estimatedUptime

Returns:

  • (String)


8191
8192
8193
# File 'lib/google/apis/compute_beta/classes.rb', line 8191

def estimated_uptime
  @estimated_uptime
end

#obtainabilityFloat

The obtainability score indicates the likelihood of successfully obtaining (provisioning) the requested number of VMs. The score range is 0.0 through 1.0. Higher is better. Corresponds to the JSON property obtainability

Returns:

  • (Float)


8198
8199
8200
# File 'lib/google/apis/compute_beta/classes.rb', line 8198

def obtainability
  @obtainability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8205
8206
8207
8208
# File 'lib/google/apis/compute_beta/classes.rb', line 8205

def update!(**args)
  @estimated_uptime = args[:estimated_uptime] if args.key?(:estimated_uptime)
  @obtainability = args[:obtainability] if args.key?(:obtainability)
end