Class: Google::Apis::ComputeBeta::CapacityAdviceResponseRecommendationShard
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityAdviceResponseRecommendationShard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.
Instance Attribute Summary collapse
-
#instance_count ⇒ Fixnum
The number of instances.
-
#machine_type ⇒ String
The machine type corresponds to the instance selection in the request.
-
#provisioning_model ⇒ String
The provisioning model that you want to view recommendations for.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard
constructor
A new instance of CapacityAdviceResponseRecommendationShard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard
Returns a new instance of CapacityAdviceResponseRecommendationShard.
8307 8308 8309 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8307 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_count ⇒ Fixnum
The number of instances.
Corresponds to the JSON property instanceCount
8290 8291 8292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8290 def instance_count @instance_count end |
#machine_type ⇒ String
The machine type corresponds to the instance selection in the request.
Corresponds to the JSON property machineType
8295 8296 8297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8295 def machine_type @machine_type end |
#provisioning_model ⇒ String
The provisioning model that you want to view recommendations for.
Corresponds to the JSON property provisioningModel
8300 8301 8302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8300 def provisioning_model @provisioning_model end |
#zone ⇒ String
Output only. The zone name for this shard.
Corresponds to the JSON property zone
8305 8306 8307 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8305 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8312 8313 8314 8315 8316 8317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8312 def update!(**args) @instance_count = args[:instance_count] if args.key?(:instance_count) @machine_type = args[:machine_type] if args.key?(:machine_type) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) @zone = args[:zone] if args.key?(:zone) end |