Class: Google::Apis::ComputeBeta::CapacityAdviceResponseRecommendationShard
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityAdviceResponseRecommendationShard
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.
Instance Attribute Summary collapse
-
#instance_count ⇒ Fixnum
The number of instances.
-
#machine_type ⇒ String
The machine type corresponds to the instance selection in the request.
-
#provisioning_model ⇒ String
The provisioning model that you want to view recommendations for.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard
constructor
A new instance of CapacityAdviceResponseRecommendationShard.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard
Returns a new instance of CapacityAdviceResponseRecommendationShard.
8251 8252 8253 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8251 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_count ⇒ Fixnum
The number of instances.
Corresponds to the JSON property instanceCount
8234 8235 8236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8234 def instance_count @instance_count end |
#machine_type ⇒ String
The machine type corresponds to the instance selection in the request.
Corresponds to the JSON property machineType
8239 8240 8241 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8239 def machine_type @machine_type end |
#provisioning_model ⇒ String
The provisioning model that you want to view recommendations for.
Corresponds to the JSON property provisioningModel
8244 8245 8246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8244 def provisioning_model @provisioning_model end |
#zone ⇒ String
Output only. The zone name for this shard.
Corresponds to the JSON property zone
8249 8250 8251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8249 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8256 8257 8258 8259 8260 8261 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8256 def update!(**args) @instance_count = args[:instance_count] if args.key?(:instance_count) @machine_type = args[:machine_type] if args.key?(:machine_type) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) @zone = args[:zone] if args.key?(:zone) end |