Class: Google::Apis::ComputeBeta::CapacityAdviceResponseRecommendationShard

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Shards represent blocks of uniform capacity in recommendations. Each shard is for a single zone and a single machine shape. Each shard defines a size expressed as the number of VMs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityAdviceResponseRecommendationShard

Returns a new instance of CapacityAdviceResponseRecommendationShard.



8237
8238
8239
# File 'lib/google/apis/compute_beta/classes.rb', line 8237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_countFixnum

The number of instances. Corresponds to the JSON property instanceCount

Returns:

  • (Fixnum)


8220
8221
8222
# File 'lib/google/apis/compute_beta/classes.rb', line 8220

def instance_count
  @instance_count
end

#machine_typeString

The machine type corresponds to the instance selection in the request. Corresponds to the JSON property machineType

Returns:

  • (String)


8225
8226
8227
# File 'lib/google/apis/compute_beta/classes.rb', line 8225

def machine_type
  @machine_type
end

#provisioning_modelString

The provisioning model that you want to view recommendations for. Corresponds to the JSON property provisioningModel

Returns:

  • (String)


8230
8231
8232
# File 'lib/google/apis/compute_beta/classes.rb', line 8230

def provisioning_model
  @provisioning_model
end

#zoneString

Output only. The zone name for this shard. Corresponds to the JSON property zone

Returns:

  • (String)


8235
8236
8237
# File 'lib/google/apis/compute_beta/classes.rb', line 8235

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8242
8243
8244
8245
8246
8247
# File 'lib/google/apis/compute_beta/classes.rb', line 8242

def update!(**args)
  @instance_count = args[:instance_count] if args.key?(:instance_count)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model)
  @zone = args[:zone] if args.key?(:zone)
end