Class: Google::Apis::ComputeBeta::CapacityHistoryRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityHistoryRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A request to get the capacity history.
Instance Attribute Summary collapse
-
#instance_properties ⇒ Google::Apis::ComputeBeta::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
-
#location_policy ⇒ Google::Apis::ComputeBeta::CapacityHistoryRequestLocationPolicy
Location policy for this request.
-
#types ⇒ Array<String>
List of history types to get capacity history for.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryRequest
constructor
A new instance of CapacityHistoryRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryRequest
Returns a new instance of CapacityHistoryRequest.
8252 8253 8254 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_properties ⇒ Google::Apis::ComputeBeta::CapacityHistoryRequestInstanceProperties
Instance properties for this request.
Corresponds to the JSON property instanceProperties
8240 8241 8242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8240 def instance_properties @instance_properties end |
#location_policy ⇒ Google::Apis::ComputeBeta::CapacityHistoryRequestLocationPolicy
Location policy for this request.
Corresponds to the JSON property locationPolicy
8245 8246 8247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8245 def location_policy @location_policy end |
#types ⇒ Array<String>
List of history types to get capacity history for.
Corresponds to the JSON property types
8250 8251 8252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8250 def types @types end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8257 8258 8259 8260 8261 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8257 def update!(**args) @instance_properties = args[:instance_properties] if args.key?(:instance_properties) @location_policy = args[:location_policy] if args.key?(:location_policy) @types = args[:types] if args.key?(:types) end |