Class: Google::Apis::ComputeBeta::CapacityHistoryResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityHistoryResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains the capacity history.
Instance Attribute Summary collapse
-
#location ⇒ String
Output only.
-
#machine_type ⇒ String
The machine type for which the capacity history is returned.
-
#preemption_history ⇒ Array<Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord>
The preemption history for the requested machine type and location.
-
#price_history ⇒ Array<Google::Apis::ComputeBeta::CapacityHistoryResponsePriceRecord>
The price history for the requested machine type and location.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryResponse
constructor
A new instance of CapacityHistoryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryResponse
Returns a new instance of CapacityHistoryResponse.
8405 8406 8407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#location ⇒ String
Output only. The location (region or zone) for which the capacity history is
returned.
It is returned as a URL - For example,https://www.googleapis.com/compute/v1/
projects/project/zones/zone.
Corresponds to the JSON property location
8388 8389 8390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8388 def location @location end |
#machine_type ⇒ String
The machine type for which the capacity history is returned.
Corresponds to the JSON property machineType
8393 8394 8395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8393 def machine_type @machine_type end |
#preemption_history ⇒ Array<Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord>
The preemption history for the requested machine type and location.
Corresponds to the JSON property preemptionHistory
8398 8399 8400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8398 def preemption_history @preemption_history end |
#price_history ⇒ Array<Google::Apis::ComputeBeta::CapacityHistoryResponsePriceRecord>
The price history for the requested machine type and location.
Corresponds to the JSON property priceHistory
8403 8404 8405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8403 def price_history @price_history end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8410 8411 8412 8413 8414 8415 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8410 def update!(**args) @location = args[:location] if args.key?(:location) @machine_type = args[:machine_type] if args.key?(:machine_type) @preemption_history = args[:preemption_history] if args.key?(:preemption_history) @price_history = args[:price_history] if args.key?(:price_history) end |