Class: Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A record of Spot VM preemption history.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::ComputeBeta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#preemption_rate ⇒ Float
The preemption rate during the interval, representing the fraction of Spot VMs that were preempted.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord
constructor
A new instance of CapacityHistoryResponsePreemptionRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord
Returns a new instance of CapacityHistoryResponsePreemptionRecord.
8486 8487 8488 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8486 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::ComputeBeta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive).
The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time).
When both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
8476 8477 8478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8476 def interval @interval end |
#preemption_rate ⇒ Float
The preemption rate during the interval, representing the fraction of
Spot VMs that were preempted. Range: 0.0 to 1.0. Preemption rate is
calculated as (total preempted Spots) / (total Spots that stopped
running).
Corresponds to the JSON property preemptionRate
8484 8485 8486 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8484 def preemption_rate @preemption_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8491 8492 8493 8494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8491 def update!(**args) @interval = args[:interval] if args.key?(:interval) @preemption_rate = args[:preemption_rate] if args.key?(:preemption_rate) end |