Class: Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityHistoryResponsePreemptionRecord
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::ComputeBeta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#preemption_rate ⇒ Float
Corresponds to the JSON property
preemptionRate.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord
constructor
A new instance of CapacityHistoryResponsePreemptionRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryResponsePreemptionRecord
Returns a new instance of CapacityHistoryResponsePreemptionRecord.
8424 8425 8426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8424 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::ComputeBeta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive).
The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time).
When both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
8417 8418 8419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8417 def interval @interval end |
#preemption_rate ⇒ Float
Corresponds to the JSON property preemptionRate
8422 8423 8424 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8422 def preemption_rate @preemption_rate end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8429 8430 8431 8432 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8429 def update!(**args) @interval = args[:interval] if args.key?(:interval) @preemption_rate = args[:preemption_rate] if args.key?(:preemption_rate) end |