Class: Google::Apis::ComputeBeta::CapacityHistoryResponsePriceRecord
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CapacityHistoryResponsePriceRecord
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A record of price history.
Instance Attribute Summary collapse
-
#interval ⇒ Google::Apis::ComputeBeta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive).
-
#list_price ⇒ Google::Apis::ComputeBeta::Money
Represents an amount of money with its currency type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord
constructor
A new instance of CapacityHistoryResponsePriceRecord.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord
Returns a new instance of CapacityHistoryResponsePriceRecord.
8468 8469 8470 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8468 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interval ⇒ Google::Apis::ComputeBeta::Interval
Represents a time interval, encoded as a Timestamp start (inclusive) and a
Timestamp end (exclusive).
The start must be less than or equal to the end.
When the start equals the end, the interval is empty (matches no time).
When both start and end are unspecified, the interval matches any time.
Corresponds to the JSON property interval
8461 8462 8463 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8461 def interval @interval end |
#list_price ⇒ Google::Apis::ComputeBeta::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property listPrice
8466 8467 8468 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8466 def list_price @list_price end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8473 8474 8475 8476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8473 def update!(**args) @interval = args[:interval] if args.key?(:interval) @list_price = args[:list_price] if args.key?(:list_price) end |