Class: Google::Apis::ComputeBeta::CapacityHistoryResponsePriceRecord

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CapacityHistoryResponsePriceRecord

Returns a new instance of CapacityHistoryResponsePriceRecord.



8439
8440
8441
# File 'lib/google/apis/compute_beta/classes.rb', line 8439

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intervalGoogle::Apis::ComputeBeta::Interval

Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time. Corresponds to the JSON property interval



8432
8433
8434
# File 'lib/google/apis/compute_beta/classes.rb', line 8432

def interval
  @interval
end

#list_priceGoogle::Apis::ComputeBeta::Money

Represents an amount of money with its currency type. Corresponds to the JSON property listPrice



8437
8438
8439
# File 'lib/google/apis/compute_beta/classes.rb', line 8437

def list_price
  @list_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8444
8445
8446
8447
# File 'lib/google/apis/compute_beta/classes.rb', line 8444

def update!(**args)
  @interval = args[:interval] if args.key?(:interval)
  @list_price = args[:list_price] if args.key?(:list_price)
end