Class: Google::Apis::ComputeBeta::CircuitBreakers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CircuitBreakers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Settings controlling the volume of requests, connections and retries to this backend service.
Instance Attribute Summary collapse
-
#connect_timeout ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#max_connections ⇒ Fixnum
The maximum number of connections to the backend service.
-
#max_pending_requests ⇒ Fixnum
The maximum number of pending requests allowed to the backend service.
-
#max_requests ⇒ Fixnum
The maximum number of parallel requests that allowed to the backend service.
-
#max_requests_per_connection ⇒ Fixnum
Maximum requests for a single connection to the backend service.
-
#max_retries ⇒ Fixnum
The maximum number of parallel retries allowed to the backend cluster.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CircuitBreakers
constructor
A new instance of CircuitBreakers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CircuitBreakers
Returns a new instance of CircuitBreakers.
8579 8580 8581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8579 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connect_timeout ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property connectTimeout
8537 8538 8539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8537 def connect_timeout @connect_timeout end |
#max_connections ⇒ Fixnum
The maximum number of connections to the backend service. If not specified,
there is no limit.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxConnections
8545 8546 8547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8545 def max_connections @max_connections end |
#max_pending_requests ⇒ Fixnum
The maximum number of pending requests allowed to the backend service. If
not specified, there is no limit.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxPendingRequests
8553 8554 8555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8553 def max_pending_requests @max_pending_requests end |
#max_requests ⇒ Fixnum
The maximum number of parallel requests that allowed to the backend
service. If not specified, there is no limit.
Corresponds to the JSON property maxRequests
8559 8560 8561 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8559 def max_requests @max_requests end |
#max_requests_per_connection ⇒ Fixnum
Maximum requests for a single connection to the backend service.
This parameter is respected by both the HTTP/1.1 and HTTP/2
implementations. If not specified, there is no limit. Setting this
parameter to 1 will effectively disable keep alive.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxRequestsPerConnection
8569 8570 8571 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8569 def max_requests_per_connection @max_requests_per_connection end |
#max_retries ⇒ Fixnum
The maximum number of parallel retries allowed to the backend cluster. If
not specified, the default is 1.
Not supported when the backend service is referenced by a URL map that is
bound to target gRPC proxy that has validateForProxyless field set to true.
Corresponds to the JSON property maxRetries
8577 8578 8579 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8577 def max_retries @max_retries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8584 8585 8586 8587 8588 8589 8590 8591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8584 def update!(**args) @connect_timeout = args[:connect_timeout] if args.key?(:connect_timeout) @max_connections = args[:max_connections] if args.key?(:max_connections) @max_pending_requests = args[:max_pending_requests] if args.key?(:max_pending_requests) @max_requests = args[:max_requests] if args.key?(:max_requests) @max_requests_per_connection = args[:max_requests_per_connection] if args.key?(:max_requests_per_connection) @max_retries = args[:max_retries] if args.key?(:max_retries) end |