Class: Google::Apis::ComputeBeta::CircuitBreakers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Settings controlling the volume of requests, connections and retries to this backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CircuitBreakers

Returns a new instance of CircuitBreakers.



8532
8533
8534
# File 'lib/google/apis/compute_beta/classes.rb', line 8532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connect_timeoutGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property connectTimeout



8490
8491
8492
# File 'lib/google/apis/compute_beta/classes.rb', line 8490

def connect_timeout
  @connect_timeout
end

#max_connectionsFixnum

The maximum number of connections to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxConnections

Returns:

  • (Fixnum)


8498
8499
8500
# File 'lib/google/apis/compute_beta/classes.rb', line 8498

def max_connections
  @max_connections
end

#max_pending_requestsFixnum

The maximum number of pending requests allowed to the backend service. If not specified, there is no limit. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxPendingRequests

Returns:

  • (Fixnum)


8506
8507
8508
# File 'lib/google/apis/compute_beta/classes.rb', line 8506

def max_pending_requests
  @max_pending_requests
end

#max_requestsFixnum

The maximum number of parallel requests that allowed to the backend service. If not specified, there is no limit. Corresponds to the JSON property maxRequests

Returns:

  • (Fixnum)


8512
8513
8514
# File 'lib/google/apis/compute_beta/classes.rb', line 8512

def max_requests
  @max_requests
end

#max_requests_per_connectionFixnum

Maximum requests for a single connection to the backend service. This parameter is respected by both the HTTP/1.1 and HTTP/2 implementations. If not specified, there is no limit. Setting this parameter to 1 will effectively disable keep alive. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxRequestsPerConnection

Returns:

  • (Fixnum)


8522
8523
8524
# File 'lib/google/apis/compute_beta/classes.rb', line 8522

def max_requests_per_connection
  @max_requests_per_connection
end

#max_retriesFixnum

The maximum number of parallel retries allowed to the backend cluster. If not specified, the default is 1. Not supported when the backend service is referenced by a URL map that is bound to target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property maxRetries

Returns:

  • (Fixnum)


8530
8531
8532
# File 'lib/google/apis/compute_beta/classes.rb', line 8530

def max_retries
  @max_retries
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8537
8538
8539
8540
8541
8542
8543
8544
# File 'lib/google/apis/compute_beta/classes.rb', line 8537

def update!(**args)
  @connect_timeout = args[:connect_timeout] if args.key?(:connect_timeout)
  @max_connections = args[:max_connections] if args.key?(:max_connections)
  @max_pending_requests = args[:max_pending_requests] if args.key?(:max_pending_requests)
  @max_requests = args[:max_requests] if args.key?(:max_requests)
  @max_requests_per_connection = args[:max_requests_per_connection] if args.key?(:max_requests_per_connection)
  @max_retries = args[:max_retries] if args.key?(:max_retries)
end