Class: Google::Apis::ComputeBeta::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
9005 9006 9007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9005 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8972 8973 8974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8972 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
8977 8978 8979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8977 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
8983 8984 8985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8983 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8993 8994 8995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8993 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8998 8999 9000 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8998 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9003 9004 9005 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9003 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9010 9011 9012 9013 9014 9015 9016 9017 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9010 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |