Class: Google::Apis::ComputeBeta::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



8935
8936
8937
# File 'lib/google/apis/compute_beta/classes.rb', line 8935

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8902
8903
8904
# File 'lib/google/apis/compute_beta/classes.rb', line 8902

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



8907
8908
8909
# File 'lib/google/apis/compute_beta/classes.rb', line 8907

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


8913
8914
8915
# File 'lib/google/apis/compute_beta/classes.rb', line 8913

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8923
8924
8925
# File 'lib/google/apis/compute_beta/classes.rb', line 8923

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8928
8929
8930
# File 'lib/google/apis/compute_beta/classes.rb', line 8928

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8933
8934
8935
# File 'lib/google/apis/compute_beta/classes.rb', line 8933

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8940
8941
8942
8943
8944
8945
8946
8947
# File 'lib/google/apis/compute_beta/classes.rb', line 8940

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end