Class: Google::Apis::ComputeBeta::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



8397
8398
8399
# File 'lib/google/apis/compute_beta/classes.rb', line 8397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8364
8365
8366
# File 'lib/google/apis/compute_beta/classes.rb', line 8364

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



8369
8370
8371
# File 'lib/google/apis/compute_beta/classes.rb', line 8369

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


8375
8376
8377
# File 'lib/google/apis/compute_beta/classes.rb', line 8375

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8385
8386
8387
# File 'lib/google/apis/compute_beta/classes.rb', line 8385

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8390
8391
8392
# File 'lib/google/apis/compute_beta/classes.rb', line 8390

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8395
8396
8397
# File 'lib/google/apis/compute_beta/classes.rb', line 8395

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/google/apis/compute_beta/classes.rb', line 8402

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end