Class: Google::Apis::ComputeBeta::CommitmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Commitment resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentList

Returns a new instance of CommitmentList.



8345
8346
8347
# File 'lib/google/apis/compute_beta/classes.rb', line 8345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8312
8313
8314
# File 'lib/google/apis/compute_beta/classes.rb', line 8312

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Commitment>

A list of Commitment resources. Corresponds to the JSON property items



8317
8318
8319
# File 'lib/google/apis/compute_beta/classes.rb', line 8317

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#commitmentList for lists of commitments. Corresponds to the JSON property kind

Returns:

  • (String)


8323
8324
8325
# File 'lib/google/apis/compute_beta/classes.rb', line 8323

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8333
8334
8335
# File 'lib/google/apis/compute_beta/classes.rb', line 8333

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8338
8339
8340
# File 'lib/google/apis/compute_beta/classes.rb', line 8338

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::CommitmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8343
8344
8345
# File 'lib/google/apis/compute_beta/classes.rb', line 8343

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8350
8351
8352
8353
8354
8355
8356
8357
# File 'lib/google/apis/compute_beta/classes.rb', line 8350

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end