Class: Google::Apis::ComputeBeta::CommitmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CommitmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Commitment resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Commitment>
A list of Commitment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::CommitmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CommitmentList
constructor
A new instance of CommitmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CommitmentList
Returns a new instance of CommitmentList.
8040 8041 8042 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8007 8008 8009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8007 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Commitment>
A list of Commitment resources.
Corresponds to the JSON property items
8012 8013 8014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8012 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#commitmentList
for lists of commitments.
Corresponds to the JSON property kind
8018 8019 8020 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8018 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8028 8029 8030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8028 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8033 8034 8035 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8033 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::CommitmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8038 8039 8040 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8038 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8045 8046 8047 8048 8049 8050 8051 8052 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8045 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |