Class: Google::Apis::ComputeBeta::CommitmentParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Additional commitment params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommitmentParams

Returns a new instance of CommitmentParams.



9004
9005
9006
# File 'lib/google/apis/compute_beta/classes.rb', line 9004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the commitment. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


9002
9003
9004
# File 'lib/google/apis/compute_beta/classes.rb', line 9002

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9009
9010
9011
# File 'lib/google/apis/compute_beta/classes.rb', line 9009

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end