Class: Google::Apis::ComputeBeta::CompositeHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a composite health check. A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheck

Returns a new instance of CompositeHealthCheck.



9226
9227
9228
# File 'lib/google/apis/compute_beta/classes.rb', line 9226

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


9144
9145
9146
# File 'lib/google/apis/compute_beta/classes.rb', line 9144

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


9150
9151
9152
# File 'lib/google/apis/compute_beta/classes.rb', line 9150

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a CompositeHealthCheck. An up-to-date fingerprint must be provided in order to patch the CompositeHealthCheck; Otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the CompositeHealthCheck. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


9162
9163
9164
# File 'lib/google/apis/compute_beta/classes.rb', line 9162

def fingerprint
  @fingerprint
end

#health_destinationString

URL to the destination resource. Must be set. Must be aForwardingRule. The ForwardingRule must have load balancing scheme INTERNAL orINTERNAL_MANAGED and must be regional and in the same region as the CompositeHealthCheck (cross-region deployment forINTERNAL_MANAGED is not supported). Can be mutated. Corresponds to the JSON property healthDestination

Returns:

  • (String)


9172
9173
9174
# File 'lib/google/apis/compute_beta/classes.rb', line 9172

def health_destination
  @health_destination
end

#health_sourcesArray<String>

URLs to the HealthSource resources whose results are AND'ed. I.e. he aggregated result is is HEALTHY only if all sources are HEALTHY. Must have at least 1. Must not have more than 10. Must be regional and in the same region as theCompositeHealthCheck. Can be mutated. Corresponds to the JSON property healthSources

Returns:

  • (Array<String>)


9181
9182
9183
# File 'lib/google/apis/compute_beta/classes.rb', line 9181

def health_sources
  @health_sources
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


9188
9189
9190
# File 'lib/google/apis/compute_beta/classes.rb', line 9188

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


9194
9195
9196
# File 'lib/google/apis/compute_beta/classes.rb', line 9194

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


9205
9206
9207
# File 'lib/google/apis/compute_beta/classes.rb', line 9205

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the composite health check resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


9214
9215
9216
# File 'lib/google/apis/compute_beta/classes.rb', line 9214

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9219
9220
9221
# File 'lib/google/apis/compute_beta/classes.rb', line 9219

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


9224
9225
9226
# File 'lib/google/apis/compute_beta/classes.rb', line 9224

def self_link_with_id
  @self_link_with_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9231
9232
9233
9234
9235
9236
9237
9238
9239
9240
9241
9242
9243
# File 'lib/google/apis/compute_beta/classes.rb', line 9231

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @health_destination = args[:health_destination] if args.key?(:health_destination)
  @health_sources = args[:health_sources] if args.key?(:health_sources)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
end