Class: Google::Apis::ComputeBeta::CompositeHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CompositeHealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a composite health check. A composite health check resource specifies the health source resources and the health destination resource to which the aggregated health result from the health source resources is delivered.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_destination ⇒ String
URL to the destination resource.
-
#health_sources ⇒ Array<String>
URLs to the HealthSource resources whose results are AND'ed.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheck
constructor
A new instance of CompositeHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheck
Returns a new instance of CompositeHealthCheck.
8642 8643 8644 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8642 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
8560 8561 8562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8560 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
8566 8567 8568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8566 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a CompositeHealthCheck. An up-to-date fingerprint
must be provided in order to patch the CompositeHealthCheck; Otherwise,
the request will fail with error 412 conditionNotMet. To see
the latest fingerprint, make a get() request to retrieve the
CompositeHealthCheck.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
8578 8579 8580 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8578 def fingerprint @fingerprint end |
#health_destination ⇒ String
URL to the destination resource. Must be set. Must be aForwardingRule. The
ForwardingRule must have
load balancing scheme INTERNAL orINTERNAL_MANAGED and must be regional and in
the same region
as the CompositeHealthCheck (cross-region deployment forINTERNAL_MANAGED is
not supported). Can be mutated.
Corresponds to the JSON property healthDestination
8588 8589 8590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8588 def health_destination @health_destination end |
#health_sources ⇒ Array<String>
URLs to the HealthSource resources whose results are AND'ed.
I.e. he aggregated result is is HEALTHY only if all sources
are HEALTHY. Must have at least 1. Must not have more than 10.
Must be regional and in the same region as theCompositeHealthCheck. Can be
mutated.
Corresponds to the JSON property healthSources
8597 8598 8599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8597 def health_sources @health_sources end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
8604 8605 8606 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8604 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
compositeHealthCheck for composite health checks.
Corresponds to the JSON property kind
8610 8611 8612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8610 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
8621 8622 8623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8621 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the composite health check
resides.
This field applies only to the regional resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
8630 8631 8632 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8630 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
8635 8636 8637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8635 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
8640 8641 8642 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8640 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8647 8648 8649 8650 8651 8652 8653 8654 8655 8656 8657 8658 8659 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8647 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_destination = args[:health_destination] if args.key?(:health_destination) @health_sources = args[:health_sources] if args.key?(:health_sources) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |