Class: Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of CompositeHealthChecksScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>
A list of CompositeHealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckAggregatedList
constructor
A new instance of CompositeHealthCheckAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckAggregatedList
Returns a new instance of CompositeHealthCheckAggregatedList.
9344 9345 9346 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9344 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9307 9308 9309 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9307 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>
A list of CompositeHealthChecksScopedList resources.
Corresponds to the JSON property items
9312 9313 9314 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9312 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
9317 9318 9319 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9317 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9327 9328 9329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9327 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9332 9333 9334 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9332 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
9337 9338 9339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9337 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9342 9343 9344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9342 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9349 9350 9351 9352 9353 9354 9355 9356 9357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9349 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |