Class: Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



9290
9291
9292
# File 'lib/google/apis/compute_beta/classes.rb', line 9290

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9253
9254
9255
# File 'lib/google/apis/compute_beta/classes.rb', line 9253

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



9258
9259
9260
# File 'lib/google/apis/compute_beta/classes.rb', line 9258

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


9263
9264
9265
# File 'lib/google/apis/compute_beta/classes.rb', line 9263

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9273
9274
9275
# File 'lib/google/apis/compute_beta/classes.rb', line 9273

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9278
9279
9280
# File 'lib/google/apis/compute_beta/classes.rb', line 9278

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


9283
9284
9285
# File 'lib/google/apis/compute_beta/classes.rb', line 9283

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9288
9289
9290
# File 'lib/google/apis/compute_beta/classes.rb', line 9288

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9295
9296
9297
9298
9299
9300
9301
9302
9303
# File 'lib/google/apis/compute_beta/classes.rb', line 9295

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end