Class: Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



9307
9308
9309
# File 'lib/google/apis/compute_beta/classes.rb', line 9307

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9270
9271
9272
# File 'lib/google/apis/compute_beta/classes.rb', line 9270

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



9275
9276
9277
# File 'lib/google/apis/compute_beta/classes.rb', line 9275

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


9280
9281
9282
# File 'lib/google/apis/compute_beta/classes.rb', line 9280

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9290
9291
9292
# File 'lib/google/apis/compute_beta/classes.rb', line 9290

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9295
9296
9297
# File 'lib/google/apis/compute_beta/classes.rb', line 9295

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


9300
9301
9302
# File 'lib/google/apis/compute_beta/classes.rb', line 9300

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9305
9306
9307
# File 'lib/google/apis/compute_beta/classes.rb', line 9305

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9312
9313
9314
9315
9316
9317
9318
9319
9320
# File 'lib/google/apis/compute_beta/classes.rb', line 9312

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end