Class: Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



8783
8784
8785
# File 'lib/google/apis/compute_beta/classes.rb', line 8783

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8746
8747
8748
# File 'lib/google/apis/compute_beta/classes.rb', line 8746

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



8751
8752
8753
# File 'lib/google/apis/compute_beta/classes.rb', line 8751

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


8756
8757
8758
# File 'lib/google/apis/compute_beta/classes.rb', line 8756

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8766
8767
8768
# File 'lib/google/apis/compute_beta/classes.rb', line 8766

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8771
8772
8773
# File 'lib/google/apis/compute_beta/classes.rb', line 8771

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


8776
8777
8778
# File 'lib/google/apis/compute_beta/classes.rb', line 8776

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8781
8782
8783
# File 'lib/google/apis/compute_beta/classes.rb', line 8781

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8788
8789
8790
8791
8792
8793
8794
8795
8796
# File 'lib/google/apis/compute_beta/classes.rb', line 8788

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end