Class: Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



8706
8707
8708
# File 'lib/google/apis/compute_beta/classes.rb', line 8706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8669
8670
8671
# File 'lib/google/apis/compute_beta/classes.rb', line 8669

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



8674
8675
8676
# File 'lib/google/apis/compute_beta/classes.rb', line 8674

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


8679
8680
8681
# File 'lib/google/apis/compute_beta/classes.rb', line 8679

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8689
8690
8691
# File 'lib/google/apis/compute_beta/classes.rb', line 8689

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8694
8695
8696
# File 'lib/google/apis/compute_beta/classes.rb', line 8694

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


8699
8700
8701
# File 'lib/google/apis/compute_beta/classes.rb', line 8699

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8704
8705
8706
# File 'lib/google/apis/compute_beta/classes.rb', line 8704

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8711
8712
8713
8714
8715
8716
8717
8718
8719
# File 'lib/google/apis/compute_beta/classes.rb', line 8711

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end