Class: Google::Apis::ComputeBeta::CompositeHealthCheckAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of CompositeHealthChecksScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckAggregatedList

Returns a new instance of CompositeHealthCheckAggregatedList.



8401
8402
8403
# File 'lib/google/apis/compute_beta/classes.rb', line 8401

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


8364
8365
8366
# File 'lib/google/apis/compute_beta/classes.rb', line 8364

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::CompositeHealthChecksScopedList>

A list of CompositeHealthChecksScopedList resources. Corresponds to the JSON property items



8369
8370
8371
# File 'lib/google/apis/compute_beta/classes.rb', line 8369

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


8374
8375
8376
# File 'lib/google/apis/compute_beta/classes.rb', line 8374

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


8384
8385
8386
# File 'lib/google/apis/compute_beta/classes.rb', line 8384

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


8389
8390
8391
# File 'lib/google/apis/compute_beta/classes.rb', line 8389

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


8394
8395
8396
# File 'lib/google/apis/compute_beta/classes.rb', line 8394

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CompositeHealthCheckAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



8399
8400
8401
# File 'lib/google/apis/compute_beta/classes.rb', line 8399

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8406
8407
8408
8409
8410
8411
8412
8413
8414
# File 'lib/google/apis/compute_beta/classes.rb', line 8406

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end