Class: Google::Apis::ComputeBeta::CompositeHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CompositeHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckList
constructor
A new instance of CompositeHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckList
Returns a new instance of CompositeHealthCheckList.
9567 9568 9569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9567 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9534 9535 9536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9534 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
Corresponds to the JSON property items
9539 9540 9541 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9539 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
compositeHealthCheck for composite health checks.
Corresponds to the JSON property kind
9545 9546 9547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9545 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9555 9556 9557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9555 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9560 9561 9562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9560 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9565 9566 9567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9565 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9572 9573 9574 9575 9576 9577 9578 9579 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9572 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |