Class: Google::Apis::ComputeBeta::CompositeHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CompositeHealthCheckList

Returns a new instance of CompositeHealthCheckList.



9466
9467
9468
# File 'lib/google/apis/compute_beta/classes.rb', line 9466

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9433
9434
9435
# File 'lib/google/apis/compute_beta/classes.rb', line 9433

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::CompositeHealthCheck>

A list of CompositeHealthCheck resources. Corresponds to the JSON property items



9438
9439
9440
# File 'lib/google/apis/compute_beta/classes.rb', line 9438

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# compositeHealthCheck for composite health checks. Corresponds to the JSON property kind

Returns:

  • (String)


9444
9445
9446
# File 'lib/google/apis/compute_beta/classes.rb', line 9444

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9454
9455
9456
# File 'lib/google/apis/compute_beta/classes.rb', line 9454

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9459
9460
9461
# File 'lib/google/apis/compute_beta/classes.rb', line 9459

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::CompositeHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9464
9465
9466
# File 'lib/google/apis/compute_beta/classes.rb', line 9464

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9471
9472
9473
9474
9475
9476
9477
9478
# File 'lib/google/apis/compute_beta/classes.rb', line 9471

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end