Class: Google::Apis::ComputeBeta::CompositeHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CompositeHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CompositeHealthCheckList
constructor
A new instance of CompositeHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CompositeHealthCheckList
Returns a new instance of CompositeHealthCheckList.
8942 8943 8944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
8909 8910 8911 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8909 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::CompositeHealthCheck>
A list of CompositeHealthCheck resources.
Corresponds to the JSON property items
8914 8915 8916 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8914 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
compositeHealthCheck for composite health checks.
Corresponds to the JSON property kind
8920 8921 8922 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8920 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
8930 8931 8932 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8930 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
8935 8936 8937 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8935 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::CompositeHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
8940 8941 8942 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8940 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8947 8948 8949 8950 8951 8952 8953 8954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8947 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |