Class: Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
This message defines settings for a consistent hash style load balancer.
Instance Attribute Summary collapse
-
#http_cookie ⇒ Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettingsHttpCookie
The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.
-
#http_header_name ⇒ String
The hash based on the value of the specified header field.
-
#minimum_ring_size ⇒ Fixnum
The minimum number of virtual nodes to use for the hash ring.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettings
constructor
A new instance of ConsistentHashLoadBalancerSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettings
Returns a new instance of ConsistentHashLoadBalancerSettings.
8780 8781 8782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8780 def initialize(**args) update!(**args) end |
Instance Attribute Details
#http_cookie ⇒ Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettingsHttpCookie
The information about the HTTP Cookie on which the hash function is based
for load balancing policies that use a consistent hash.
Corresponds to the JSON property httpCookie
8764 8765 8766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8764 def @http_cookie end |
#http_header_name ⇒ String
The hash based on the value of the specified header field. This field is
applicable if the sessionAffinity is set toHEADER_FIELD.
Corresponds to the JSON property httpHeaderName
8770 8771 8772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8770 def http_header_name @http_header_name end |
#minimum_ring_size ⇒ Fixnum
The minimum number of virtual nodes to use for the hash ring. Defaults to
- Larger ring sizes result in more granular load distributions. If the
number of hosts in the load balancing pool is larger than the ring size,
each host will be assigned a single virtual node.
Corresponds to the JSON property
minimumRingSize
8778 8779 8780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8778 def minimum_ring_size @minimum_ring_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8785 8786 8787 8788 8789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8785 def update!(**args) @http_cookie = args[:http_cookie] if args.key?(:http_cookie) @http_header_name = args[:http_header_name] if args.key?(:http_header_name) @minimum_ring_size = args[:minimum_ring_size] if args.key?(:minimum_ring_size) end |