Class: Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettingsHttpCookie

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie

Returns a new instance of ConsistentHashLoadBalancerSettingsHttpCookie.



9762
9763
9764
# File 'lib/google/apis/compute_beta/classes.rb', line 9762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the cookie. Corresponds to the JSON property name

Returns:

  • (String)


9747
9748
9749
# File 'lib/google/apis/compute_beta/classes.rb', line 9747

def name
  @name
end

#pathString

Path to set for the cookie. Corresponds to the JSON property path

Returns:

  • (String)


9752
9753
9754
# File 'lib/google/apis/compute_beta/classes.rb', line 9752

def path
  @path
end

#ttlGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property ttl



9760
9761
9762
# File 'lib/google/apis/compute_beta/classes.rb', line 9760

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9767
9768
9769
9770
9771
# File 'lib/google/apis/compute_beta/classes.rb', line 9767

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @ttl = args[:ttl] if args.key?(:ttl)
end