Class: Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettingsHttpCookie

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie

Returns a new instance of ConsistentHashLoadBalancerSettingsHttpCookie.



9255
9256
9257
# File 'lib/google/apis/compute_beta/classes.rb', line 9255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

Name of the cookie. Corresponds to the JSON property name

Returns:

  • (String)


9240
9241
9242
# File 'lib/google/apis/compute_beta/classes.rb', line 9240

def name
  @name
end

#pathString

Path to set for the cookie. Corresponds to the JSON property path

Returns:

  • (String)


9245
9246
9247
# File 'lib/google/apis/compute_beta/classes.rb', line 9245

def path
  @path
end

#ttlGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property ttl



9253
9254
9255
# File 'lib/google/apis/compute_beta/classes.rb', line 9253

def ttl
  @ttl
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9260
9261
9262
9263
9264
# File 'lib/google/apis/compute_beta/classes.rb', line 9260

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @path = args[:path] if args.key?(:path)
  @ttl = args[:ttl] if args.key?(:ttl)
end