Class: Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettingsHttpCookie
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ConsistentHashLoadBalancerSettingsHttpCookie
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The information about the HTTP Cookie on which the hash function is based for load balancing policies that use a consistent hash.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of the cookie.
-
#path ⇒ String
Path to set for the cookie.
-
#ttl ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie
constructor
A new instance of ConsistentHashLoadBalancerSettingsHttpCookie.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConsistentHashLoadBalancerSettingsHttpCookie
Returns a new instance of ConsistentHashLoadBalancerSettingsHttpCookie.
8815 8816 8817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of the cookie.
Corresponds to the JSON property name
8800 8801 8802 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8800 def name @name end |
#path ⇒ String
Path to set for the cookie.
Corresponds to the JSON property path
8805 8806 8807 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8805 def path @path end |
#ttl ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property ttl
8813 8814 8815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8813 def ttl @ttl end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8820 8821 8822 8823 8824 |
# File 'lib/google/apis/compute_beta/classes.rb', line 8820 def update!(**args) @name = args[:name] if args.key?(:name) @path = args[:path] if args.key?(:path) @ttl = args[:ttl] if args.key?(:ttl) end |