Class: Google::Apis::ComputeBeta::CrossSiteNetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CrossSiteNetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request that contains a list of cross-site networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetworkList
constructor
A new instance of CrossSiteNetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetworkList
Returns a new instance of CrossSiteNetworkList.
10088 10089 10090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10088 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
10044 10045 10046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10044 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10049 10050 10051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10049 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
Corresponds to the JSON property items
10054 10055 10056 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10054 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
10060 10061 10062 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10060 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10070 10071 10072 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10070 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10075 10076 10077 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10075 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
10081 10082 10083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10081 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10086 10087 10088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10086 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10093 10094 10095 10096 10097 10098 10099 10100 10101 10102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10093 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |