Class: Google::Apis::ComputeBeta::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



10071
10072
10073
# File 'lib/google/apis/compute_beta/classes.rb', line 10071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


10027
10028
10029
# File 'lib/google/apis/compute_beta/classes.rb', line 10027

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10032
10033
10034
# File 'lib/google/apis/compute_beta/classes.rb', line 10032

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



10037
10038
10039
# File 'lib/google/apis/compute_beta/classes.rb', line 10037

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


10043
10044
10045
# File 'lib/google/apis/compute_beta/classes.rb', line 10043

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10053
10054
10055
# File 'lib/google/apis/compute_beta/classes.rb', line 10053

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10058
10059
10060
# File 'lib/google/apis/compute_beta/classes.rb', line 10058

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10064
10065
10066
# File 'lib/google/apis/compute_beta/classes.rb', line 10064

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10069
10070
10071
# File 'lib/google/apis/compute_beta/classes.rb', line 10069

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10076
10077
10078
10079
10080
10081
10082
10083
10084
10085
# File 'lib/google/apis/compute_beta/classes.rb', line 10076

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end