Class: Google::Apis::ComputeBeta::CrossSiteNetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::CrossSiteNetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request that contains a list of cross-site networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CrossSiteNetworkList
constructor
A new instance of CrossSiteNetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CrossSiteNetworkList
Returns a new instance of CrossSiteNetworkList.
9463 9464 9465 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
9419 9420 9421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9419 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
9424 9425 9426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9424 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::CrossSiteNetwork>
A list of CrossSiteNetwork resources.
Corresponds to the JSON property items
9429 9430 9431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9429 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
crossSiteNetwork for cross-site networks.
Corresponds to the JSON property kind
9435 9436 9437 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9435 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
9445 9446 9447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9445 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
9450 9451 9452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9450 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
9456 9457 9458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9456 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::CrossSiteNetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
9461 9462 9463 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9461 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9468 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |