Class: Google::Apis::ComputeBeta::CrossSiteNetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request that contains a list of cross-site networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CrossSiteNetworkList

Returns a new instance of CrossSiteNetworkList.



9328
9329
9330
# File 'lib/google/apis/compute_beta/classes.rb', line 9328

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


9284
9285
9286
# File 'lib/google/apis/compute_beta/classes.rb', line 9284

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


9289
9290
9291
# File 'lib/google/apis/compute_beta/classes.rb', line 9289

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::CrossSiteNetwork>

A list of CrossSiteNetwork resources. Corresponds to the JSON property items



9294
9295
9296
# File 'lib/google/apis/compute_beta/classes.rb', line 9294

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# crossSiteNetwork for cross-site networks. Corresponds to the JSON property kind

Returns:

  • (String)


9300
9301
9302
# File 'lib/google/apis/compute_beta/classes.rb', line 9300

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


9310
9311
9312
# File 'lib/google/apis/compute_beta/classes.rb', line 9310

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


9315
9316
9317
# File 'lib/google/apis/compute_beta/classes.rb', line 9315

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


9321
9322
9323
# File 'lib/google/apis/compute_beta/classes.rb', line 9321

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::CrossSiteNetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



9326
9327
9328
# File 'lib/google/apis/compute_beta/classes.rb', line 9326

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9333
9334
9335
9336
9337
9338
9339
9340
9341
9342
# File 'lib/google/apis/compute_beta/classes.rb', line 9333

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end