Class: Google::Apis::ComputeBeta::Date

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:

  • A full date, with non-zero year, month, and day values.
  • A month and day, with a zero year (for example, an anniversary).
  • A year on its own, with a zero month and a zero day.
  • A year and month, with a zero day (for example, a credit card expiration date). Related types:
  • google.type.TimeOfDay
  • google.type.DateTime
  • google.protobuf.Timestamp

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Date

Returns a new instance of Date.



9362
9363
9364
# File 'lib/google/apis/compute_beta/classes.rb', line 9362

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayFixnum

Day of a month. Must be from 1 to 31 and valid for the year and month, or 0 to specify a year by itself or a year and month where the day isn't significant. Corresponds to the JSON property day

Returns:

  • (Fixnum)


9348
9349
9350
# File 'lib/google/apis/compute_beta/classes.rb', line 9348

def day
  @day
end

#monthFixnum

Month of a year. Must be from 1 to 12, or 0 to specify a year without a month and day. Corresponds to the JSON property month

Returns:

  • (Fixnum)


9354
9355
9356
# File 'lib/google/apis/compute_beta/classes.rb', line 9354

def month
  @month
end

#yearFixnum

Year of the date. Must be from 1 to 9999, or 0 to specify a date without a year. Corresponds to the JSON property year

Returns:

  • (Fixnum)


9360
9361
9362
# File 'lib/google/apis/compute_beta/classes.rb', line 9360

def year
  @year
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9367
9368
9369
9370
9371
# File 'lib/google/apis/compute_beta/classes.rb', line 9367

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @month = args[:month] if args.key?(:month)
  @year = args[:year] if args.key?(:year)
end