Class: Google::Apis::ComputeBeta::DeprecationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Deprecation status for a public resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DeprecationStatus

Returns a new instance of DeprecationStatus.



10498
10499
10500
# File 'lib/google/apis/compute_beta/classes.rb', line 10498

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deletedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deleted

Returns:

  • (String)


10456
10457
10458
# File 'lib/google/apis/compute_beta/classes.rb', line 10456

def deleted
  @deleted
end

#deprecatedString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property deprecated

Returns:

  • (String)


10464
10465
10466
# File 'lib/google/apis/compute_beta/classes.rb', line 10464

def deprecated
  @deprecated
end

#obsoleteString

An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE. This is only informational and the status will not change unless the client explicitly changes it. Corresponds to the JSON property obsolete

Returns:

  • (String)


10472
10473
10474
# File 'lib/google/apis/compute_beta/classes.rb', line 10472

def obsolete
  @obsolete
end

#replacementString

The URL of the suggested replacement for a deprecated resource. The suggested replacement resource must be the same kind of resource as the deprecated resource. Corresponds to the JSON property replacement

Returns:

  • (String)


10479
10480
10481
# File 'lib/google/apis/compute_beta/classes.rb', line 10479

def replacement
  @replacement
end

#stateString

The deprecation state of this resource. This can be ACTIVE,DEPRECATED, OBSOLETE, or DELETED. Operations which communicate the end of life date for an image, can useACTIVE. Operations which create a new resource using aDEPRECATED resource will return successfully, but with a warning indicating the deprecated resource and recommending its replacement. Operations which use OBSOLETE orDELETED resources will be rejected and result in an error. Corresponds to the JSON property state

Returns:

  • (String)


10491
10492
10493
# File 'lib/google/apis/compute_beta/classes.rb', line 10491

def state
  @state
end

#state_overrideGoogle::Apis::ComputeBeta::RolloutPolicy

A rollout policy configuration. Corresponds to the JSON property stateOverride



10496
10497
10498
# File 'lib/google/apis/compute_beta/classes.rb', line 10496

def state_override
  @state_override
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10503
10504
10505
10506
10507
10508
10509
10510
# File 'lib/google/apis/compute_beta/classes.rb', line 10503

def update!(**args)
  @deleted = args[:deleted] if args.key?(:deleted)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @obsolete = args[:obsolete] if args.key?(:obsolete)
  @replacement = args[:replacement] if args.key?(:replacement)
  @state = args[:state] if args.key?(:state)
  @state_override = args[:state_override] if args.key?(:state_override)
end