Class: Google::Apis::ComputeBeta::DeprecationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DeprecationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Deprecation status for a public resource.
Instance Attribute Summary collapse
-
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DELETED.
-
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to DEPRECATED.
-
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this resource is intended to change to OBSOLETE.
-
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
-
#state ⇒ String
The deprecation state of this resource.
-
#state_override ⇒ Google::Apis::ComputeBeta::RolloutPolicy
A rollout policy configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DeprecationStatus
constructor
A new instance of DeprecationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DeprecationStatus
Returns a new instance of DeprecationStatus.
9731 9732 9733 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9731 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deleted ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DELETED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deleted
9689 9690 9691 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9689 def deleted @deleted end |
#deprecated ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to DEPRECATED. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property deprecated
9697 9698 9699 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9697 def deprecated @deprecated end |
#obsolete ⇒ String
An optional RFC3339 timestamp on or after which the state of this
resource is intended to change to OBSOLETE. This is only
informational and the status will not change unless the client explicitly
changes it.
Corresponds to the JSON property obsolete
9705 9706 9707 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9705 def obsolete @obsolete end |
#replacement ⇒ String
The URL of the suggested replacement for a deprecated resource.
The suggested replacement resource must be the same kind of resource as the
deprecated resource.
Corresponds to the JSON property replacement
9712 9713 9714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9712 def replacement @replacement end |
#state ⇒ String
The deprecation state of this resource. This can be ACTIVE,DEPRECATED,
OBSOLETE, or DELETED.
Operations which communicate the end of life date for an image, can useACTIVE.
Operations which create a new resource using aDEPRECATED resource will return
successfully, but with a
warning indicating the deprecated resource and recommending its
replacement. Operations which use OBSOLETE orDELETED resources will be
rejected and result in an error.
Corresponds to the JSON property state
9724 9725 9726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9724 def state @state end |
#state_override ⇒ Google::Apis::ComputeBeta::RolloutPolicy
A rollout policy configuration.
Corresponds to the JSON property stateOverride
9729 9730 9731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9729 def state_override @state_override end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9736 9737 9738 9739 9740 9741 9742 9743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 9736 def update!(**args) @deleted = args[:deleted] if args.key?(:deleted) @deprecated = args[:deprecated] if args.key?(:deprecated) @obsolete = args[:obsolete] if args.key?(:obsolete) @replacement = args[:replacement] if args.key?(:replacement) @state = args[:state] if args.key?(:state) @state_override = args[:state_override] if args.key?(:state_override) end |