Class: Google::Apis::ComputeBeta::Disk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Persistent Disk resource. Google Compute Engine has two Disk resources:

  • Zonal
  • Regional Persistent disks are required for running your VM instances. Create both boot and non-boot (data) persistent disks. For more information, read Persistent Disks. For more storage options, read Storage options. The disks resource represents a zonal persistent disk. For more information, readZonal persistent disks. The regionDisks resource represents a regional persistent disk. For more information, read Regional resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Disk

Returns a new instance of Disk.



10933
10934
10935
# File 'lib/google/apis/compute_beta/classes.rb', line 10933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_modeString

The access mode of the disk.

  • READ_WRITE_SINGLE: The default AccessMode, means the disk can be attached to single instance in RW mode.
  • READ_WRITE_MANY: The AccessMode means the disk can be attached to multiple instances in RW mode.
  • READ_ONLY_MANY: The AccessMode means the disk can be attached to multiple instances in RO mode. The AccessMode is only valid for Hyperdisk disk types. Corresponds to the JSON property accessMode

Returns:

  • (String)


10416
10417
10418
# File 'lib/google/apis/compute_beta/classes.rb', line 10416

def access_mode
  @access_mode
end

#architectureString

The architecture of the disk. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


10422
10423
10424
# File 'lib/google/apis/compute_beta/classes.rb', line 10422

def architecture
  @architecture
end

#async_primary_diskGoogle::Apis::ComputeBeta::DiskAsyncReplication

Disk asynchronously replicated into this disk. Corresponds to the JSON property asyncPrimaryDisk



10427
10428
10429
# File 'lib/google/apis/compute_beta/classes.rb', line 10427

def async_primary_disk
  @async_primary_disk
end

#async_secondary_disksHash<String,Google::Apis::ComputeBeta::DiskAsyncReplicationList>

Output only. [Output Only] A list of disks this disk is asynchronously replicated to. Corresponds to the JSON property asyncSecondaryDisks



10433
10434
10435
# File 'lib/google/apis/compute_beta/classes.rb', line 10433

def async_secondary_disks
  @async_secondary_disks
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


10439
10440
10441
# File 'lib/google/apis/compute_beta/classes.rb', line 10439

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


10445
10446
10447
# File 'lib/google/apis/compute_beta/classes.rb', line 10445

def description
  @description
end

#disk_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Encrypts the disk using a customer-supplied encryption key or a customer-managed encryption key. Encryption keys do not protect access to metadata of the disk. After you encrypt a disk with a customer-supplied key, you must provide the same key if you use the disk later. For example, to create a disk snapshot, to create a disk image, to create a machine image, or to attach the disk to a virtual machine. After you encrypt a disk with a customer-managed key, thediskEncryptionKey. kmsKeyName is set to a key version name once the disk is created. The disk is encrypted with this version of the key. In the response, diskEncryptionKey.kmsKeyName appears in the following format: "diskEncryptionKey.kmsKeyName": "projects/kms_project_id/locations/region/keyRings/ key_region/cryptoKeys/key /cryptoKeysVersions/version If you do not provide an encryption key when creating the disk, then the disk is encrypted using an automatically generated key and you don't need to provide a key to use the disk later. Corresponds to the JSON property diskEncryptionKey



10469
10470
10471
# File 'lib/google/apis/compute_beta/classes.rb', line 10469

def disk_encryption_key
  @disk_encryption_key
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Whether this disk is using confidential compute mode. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


10474
10475
10476
# File 'lib/google/apis/compute_beta/classes.rb', line 10474

def enable_confidential_compute
  @enable_confidential_compute
end

#erase_windows_vss_signatureBoolean Also known as: erase_windows_vss_signature?

Specifies whether the disk restored from a source snapshot should erase Windows specific VSS signature. Corresponds to the JSON property eraseWindowsVssSignature

Returns:

  • (Boolean)


10481
10482
10483
# File 'lib/google/apis/compute_beta/classes.rb', line 10481

def erase_windows_vss_signature
  @erase_windows_vss_signature
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



10490
10491
10492
# File 'lib/google/apis/compute_beta/classes.rb', line 10490

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


10497
10498
10499
# File 'lib/google/apis/compute_beta/classes.rb', line 10497

def id
  @id
end

#interfaceString

[Deprecated] Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. The default isSCSI. Corresponds to the JSON property interface

Returns:

  • (String)


10503
10504
10505
# File 'lib/google/apis/compute_beta/classes.rb', line 10503

def interface
  @interface
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#disk for disks. Corresponds to the JSON property kind

Returns:

  • (String)


10509
10510
10511
# File 'lib/google/apis/compute_beta/classes.rb', line 10509

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this disk, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a disk. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


10522
10523
10524
# File 'lib/google/apis/compute_beta/classes.rb', line 10522

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this disk. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


10528
10529
10530
# File 'lib/google/apis/compute_beta/classes.rb', line 10528

def labels
  @labels
end

#last_attach_timestampString

Output only. [Output Only] Last attach timestamp inRFC3339 text format. Corresponds to the JSON property lastAttachTimestamp

Returns:

  • (String)


10534
10535
10536
# File 'lib/google/apis/compute_beta/classes.rb', line 10534

def last_attach_timestamp
  @last_attach_timestamp
end

#last_detach_timestampString

Output only. [Output Only] Last detach timestamp inRFC3339 text format. Corresponds to the JSON property lastDetachTimestamp

Returns:

  • (String)


10540
10541
10542
# File 'lib/google/apis/compute_beta/classes.rb', line 10540

def last_detach_timestamp
  @last_detach_timestamp
end

#license_codesArray<Fixnum>

Integer license codes indicating which licenses are attached to this disk. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


10545
10546
10547
# File 'lib/google/apis/compute_beta/classes.rb', line 10545

def license_codes
  @license_codes
end

#licensesArray<String>

A list of publicly visible licenses. Reserved for Google's use. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


10550
10551
10552
# File 'lib/google/apis/compute_beta/classes.rb', line 10550

def licenses
  @licenses
end

#location_hintString

An opaque location hint used to place the disk close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


10556
10557
10558
# File 'lib/google/apis/compute_beta/classes.rb', line 10556

def location_hint
  @location_hint
end

#lockedBoolean Also known as: locked?

Output only. [Output Only] The field indicates if the disk is created from a locked source image. Attachment of a disk created from a locked source image will cause the following operations to become irreversibly prohibited:

  • R/W or R/O disk attachment to any other instance
  • Disk detachment. And the disk can only be deleted when the instance is deleted
  • Creation of images or snapshots
  • Disk cloning Furthermore, the instance with at least one disk with locked flag set to true will be prohibited from performing the operations below:

  • Further attachment of secondary disks.

  • Detachment of any disks

  • Create machine images

  • Create instance template

  • Delete the instance with --keep-disk parameter set to true for locked disks

  • Attach a locked disk with --auto-delete parameter set to false Corresponds to the JSON property locked

Returns:

  • (Boolean)


10580
10581
10582
# File 'lib/google/apis/compute_beta/classes.rb', line 10580

def locked
  @locked
end

#multi_writerBoolean Also known as: multi_writer?

Indicates whether or not the disk can be read/write attached to more than one instance. Corresponds to the JSON property multiWriter

Returns:

  • (Boolean)


10587
10588
10589
# File 'lib/google/apis/compute_beta/classes.rb', line 10587

def multi_writer
  @multi_writer
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


10599
10600
10601
# File 'lib/google/apis/compute_beta/classes.rb', line 10599

def name
  @name
end

#optionsString

Internal use only. Corresponds to the JSON property options

Returns:

  • (String)


10604
10605
10606
# File 'lib/google/apis/compute_beta/classes.rb', line 10604

def options
  @options
end

#paramsGoogle::Apis::ComputeBeta::DiskParams

Additional disk params. Corresponds to the JSON property params



10609
10610
10611
# File 'lib/google/apis/compute_beta/classes.rb', line 10609

def params
  @params
end

#physical_block_size_bytesFixnum

Physical block size of the persistent disk, in bytes. If not present in a request, a default value is used. The currently supported size is 4096, other sizes may be added in the future. If an unsupported value is requested, the error message will list the supported values for the caller's project. Corresponds to the JSON property physicalBlockSizeBytes

Returns:

  • (Fixnum)


10619
10620
10621
# File 'lib/google/apis/compute_beta/classes.rb', line 10619

def physical_block_size_bytes
  @physical_block_size_bytes
end

#provisioned_iopsFixnum

Indicates how many IOPS to provision for the disk. This sets the number of I/O operations per second that the disk can handle. Values must be between 10,000 and 120,000. For more details, see theExtreme persistent disk documentation. Corresponds to the JSON property provisionedIops

Returns:

  • (Fixnum)


10627
10628
10629
# File 'lib/google/apis/compute_beta/classes.rb', line 10627

def provisioned_iops
  @provisioned_iops
end

#provisioned_throughputFixnum

Indicates how much throughput to provision for the disk. This sets the number of throughput mb per second that the disk can handle. Values must be greater than or equal to 1. Corresponds to the JSON property provisionedThroughput

Returns:

  • (Fixnum)


10634
10635
10636
# File 'lib/google/apis/compute_beta/classes.rb', line 10634

def provisioned_throughput
  @provisioned_throughput
end

#regionString

Output only. [Output Only] URL of the region where the disk resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


10643
10644
10645
# File 'lib/google/apis/compute_beta/classes.rb', line 10643

def region
  @region
end

#replica_zonesArray<String>

URLs of the zones where the disk should be replicated to. Only applicable for regional resources. Corresponds to the JSON property replicaZones

Returns:

  • (Array<String>)


10649
10650
10651
# File 'lib/google/apis/compute_beta/classes.rb', line 10649

def replica_zones
  @replica_zones
end

#resource_policiesArray<String>

Resource policies applied to this disk for automatic snapshot creations. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


10654
10655
10656
# File 'lib/google/apis/compute_beta/classes.rb', line 10654

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeBeta::DiskResourceStatus

Output only. [Output Only] Status information for the disk resource. Corresponds to the JSON property resourceStatus



10659
10660
10661
# File 'lib/google/apis/compute_beta/classes.rb', line 10659

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


10664
10665
10666
# File 'lib/google/apis/compute_beta/classes.rb', line 10664

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


10670
10671
10672
# File 'lib/google/apis/compute_beta/classes.rb', line 10670

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10677
10678
10679
# File 'lib/google/apis/compute_beta/classes.rb', line 10677

def self_link
  @self_link
end

#size_gbFixnum

Size, in GB, of the persistent disk. You can specify this field when creating a persistent disk using thesourceImage, sourceSnapshot, orsourceDisk parameter, or specify it alone to create an empty persistent disk. If you specify this field along with a source, the value ofsizeGb must not be less than the size of the source. Acceptable values are greater than 0. Corresponds to the JSON property sizeGb

Returns:

  • (Fixnum)


10689
10690
10691
# File 'lib/google/apis/compute_beta/classes.rb', line 10689

def size_gb
  @size_gb
end

#source_consistency_group_policyString

Output only. [Output Only] URL of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group. Corresponds to the JSON property sourceConsistencyGroupPolicy

Returns:

  • (String)


10696
10697
10698
# File 'lib/google/apis/compute_beta/classes.rb', line 10696

def source_consistency_group_policy
  @source_consistency_group_policy
end

#source_consistency_group_policy_idString

Output only. [Output Only] ID of the DiskConsistencyGroupPolicy for a secondary disk that was created using a consistency group. Corresponds to the JSON property sourceConsistencyGroupPolicyId

Returns:

  • (String)


10703
10704
10705
# File 'lib/google/apis/compute_beta/classes.rb', line 10703

def source_consistency_group_policy_id
  @source_consistency_group_policy_id
end

#source_diskString

The source disk used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk

- https://www.googleapis.com/compute/v1/projects/project/regions/region/ disks/disk

- projects/project/zones/zone/disks/disk

- projects/project/regions/region/disks/disk

- zones/zone/disks/disk

- regions/region/disks/disk Corresponds to the JSON property sourceDisk

Returns:

  • (String)


10731
10732
10733
# File 'lib/google/apis/compute_beta/classes.rb', line 10731

def source_disk
  @source_disk
end

#source_disk_idString

Output only. [Output Only] The unique ID of the disk used to create this disk. This value identifies the exact disk that was used to create this persistent disk. For example, if you created the persistent disk from a disk that was later deleted and recreated under the same name, the source disk ID would identify the exact version of the disk that was used. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


10741
10742
10743
# File 'lib/google/apis/compute_beta/classes.rb', line 10741

def source_disk_id
  @source_disk_id
end

#source_imageString

The source image used to create this disk. If the source image is deleted, this field will not be set. To create a disk with one of the public operating system images, specify the image by its family name. For example, specifyfamily/debian-9 to use the latest Debian 9 image: projects/debian-cloud/global/images/family/debian-9 Alternatively, use a specific version of a public operating system image: projects/debian-cloud/global/images/debian-9-stretch-vYYYYMMDD To create a disk with a custom image that you created, specify the image name in the following format: global/images/my-custom-image You can also specify a custom image by its image family, which returns the latest version of the image in that family. Replace the image name with family/family-name: global/images/family/my-image-family Corresponds to the JSON property sourceImage

Returns:

  • (String)


10760
10761
10762
# File 'lib/google/apis/compute_beta/classes.rb', line 10760

def source_image
  @source_image
end

#source_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source image. Required if the source image is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceImageEncryptionKey



10767
10768
10769
# File 'lib/google/apis/compute_beta/classes.rb', line 10767

def source_image_encryption_key
  @source_image_encryption_key
end

#source_image_idString

Output only. [Output Only] The ID value of the image used to create this disk. This value identifies the exact image that was used to create this persistent disk. For example, if you created the persistent disk from an image that was later deleted and recreated under the same name, the source image ID would identify the exact version of the image that was used. Corresponds to the JSON property sourceImageId

Returns:

  • (String)


10777
10778
10779
# File 'lib/google/apis/compute_beta/classes.rb', line 10777

def source_image_id
  @source_image_id
end

#source_instant_snapshotString

The source instant snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10790
10791
10792
# File 'lib/google/apis/compute_beta/classes.rb', line 10790

def source_instant_snapshot
  @source_instant_snapshot
end

#source_instant_snapshot_idString

Output only. [Output Only] The unique ID of the instant snapshot used to create this disk. This value identifies the exact instant snapshot that was used to create this persistent disk. For example, if you created the persistent disk from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact version of the instant snapshot that was used. Corresponds to the JSON property sourceInstantSnapshotId

Returns:

  • (String)


10801
10802
10803
# File 'lib/google/apis/compute_beta/classes.rb', line 10801

def source_instant_snapshot_id
  @source_instant_snapshot_id
end

#source_machine_imageString

The machine image to create the disk from. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10814
10815
10816
# File 'lib/google/apis/compute_beta/classes.rb', line 10814

def source_machine_image
  @source_machine_image
end

#source_machine_image_disk_device_nameString

The device name of a disk within a given machine image. The source_machine_image must be specified. Corresponds to the JSON property sourceMachineImageDiskDeviceName

Returns:

  • (String)


10820
10821
10822
# File 'lib/google/apis/compute_beta/classes.rb', line 10820

def source_machine_image_disk_device_name
  @source_machine_image_disk_device_name
end

#source_machine_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source machine image. Required if the source machine image is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceMachineImageEncryptionKey



10827
10828
10829
# File 'lib/google/apis/compute_beta/classes.rb', line 10827

def source_machine_image_encryption_key
  @source_machine_image_encryption_key
end

#source_machine_image_idString

Output only. [Output Only] The unique ID of the machine image used to create this disk. This value identifies the exact machine image that was used to create this persistent disk. For example, if you created the persistent disk from a machine image that was later deleted and recreated under the same name, the source machine image ID would identify the exact version of the machine image that was used. Corresponds to the JSON property sourceMachineImageId

Returns:

  • (String)


10838
10839
10840
# File 'lib/google/apis/compute_beta/classes.rb', line 10838

def source_machine_image_id
  @source_machine_image_id
end

#source_snapshotString

The source snapshot used to create this disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10851
10852
10853
# File 'lib/google/apis/compute_beta/classes.rb', line 10851

def source_snapshot
  @source_snapshot
end

#source_snapshot_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Thecustomer-supplied encryption key of the source snapshot. Required if the source snapshot is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceSnapshotEncryptionKey



10858
10859
10860
# File 'lib/google/apis/compute_beta/classes.rb', line 10858

def source_snapshot_encryption_key
  @source_snapshot_encryption_key
end

#source_snapshot_idString

Output only. [Output Only] The unique ID of the snapshot used to create this disk. This value identifies the exact snapshot that was used to create this persistent disk. For example, if you created the persistent disk from a snapshot that was later deleted and recreated under the same name, the source snapshot ID would identify the exact version of the snapshot that was used. Corresponds to the JSON property sourceSnapshotId

Returns:

  • (String)


10868
10869
10870
# File 'lib/google/apis/compute_beta/classes.rb', line 10868

def source_snapshot_id
  @source_snapshot_id
end

#source_storage_objectString

The full Google Cloud Storage URI where the disk image is stored. This file must be a gzip-compressed tarball whose name ends in .tar.gz or virtual machine disk whose name ends in vmdk. Valid URIs may start with gs:// or https://storage.googleapis.com/. This flag is not optimized for creating multiple disks from a source storage object. To create many disks from a source storage object, use gcloud compute images import instead. Corresponds to the JSON property sourceStorageObject

Returns:

  • (String)


10879
10880
10881
# File 'lib/google/apis/compute_beta/classes.rb', line 10879

def source_storage_object
  @source_storage_object
end

#statusString

Output only. [Output Only] The status of disk creation.

  • CREATING: Disk is provisioning.
  • RESTORING: Source data is being copied into the disk.
  • FAILED: Disk creation failed.
  • READY: Disk is ready for use.
  • DELETING: Disk is deleting. Corresponds to the JSON property status

Returns:

  • (String)


10892
10893
10894
# File 'lib/google/apis/compute_beta/classes.rb', line 10892

def status
  @status
end

#storage_poolString

The storage pool in which the new disk is created. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


10905
10906
10907
# File 'lib/google/apis/compute_beta/classes.rb', line 10905

def storage_pool
  @storage_pool
end

#storage_typeString

[Deprecated] Storage type of the persistent disk. Corresponds to the JSON property storageType

Returns:

  • (String)


10910
10911
10912
# File 'lib/google/apis/compute_beta/classes.rb', line 10910

def storage_type
  @storage_type
end

#typeString

URL of the disk type resource describing which disk type to use to create the disk. Provide this when creating the disk. For example:projects/project/ zones/zone/diskTypes/pd-ssd. See Persistent disk types. Corresponds to the JSON property type

Returns:

  • (String)


10918
10919
10920
# File 'lib/google/apis/compute_beta/classes.rb', line 10918

def type
  @type
end

#usersArray<String>

Output only. [Output Only] Links to the users of the disk (attached instances) in form:projects/project/zones/zone/instances/instance Corresponds to the JSON property users

Returns:

  • (Array<String>)


10924
10925
10926
# File 'lib/google/apis/compute_beta/classes.rb', line 10924

def users
  @users
end

#zoneString

Output only. [Output Only] URL of the zone where the disk resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


10931
10932
10933
# File 'lib/google/apis/compute_beta/classes.rb', line 10931

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10938
10939
10940
10941
10942
10943
10944
10945
10946
10947
10948
10949
10950
10951
10952
10953
10954
10955
10956
10957
10958
10959
10960
10961
10962
10963
10964
10965
10966
10967
10968
10969
10970
10971
10972
10973
10974
10975
10976
10977
10978
10979
10980
10981
10982
10983
10984
10985
10986
10987
10988
10989
10990
10991
10992
10993
10994
10995
10996
10997
10998
# File 'lib/google/apis/compute_beta/classes.rb', line 10938

def update!(**args)
  @access_mode = args[:access_mode] if args.key?(:access_mode)
  @architecture = args[:architecture] if args.key?(:architecture)
  @async_primary_disk = args[:async_primary_disk] if args.key?(:async_primary_disk)
  @async_secondary_disks = args[:async_secondary_disks] if args.key?(:async_secondary_disks)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_attach_timestamp = args[:last_attach_timestamp] if args.key?(:last_attach_timestamp)
  @last_detach_timestamp = args[:last_detach_timestamp] if args.key?(:last_detach_timestamp)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @locked = args[:locked] if args.key?(:locked)
  @multi_writer = args[:multi_writer] if args.key?(:multi_writer)
  @name = args[:name] if args.key?(:name)
  @options = args[:options] if args.key?(:options)
  @params = args[:params] if args.key?(:params)
  @physical_block_size_bytes = args[:physical_block_size_bytes] if args.key?(:physical_block_size_bytes)
  @provisioned_iops = args[:provisioned_iops] if args.key?(:provisioned_iops)
  @provisioned_throughput = args[:provisioned_throughput] if args.key?(:provisioned_throughput)
  @region = args[:region] if args.key?(:region)
  @replica_zones = args[:replica_zones] if args.key?(:replica_zones)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @size_gb = args[:size_gb] if args.key?(:size_gb)
  @source_consistency_group_policy = args[:source_consistency_group_policy] if args.key?(:source_consistency_group_policy)
  @source_consistency_group_policy_id = args[:source_consistency_group_policy_id] if args.key?(:source_consistency_group_policy_id)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_image = args[:source_image] if args.key?(:source_image)
  @source_image_encryption_key = args[:source_image_encryption_key] if args.key?(:source_image_encryption_key)
  @source_image_id = args[:source_image_id] if args.key?(:source_image_id)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id)
  @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image)
  @source_machine_image_disk_device_name = args[:source_machine_image_disk_device_name] if args.key?(:source_machine_image_disk_device_name)
  @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key)
  @source_machine_image_id = args[:source_machine_image_id] if args.key?(:source_machine_image_id)
  @source_snapshot = args[:source_snapshot] if args.key?(:source_snapshot)
  @source_snapshot_encryption_key = args[:source_snapshot_encryption_key] if args.key?(:source_snapshot_encryption_key)
  @source_snapshot_id = args[:source_snapshot_id] if args.key?(:source_snapshot_id)
  @source_storage_object = args[:source_storage_object] if args.key?(:source_storage_object)
  @status = args[:status] if args.key?(:status)
  @storage_pool = args[:storage_pool] if args.key?(:storage_pool)
  @storage_type = args[:storage_type] if args.key?(:storage_type)
  @type = args[:type] if args.key?(:type)
  @users = args[:users] if args.key?(:users)
  @zone = args[:zone] if args.key?(:zone)
end