Class: Google::Apis::ComputeBeta::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



11245
11246
11247
# File 'lib/google/apis/compute_beta/classes.rb', line 11245

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11206
11207
11208
# File 'lib/google/apis/compute_beta/classes.rb', line 11206

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



11211
11212
11213
# File 'lib/google/apis/compute_beta/classes.rb', line 11211

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


11218
11219
11220
# File 'lib/google/apis/compute_beta/classes.rb', line 11218

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11228
11229
11230
# File 'lib/google/apis/compute_beta/classes.rb', line 11228

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11233
11234
11235
# File 'lib/google/apis/compute_beta/classes.rb', line 11233

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


11238
11239
11240
# File 'lib/google/apis/compute_beta/classes.rb', line 11238

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11243
11244
11245
# File 'lib/google/apis/compute_beta/classes.rb', line 11243

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11250
11251
11252
11253
11254
11255
11256
11257
11258
# File 'lib/google/apis/compute_beta/classes.rb', line 11250

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end