Class: Google::Apis::ComputeBeta::DiskAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::DisksScopedList>
A list of DisksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAggregatedList
constructor
A new instance of DiskAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAggregatedList
Returns a new instance of DiskAggregatedList.
11195 11196 11197 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11195 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11156 11157 11158 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11156 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::DisksScopedList>
A list of DisksScopedList resources.
Corresponds to the JSON property items
11161 11162 11163 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11161 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList
for aggregated lists of persistent
disks.
Corresponds to the JSON property kind
11168 11169 11170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11168 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11178 11179 11180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11178 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11183 11184 11185 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11183 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
11188 11189 11190 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11188 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11193 11194 11195 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11193 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11200 11201 11202 11203 11204 11205 11206 11207 11208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11200 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |