Class: Google::Apis::ComputeBeta::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



11047
11048
11049
# File 'lib/google/apis/compute_beta/classes.rb', line 11047

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11008
11009
11010
# File 'lib/google/apis/compute_beta/classes.rb', line 11008

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



11013
11014
11015
# File 'lib/google/apis/compute_beta/classes.rb', line 11013

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


11020
11021
11022
# File 'lib/google/apis/compute_beta/classes.rb', line 11020

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11030
11031
11032
# File 'lib/google/apis/compute_beta/classes.rb', line 11030

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11035
11036
11037
# File 'lib/google/apis/compute_beta/classes.rb', line 11035

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


11040
11041
11042
# File 'lib/google/apis/compute_beta/classes.rb', line 11040

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11045
11046
11047
# File 'lib/google/apis/compute_beta/classes.rb', line 11045

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11052
11053
11054
11055
11056
11057
11058
11059
11060
# File 'lib/google/apis/compute_beta/classes.rb', line 11052

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end