Class: Google::Apis::ComputeBeta::DiskAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::DisksScopedList>
A list of DisksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAggregatedList
constructor
A new instance of DiskAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAggregatedList
Returns a new instance of DiskAggregatedList.
11023 11024 11025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11023 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10984 10985 10986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10984 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::DisksScopedList>
A list of DisksScopedList resources.
Corresponds to the JSON property items
10989 10990 10991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10989 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList
for aggregated lists of persistent
disks.
Corresponds to the JSON property kind
10996 10997 10998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10996 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11006 11007 11008 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11006 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
11011 11012 11013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11011 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
11016 11017 11018 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11016 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
11021 11022 11023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11021 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11028 11029 11030 11031 11032 11033 11034 11035 11036 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11028 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |