Class: Google::Apis::ComputeBeta::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



10499
10500
10501
# File 'lib/google/apis/compute_beta/classes.rb', line 10499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10460
10461
10462
# File 'lib/google/apis/compute_beta/classes.rb', line 10460

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



10465
10466
10467
# File 'lib/google/apis/compute_beta/classes.rb', line 10465

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


10472
10473
10474
# File 'lib/google/apis/compute_beta/classes.rb', line 10472

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10482
10483
10484
# File 'lib/google/apis/compute_beta/classes.rb', line 10482

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10487
10488
10489
# File 'lib/google/apis/compute_beta/classes.rb', line 10487

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10492
10493
10494
# File 'lib/google/apis/compute_beta/classes.rb', line 10492

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10497
10498
10499
# File 'lib/google/apis/compute_beta/classes.rb', line 10497

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10504
10505
10506
10507
10508
10509
10510
10511
10512
# File 'lib/google/apis/compute_beta/classes.rb', line 10504

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end