Class: Google::Apis::ComputeBeta::DiskAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::DisksScopedList>
A list of DisksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAggregatedList
constructor
A new instance of DiskAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAggregatedList
Returns a new instance of DiskAggregatedList.
10364 10365 10366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10325 10326 10327 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10325 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::DisksScopedList>
A list of DisksScopedList resources.
Corresponds to the JSON property items
10330 10331 10332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10330 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList
for aggregated lists of persistent
disks.
Corresponds to the JSON property kind
10337 10338 10339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10337 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10347 10348 10349 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10347 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10352 10353 10354 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10352 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
10357 10358 10359 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10357 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::DiskAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10362 10363 10364 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10362 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10369 10370 10371 10372 10373 10374 10375 10376 10377 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10369 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |