Class: Google::Apis::ComputeBeta::DiskAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskAggregatedList

Returns a new instance of DiskAggregatedList.



10070
10071
10072
# File 'lib/google/apis/compute_beta/classes.rb', line 10070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


10031
10032
10033
# File 'lib/google/apis/compute_beta/classes.rb', line 10031

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::DisksScopedList>

A list of DisksScopedList resources. Corresponds to the JSON property items



10036
10037
10038
# File 'lib/google/apis/compute_beta/classes.rb', line 10036

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#diskAggregatedList for aggregated lists of persistent disks. Corresponds to the JSON property kind

Returns:

  • (String)


10043
10044
10045
# File 'lib/google/apis/compute_beta/classes.rb', line 10043

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


10053
10054
10055
# File 'lib/google/apis/compute_beta/classes.rb', line 10053

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


10058
10059
10060
# File 'lib/google/apis/compute_beta/classes.rb', line 10058

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


10063
10064
10065
# File 'lib/google/apis/compute_beta/classes.rb', line 10063

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::DiskAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



10068
10069
10070
# File 'lib/google/apis/compute_beta/classes.rb', line 10068

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10075
10076
10077
10078
10079
10080
10081
10082
10083
# File 'lib/google/apis/compute_beta/classes.rb', line 10075

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end