Class: Google::Apis::ComputeBeta::DiskAsyncReplication
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskAsyncReplication
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#consistency_group_policy ⇒ String
Output only.
-
#consistency_group_policy_id ⇒ String
Output only.
-
#disk ⇒ String
The other disk asynchronously replicated to or from the current disk.
-
#disk_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskAsyncReplication
constructor
A new instance of DiskAsyncReplication.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskAsyncReplication
Returns a new instance of DiskAsyncReplication.
10492 10493 10494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consistency_group_policy ⇒ String
Output only. [Output Only] URL of the DiskConsistencyGroupPolicy if
replication was
started on the disk as a member of a group.
Corresponds to the JSON property consistencyGroupPolicy
10459 10460 10461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10459 def consistency_group_policy @consistency_group_policy end |
#consistency_group_policy_id ⇒ String
Output only. [Output Only] ID of the DiskConsistencyGroupPolicy if replication
was
started on the disk as a member of a group.
Corresponds to the JSON property consistencyGroupPolicyId
10466 10467 10468 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10466 def consistency_group_policy_id @consistency_group_policy_id end |
#disk ⇒ String
The other disk asynchronously replicated to or from the current disk. You can provide this as a partial or full URL to the resource. For example, the following are valid values:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk
- projects/project/zones/zone/disks/disk
- zones/zone/disks/disk
Corresponds to the JSON property
disk
10479 10480 10481 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10479 def disk @disk end |
#disk_id ⇒ String
Output only. [Output Only] The unique ID of the other disk asynchronously
replicated
to or from the current disk. This value identifies the exact disk that
was used to create this replication. For example, if you started
replicating the persistent disk from a disk that was later deleted and
recreated under the same name, the disk ID would identify the exact
version of the disk that was used.
Corresponds to the JSON property diskId
10490 10491 10492 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10490 def disk_id @disk_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10497 10498 10499 10500 10501 10502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10497 def update!(**args) @consistency_group_policy = args[:consistency_group_policy] if args.key?(:consistency_group_policy) @consistency_group_policy_id = args[:consistency_group_policy_id] if args.key?(:consistency_group_policy_id) @disk = args[:disk] if args.key?(:disk) @disk_id = args[:disk_id] if args.key?(:disk_id) end |