Class: Google::Apis::ComputeBeta::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



11305
11306
11307
# File 'lib/google/apis/compute_beta/classes.rb', line 11305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11272
11273
11274
# File 'lib/google/apis/compute_beta/classes.rb', line 11272

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Disk>

A list of Disk resources. Corresponds to the JSON property items



11277
11278
11279
# File 'lib/google/apis/compute_beta/classes.rb', line 11277

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


11283
11284
11285
# File 'lib/google/apis/compute_beta/classes.rb', line 11283

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11293
11294
11295
# File 'lib/google/apis/compute_beta/classes.rb', line 11293

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11298
11299
11300
# File 'lib/google/apis/compute_beta/classes.rb', line 11298

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11303
11304
11305
# File 'lib/google/apis/compute_beta/classes.rb', line 11303

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11310
11311
11312
11313
11314
11315
11316
11317
# File 'lib/google/apis/compute_beta/classes.rb', line 11310

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end