Class: Google::Apis::ComputeBeta::DiskList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of Disk resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskList

Returns a new instance of DiskList.



11281
11282
11283
# File 'lib/google/apis/compute_beta/classes.rb', line 11281

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11248
11249
11250
# File 'lib/google/apis/compute_beta/classes.rb', line 11248

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Disk>

A list of Disk resources. Corresponds to the JSON property items



11253
11254
11255
# File 'lib/google/apis/compute_beta/classes.rb', line 11253

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#diskList for lists of disks. Corresponds to the JSON property kind

Returns:

  • (String)


11259
11260
11261
# File 'lib/google/apis/compute_beta/classes.rb', line 11259

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11269
11270
11271
# File 'lib/google/apis/compute_beta/classes.rb', line 11269

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11274
11275
11276
# File 'lib/google/apis/compute_beta/classes.rb', line 11274

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::DiskList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11279
11280
11281
# File 'lib/google/apis/compute_beta/classes.rb', line 11279

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11286
11287
11288
11289
11290
11291
11292
11293
# File 'lib/google/apis/compute_beta/classes.rb', line 11286

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end