Class: Google::Apis::ComputeBeta::DiskList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of Disk resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Disk>
A list of Disk resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::DiskList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskList
constructor
A new instance of DiskList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskList
Returns a new instance of DiskList.
10757 10758 10759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10757 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
10724 10725 10726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10724 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Disk>
A list of Disk resources.
Corresponds to the JSON property items
10729 10730 10731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10729 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#diskList for
lists of disks.
Corresponds to the JSON property kind
10735 10736 10737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10735 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
10745 10746 10747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10745 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
10750 10751 10752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10750 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::DiskList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
10755 10756 10757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10755 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10762 10763 10764 10765 10766 10767 10768 10769 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10762 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |