Class: Google::Apis::ComputeBeta::DiskParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Additional disk params.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to be bound to the disk.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskParams
constructor
A new instance of DiskParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskParams
Returns a new instance of DiskParams.
10464 10465 10466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to be bound to the disk. Tag keys and values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/456` or in namespaced
format such asorg_id|project_id/tag_key_short_nameand
tag_value_short_name`. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON propertyresourceManagerTags`
10462 10463 10464 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10462 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10469 10470 10471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10469 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |