Class: Google::Apis::ComputeBeta::DiskType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:
- Regional
- Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
-
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskType
constructor
A new instance of DiskType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskType
Returns a new instance of DiskType.
11813 11814 11815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
11753 11754 11755 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11753 def @creation_timestamp end |
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
Corresponds to the JSON property defaultDiskSizeGb
11758 11759 11760 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11758 def default_disk_size_gb @default_disk_size_gb end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
11763 11764 11765 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11763 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional description of this resource.
Corresponds to the JSON property description
11768 11769 11770 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11768 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
11774 11775 11776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11774 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#diskType
for disk types.
Corresponds to the JSON property kind
11780 11781 11782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11780 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
11785 11786 11787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11785 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the disk type resides. Only
applicable for regional resources.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
11793 11794 11795 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11793 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
11798 11799 11800 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11798 def self_link @self_link end |
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size,
such as "10GB-10TB".
Corresponds to the JSON property validDiskSize
11804 11805 11806 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11804 def valid_disk_size @valid_disk_size end |
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
11811 11812 11813 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11811 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11818 11819 11820 11821 11822 11823 11824 11825 11826 11827 11828 11829 11830 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11818 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size) @zone = args[:zone] if args.key?(:zone) end |