Class: Google::Apis::ComputeBeta::DiskType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:
- Regional
- Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
-
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskType
constructor
A new instance of DiskType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskType
Returns a new instance of DiskType.
11790 11791 11792 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
11730 11731 11732 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11730 def @creation_timestamp end |
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
Corresponds to the JSON property defaultDiskSizeGb
11735 11736 11737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11735 def default_disk_size_gb @default_disk_size_gb end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
11740 11741 11742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11740 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional description of this resource.
Corresponds to the JSON property description
11745 11746 11747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11745 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
11751 11752 11753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11751 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#diskType
for disk types.
Corresponds to the JSON property kind
11757 11758 11759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11757 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
11762 11763 11764 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11762 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the disk type resides. Only
applicable for regional resources.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
11770 11771 11772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11770 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
11775 11776 11777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11775 def self_link @self_link end |
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size,
such as "10GB-10TB".
Corresponds to the JSON property validDiskSize
11781 11782 11783 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11781 def valid_disk_size @valid_disk_size end |
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
11788 11789 11790 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11788 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 11806 11807 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11795 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size) @zone = args[:zone] if args.key?(:zone) end |