Class: Google::Apis::ComputeBeta::DiskType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:

  • Regional
  • Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskType

Returns a new instance of DiskType.



11665
11666
11667
# File 'lib/google/apis/compute_beta/classes.rb', line 11665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


11605
11606
11607
# File 'lib/google/apis/compute_beta/classes.rb', line 11605

def creation_timestamp
  @creation_timestamp
end

#default_disk_size_gbFixnum

[Output Only] Server-defined default disk size in GB. Corresponds to the JSON property defaultDiskSizeGb

Returns:

  • (Fixnum)


11610
11611
11612
# File 'lib/google/apis/compute_beta/classes.rb', line 11610

def default_disk_size_gb
  @default_disk_size_gb
end

#deprecatedGoogle::Apis::ComputeBeta::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



11615
11616
11617
# File 'lib/google/apis/compute_beta/classes.rb', line 11615

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


11620
11621
11622
# File 'lib/google/apis/compute_beta/classes.rb', line 11620

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


11626
11627
11628
# File 'lib/google/apis/compute_beta/classes.rb', line 11626

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#diskType for disk types. Corresponds to the JSON property kind

Returns:

  • (String)


11632
11633
11634
# File 'lib/google/apis/compute_beta/classes.rb', line 11632

def kind
  @kind
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


11637
11638
11639
# File 'lib/google/apis/compute_beta/classes.rb', line 11637

def name
  @name
end

#regionString

[Output Only] URL of the region where the disk type resides. Only applicable for regional resources. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


11645
11646
11647
# File 'lib/google/apis/compute_beta/classes.rb', line 11645

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11650
11651
11652
# File 'lib/google/apis/compute_beta/classes.rb', line 11650

def self_link
  @self_link
end

#valid_disk_sizeString

[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB". Corresponds to the JSON property validDiskSize

Returns:

  • (String)


11656
11657
11658
# File 'lib/google/apis/compute_beta/classes.rb', line 11656

def valid_disk_size
  @valid_disk_size
end

#zoneString

[Output Only] URL of the zone where the disk type resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


11663
11664
11665
# File 'lib/google/apis/compute_beta/classes.rb', line 11663

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11670
11671
11672
11673
11674
11675
11676
11677
11678
11679
11680
11681
11682
# File 'lib/google/apis/compute_beta/classes.rb', line 11670

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size)
  @zone = args[:zone] if args.key?(:zone)
end