Class: Google::Apis::ComputeBeta::DiskType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Disk Type resource. Google Compute Engine has two Disk Type resources:
- Regional
- Zonal You can choose from a variety of disk types based on your needs. For more information, readStorage options. The diskTypes resource represents disk types for a zonal persistent disk. For more information, readZonal persistent disks. The regionDiskTypes resource represents disk types for a regional persistent disk. For more information, read Regional persistent disks.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] URL of the region where the disk type resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size, such as "10GB-10TB".
-
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskType
constructor
A new instance of DiskType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskType
Returns a new instance of DiskType.
10982 10983 10984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
10922 10923 10924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10922 def @creation_timestamp end |
#default_disk_size_gb ⇒ Fixnum
[Output Only] Server-defined default disk size in GB.
Corresponds to the JSON property defaultDiskSizeGb
10927 10928 10929 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10927 def default_disk_size_gb @default_disk_size_gb end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
10932 10933 10934 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10932 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional description of this resource.
Corresponds to the JSON property description
10937 10938 10939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10937 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
10943 10944 10945 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10943 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#diskType
for disk types.
Corresponds to the JSON property kind
10949 10950 10951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10949 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
10954 10955 10956 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10954 def name @name end |
#region ⇒ String
[Output Only] URL of the region where the disk type resides. Only
applicable for regional resources.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
10962 10963 10964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10962 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
10967 10968 10969 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10967 def self_link @self_link end |
#valid_disk_size ⇒ String
[Output Only] An optional textual description of the valid disk size,
such as "10GB-10TB".
Corresponds to the JSON property validDiskSize
10973 10974 10975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10973 def valid_disk_size @valid_disk_size end |
#zone ⇒ String
[Output Only] URL of the zone where the disk type resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
10980 10981 10982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10980 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10987 10988 10989 10990 10991 10992 10993 10994 10995 10996 10997 10998 10999 |
# File 'lib/google/apis/compute_beta/classes.rb', line 10987 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_disk_size_gb = args[:default_disk_size_gb] if args.key?(:default_disk_size_gb) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @valid_disk_size = args[:valid_disk_size] if args.key?(:valid_disk_size) @zone = args[:zone] if args.key?(:zone) end |