Class: Google::Apis::ComputeBeta::DiskUpdateKmsKeyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DiskUpdateKmsKeyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#kms_key_name ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiskUpdateKmsKeyRequest
constructor
A new instance of DiskUpdateKmsKeyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiskUpdateKmsKeyRequest
Returns a new instance of DiskUpdateKmsKeyRequest.
11508 11509 11510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kms_key_name ⇒ String
Optional. The new KMS key to replace the current one on the disk. If empty, the disk will be re-encrypted using the primary version of the disk's current KMS key. The KMS key can be provided in the following formats:
- projects/project_id/locations/location/keyRings/key_ring/cryptoKeys/key
Where project is the project ID or
project number.
Corresponds to the JSON property
kmsKeyName
11506 11507 11508 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11506 def kms_key_name @kms_key_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11513 11514 11515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11513 def update!(**args) @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name) end |