Class: Google::Apis::ComputeBeta::DistributionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DistributionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy. instanceRedistributionType).
-
#zones ⇒ Array<Google::Apis::ComputeBeta::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage its instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DistributionPolicy
constructor
A new instance of DistributionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DistributionPolicy
Returns a new instance of DistributionPolicy.
12536 12537 12538 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12536 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or
on resize events (depending on the value set inupdatePolicy.
instanceRedistributionType).
Corresponds to the JSON property targetShape
12523 12524 12525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12523 def target_shape @target_shape end |
#zones ⇒ Array<Google::Apis::ComputeBeta::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage
its instances.
By default, a regional MIG doesn't automatically select an AI zone to create
instances, even if an AI zone is available in the specified region. To
create instances in an AI zone in the selected region, you must explicitly
specify it in the distribution policy together with the other preferred
zones.
Corresponds to the JSON property zones
12534 12535 12536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12534 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12541 12542 12543 12544 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12541 def update!(**args) @target_shape = args[:target_shape] if args.key?(:target_shape) @zones = args[:zones] if args.key?(:zones) end |