Class: Google::Apis::ComputeBeta::DistributionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DistributionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy. instanceRedistributionType).
-
#zones ⇒ Array<Google::Apis::ComputeBeta::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage its instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DistributionPolicy
constructor
A new instance of DistributionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DistributionPolicy
Returns a new instance of DistributionPolicy.
11790 11791 11792 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or
on resize events (depending on the value set inupdatePolicy.
instanceRedistributionType).
Corresponds to the JSON property targetShape
11777 11778 11779 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11777 def target_shape @target_shape end |
#zones ⇒ Array<Google::Apis::ComputeBeta::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage
its instances.
By default, a regional MIG doesn't automatically select an AI zone to create
instances, even if an AI zone is available in the specified region. To
create instances in an AI zone in the selected region, you must explicitly
specify it in the distribution policy together with the other preferred
zones.
Corresponds to the JSON property zones
11788 11789 11790 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11788 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11795 11796 11797 11798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11795 def update!(**args) @target_shape = args[:target_shape] if args.key?(:target_shape) @zones = args[:zones] if args.key?(:zones) end |