Class: Google::Apis::ComputeBeta::DistributionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::DistributionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or on resize events (depending on the value set inupdatePolicy. instanceRedistributionType).
-
#zones ⇒ Array<Google::Apis::ComputeBeta::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage its instances.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DistributionPolicy
constructor
A new instance of DistributionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DistributionPolicy
Returns a new instance of DistributionPolicy.
11328 11329 11330 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11328 def initialize(**args) update!(**args) end |
Instance Attribute Details
#target_shape ⇒ String
The distribution shape to which the group converges either proactively or
on resize events (depending on the value set inupdatePolicy.
instanceRedistributionType).
Corresponds to the JSON property targetShape
11320 11321 11322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11320 def target_shape @target_shape end |
#zones ⇒ Array<Google::Apis::ComputeBeta::DistributionPolicyZoneConfiguration>
Zones where the regional managed instance group will create and manage
its instances.
Corresponds to the JSON property zones
11326 11327 11328 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11326 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
11333 11334 11335 11336 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11333 def update!(**args) @target_shape = args[:target_shape] if args.key?(:target_shape) @zones = args[:zones] if args.key?(:zones) end |