Class: Google::Apis::ComputeBeta::Duration
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Duration
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years.
Instance Attribute Summary collapse
-
#nanos ⇒ Fixnum
Span of time that's a fraction of a second at nanosecond resolution.
-
#seconds ⇒ Fixnum
Span of time at a resolution of a second.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Duration
constructor
A new instance of Duration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Duration
Returns a new instance of Duration.
12590 12591 12592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#nanos ⇒ Fixnum
Span of time that's a fraction of a second at nanosecond resolution.
Durations less than one second are represented with a 0
seconds field and a positive nanos field. Must be from 0
to 999,999,999 inclusive.
Corresponds to the JSON property nanos
12581 12582 12583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12581 def nanos @nanos end |
#seconds ⇒ Fixnum
Span of time at a resolution of a second. Must be from 0
to 315,576,000,000 inclusive. Note: these bounds are computed from:
60 sec/min * 60 min/hr * 24 hr/day * 365.25 days/year * 10000 years
Corresponds to the JSON property seconds
12588 12589 12590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12588 def seconds @seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12595 12596 12597 12598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12595 def update!(**args) @nanos = args[:nanos] if args.key?(:nanos) @seconds = args[:seconds] if args.key?(:seconds) end |