Class: Google::Apis::ComputeBeta::ErrorInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: "reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": "projects/123", "service": "pubsub.googleapis.com" This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata": "availableRegions": "us-central1,us-east2"

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorInfo

Returns a new instance of ErrorInfo.



12432
12433
12434
# File 'lib/google/apis/compute_beta/classes.rb', line 12432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#domainString

The logical grouping to which the "reason" belongs. The error domain is typically the registered service name of the tool or product that generates the error. Example: "pubsub.googleapis.com". If the error is generated by some common infrastructure, the error domain must be a globally unique value that identifies the infrastructure. For Google API infrastructure, the error domain is "googleapis.com". Corresponds to the JSON property domain

Returns:

  • (String)


12409
12410
12411
# File 'lib/google/apis/compute_beta/classes.rb', line 12409

def domain
  @domain
end

#metadatasHash<String,String>

Additional structured details about this error. Keys must match a regular expression of a-z+ but should ideally be lowerCamelCase. Also, they must be limited to 64 characters in length. When identifying the current value of an exceeded limit, the units should be contained in the key, not the value. For example, rather than "instanceLimit": "100/request", should be returned as, "instanceLimitPerRequest": "100", if the client exceeds the number of instances that can be created in a single (batch) request. Corresponds to the JSON property metadatas

Returns:

  • (Hash<String,String>)


12421
12422
12423
# File 'lib/google/apis/compute_beta/classes.rb', line 12421

def metadatas
  @metadatas
end

#reasonString

The reason of the error. This is a constant value that identifies the proximate cause of the error. Error reasons are unique within a particular domain of errors. This should be at most 63 characters and match a regular expression of A-Z+[A-Z0-9], which represents UPPER_SNAKE_CASE. Corresponds to the JSON property reason

Returns:

  • (String)


12430
12431
12432
# File 'lib/google/apis/compute_beta/classes.rb', line 12430

def reason
  @reason
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12437
12438
12439
12440
12441
# File 'lib/google/apis/compute_beta/classes.rb', line 12437

def update!(**args)
  @domain = args[:domain] if args.key?(:domain)
  @metadatas = args[:metadatas] if args.key?(:metadatas)
  @reason = args[:reason] if args.key?(:reason)
end