Class: Google::Apis::ComputeBeta::ExchangedPeeringRoute

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoute

Returns a new instance of ExchangedPeeringRoute.



12478
12479
12480
# File 'lib/google/apis/compute_beta/classes.rb', line 12478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_rangeString

The destination range of the route. Corresponds to the JSON property destRange

Returns:

  • (String)


12451
12452
12453
# File 'lib/google/apis/compute_beta/classes.rb', line 12451

def dest_range
  @dest_range
end

#importedBoolean Also known as: imported?

True if the peering route has been imported from a peer. The actual import happens if the field networkPeering.importCustomRoutes is true for this network, and networkPeering.exportCustomRoutes is true for the peer network, and the import does not result in a route conflict. Corresponds to the JSON property imported

Returns:

  • (Boolean)


12460
12461
12462
# File 'lib/google/apis/compute_beta/classes.rb', line 12460

def imported
  @imported
end

#next_hop_regionString

The region of peering route next hop, only applies to dynamic routes. Corresponds to the JSON property nextHopRegion

Returns:

  • (String)


12466
12467
12468
# File 'lib/google/apis/compute_beta/classes.rb', line 12466

def next_hop_region
  @next_hop_region
end

#priorityFixnum

The priority of the peering route. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


12471
12472
12473
# File 'lib/google/apis/compute_beta/classes.rb', line 12471

def priority
  @priority
end

#typeString

The type of the peering route. Corresponds to the JSON property type

Returns:

  • (String)


12476
12477
12478
# File 'lib/google/apis/compute_beta/classes.rb', line 12476

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12483
12484
12485
12486
12487
12488
12489
# File 'lib/google/apis/compute_beta/classes.rb', line 12483

def update!(**args)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @imported = args[:imported] if args.key?(:imported)
  @next_hop_region = args[:next_hop_region] if args.key?(:next_hop_region)
  @priority = args[:priority] if args.key?(:priority)
  @type = args[:type] if args.key?(:type)
end