Class: Google::Apis::ComputeBeta::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



12755
12756
12757
# File 'lib/google/apis/compute_beta/classes.rb', line 12755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12721
12722
12723
# File 'lib/google/apis/compute_beta/classes.rb', line 12721

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



12726
12727
12728
# File 'lib/google/apis/compute_beta/classes.rb', line 12726

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


12733
12734
12735
# File 'lib/google/apis/compute_beta/classes.rb', line 12733

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12743
12744
12745
# File 'lib/google/apis/compute_beta/classes.rb', line 12743

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12748
12749
12750
# File 'lib/google/apis/compute_beta/classes.rb', line 12748

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12753
12754
12755
# File 'lib/google/apis/compute_beta/classes.rb', line 12753

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12760
12761
12762
12763
12764
12765
12766
12767
# File 'lib/google/apis/compute_beta/classes.rb', line 12760

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end