Class: Google::Apis::ComputeBeta::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



12705
12706
12707
# File 'lib/google/apis/compute_beta/classes.rb', line 12705

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12671
12672
12673
# File 'lib/google/apis/compute_beta/classes.rb', line 12671

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



12676
12677
12678
# File 'lib/google/apis/compute_beta/classes.rb', line 12676

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


12683
12684
12685
# File 'lib/google/apis/compute_beta/classes.rb', line 12683

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12693
12694
12695
# File 'lib/google/apis/compute_beta/classes.rb', line 12693

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12698
12699
12700
# File 'lib/google/apis/compute_beta/classes.rb', line 12698

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12703
12704
12705
# File 'lib/google/apis/compute_beta/classes.rb', line 12703

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12710
12711
12712
12713
12714
12715
12716
12717
# File 'lib/google/apis/compute_beta/classes.rb', line 12710

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end