Class: Google::Apis::ComputeBeta::ExchangedPeeringRoutesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangedPeeringRoutesList

Returns a new instance of ExchangedPeeringRoutesList.



12682
12683
12684
# File 'lib/google/apis/compute_beta/classes.rb', line 12682

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12648
12649
12650
# File 'lib/google/apis/compute_beta/classes.rb', line 12648

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ExchangedPeeringRoute>

A list of ExchangedPeeringRoute resources. Corresponds to the JSON property items



12653
12654
12655
# File 'lib/google/apis/compute_beta/classes.rb', line 12653

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# exchangedPeeringRoutesList for exchanged peering routes lists. Corresponds to the JSON property kind

Returns:

  • (String)


12660
12661
12662
# File 'lib/google/apis/compute_beta/classes.rb', line 12660

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12670
12671
12672
# File 'lib/google/apis/compute_beta/classes.rb', line 12670

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12675
12676
12677
# File 'lib/google/apis/compute_beta/classes.rb', line 12675

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12680
12681
12682
# File 'lib/google/apis/compute_beta/classes.rb', line 12680

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12687
12688
12689
12690
12691
12692
12693
12694
# File 'lib/google/apis/compute_beta/classes.rb', line 12687

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end