Class: Google::Apis::ComputeBeta::ExchangedPeeringRoutesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ExchangedPeeringRoutesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangedPeeringRoutesList
constructor
A new instance of ExchangedPeeringRoutesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangedPeeringRoutesList
Returns a new instance of ExchangedPeeringRoutesList.
12557 12558 12559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12523 12524 12525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12523 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
Corresponds to the JSON property items
12528 12529 12530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12528 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
exchangedPeeringRoutesList for exchanged peering
routes lists.
Corresponds to the JSON property kind
12535 12536 12537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12535 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12545 12546 12547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12545 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12550 12551 12552 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12550 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12555 12556 12557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12555 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12562 12563 12564 12565 12566 12567 12568 12569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12562 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |