Class: Google::Apis::ComputeBeta::ExchangedPeeringRoutesList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ExchangedPeeringRoutesList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExchangedPeeringRoutesList
constructor
A new instance of ExchangedPeeringRoutesList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExchangedPeeringRoutesList
Returns a new instance of ExchangedPeeringRoutesList.
12009 12010 12011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
11975 11976 11977 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11975 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ExchangedPeeringRoute>
A list of ExchangedPeeringRoute resources.
Corresponds to the JSON property items
11980 11981 11982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11980 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
exchangedPeeringRoutesList for exchanged peering
routes lists.
Corresponds to the JSON property kind
11987 11988 11989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11987 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
11997 11998 11999 |
# File 'lib/google/apis/compute_beta/classes.rb', line 11997 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12002 12003 12004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12002 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ExchangedPeeringRoutesList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12007 12008 12009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12007 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12014 12015 12016 12017 12018 12019 12020 12021 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12014 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |