Class: Google::Apis::ComputeBeta::ExternalVpnGateway
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ExternalVpnGateway
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an external VPN gateway. External VPN gateway is the on-premises VPN gateway(s) or another cloud provider's VPN gateway that connects to your Google Cloud VPN gateway. To create a highly available VPN from Google Cloud Platform to your VPN gateway or another cloud provider's VPN gateway, you must create a external VPN gateway resource with information about the other gateway. For more information about using external VPN gateways, see Creating an HA VPN gateway and tunnel pair to a peer VPN.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#interfaces ⇒ Array<Google::Apis::ComputeBeta::ExternalVpnGatewayInterface>
A list of interfaces for this external VPN gateway.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this ExternalVpnGateway, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeBeta::ExternalVpnGatewayParams
Input only.
-
#redundancy_type ⇒ String
Indicates the user-supplied redundancy type of this external VPN gateway.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGateway
constructor
A new instance of ExternalVpnGateway.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGateway
Returns a new instance of ExternalVpnGateway.
12250 12251 12252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12250 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
12172 12173 12174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12172 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
12178 12179 12180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12178 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
12185 12186 12187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12185 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeBeta::ExternalVpnGatewayInterface>
A list of interfaces for this external VPN gateway.
If your peer-side gateway is an on-premises gateway and non-AWS cloud
providers' gateway, at most two interfaces can be provided for an external
VPN gateway. If your peer side is an AWS virtual private gateway, four
interfaces should be provided for an external VPN gateway.
Corresponds to the JSON property interfaces
12194 12195 12196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12194 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
externalVpnGateway for externalVpnGateways.
Corresponds to the JSON property kind
12200 12201 12202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12200 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this ExternalVpnGateway,
which is essentially a hash of the labels set used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an ExternalVpnGateway.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
12213 12214 12215 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12213 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
12220 12221 12222 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12220 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
12231 12232 12233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12231 def name @name end |
#params ⇒ Google::Apis::ComputeBeta::ExternalVpnGatewayParams
Input only. [Input Only] Additional params passed with the request, but not
persisted
as part of resource payload.
Corresponds to the JSON property params
12238 12239 12240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12238 def params @params end |
#redundancy_type ⇒ String
Indicates the user-supplied redundancy type of this external VPN gateway.
Corresponds to the JSON property redundancyType
12243 12244 12245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12243 def redundancy_type @redundancy_type end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
12248 12249 12250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12248 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12255 12256 12257 12258 12259 12260 12261 12262 12263 12264 12265 12266 12267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12255 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @redundancy_type = args[:redundancy_type] if args.key?(:redundancy_type) @self_link = args[:self_link] if args.key?(:self_link) end |