Class: Google::Apis::ComputeBeta::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



13106
13107
13108
# File 'lib/google/apis/compute_beta/classes.rb', line 13106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


13068
13069
13070
# File 'lib/google/apis/compute_beta/classes.rb', line 13068

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13073
13074
13075
# File 'lib/google/apis/compute_beta/classes.rb', line 13073

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



13078
13079
13080
# File 'lib/google/apis/compute_beta/classes.rb', line 13078

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


13084
13085
13086
# File 'lib/google/apis/compute_beta/classes.rb', line 13084

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13094
13095
13096
# File 'lib/google/apis/compute_beta/classes.rb', line 13094

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


13099
13100
13101
# File 'lib/google/apis/compute_beta/classes.rb', line 13099

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13104
13105
13106
# File 'lib/google/apis/compute_beta/classes.rb', line 13104

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13111
13112
13113
13114
13115
13116
13117
13118
13119
# File 'lib/google/apis/compute_beta/classes.rb', line 13111

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end