Class: Google::Apis::ComputeBeta::ExternalVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ExternalVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of externalVpnGateways.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ExternalVpnGatewayList
constructor
A new instance of ExternalVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ExternalVpnGatewayList
Returns a new instance of ExternalVpnGatewayList.
13033 13034 13035 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13033 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
12995 12996 12997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12995 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13000 13001 13002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13000 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ExternalVpnGateway>
A list of ExternalVpnGateway resources.
Corresponds to the JSON property items
13005 13006 13007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13005 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
externalVpnGatewayList for lists of externalVpnGateways.
Corresponds to the JSON property kind
13011 13012 13013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13011 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13021 13022 13023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13021 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
13026 13027 13028 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13026 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ExternalVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13031 13032 13033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13031 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13038 13039 13040 13041 13042 13043 13044 13045 13046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13038 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |