Class: Google::Apis::ComputeBeta::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



12884
12885
12886
# File 'lib/google/apis/compute_beta/classes.rb', line 12884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


12846
12847
12848
# File 'lib/google/apis/compute_beta/classes.rb', line 12846

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12851
12852
12853
# File 'lib/google/apis/compute_beta/classes.rb', line 12851

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



12856
12857
12858
# File 'lib/google/apis/compute_beta/classes.rb', line 12856

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


12862
12863
12864
# File 'lib/google/apis/compute_beta/classes.rb', line 12862

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12872
12873
12874
# File 'lib/google/apis/compute_beta/classes.rb', line 12872

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12877
12878
12879
# File 'lib/google/apis/compute_beta/classes.rb', line 12877

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12882
12883
12884
# File 'lib/google/apis/compute_beta/classes.rb', line 12882

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12889
12890
12891
12892
12893
12894
12895
12896
12897
# File 'lib/google/apis/compute_beta/classes.rb', line 12889

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end