Class: Google::Apis::ComputeBeta::ExternalVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of externalVpnGateways.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExternalVpnGatewayList

Returns a new instance of ExternalVpnGatewayList.



11890
11891
11892
# File 'lib/google/apis/compute_beta/classes.rb', line 11890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


11852
11853
11854
# File 'lib/google/apis/compute_beta/classes.rb', line 11852

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


11857
11858
11859
# File 'lib/google/apis/compute_beta/classes.rb', line 11857

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ExternalVpnGateway>

A list of ExternalVpnGateway resources. Corresponds to the JSON property items



11862
11863
11864
# File 'lib/google/apis/compute_beta/classes.rb', line 11862

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# externalVpnGatewayList for lists of externalVpnGateways. Corresponds to the JSON property kind

Returns:

  • (String)


11868
11869
11870
# File 'lib/google/apis/compute_beta/classes.rb', line 11868

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


11878
11879
11880
# File 'lib/google/apis/compute_beta/classes.rb', line 11878

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


11883
11884
11885
# File 'lib/google/apis/compute_beta/classes.rb', line 11883

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ExternalVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



11888
11889
11890
# File 'lib/google/apis/compute_beta/classes.rb', line 11888

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11895
11896
11897
11898
11899
11900
11901
11902
11903
# File 'lib/google/apis/compute_beta/classes.rb', line 11895

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end