Class: Google::Apis::ComputeBeta::Firewall
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Firewall
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, readFirewall rules.
Defined Under Namespace
Instance Attribute Summary collapse
-
#allowed ⇒ Array<Google::Apis::ComputeBeta::Firewall::Allowed>
The list of ALLOW rules specified by this firewall.
-
#creation_timestamp ⇒ String
Output only.
-
#denied ⇒ Array<Google::Apis::ComputeBeta::Firewall::Denied>
The list of DENY rules specified by this firewall.
-
#description ⇒ String
An optional description of this resource.
-
#destination_ranges ⇒ Array<String>
If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges.
-
#direction ⇒ String
Direction of traffic to which this firewall applies, either
INGRESSorEGRESS. -
#disabled ⇒ Boolean
(also: #disabled?)
Denotes whether the firewall rule is disabled.
-
#enable_logging ⇒ Boolean
(also: #enable_logging?)
Deprecated in favor of enable in LogConfig.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeBeta::FirewallLogConfig
The available logging options for a firewall rule.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ String
URL of the network resource for this firewall rule.
-
#params ⇒ Google::Apis::ComputeBeta::FirewallParams
Additional firewall parameters.
-
#priority ⇒ Fixnum
Priority for this rule.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_ranges ⇒ Array<String>
If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges.
-
#source_service_accounts ⇒ Array<String>
If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list.
-
#source_tags ⇒ Array<String>
If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network.
-
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating sets of instances located in the network that may make network connections as specified inallowed[].
-
#target_tags ⇒ Array<String>
A list of tags that controls which instances the firewall rule applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Firewall
constructor
A new instance of Firewall.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Firewall
Returns a new instance of Firewall.
13224 13225 13226 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Array<Google::Apis::ComputeBeta::Firewall::Allowed>
The list of ALLOW rules specified by this firewall. Each rule specifies a
protocol and port-range tuple that describes a permitted connection.
Corresponds to the JSON property allowed
13038 13039 13040 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13038 def allowed @allowed end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
13044 13045 13046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13044 def @creation_timestamp end |
#denied ⇒ Array<Google::Apis::ComputeBeta::Firewall::Denied>
The list of DENY rules specified by this firewall. Each rule specifies a
protocol and port-range tuple that describes a denied connection.
Corresponds to the JSON property denied
13050 13051 13052 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13050 def denied @denied end |
#description ⇒ String
An optional description of this resource. Provide this field when you
create the resource.
Corresponds to the JSON property description
13056 13057 13058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13056 def description @description end |
#destination_ranges ⇒ Array<String>
If destination ranges are specified, the firewall rule applies only to
traffic that has destination IP address in these ranges. These ranges must
be expressed inCIDR format. Both IPv4 and IPv6 are supported.
Corresponds to the JSON property destinationRanges
13063 13064 13065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13063 def destination_ranges @destination_ranges end |
#direction ⇒ String
Direction of traffic to which this firewall applies, either INGRESS or
EGRESS. The default is INGRESS. For EGRESS traffic, you cannot
specify the sourceTags fields.
Corresponds to the JSON property direction
13070 13071 13072 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13070 def direction @direction end |
#disabled ⇒ Boolean Also known as: disabled?
Denotes whether the firewall rule is disabled. When set to true, the
firewall rule is not enforced and the network behaves as if it did not
exist. If this is unspecified, the firewall rule will be enabled.
Corresponds to the JSON property disabled
13077 13078 13079 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13077 def disabled @disabled end |
#enable_logging ⇒ Boolean Also known as: enable_logging?
Deprecated in favor of enable in LogConfig.
This field denotes whether to enable logging for a particular
firewall rule. If logging is enabled, logs will be exported t
Cloud Logging.
Corresponds to the JSON property enableLogging
13086 13087 13088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13086 def enable_logging @enable_logging end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
13094 13095 13096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13094 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#firewall
for firewall rules.
Corresponds to the JSON property kind
13100 13101 13102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13100 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeBeta::FirewallLogConfig
The available logging options for a firewall rule.
Corresponds to the JSON property logConfig
13105 13106 13107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13105 def log_config @log_config end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character
must be a lowercase letter, and all following characters (except for the
last character) must be a dash, lowercase letter, or digit. The last
character must be a lowercase letter or digit.
Corresponds to the JSON property name
13116 13117 13118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13116 def name @name end |
#network ⇒ String
URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my- network
- projects/myproject/global/networks/my-network
- global/networks/default
Corresponds to the JSON property
network
13132 13133 13134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13132 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::FirewallParams
Additional firewall parameters.
Corresponds to the JSON property params
13137 13138 13139 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13137 def params @params end |
#priority ⇒ Fixnum
Priority for this rule.
This is an integer between 0 and 65535, both inclusive.
The default value is 1000.
Relative priorities determine which rule takes effect if multiple rules
apply. Lower values indicate higher priority. For example, a rule with
priority 0 has higher precedence than a rule with priority 1.
DENY rules take precedence over ALLOW rules if they have equal priority.
Note that VPC networks have implied
rules with a priority of 65535. To avoid conflicts with the implied
rules, use a priority number less than 65535.
Corresponds to the JSON property priority
13151 13152 13153 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13151 def priority @priority end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
13156 13157 13158 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13156 def self_link @self_link end |
#source_ranges ⇒ Array<String>
If source ranges are specified, the firewall rule applies only to traffic
that has a source IP address in these ranges. These ranges must be
expressed inCIDR format. One or both of sourceRanges
and sourceTags may be set.
If both fields are set, the rule applies to traffic that has a
source IP address within sourceRanges OR a source IP
from a resource with a matching tag listed in thesourceTags field. The
connection does not need to match
both fields for the rule to
apply. Both IPv4 and IPv6 are supported.
Corresponds to the JSON property sourceRanges
13170 13171 13172 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13170 def source_ranges @source_ranges end |
#source_service_accounts ⇒ Array<String>
If source service accounts are specified, the firewall rules apply only to
traffic originating from an instance with a service account in this list.
Source service accounts cannot be used to control traffic to an instance's
external IP address because service accounts are associated with an
instance, not an IP address.sourceRanges can be set at the same time
assourceServiceAccounts.
If both are set, the firewall applies to traffic that
has a source IP address within the sourceRanges OR a source
IP that belongs to an instance with service account listed
insourceServiceAccount. The connection does not need to match
both fields for the firewall to apply.sourceServiceAccounts cannot be used at
the same time assourceTags or targetTags.
Corresponds to the JSON property sourceServiceAccounts
13186 13187 13188 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13186 def source_service_accounts @source_service_accounts end |
#source_tags ⇒ Array<String>
If source tags are specified, the firewall rule applies only to traffic
with source IPs that match the primary network interfaces of VM instances
that have the tag and are in the same VPC network.
Source tags cannot be used to control traffic to an instance's external IP
address, it only applies to traffic between instances in the same virtual
network. Because tags are associated with instances, not IP addresses.
One or both of sourceRanges and sourceTags may be
set. If both fields are set, the firewall applies to traffic that has a
source IP address within sourceRanges OR a source IP from a
resource with a matching tag listed in the sourceTags
field. The connection does not need to match both fields for the
firewall to apply.
Corresponds to the JSON property sourceTags
13202 13203 13204 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13202 def @source_tags end |
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating sets of instances located in the
network that may make network connections as specified inallowed[].
targetServiceAccounts cannot be used at the same time astargetTags or
sourceTags.
If neither targetServiceAccounts nor targetTags
are specified, the firewall rule applies to all instances on the specified
network.
Corresponds to the JSON property targetServiceAccounts
13213 13214 13215 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13213 def target_service_accounts @target_service_accounts end |
#target_tags ⇒ Array<String>
A list of tags that controls which instances the firewall rule
applies to. If targetTags are specified, then the firewall
rule applies only to instances in the VPC network that have one of those
tags. If no targetTags are specified, the firewall rule
applies to all instances on the specified network.
Corresponds to the JSON property targetTags
13222 13223 13224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13222 def @target_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13229 13230 13231 13232 13233 13234 13235 13236 13237 13238 13239 13240 13241 13242 13243 13244 13245 13246 13247 13248 13249 13250 13251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13229 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @denied = args[:denied] if args.key?(:denied) @description = args[:description] if args.key?(:description) @destination_ranges = args[:destination_ranges] if args.key?(:destination_ranges) @direction = args[:direction] if args.key?(:direction) @disabled = args[:disabled] if args.key?(:disabled) @enable_logging = args[:enable_logging] if args.key?(:enable_logging) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @priority = args[:priority] if args.key?(:priority) @self_link = args[:self_link] if args.key?(:self_link) @source_ranges = args[:source_ranges] if args.key?(:source_ranges) @source_service_accounts = args[:source_service_accounts] if args.key?(:source_service_accounts) @source_tags = args[:source_tags] if args.key?(:source_tags) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) @target_tags = args[:target_tags] if args.key?(:target_tags) end |