Class: Google::Apis::ComputeBeta::Firewall
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Firewall
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Firewall Rule resource. Firewall rules allow or deny ingress traffic to, and egress traffic from your instances. For more information, readFirewall rules.
Defined Under Namespace
Instance Attribute Summary collapse
-
#allowed ⇒ Array<Google::Apis::ComputeBeta::Firewall::Allowed>
The list of ALLOW rules specified by this firewall.
-
#creation_timestamp ⇒ String
Output only.
-
#denied ⇒ Array<Google::Apis::ComputeBeta::Firewall::Denied>
The list of DENY rules specified by this firewall.
-
#description ⇒ String
An optional description of this resource.
-
#destination_ranges ⇒ Array<String>
If destination ranges are specified, the firewall rule applies only to traffic that has destination IP address in these ranges.
-
#direction ⇒ String
Direction of traffic to which this firewall applies, either
INGRESSorEGRESS. -
#disabled ⇒ Boolean
(also: #disabled?)
Denotes whether the firewall rule is disabled.
-
#enable_logging ⇒ Boolean
(also: #enable_logging?)
Deprecated in favor of enable in LogConfig.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeBeta::FirewallLogConfig
The available logging options for a firewall rule.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ String
URL of the network resource for this firewall rule.
-
#params ⇒ Google::Apis::ComputeBeta::FirewallParams
Additional firewall parameters.
-
#priority ⇒ Fixnum
Priority for this rule.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_ranges ⇒ Array<String>
If source ranges are specified, the firewall rule applies only to traffic that has a source IP address in these ranges.
-
#source_service_accounts ⇒ Array<String>
If source service accounts are specified, the firewall rules apply only to traffic originating from an instance with a service account in this list.
-
#source_tags ⇒ Array<String>
If source tags are specified, the firewall rule applies only to traffic with source IPs that match the primary network interfaces of VM instances that have the tag and are in the same VPC network.
-
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating sets of instances located in the network that may make network connections as specified inallowed[].
-
#target_tags ⇒ Array<String>
A list of tags that controls which instances the firewall rule applies to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Firewall
constructor
A new instance of Firewall.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Firewall
Returns a new instance of Firewall.
12532 12533 12534 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed ⇒ Array<Google::Apis::ComputeBeta::Firewall::Allowed>
The list of ALLOW rules specified by this firewall. Each rule specifies a
protocol and port-range tuple that describes a permitted connection.
Corresponds to the JSON property allowed
12346 12347 12348 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12346 def allowed @allowed end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
12352 12353 12354 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12352 def @creation_timestamp end |
#denied ⇒ Array<Google::Apis::ComputeBeta::Firewall::Denied>
The list of DENY rules specified by this firewall. Each rule specifies a
protocol and port-range tuple that describes a denied connection.
Corresponds to the JSON property denied
12358 12359 12360 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12358 def denied @denied end |
#description ⇒ String
An optional description of this resource. Provide this field when you
create the resource.
Corresponds to the JSON property description
12364 12365 12366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12364 def description @description end |
#destination_ranges ⇒ Array<String>
If destination ranges are specified, the firewall rule applies only to
traffic that has destination IP address in these ranges. These ranges must
be expressed inCIDR format. Both IPv4 and IPv6 are supported.
Corresponds to the JSON property destinationRanges
12371 12372 12373 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12371 def destination_ranges @destination_ranges end |
#direction ⇒ String
Direction of traffic to which this firewall applies, either INGRESS or
EGRESS. The default is INGRESS. For EGRESS traffic, you cannot
specify the sourceTags fields.
Corresponds to the JSON property direction
12378 12379 12380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12378 def direction @direction end |
#disabled ⇒ Boolean Also known as: disabled?
Denotes whether the firewall rule is disabled. When set to true, the
firewall rule is not enforced and the network behaves as if it did not
exist. If this is unspecified, the firewall rule will be enabled.
Corresponds to the JSON property disabled
12385 12386 12387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12385 def disabled @disabled end |
#enable_logging ⇒ Boolean Also known as: enable_logging?
Deprecated in favor of enable in LogConfig.
This field denotes whether to enable logging for a particular
firewall rule. If logging is enabled, logs will be exported t
Cloud Logging.
Corresponds to the JSON property enableLogging
12394 12395 12396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12394 def enable_logging @enable_logging end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
12402 12403 12404 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12402 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#firewall
for firewall rules.
Corresponds to the JSON property kind
12408 12409 12410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12408 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeBeta::FirewallLogConfig
The available logging options for a firewall rule.
Corresponds to the JSON property logConfig
12413 12414 12415 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12413 def log_config @log_config end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character
must be a lowercase letter, and all following characters (except for the
last character) must be a dash, lowercase letter, or digit. The last
character must be a lowercase letter or digit.
Corresponds to the JSON property name
12424 12425 12426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12424 def name @name end |
#network ⇒ String
URL of the network resource for this firewall rule. If not specified when creating a firewall rule, the default network is used: global/networks/default If you choose to specify this field, you can specify the network as a full or partial URL. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/myproject/global/networks/my- network
- projects/myproject/global/networks/my-network
- global/networks/default
Corresponds to the JSON property
network
12440 12441 12442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12440 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::FirewallParams
Additional firewall parameters.
Corresponds to the JSON property params
12445 12446 12447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12445 def params @params end |
#priority ⇒ Fixnum
Priority for this rule.
This is an integer between 0 and 65535, both inclusive.
The default value is 1000.
Relative priorities determine which rule takes effect if multiple rules
apply. Lower values indicate higher priority. For example, a rule with
priority 0 has higher precedence than a rule with priority 1.
DENY rules take precedence over ALLOW rules if they have equal priority.
Note that VPC networks have implied
rules with a priority of 65535. To avoid conflicts with the implied
rules, use a priority number less than 65535.
Corresponds to the JSON property priority
12459 12460 12461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12459 def priority @priority end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
12464 12465 12466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12464 def self_link @self_link end |
#source_ranges ⇒ Array<String>
If source ranges are specified, the firewall rule applies only to traffic
that has a source IP address in these ranges. These ranges must be
expressed inCIDR format. One or both of sourceRanges
and sourceTags may be set.
If both fields are set, the rule applies to traffic that has a
source IP address within sourceRanges OR a source IP
from a resource with a matching tag listed in thesourceTags field. The
connection does not need to match
both fields for the rule to
apply. Both IPv4 and IPv6 are supported.
Corresponds to the JSON property sourceRanges
12478 12479 12480 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12478 def source_ranges @source_ranges end |
#source_service_accounts ⇒ Array<String>
If source service accounts are specified, the firewall rules apply only to
traffic originating from an instance with a service account in this list.
Source service accounts cannot be used to control traffic to an instance's
external IP address because service accounts are associated with an
instance, not an IP address.sourceRanges can be set at the same time
assourceServiceAccounts.
If both are set, the firewall applies to traffic that
has a source IP address within the sourceRanges OR a source
IP that belongs to an instance with service account listed
insourceServiceAccount. The connection does not need to match
both fields for the firewall to apply.sourceServiceAccounts cannot be used at
the same time assourceTags or targetTags.
Corresponds to the JSON property sourceServiceAccounts
12494 12495 12496 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12494 def source_service_accounts @source_service_accounts end |
#source_tags ⇒ Array<String>
If source tags are specified, the firewall rule applies only to traffic
with source IPs that match the primary network interfaces of VM instances
that have the tag and are in the same VPC network.
Source tags cannot be used to control traffic to an instance's external IP
address, it only applies to traffic between instances in the same virtual
network. Because tags are associated with instances, not IP addresses.
One or both of sourceRanges and sourceTags may be
set. If both fields are set, the firewall applies to traffic that has a
source IP address within sourceRanges OR a source IP from a
resource with a matching tag listed in the sourceTags
field. The connection does not need to match both fields for the
firewall to apply.
Corresponds to the JSON property sourceTags
12510 12511 12512 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12510 def @source_tags end |
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating sets of instances located in the
network that may make network connections as specified inallowed[].
targetServiceAccounts cannot be used at the same time astargetTags or
sourceTags.
If neither targetServiceAccounts nor targetTags
are specified, the firewall rule applies to all instances on the specified
network.
Corresponds to the JSON property targetServiceAccounts
12521 12522 12523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12521 def target_service_accounts @target_service_accounts end |
#target_tags ⇒ Array<String>
A list of tags that controls which instances the firewall rule
applies to. If targetTags are specified, then the firewall
rule applies only to instances in the VPC network that have one of those
tags. If no targetTags are specified, the firewall rule
applies to all instances on the specified network.
Corresponds to the JSON property targetTags
12530 12531 12532 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12530 def @target_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12537 12538 12539 12540 12541 12542 12543 12544 12545 12546 12547 12548 12549 12550 12551 12552 12553 12554 12555 12556 12557 12558 12559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12537 def update!(**args) @allowed = args[:allowed] if args.key?(:allowed) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @denied = args[:denied] if args.key?(:denied) @description = args[:description] if args.key?(:description) @destination_ranges = args[:destination_ranges] if args.key?(:destination_ranges) @direction = args[:direction] if args.key?(:direction) @disabled = args[:disabled] if args.key?(:disabled) @enable_logging = args[:enable_logging] if args.key?(:enable_logging) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @priority = args[:priority] if args.key?(:priority) @self_link = args[:self_link] if args.key?(:self_link) @source_ranges = args[:source_ranges] if args.key?(:source_ranges) @source_service_accounts = args[:source_service_accounts] if args.key?(:source_service_accounts) @source_tags = args[:source_tags] if args.key?(:source_tags) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) @target_tags = args[:target_tags] if args.key?(:target_tags) end |