Class: Google::Apis::ComputeBeta::Firewall::Denied

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Denied

Returns a new instance of Denied.



13308
13309
13310
# File 'lib/google/apis/compute_beta/classes.rb', line 13308

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or the IP protocol number. Corresponds to the JSON property IPProtocol

Returns:

  • (String)


13296
13297
13298
# File 'lib/google/apis/compute_beta/classes.rb', line 13296

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for the UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"], ["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


13306
13307
13308
# File 'lib/google/apis/compute_beta/classes.rb', line 13306

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13313
13314
13315
13316
# File 'lib/google/apis/compute_beta/classes.rb', line 13313

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end