Class: Google::Apis::ComputeBeta::Firewall::Denied
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Firewall::Denied
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Denied
constructor
A new instance of Denied.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Denied
Returns a new instance of Denied.
12784 12785 12786 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a firewall rule. This value can either be one of the
following well known protocol strings (tcp, udp,icmp, esp, ah, ipip,sctp) or
the IP protocol number.
Corresponds to the JSON property IPProtocol
12772 12773 12774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12772 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
This field is only applicable for the UDP or TCP protocol.
Each entry must be either an integer or a range.
If not specified, this rule applies to connections through any port.
Example inputs include: ["22"], ["80","443"],
and ["12345-12349"].
Corresponds to the JSON property ports
12782 12783 12784 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12782 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12789 12790 12791 12792 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12789 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |