Class: Google::Apis::ComputeBeta::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
13532 13533 13534 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13532 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13499 13500 13501 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13499 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
13504 13505 13506 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13504 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
13510 13511 13512 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13510 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13520 13521 13522 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13520 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
13525 13526 13527 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13525 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13530 13531 13532 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13530 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13537 13538 13539 13540 13541 13542 13543 13544 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13537 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |