Class: Google::Apis::ComputeBeta::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
13360 13361 13362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13327 13328 13329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13327 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
13332 13333 13334 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13332 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
13338 13339 13340 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13338 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13348 13349 13350 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13348 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
13353 13354 13355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13353 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13358 13359 13360 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13358 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13365 13366 13367 13368 13369 13370 13371 13372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13365 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |