Class: Google::Apis::ComputeBeta::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
12836 12837 12838 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12803 12804 12805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12803 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
12808 12809 12810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12808 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
12814 12815 12816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12814 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12824 12825 12826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12824 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12829 12830 12831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12829 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12834 12835 12836 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12834 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12841 12842 12843 12844 12845 12846 12847 12848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12841 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |