Class: Google::Apis::ComputeBeta::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



12668
12669
12670
# File 'lib/google/apis/compute_beta/classes.rb', line 12668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12635
12636
12637
# File 'lib/google/apis/compute_beta/classes.rb', line 12635

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



12640
12641
12642
# File 'lib/google/apis/compute_beta/classes.rb', line 12640

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


12646
12647
12648
# File 'lib/google/apis/compute_beta/classes.rb', line 12646

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12656
12657
12658
# File 'lib/google/apis/compute_beta/classes.rb', line 12656

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12661
12662
12663
# File 'lib/google/apis/compute_beta/classes.rb', line 12661

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12666
12667
12668
# File 'lib/google/apis/compute_beta/classes.rb', line 12666

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12673
12674
12675
12676
12677
12678
12679
12680
# File 'lib/google/apis/compute_beta/classes.rb', line 12673

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end