Class: Google::Apis::ComputeBeta::FirewallList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of firewalls.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallList
constructor
A new instance of FirewallList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallList
Returns a new instance of FirewallList.
12668 12669 12670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
12635 12636 12637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12635 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Firewall>
A list of Firewall resources.
Corresponds to the JSON property items
12640 12641 12642 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12640 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#firewallList
for lists of firewalls.
Corresponds to the JSON property kind
12646 12647 12648 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12646 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
12656 12657 12658 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12656 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
12661 12662 12663 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12661 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
12666 12667 12668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12666 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12673 12674 12675 12676 12677 12678 12679 12680 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12673 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |