Class: Google::Apis::ComputeBeta::FirewallList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of firewalls.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallList

Returns a new instance of FirewallList.



12334
12335
12336
# File 'lib/google/apis/compute_beta/classes.rb', line 12334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12301
12302
12303
# File 'lib/google/apis/compute_beta/classes.rb', line 12301

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Firewall>

A list of Firewall resources. Corresponds to the JSON property items



12306
12307
12308
# File 'lib/google/apis/compute_beta/classes.rb', line 12306

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#firewallList for lists of firewalls. Corresponds to the JSON property kind

Returns:

  • (String)


12312
12313
12314
# File 'lib/google/apis/compute_beta/classes.rb', line 12312

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12322
12323
12324
# File 'lib/google/apis/compute_beta/classes.rb', line 12322

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


12327
12328
12329
# File 'lib/google/apis/compute_beta/classes.rb', line 12327

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::FirewallList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12332
12333
12334
# File 'lib/google/apis/compute_beta/classes.rb', line 12332

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12339
12340
12341
12342
12343
12344
12345
12346
# File 'lib/google/apis/compute_beta/classes.rb', line 12339

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end