Class: Google::Apis::ComputeBeta::FirewallLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The available logging options for a firewall rule.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
This field denotes whether to enable logging for a particular firewall rule.
-
#metadata ⇒ String
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallLogConfig
constructor
A new instance of FirewallLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallLogConfig
Returns a new instance of FirewallLogConfig.
13612 13613 13614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13612 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
This field denotes whether to enable logging for a particular firewall
rule.
Corresponds to the JSON property enable
13602 13603 13604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13602 def enable @enable end |
#metadata ⇒ String
This field can only be specified for a particular firewall rule if
logging is enabled for that rule. This field denotes whether to include
or exclude metadata for firewall logs.
Corresponds to the JSON property metadata
13610 13611 13612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13610 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13617 13618 13619 13620 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13617 def update!(**args) @enable = args[:enable] if args.key?(:enable) @metadata = args[:metadata] if args.key?(:metadata) end |