Class: Google::Apis::ComputeBeta::FirewallLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The available logging options for a firewall rule.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
This field denotes whether to enable logging for a particular firewall rule.
-
#metadata ⇒ String
This field can only be specified for a particular firewall rule if logging is enabled for that rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallLogConfig
constructor
A new instance of FirewallLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallLogConfig
Returns a new instance of FirewallLogConfig.
12771 12772 12773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
This field denotes whether to enable logging for a particular firewall
rule.
Corresponds to the JSON property enable
12761 12762 12763 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12761 def enable @enable end |
#metadata ⇒ String
This field can only be specified for a particular firewall rule if
logging is enabled for that rule. This field denotes whether to include
or exclude metadata for firewall logs.
Corresponds to the JSON property metadata
12769 12770 12771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12769 def @metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12776 12777 12778 12779 |
# File 'lib/google/apis/compute_beta/classes.rb', line 12776 def update!(**args) @enable = args[:enable] if args.key?(:enable) @metadata = args[:metadata] if args.key?(:metadata) end |