Class: Google::Apis::ComputeBeta::FirewallPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPoliciesScopedList

Returns a new instance of FirewallPoliciesScopedList.



13718
13719
13720
# File 'lib/google/apis/compute_beta/classes.rb', line 13718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policiesArray<Google::Apis::ComputeBeta::FirewallPolicy>

A list of firewall policies contained in this scope. Corresponds to the JSON property firewallPolicies



13710
13711
13712
# File 'lib/google/apis/compute_beta/classes.rb', line 13710

def firewall_policies
  @firewall_policies
end

#warningGoogle::Apis::ComputeBeta::FirewallPoliciesScopedList::Warning

Informational warning which replaces the list of firewall policies when the list is empty. Corresponds to the JSON property warning



13716
13717
13718
# File 'lib/google/apis/compute_beta/classes.rb', line 13716

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13723
13724
13725
13726
# File 'lib/google/apis/compute_beta/classes.rb', line 13723

def update!(**args)
  @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies)
  @warning = args[:warning] if args.key?(:warning)
end