Class: Google::Apis::ComputeBeta::FirewallPoliciesScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallPoliciesScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#firewall_policies ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicy>
A list of firewall policies contained in this scope.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallPoliciesScopedList::Warning
Informational warning which replaces the list of firewall policies when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPoliciesScopedList
constructor
A new instance of FirewallPoliciesScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPoliciesScopedList
Returns a new instance of FirewallPoliciesScopedList.
13022 13023 13024 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13022 def initialize(**args) update!(**args) end |
Instance Attribute Details
#firewall_policies ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicy>
A list of firewall policies contained in this scope.
Corresponds to the JSON property firewallPolicies
13014 13015 13016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13014 def firewall_policies @firewall_policies end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallPoliciesScopedList::Warning
Informational warning which replaces the list of firewall policies when
the list is empty.
Corresponds to the JSON property warning
13020 13021 13022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13020 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13027 13028 13029 13030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13027 def update!(**args) @firewall_policies = args[:firewall_policies] if args.key?(:firewall_policies) @warning = args[:warning] if args.key?(:warning) end |