Class: Google::Apis::ComputeBeta::FirewallPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyAssociation

Returns a new instance of FirewallPolicyAssociation.



13843
13844
13845
# File 'lib/google/apis/compute_beta/classes.rb', line 13843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_targetString

The target that the firewall policy is attached to. Corresponds to the JSON property attachmentTarget

Returns:

  • (String)


13809
13810
13811
# File 'lib/google/apis/compute_beta/classes.rb', line 13809

def attachment_target
  @attachment_target
end

#display_nameString

[Output Only] Deprecated, please use short name instead. The display name of the firewall policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


13815
13816
13817
# File 'lib/google/apis/compute_beta/classes.rb', line 13815

def display_name
  @display_name
end

#firewall_policy_idString

Output only. [Output Only] The firewall policy ID of the association. Corresponds to the JSON property firewallPolicyId

Returns:

  • (String)


13820
13821
13822
# File 'lib/google/apis/compute_beta/classes.rb', line 13820

def firewall_policy_id
  @firewall_policy_id
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


13825
13826
13827
# File 'lib/google/apis/compute_beta/classes.rb', line 13825

def name
  @name
end

#priorityFixnum

An integer indicating the priority of an association. The priority must be a positive value between 1 and 2147483647. Firewall Policies are evaluated from highest to lowest priority where 1 is the highest priority and 2147483647 is the lowest priority. The default value is 1000. If two associations have the same priority then lexicographical order on association names is applied. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


13835
13836
13837
# File 'lib/google/apis/compute_beta/classes.rb', line 13835

def priority
  @priority
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


13841
13842
13843
# File 'lib/google/apis/compute_beta/classes.rb', line 13841

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13848
13849
13850
13851
13852
13853
13854
13855
# File 'lib/google/apis/compute_beta/classes.rb', line 13848

def update!(**args)
  @attachment_target = args[:attachment_target] if args.key?(:attachment_target)
  @display_name = args[:display_name] if args.key?(:display_name)
  @firewall_policy_id = args[:firewall_policy_id] if args.key?(:firewall_policy_id)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @short_name = args[:short_name] if args.key?(:short_name)
end