Class: Google::Apis::ComputeBeta::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
14065 14066 14067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14037 14038 14039 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14037 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
14042 14043 14044 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14042 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList
for listsof FirewallPolicies
Corresponds to the JSON property kind
14048 14049 14050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14048 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14058 14059 14060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14058 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14063 14064 14065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14063 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14070 14071 14072 14073 14074 14075 14076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14070 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |