Class: Google::Apis::ComputeBeta::FirewallPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyList

Returns a new instance of FirewallPolicyList.



14042
14043
14044
# File 'lib/google/apis/compute_beta/classes.rb', line 14042

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


14014
14015
14016
# File 'lib/google/apis/compute_beta/classes.rb', line 14014

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::FirewallPolicy>

A list of FirewallPolicy resources. Corresponds to the JSON property items



14019
14020
14021
# File 'lib/google/apis/compute_beta/classes.rb', line 14019

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList for listsof FirewallPolicies Corresponds to the JSON property kind

Returns:

  • (String)


14025
14026
14027
# File 'lib/google/apis/compute_beta/classes.rb', line 14025

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


14035
14036
14037
# File 'lib/google/apis/compute_beta/classes.rb', line 14035

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::FirewallPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



14040
14041
14042
# File 'lib/google/apis/compute_beta/classes.rb', line 14040

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14047
14048
14049
14050
14051
14052
14053
# File 'lib/google/apis/compute_beta/classes.rb', line 14047

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end