Class: Google::Apis::ComputeBeta::FirewallPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicy>
A list of FirewallPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyList
constructor
A new instance of FirewallPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyList
Returns a new instance of FirewallPolicyList.
13917 13918 13919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13917 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
13889 13890 13891 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13889 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicy>
A list of FirewallPolicy resources.
Corresponds to the JSON property items
13894 13895 13896 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13894 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList
for listsof FirewallPolicies
Corresponds to the JSON property kind
13900 13901 13902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13900 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
13910 13911 13912 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13910 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::FirewallPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
13915 13916 13917 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13915 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13922 13923 13924 13925 13926 13927 13928 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13922 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |