Class: Google::Apis::ComputeBeta::FirewallPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyList

Returns a new instance of FirewallPolicyList.



13369
13370
13371
# File 'lib/google/apis/compute_beta/classes.rb', line 13369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


13341
13342
13343
# File 'lib/google/apis/compute_beta/classes.rb', line 13341

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::FirewallPolicy>

A list of FirewallPolicy resources. Corresponds to the JSON property items



13346
13347
13348
# File 'lib/google/apis/compute_beta/classes.rb', line 13346

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList for listsof FirewallPolicies Corresponds to the JSON property kind

Returns:

  • (String)


13352
13353
13354
# File 'lib/google/apis/compute_beta/classes.rb', line 13352

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


13362
13363
13364
# File 'lib/google/apis/compute_beta/classes.rb', line 13362

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::FirewallPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



13367
13368
13369
# File 'lib/google/apis/compute_beta/classes.rb', line 13367

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13374
13375
13376
13377
13378
13379
13380
# File 'lib/google/apis/compute_beta/classes.rb', line 13374

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end