Class: Google::Apis::ComputeBeta::FirewallPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyList

Returns a new instance of FirewallPolicyList.



12867
12868
12869
# File 'lib/google/apis/compute_beta/classes.rb', line 12867

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


12839
12840
12841
# File 'lib/google/apis/compute_beta/classes.rb', line 12839

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::FirewallPolicy>

A list of FirewallPolicy resources. Corresponds to the JSON property items



12844
12845
12846
# File 'lib/google/apis/compute_beta/classes.rb', line 12844

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#firewallPolicyList for listsof FirewallPolicies Corresponds to the JSON property kind

Returns:

  • (String)


12850
12851
12852
# File 'lib/google/apis/compute_beta/classes.rb', line 12850

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


12860
12861
12862
# File 'lib/google/apis/compute_beta/classes.rb', line 12860

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::FirewallPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



12865
12866
12867
# File 'lib/google/apis/compute_beta/classes.rb', line 12865

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12872
12873
12874
12875
12876
12877
12878
# File 'lib/google/apis/compute_beta/classes.rb', line 12872

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end