Class: Google::Apis::ComputeBeta::FirewallPolicyRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a rule that describes one or more match conditions along with the action to be taken when traffic matches this condition (allow or deny).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRule

Returns a new instance of FirewallPolicyRule.



14145
14146
14147
# File 'lib/google/apis/compute_beta/classes.rb', line 14145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

The Action to perform when the client connection triggers the rule. Valid actions for firewall rules are: "allow", "deny", "apply_security_profile_group" and "goto_next". Valid actions for packet mirroring rules are: "mirror", "do_not_mirror" and "goto_next". Corresponds to the JSON property action

Returns:

  • (String)


14013
14014
14015
# File 'lib/google/apis/compute_beta/classes.rb', line 14013

def action
  @action
end

#descriptionString

An optional description for this resource. Corresponds to the JSON property description

Returns:

  • (String)


14018
14019
14020
# File 'lib/google/apis/compute_beta/classes.rb', line 14018

def description
  @description
end

#directionString

The direction in which this rule applies. Corresponds to the JSON property direction

Returns:

  • (String)


14023
14024
14025
# File 'lib/google/apis/compute_beta/classes.rb', line 14023

def direction
  @direction
end

#disabledBoolean Also known as: disabled?

Denotes whether the firewall policy rule is disabled. When set to true, the firewall policy rule is not enforced and traffic behaves as if it did not exist. If this is unspecified, the firewall policy rule will be enabled. Corresponds to the JSON property disabled

Returns:

  • (Boolean)


14031
14032
14033
# File 'lib/google/apis/compute_beta/classes.rb', line 14031

def disabled
  @disabled
end

#enable_loggingBoolean Also known as: enable_logging?

Denotes whether to enable logging for a particular rule. If logging is enabled, logs will be exported to the configured export destination in Stackdriver. Logs may be exported to BigQuery or Pub/Sub. Note: you cannot enable logging on "goto_next" rules. Corresponds to the JSON property enableLogging

Returns:

  • (Boolean)


14040
14041
14042
# File 'lib/google/apis/compute_beta/classes.rb', line 14040

def enable_logging
  @enable_logging
end

#kindString

Output only. [Output only] Type of the resource. Returnscompute# firewallPolicyRule for firewall rules andcompute#packetMirroringRule for packet mirroring rules. Corresponds to the JSON property kind

Returns:

  • (String)


14048
14049
14050
# File 'lib/google/apis/compute_beta/classes.rb', line 14048

def kind
  @kind
end

#matchGoogle::Apis::ComputeBeta::FirewallPolicyRuleMatcher

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified. Corresponds to the JSON property match



14054
14055
14056
# File 'lib/google/apis/compute_beta/classes.rb', line 14054

def match
  @match
end

#priorityFixnum

An integer indicating the priority of a rule in the list. The priority must be a positive value between 0 and 2147483647. Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest priority. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


14062
14063
14064
# File 'lib/google/apis/compute_beta/classes.rb', line 14062

def priority
  @priority
end

#rule_nameString

An optional name for the rule. This field is not a unique identifier and can be updated. Corresponds to the JSON property ruleName

Returns:

  • (String)


14068
14069
14070
# File 'lib/google/apis/compute_beta/classes.rb', line 14068

def rule_name
  @rule_name
end

#rule_tuple_countFixnum

Output only. [Output Only] Calculation of the complexity of a single firewall policy rule. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


14075
14076
14077
# File 'lib/google/apis/compute_beta/classes.rb', line 14075

def rule_tuple_count
  @rule_tuple_count
end

#security_profile_groupString

A fully-qualified URL of a SecurityProfile resource instance. Example: https://networksecurity.googleapis.com/v1/projects/`project`/locations/` location/securityProfileGroups/my-security-profile-group Must be specified if action is one of 'apply_security_profile_group' or 'mirror'. Cannot be specified for other actions. Corresponds to the JSON propertysecurityProfileGroup`

Returns:

  • (String)


14085
14086
14087
# File 'lib/google/apis/compute_beta/classes.rb', line 14085

def security_profile_group
  @security_profile_group
end

#target_forwarding_rulesArray<String>

A list of forwarding rules to which this rule applies. This field allows you to control which load balancers get this rule. For example, the following are valid values:

Returns:

  • (Array<String>)


14102
14103
14104
# File 'lib/google/apis/compute_beta/classes.rb', line 14102

def target_forwarding_rules
  @target_forwarding_rules
end

#target_resourcesArray<String>

A list of network resource URLs to which this rule applies. This field allows you to control which network's VMs get this rule. If this field is left blank, all VMs within the organization will receive the rule. Corresponds to the JSON property targetResources

Returns:

  • (Array<String>)


14109
14110
14111
# File 'lib/google/apis/compute_beta/classes.rb', line 14109

def target_resources
  @target_resources
end

#target_secure_tagsArray<Google::Apis::ComputeBeta::FirewallPolicyRuleSecureTag>

A list of secure tags that controls which instances the firewall rule applies to. If targetSecureTag are specified, then the firewall rule applies only to instances in the VPC network that have one of those EFFECTIVE secure tags, if all the target_secure_tag are in INEFFECTIVE state, then this rule will be ignored.targetSecureTag may not be set at the same time astargetServiceAccounts. If neither targetServiceAccounts nortargetSecureTag are specified, the firewall rule applies to all instances on the specified network. Maximum number of target label tags allowed is 256. Corresponds to the JSON property targetSecureTags



14123
14124
14125
# File 'lib/google/apis/compute_beta/classes.rb', line 14123

def target_secure_tags
  @target_secure_tags
end

#target_service_accountsArray<String>

A list of service accounts indicating the sets of instances that are applied with this rule. Corresponds to the JSON property targetServiceAccounts

Returns:

  • (Array<String>)


14129
14130
14131
# File 'lib/google/apis/compute_beta/classes.rb', line 14129

def target_service_accounts
  @target_service_accounts
end

#target_typeString

Target types of the firewall policy rule. Default value is INSTANCES. Corresponds to the JSON property targetType

Returns:

  • (String)


14135
14136
14137
# File 'lib/google/apis/compute_beta/classes.rb', line 14135

def target_type
  @target_type
end

#tls_inspectBoolean Also known as: tls_inspect?

Boolean flag indicating if the traffic should be TLS decrypted. Can be set only if action = 'apply_security_profile_group' and cannot be set for other actions. Corresponds to the JSON property tlsInspect

Returns:

  • (Boolean)


14142
14143
14144
# File 'lib/google/apis/compute_beta/classes.rb', line 14142

def tls_inspect
  @tls_inspect
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14150
14151
14152
14153
14154
14155
14156
14157
14158
14159
14160
14161
14162
14163
14164
14165
14166
14167
14168
# File 'lib/google/apis/compute_beta/classes.rb', line 14150

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @description = args[:description] if args.key?(:description)
  @direction = args[:direction] if args.key?(:direction)
  @disabled = args[:disabled] if args.key?(:disabled)
  @enable_logging = args[:enable_logging] if args.key?(:enable_logging)
  @kind = args[:kind] if args.key?(:kind)
  @match = args[:match] if args.key?(:match)
  @priority = args[:priority] if args.key?(:priority)
  @rule_name = args[:rule_name] if args.key?(:rule_name)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @security_profile_group = args[:security_profile_group] if args.key?(:security_profile_group)
  @target_forwarding_rules = args[:target_forwarding_rules] if args.key?(:target_forwarding_rules)
  @target_resources = args[:target_resources] if args.key?(:target_resources)
  @target_secure_tags = args[:target_secure_tags] if args.key?(:target_secure_tags)
  @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts)
  @target_type = args[:target_type] if args.key?(:target_type)
  @tls_inspect = args[:tls_inspect] if args.key?(:tls_inspect)
end