Class: Google::Apis::ComputeBeta::FirewallPolicyRuleMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FirewallPolicyRuleMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.
Instance Attribute Summary collapse
-
#dest_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic destination.
-
#dest_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic destination.
-
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#dest_network_context ⇒ String
Network context of the traffic destination.
-
#dest_network_scope ⇒ String
Network scope of the traffic destination.
-
#dest_network_type ⇒ String
Network type of the traffic destination.
-
#dest_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for destination of traffic.
-
#dest_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
-
#layer4_configs ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
-
#src_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic source.
-
#src_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against traffic source.
-
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
-
#src_network_context ⇒ String
Network context of the traffic source.
-
#src_network_scope ⇒ String
Network scope of the traffic source.
-
#src_network_type ⇒ String
Network type of the traffic source.
-
#src_networks ⇒ Array<String>
Networks of the traffic source.
-
#src_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for source of traffic.
-
#src_secure_tags ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source of the traffic.
-
#src_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirewallPolicyRuleMatcher
constructor
A new instance of FirewallPolicyRuleMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirewallPolicyRuleMatcher
Returns a new instance of FirewallPolicyRuleMatcher.
13599 13600 13601 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dest_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic destination.
Maximum number of destination address groups is 10.
Corresponds to the JSON property destAddressGroups
13464 13465 13466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13464 def dest_address_groups @dest_address_groups end |
#dest_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against
traffic destination.
Maximum number of destination fqdn allowed is 100.
Corresponds to the JSON property destFqdns
13471 13472 13473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13471 def dest_fqdns @dest_fqdns end |
#dest_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of destination CIDR IP ranges allowed is 5000.
Corresponds to the JSON property destIpRanges
13477 13478 13479 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13477 def dest_ip_ranges @dest_ip_ranges end |
#dest_network_context ⇒ String
Network context of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Corresponds to the JSON property
destNetworkContext
13487 13488 13489 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13487 def dest_network_context @dest_network_context end |
#dest_network_scope ⇒ String
Network scope of the traffic destination.
Corresponds to the JSON property destNetworkScope
13492 13493 13494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13492 def dest_network_scope @dest_network_scope end |
#dest_network_type ⇒ String
Network type of the traffic destination. Allowed values are:
- UNSPECIFIED
- INTERNET
- NON_INTERNET
Corresponds to the JSON property
destNetworkType
13502 13503 13504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13502 def dest_network_type @dest_network_type end |
#dest_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for destination
of traffic. Should be specified as 2 letter country code defined as per
ISO 3166 alpha-2 country codes. ex."US"
Maximum number of dest region codes allowed is 5000.
Corresponds to the JSON property destRegionCodes
13510 13511 13512 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13510 def dest_region_codes @dest_region_codes end |
#dest_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
The IPs in these lists will be matched against traffic destination.
Corresponds to the JSON property destThreatIntelligences
13516 13517 13518 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13516 def dest_threat_intelligences @dest_threat_intelligences end |
#layer4_configs ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicyRuleMatcherLayer4Config>
Pairs of IP protocols and ports that the rule should match.
Corresponds to the JSON property layer4Configs
13521 13522 13523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13521 def layer4_configs @layer4_configs end |
#src_address_groups ⇒ Array<String>
Address groups which should be matched against the traffic source.
Maximum number of source address groups is 10.
Corresponds to the JSON property srcAddressGroups
13527 13528 13529 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13527 def src_address_groups @src_address_groups end |
#src_fqdns ⇒ Array<String>
Fully Qualified Domain Name (FQDN) which should be matched against
traffic source.
Maximum number of source fqdn allowed is 100.
Corresponds to the JSON property srcFqdns
13534 13535 13536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13534 def src_fqdns @src_fqdns end |
#src_ip_ranges ⇒ Array<String>
CIDR IP address range.
Maximum number of source CIDR IP ranges allowed is 5000.
Corresponds to the JSON property srcIpRanges
13540 13541 13542 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13540 def src_ip_ranges @src_ip_ranges end |
#src_network_context ⇒ String
Network context of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Corresponds to the JSON property
srcNetworkContext
13552 13553 13554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13552 def src_network_context @src_network_context end |
#src_network_scope ⇒ String
Network scope of the traffic source.
Corresponds to the JSON property srcNetworkScope
13557 13558 13559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13557 def src_network_scope @src_network_scope end |
#src_network_type ⇒ String
Network type of the traffic source. Allowed values are:
- UNSPECIFIED
- INTERNET
- INTRA_VPC
- NON_INTERNET
- VPC_NETWORKS
Corresponds to the JSON property
srcNetworkType
13569 13570 13571 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13569 def src_network_type @src_network_type end |
#src_networks ⇒ Array<String>
Networks of the traffic source. It can be either a full or partial url.
Corresponds to the JSON property srcNetworks
13574 13575 13576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13574 def src_networks @src_networks end |
#src_region_codes ⇒ Array<String>
Region codes whose IP addresses will be used to match for source
of traffic. Should be specified as 2 letter country code defined as per
ISO 3166 alpha-2 country codes. ex."US"
Maximum number of source region codes allowed is 5000.
Corresponds to the JSON property srcRegionCodes
13582 13583 13584 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13582 def src_region_codes @src_region_codes end |
#src_secure_tags ⇒ Array<Google::Apis::ComputeBeta::FirewallPolicyRuleSecureTag>
List of secure tag values, which should be matched at the source
of the traffic.
For INGRESS rule, if all the srcSecureTag are INEFFECTIVE,
and there is no srcIpRange, this rule will be ignored.
Maximum number of source tag values allowed is 256.
Corresponds to the JSON property srcSecureTags
13591 13592 13593 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13591 def @src_secure_tags end |
#src_threat_intelligences ⇒ Array<String>
Names of Network Threat Intelligence lists.
The IPs in these lists will be matched against traffic source.
Corresponds to the JSON property srcThreatIntelligences
13597 13598 13599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13597 def src_threat_intelligences @src_threat_intelligences end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13604 13605 13606 13607 13608 13609 13610 13611 13612 13613 13614 13615 13616 13617 13618 13619 13620 13621 13622 13623 13624 |
# File 'lib/google/apis/compute_beta/classes.rb', line 13604 def update!(**args) @dest_address_groups = args[:dest_address_groups] if args.key?(:dest_address_groups) @dest_fqdns = args[:dest_fqdns] if args.key?(:dest_fqdns) @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges) @dest_network_context = args[:dest_network_context] if args.key?(:dest_network_context) @dest_network_scope = args[:dest_network_scope] if args.key?(:dest_network_scope) @dest_network_type = args[:dest_network_type] if args.key?(:dest_network_type) @dest_region_codes = args[:dest_region_codes] if args.key?(:dest_region_codes) @dest_threat_intelligences = args[:dest_threat_intelligences] if args.key?(:dest_threat_intelligences) @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs) @src_address_groups = args[:src_address_groups] if args.key?(:src_address_groups) @src_fqdns = args[:src_fqdns] if args.key?(:src_fqdns) @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges) @src_network_context = args[:src_network_context] if args.key?(:src_network_context) @src_network_scope = args[:src_network_scope] if args.key?(:src_network_scope) @src_network_type = args[:src_network_type] if args.key?(:src_network_type) @src_networks = args[:src_networks] if args.key?(:src_networks) @src_region_codes = args[:src_region_codes] if args.key?(:src_region_codes) @src_secure_tags = args[:src_secure_tags] if args.key?(:src_secure_tags) @src_threat_intelligences = args[:src_threat_intelligences] if args.key?(:src_threat_intelligences) end |