Class: Google::Apis::ComputeBeta::FirewallPolicyRuleMatcherLayer4Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirewallPolicyRuleMatcherLayer4Config

Returns a new instance of FirewallPolicyRuleMatcherLayer4Config.



13315
13316
13317
# File 'lib/google/apis/compute_beta/classes.rb', line 13315

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a firewall rule. This value can either be one of the following well known protocol strings (tcp,udp, icmp, esp,ah, ipip, sctp), or the IP protocol number. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


13304
13305
13306
# File 'lib/google/apis/compute_beta/classes.rb', line 13304

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"],["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


13313
13314
13315
# File 'lib/google/apis/compute_beta/classes.rb', line 13313

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13320
13321
13322
13323
# File 'lib/google/apis/compute_beta/classes.rb', line 13320

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end