Class: Google::Apis::ComputeBeta::FlexibleTimeRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlexibleTimeRange

Returns a new instance of FlexibleTimeRange.



14633
14634
14635
# File 'lib/google/apis/compute_beta/classes.rb', line 14633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_not_earlier_thanString

Corresponds to the JSON property endTimeNotEarlierThan

Returns:

  • (String)


14606
14607
14608
# File 'lib/google/apis/compute_beta/classes.rb', line 14606

def end_time_not_earlier_than
  @end_time_not_earlier_than
end

#end_time_not_later_thanString

Corresponds to the JSON property endTimeNotLaterThan

Returns:

  • (String)


14611
14612
14613
# File 'lib/google/apis/compute_beta/classes.rb', line 14611

def end_time_not_later_than
  @end_time_not_later_than
end

#max_durationString

Corresponds to the JSON property maxDuration

Returns:

  • (String)


14616
14617
14618
# File 'lib/google/apis/compute_beta/classes.rb', line 14616

def max_duration
  @max_duration
end

#min_durationString

Corresponds to the JSON property minDuration

Returns:

  • (String)


14621
14622
14623
# File 'lib/google/apis/compute_beta/classes.rb', line 14621

def min_duration
  @min_duration
end

#start_time_not_earlier_thanString

Corresponds to the JSON property startTimeNotEarlierThan

Returns:

  • (String)


14626
14627
14628
# File 'lib/google/apis/compute_beta/classes.rb', line 14626

def start_time_not_earlier_than
  @start_time_not_earlier_than
end

#start_time_not_later_thanString

Corresponds to the JSON property startTimeNotLaterThan

Returns:

  • (String)


14631
14632
14633
# File 'lib/google/apis/compute_beta/classes.rb', line 14631

def start_time_not_later_than
  @start_time_not_later_than
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14638
14639
14640
14641
14642
14643
14644
14645
# File 'lib/google/apis/compute_beta/classes.rb', line 14638

def update!(**args)
  @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than)
  @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @min_duration = args[:min_duration] if args.key?(:min_duration)
  @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than)
  @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than)
end