Class: Google::Apis::ComputeBeta::FlexibleTimeRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FlexibleTimeRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.
Instance Attribute Summary collapse
-
#end_time_not_earlier_than ⇒ String
Corresponds to the JSON property
endTimeNotEarlierThan. -
#end_time_not_later_than ⇒ String
Corresponds to the JSON property
endTimeNotLaterThan. -
#max_duration ⇒ String
Corresponds to the JSON property
maxDuration. -
#min_duration ⇒ String
Corresponds to the JSON property
minDuration. -
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property
startTimeNotEarlierThan. -
#start_time_not_later_than ⇒ String
Corresponds to the JSON property
startTimeNotLaterThan.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlexibleTimeRange
constructor
A new instance of FlexibleTimeRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlexibleTimeRange
Returns a new instance of FlexibleTimeRange.
14482 14483 14484 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time_not_earlier_than ⇒ String
Corresponds to the JSON property endTimeNotEarlierThan
14455 14456 14457 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14455 def end_time_not_earlier_than @end_time_not_earlier_than end |
#end_time_not_later_than ⇒ String
Corresponds to the JSON property endTimeNotLaterThan
14460 14461 14462 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14460 def end_time_not_later_than @end_time_not_later_than end |
#max_duration ⇒ String
Corresponds to the JSON property maxDuration
14465 14466 14467 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14465 def max_duration @max_duration end |
#min_duration ⇒ String
Corresponds to the JSON property minDuration
14470 14471 14472 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14470 def min_duration @min_duration end |
#start_time_not_earlier_than ⇒ String
Corresponds to the JSON property startTimeNotEarlierThan
14475 14476 14477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14475 def start_time_not_earlier_than @start_time_not_earlier_than end |
#start_time_not_later_than ⇒ String
Corresponds to the JSON property startTimeNotLaterThan
14480 14481 14482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14480 def start_time_not_later_than @start_time_not_later_than end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14487 14488 14489 14490 14491 14492 14493 14494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14487 def update!(**args) @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than) @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than) @max_duration = args[:max_duration] if args.key?(:max_duration) @min_duration = args[:min_duration] if args.key?(:min_duration) @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than) @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than) end |