Class: Google::Apis::ComputeBeta::FlexibleTimeRange

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies a flexible time range with flexible start time and duration. It is possible to specify a contradictory time range that cannot be matched by any Interval. This causes a validation error.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FlexibleTimeRange

Returns a new instance of FlexibleTimeRange.



14458
14459
14460
# File 'lib/google/apis/compute_beta/classes.rb', line 14458

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_time_not_earlier_thanString

Corresponds to the JSON property endTimeNotEarlierThan

Returns:

  • (String)


14431
14432
14433
# File 'lib/google/apis/compute_beta/classes.rb', line 14431

def end_time_not_earlier_than
  @end_time_not_earlier_than
end

#end_time_not_later_thanString

Corresponds to the JSON property endTimeNotLaterThan

Returns:

  • (String)


14436
14437
14438
# File 'lib/google/apis/compute_beta/classes.rb', line 14436

def end_time_not_later_than
  @end_time_not_later_than
end

#max_durationString

Corresponds to the JSON property maxDuration

Returns:

  • (String)


14441
14442
14443
# File 'lib/google/apis/compute_beta/classes.rb', line 14441

def max_duration
  @max_duration
end

#min_durationString

Corresponds to the JSON property minDuration

Returns:

  • (String)


14446
14447
14448
# File 'lib/google/apis/compute_beta/classes.rb', line 14446

def min_duration
  @min_duration
end

#start_time_not_earlier_thanString

Corresponds to the JSON property startTimeNotEarlierThan

Returns:

  • (String)


14451
14452
14453
# File 'lib/google/apis/compute_beta/classes.rb', line 14451

def start_time_not_earlier_than
  @start_time_not_earlier_than
end

#start_time_not_later_thanString

Corresponds to the JSON property startTimeNotLaterThan

Returns:

  • (String)


14456
14457
14458
# File 'lib/google/apis/compute_beta/classes.rb', line 14456

def start_time_not_later_than
  @start_time_not_later_than
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14463
14464
14465
14466
14467
14468
14469
14470
# File 'lib/google/apis/compute_beta/classes.rb', line 14463

def update!(**args)
  @end_time_not_earlier_than = args[:end_time_not_earlier_than] if args.key?(:end_time_not_earlier_than)
  @end_time_not_later_than = args[:end_time_not_later_than] if args.key?(:end_time_not_later_than)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @min_duration = args[:min_duration] if args.key?(:min_duration)
  @start_time_not_earlier_than = args[:start_time_not_earlier_than] if args.key?(:start_time_not_earlier_than)
  @start_time_not_later_than = args[:start_time_not_later_than] if args.key?(:start_time_not_later_than)
end