Class: Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
15298 15299 15300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15260 15261 15262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15260 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
15265 15266 15267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15265 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
15271 15272 15273 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15271 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15281 15282 15283 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15281 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15286 15287 15288 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15286 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15291 15292 15293 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15291 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15296 15297 15298 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15296 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15303 15304 15305 15306 15307 15308 15309 15310 15311 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15303 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |