Class: Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
15222 15223 15224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15184 15185 15186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15184 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
15189 15190 15191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15189 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
15195 15196 15197 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15195 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15205 15206 15207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15205 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15210 15211 15212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15210 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15215 15216 15217 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15215 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15220 15221 15222 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15220 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15227 15228 15229 15230 15231 15232 15233 15234 15235 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15227 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |