Class: Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleAggregatedList
constructor
A new instance of ForwardingRuleAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleAggregatedList
Returns a new instance of ForwardingRuleAggregatedList.
15073 15074 15075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15073 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
15035 15036 15037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15035 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ForwardingRulesScopedList>
A list of ForwardingRulesScopedList resources.
Corresponds to the JSON property items
15040 15041 15042 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15040 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
forwardingRuleAggregatedList for lists of forwarding rules.
Corresponds to the JSON property kind
15046 15047 15048 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15046 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15056 15057 15058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15056 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15061 15062 15063 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15061 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15066 15067 15068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15066 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15071 15072 15073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15071 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15078 15079 15080 15081 15082 15083 15084 15085 15086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15078 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |