Class: Google::Apis::ComputeBeta::ForwardingRuleList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of ForwardingRule resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleList

Returns a new instance of ForwardingRuleList.



15442
15443
15444
# File 'lib/google/apis/compute_beta/classes.rb', line 15442

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15410
15411
15412
# File 'lib/google/apis/compute_beta/classes.rb', line 15410

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ForwardingRule>

A list of ForwardingRule resources. Corresponds to the JSON property items



15415
15416
15417
# File 'lib/google/apis/compute_beta/classes.rb', line 15415

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


15420
15421
15422
# File 'lib/google/apis/compute_beta/classes.rb', line 15420

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15430
15431
15432
# File 'lib/google/apis/compute_beta/classes.rb', line 15430

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15435
15436
15437
# File 'lib/google/apis/compute_beta/classes.rb', line 15435

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ForwardingRuleList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15440
15441
15442
# File 'lib/google/apis/compute_beta/classes.rb', line 15440

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15447
15448
15449
15450
15451
15452
15453
15454
# File 'lib/google/apis/compute_beta/classes.rb', line 15447

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end