Class: Google::Apis::ComputeBeta::ForwardingRuleList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of ForwardingRule resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ForwardingRule>
A list of ForwardingRule resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleList
constructor
A new instance of ForwardingRuleList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleList
Returns a new instance of ForwardingRuleList.
14146 14147 14148 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
14114 14115 14116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14114 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ForwardingRule>
A list of ForwardingRule resources.
Corresponds to the JSON property items
14119 14120 14121 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14119 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
14124 14125 14126 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14124 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
14134 14135 14136 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14134 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
14139 14140 14141 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14139 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ForwardingRuleList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
14144 14145 14146 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14144 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14151 14152 14153 14154 14155 14156 14157 14158 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14151 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |