Class: Google::Apis::ComputeBeta::ForwardingRuleServiceDirectoryRegistration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Describes the auto-registration of the forwarding rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this forwarding rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration

Returns a new instance of ForwardingRuleServiceDirectoryRegistration.



15494
15495
15496
# File 'lib/google/apis/compute_beta/classes.rb', line 15494

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespaceString

Service Directory namespace to register the forwarding rule under. Corresponds to the JSON property namespace

Returns:

  • (String)


15479
15480
15481
# File 'lib/google/apis/compute_beta/classes.rb', line 15479

def namespace
  @namespace
end

#serviceString

Service Directory service to register the forwarding rule under. Corresponds to the JSON property service

Returns:

  • (String)


15484
15485
15486
# File 'lib/google/apis/compute_beta/classes.rb', line 15484

def service
  @service
end

#service_directory_regionString

[Optional] Service Directory region to register this global forwarding rule under. Default to "us-central1". Only used for PSC for Google APIs. All PSC for Google APIs forwarding rules on the same network should use the same Service Directory region. Corresponds to the JSON property serviceDirectoryRegion

Returns:

  • (String)


15492
15493
15494
# File 'lib/google/apis/compute_beta/classes.rb', line 15492

def service_directory_region
  @service_directory_region
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15499
15500
15501
15502
15503
# File 'lib/google/apis/compute_beta/classes.rb', line 15499

def update!(**args)
  @namespace = args[:namespace] if args.key?(:namespace)
  @service = args[:service] if args.key?(:service)
  @service_directory_region = args[:service_directory_region] if args.key?(:service_directory_region)
end