Class: Google::Apis::ComputeBeta::ForwardingRuleServiceDirectoryRegistration
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ForwardingRuleServiceDirectoryRegistration
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Describes the auto-registration of the forwarding rule to Service Directory. The region and project of the Service Directory resource generated from this registration will be the same as this forwarding rule.
Instance Attribute Summary collapse
-
#namespace ⇒ String
Service Directory namespace to register the forwarding rule under.
-
#service ⇒ String
Service Directory service to register the forwarding rule under.
-
#service_directory_region ⇒ String
[Optional] Service Directory region to register this global forwarding rule under.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration
constructor
A new instance of ForwardingRuleServiceDirectoryRegistration.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ForwardingRuleServiceDirectoryRegistration
Returns a new instance of ForwardingRuleServiceDirectoryRegistration.
14761 14762 14763 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14761 def initialize(**args) update!(**args) end |
Instance Attribute Details
#namespace ⇒ String
Service Directory namespace to register the forwarding rule under.
Corresponds to the JSON property namespace
14746 14747 14748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14746 def namespace @namespace end |
#service ⇒ String
Service Directory service to register the forwarding rule under.
Corresponds to the JSON property service
14751 14752 14753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14751 def service @service end |
#service_directory_region ⇒ String
[Optional] Service Directory region to register this global forwarding
rule under. Default to "us-central1". Only used for PSC for Google APIs.
All PSC for Google APIs forwarding rules on the same network should use
the same Service Directory region.
Corresponds to the JSON property serviceDirectoryRegion
14759 14760 14761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14759 def service_directory_region @service_directory_region end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14766 14767 14768 14769 14770 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14766 def update!(**args) @namespace = args[:namespace] if args.key?(:namespace) @service = args[:service] if args.key?(:service) @service_directory_region = args[:service_directory_region] if args.key?(:service_directory_region) end |