Class: Google::Apis::ComputeBeta::FutureReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservation

Returns a new instance of FutureReservation.



15824
15825
15826
# File 'lib/google/apis/compute_beta/classes.rb', line 15824

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_deployment_controlGoogle::Apis::ComputeBeta::ReservationAdvancedDeploymentControl

Advance control for cluster management, applicable only to DENSE deployment type reservations. Corresponds to the JSON property advancedDeploymentControl



15637
15638
15639
# File 'lib/google/apis/compute_beta/classes.rb', line 15637

def advanced_deployment_control
  @advanced_deployment_control
end

#aggregate_reservationGoogle::Apis::ComputeBeta::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



15644
15645
15646
# File 'lib/google/apis/compute_beta/classes.rb', line 15644

def aggregate_reservation
  @aggregate_reservation
end

#auto_created_reservations_delete_timeString

Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value. Corresponds to the JSON property autoCreatedReservationsDeleteTime

Returns:

  • (String)


15651
15652
15653
# File 'lib/google/apis/compute_beta/classes.rb', line 15651

def auto_created_reservations_delete_time
  @auto_created_reservations_delete_time
end

#auto_created_reservations_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property autoCreatedReservationsDuration



15659
15660
15661
# File 'lib/google/apis/compute_beta/classes.rb', line 15659

def auto_created_reservations_duration
  @auto_created_reservations_duration
end

#auto_delete_auto_created_reservationsBoolean Also known as: auto_delete_auto_created_reservations?

Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false. Corresponds to the JSON property autoDeleteAutoCreatedReservations

Returns:

  • (Boolean)


15671
15672
15673
# File 'lib/google/apis/compute_beta/classes.rb', line 15671

def auto_delete_auto_created_reservations
  @auto_delete_auto_created_reservations
end

#commitment_infoGoogle::Apis::ComputeBeta::FutureReservationCommitmentInfo

If not present, then FR will not deliver a new commitment or update an existing commitment. Corresponds to the JSON property commitmentInfo



15678
15679
15680
# File 'lib/google/apis/compute_beta/classes.rb', line 15678

def commitment_info
  @commitment_info
end

#confidential_compute_typeString

Corresponds to the JSON property confidentialComputeType

Returns:

  • (String)


15683
15684
15685
# File 'lib/google/apis/compute_beta/classes.rb', line 15683

def confidential_compute_type
  @confidential_compute_type
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this future reservation inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


15690
15691
15692
# File 'lib/google/apis/compute_beta/classes.rb', line 15690

def creation_timestamp
  @creation_timestamp
end

#deployment_typeString

Type of the deployment requested as part of future reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


15695
15696
15697
# File 'lib/google/apis/compute_beta/classes.rb', line 15695

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the future reservation. Corresponds to the JSON property description

Returns:

  • (String)


15701
15702
15703
# File 'lib/google/apis/compute_beta/classes.rb', line 15701

def description
  @description
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates if this group of VMs have emergent maintenance enabled. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


15706
15707
15708
# File 'lib/google/apis/compute_beta/classes.rb', line 15706

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] A unique identifier for this future reservation. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


15714
15715
15716
# File 'lib/google/apis/compute_beta/classes.rb', line 15714

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# futureReservation for future reservations. Corresponds to the JSON property kind

Returns:

  • (String)


15720
15721
15722
# File 'lib/google/apis/compute_beta/classes.rb', line 15720

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


15732
15733
15734
# File 'lib/google/apis/compute_beta/classes.rb', line 15732

def name
  @name
end

#name_prefixString

Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####. Corresponds to the JSON property namePrefix

Returns:

  • (String)


15740
15741
15742
# File 'lib/google/apis/compute_beta/classes.rb', line 15740

def name_prefix
  @name_prefix
end

#paramsGoogle::Apis::ComputeBeta::FutureReservationParams

Additional future reservation params. Corresponds to the JSON property params



15745
15746
15747
# File 'lib/google/apis/compute_beta/classes.rb', line 15745

def params
  @params
end

#planning_statusString

Planning state before being submitted for evaluation Corresponds to the JSON property planningStatus

Returns:

  • (String)


15750
15751
15752
# File 'lib/google/apis/compute_beta/classes.rb', line 15750

def planning_status
  @planning_status
end

#protection_tierString

Protection tier for the workload. Corresponds to the JSON property protectionTier

Returns:

  • (String)


15755
15756
15757
# File 'lib/google/apis/compute_beta/classes.rb', line 15755

def protection_tier
  @protection_tier
end

#reservation_modeString

The reservation mode which determines reservation-termination behavior and expected pricing. Corresponds to the JSON property reservationMode

Returns:

  • (String)


15761
15762
15763
# File 'lib/google/apis/compute_beta/classes.rb', line 15761

def reservation_mode
  @reservation_mode
end

#reservation_nameString

Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservation_name or a name_prefix. Corresponds to the JSON property reservationName

Returns:

  • (String)


15770
15771
15772
# File 'lib/google/apis/compute_beta/classes.rb', line 15770

def reservation_name
  @reservation_name
end

#scheduling_typeString

Maintenance information for this reservation Corresponds to the JSON property schedulingType

Returns:

  • (String)


15775
15776
15777
# File 'lib/google/apis/compute_beta/classes.rb', line 15775

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15781
15782
15783
# File 'lib/google/apis/compute_beta/classes.rb', line 15781

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


15787
15788
15789
# File 'lib/google/apis/compute_beta/classes.rb', line 15787

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



15792
15793
15794
# File 'lib/google/apis/compute_beta/classes.rb', line 15792

def share_settings
  @share_settings
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


15799
15800
15801
# File 'lib/google/apis/compute_beta/classes.rb', line 15799

def specific_reservation_required
  @specific_reservation_required
end

#specific_sku_propertiesGoogle::Apis::ComputeBeta::FutureReservationSpecificSkuProperties

Future Reservation configuration to indicate instance properties and total count. Corresponds to the JSON property specificSkuProperties



15806
15807
15808
# File 'lib/google/apis/compute_beta/classes.rb', line 15806

def specific_sku_properties
  @specific_sku_properties
end

#statusGoogle::Apis::ComputeBeta::FutureReservationStatus

[Output only] Represents status related to the future reservation. Corresponds to the JSON property status



15811
15812
15813
# File 'lib/google/apis/compute_beta/classes.rb', line 15811

def status
  @status
end

#time_windowGoogle::Apis::ComputeBeta::FutureReservationTimeWindow

Time window for this Future Reservation. Corresponds to the JSON property timeWindow



15816
15817
15818
# File 'lib/google/apis/compute_beta/classes.rb', line 15816

def time_window
  @time_window
end

#zoneString

Output only. [Output Only] URL of the Zone where this future reservation resides. Corresponds to the JSON property zone

Returns:

  • (String)


15822
15823
15824
# File 'lib/google/apis/compute_beta/classes.rb', line 15822

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15829
15830
15831
15832
15833
15834
15835
15836
15837
15838
15839
15840
15841
15842
15843
15844
15845
15846
15847
15848
15849
15850
15851
15852
15853
15854
15855
15856
15857
15858
15859
# File 'lib/google/apis/compute_beta/classes.rb', line 15829

def update!(**args)
  @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time)
  @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration)
  @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations)
  @commitment_info = args[:commitment_info] if args.key?(:commitment_info)
  @confidential_compute_type = args[:confidential_compute_type] if args.key?(:confidential_compute_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @params = args[:params] if args.key?(:params)
  @planning_status = args[:planning_status] if args.key?(:planning_status)
  @protection_tier = args[:protection_tier] if args.key?(:protection_tier)
  @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode)
  @reservation_name = args[:reservation_name] if args.key?(:reservation_name)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @status = args[:status] if args.key?(:status)
  @time_window = args[:time_window] if args.key?(:time_window)
  @zone = args[:zone] if args.key?(:zone)
end