Class: Google::Apis::ComputeBeta::FutureReservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservation

Returns a new instance of FutureReservation.



14887
14888
14889
# File 'lib/google/apis/compute_beta/classes.rb', line 14887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_deployment_controlGoogle::Apis::ComputeBeta::ReservationAdvancedDeploymentControl

Advance control for cluster management, applicable only to DENSE deployment type reservations. Corresponds to the JSON property advancedDeploymentControl



14710
14711
14712
# File 'lib/google/apis/compute_beta/classes.rb', line 14710

def advanced_deployment_control
  @advanced_deployment_control
end

#aggregate_reservationGoogle::Apis::ComputeBeta::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



14717
14718
14719
# File 'lib/google/apis/compute_beta/classes.rb', line 14717

def aggregate_reservation
  @aggregate_reservation
end

#auto_created_reservations_delete_timeString

Future timestamp when the FR auto-created reservations will be deleted by Compute Engine. Format of this field must be a valid href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value. Corresponds to the JSON property autoCreatedReservationsDeleteTime

Returns:

  • (String)


14724
14725
14726
# File 'lib/google/apis/compute_beta/classes.rb', line 14724

def auto_created_reservations_delete_time
  @auto_created_reservations_delete_time
end

#auto_created_reservations_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property autoCreatedReservationsDuration



14732
14733
14734
# File 'lib/google/apis/compute_beta/classes.rb', line 14732

def auto_created_reservations_duration
  @auto_created_reservations_duration
end

#auto_delete_auto_created_reservationsBoolean Also known as: auto_delete_auto_created_reservations?

Setting for enabling or disabling automatic deletion for auto-created reservation. If set to true, auto-created reservations will be deleted at Future Reservation's end time (default) or at user's defined timestamp if any of the [auto_created_reservations_delete_time, auto_created_reservations_duration] values is specified. For keeping auto-created reservation indefinitely, this value should be set to false. Corresponds to the JSON property autoDeleteAutoCreatedReservations

Returns:

  • (Boolean)


14744
14745
14746
# File 'lib/google/apis/compute_beta/classes.rb', line 14744

def auto_delete_auto_created_reservations
  @auto_delete_auto_created_reservations
end

#commitment_infoGoogle::Apis::ComputeBeta::FutureReservationCommitmentInfo

If not present, then FR will not deliver a new commitment or update an existing commitment. Corresponds to the JSON property commitmentInfo



14751
14752
14753
# File 'lib/google/apis/compute_beta/classes.rb', line 14751

def commitment_info
  @commitment_info
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this future reservation inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


14758
14759
14760
# File 'lib/google/apis/compute_beta/classes.rb', line 14758

def creation_timestamp
  @creation_timestamp
end

#deployment_typeString

Type of the deployment requested as part of future reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


14763
14764
14765
# File 'lib/google/apis/compute_beta/classes.rb', line 14763

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the future reservation. Corresponds to the JSON property description

Returns:

  • (String)


14769
14770
14771
# File 'lib/google/apis/compute_beta/classes.rb', line 14769

def description
  @description
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates if this group of VMs have emergent maintenance enabled. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


14774
14775
14776
# File 'lib/google/apis/compute_beta/classes.rb', line 14774

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] A unique identifier for this future reservation. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


14782
14783
14784
# File 'lib/google/apis/compute_beta/classes.rb', line 14782

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# futureReservation for future reservations. Corresponds to the JSON property kind

Returns:

  • (String)


14788
14789
14790
# File 'lib/google/apis/compute_beta/classes.rb', line 14788

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


14800
14801
14802
# File 'lib/google/apis/compute_beta/classes.rb', line 14800

def name
  @name
end

#name_prefixString

Name prefix for the reservations to be created at the time of delivery. The name prefix must comply with RFC1035. Maximum allowed length for name prefix is 20. Automatically created reservations name format will be -date-####. Corresponds to the JSON property namePrefix

Returns:

  • (String)


14808
14809
14810
# File 'lib/google/apis/compute_beta/classes.rb', line 14808

def name_prefix
  @name_prefix
end

#planning_statusString

Planning state before being submitted for evaluation Corresponds to the JSON property planningStatus

Returns:

  • (String)


14813
14814
14815
# File 'lib/google/apis/compute_beta/classes.rb', line 14813

def planning_status
  @planning_status
end

#protection_tierString

Protection tier for the workload. Corresponds to the JSON property protectionTier

Returns:

  • (String)


14818
14819
14820
# File 'lib/google/apis/compute_beta/classes.rb', line 14818

def protection_tier
  @protection_tier
end

#reservation_modeString

The reservation mode which determines reservation-termination behavior and expected pricing. Corresponds to the JSON property reservationMode

Returns:

  • (String)


14824
14825
14826
# File 'lib/google/apis/compute_beta/classes.rb', line 14824

def reservation_mode
  @reservation_mode
end

#reservation_nameString

Name of reservations where the capacity is provisioned at the time of delivery of future reservations. If the reservation with the given name does not exist already, it is created automatically at the time of Approval with INACTIVE state till specified start-time. Either provide the reservation_name or a name_prefix. Corresponds to the JSON property reservationName

Returns:

  • (String)


14833
14834
14835
# File 'lib/google/apis/compute_beta/classes.rb', line 14833

def reservation_name
  @reservation_name
end

#scheduling_typeString

Maintenance information for this reservation Corresponds to the JSON property schedulingType

Returns:

  • (String)


14838
14839
14840
# File 'lib/google/apis/compute_beta/classes.rb', line 14838

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


14844
14845
14846
# File 'lib/google/apis/compute_beta/classes.rb', line 14844

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


14850
14851
14852
# File 'lib/google/apis/compute_beta/classes.rb', line 14850

def self_link_with_id
  @self_link_with_id
end

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



14855
14856
14857
# File 'lib/google/apis/compute_beta/classes.rb', line 14855

def share_settings
  @share_settings
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from the delivered reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


14862
14863
14864
# File 'lib/google/apis/compute_beta/classes.rb', line 14862

def specific_reservation_required
  @specific_reservation_required
end

#specific_sku_propertiesGoogle::Apis::ComputeBeta::FutureReservationSpecificSkuProperties

Future Reservation configuration to indicate instance properties and total count. Corresponds to the JSON property specificSkuProperties



14869
14870
14871
# File 'lib/google/apis/compute_beta/classes.rb', line 14869

def specific_sku_properties
  @specific_sku_properties
end

#statusGoogle::Apis::ComputeBeta::FutureReservationStatus

[Output only] Represents status related to the future reservation. Corresponds to the JSON property status



14874
14875
14876
# File 'lib/google/apis/compute_beta/classes.rb', line 14874

def status
  @status
end

#time_windowGoogle::Apis::ComputeBeta::FutureReservationTimeWindow

Time window for this Future Reservation. Corresponds to the JSON property timeWindow



14879
14880
14881
# File 'lib/google/apis/compute_beta/classes.rb', line 14879

def time_window
  @time_window
end

#zoneString

Output only. [Output Only] URL of the Zone where this future reservation resides. Corresponds to the JSON property zone

Returns:

  • (String)


14885
14886
14887
# File 'lib/google/apis/compute_beta/classes.rb', line 14885

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14892
14893
14894
14895
14896
14897
14898
14899
14900
14901
14902
14903
14904
14905
14906
14907
14908
14909
14910
14911
14912
14913
14914
14915
14916
14917
14918
14919
14920
# File 'lib/google/apis/compute_beta/classes.rb', line 14892

def update!(**args)
  @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time)
  @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration)
  @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations)
  @commitment_info = args[:commitment_info] if args.key?(:commitment_info)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @planning_status = args[:planning_status] if args.key?(:planning_status)
  @protection_tier = args[:protection_tier] if args.key?(:protection_tier)
  @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode)
  @reservation_name = args[:reservation_name] if args.key?(:reservation_name)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @status = args[:status] if args.key?(:status)
  @time_window = args[:time_window] if args.key?(:time_window)
  @zone = args[:zone] if args.key?(:zone)
end