Class: Google::Apis::ComputeBeta::FutureReservation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#aggregate_reservation ⇒ Google::Apis::ComputeBeta::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs.
-
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by Compute Engine.
-
#auto_created_reservations_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#auto_delete_auto_created_reservations ⇒ Boolean
(also: #auto_delete_auto_created_reservations?)
Setting for enabling or disabling automatic deletion for auto-created reservation.
-
#commitment_info ⇒ Google::Apis::ComputeBeta::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an existing commitment.
-
#creation_timestamp ⇒ String
Output only.
-
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
-
#description ⇒ String
An optional description of this resource.
-
#enable_emergent_maintenance ⇒ Boolean
(also: #enable_emergent_maintenance?)
Indicates if this group of VMs have emergent maintenance enabled.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of delivery.
-
#planning_status ⇒ String
Planning state before being submitted for evaluation Corresponds to the JSON property
planningStatus. -
#protection_tier ⇒ String
Protection tier for the workload.
-
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and expected pricing.
-
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of delivery of future reservations.
-
#scheduling_type ⇒ String
Maintenance information for this reservation Corresponds to the JSON property
schedulingType. -
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#specific_reservation_required ⇒ Boolean
(also: #specific_reservation_required?)
Indicates whether the auto-created reservation can be consumed by VMs with affinity for "any" reservation.
-
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and total count.
-
#status ⇒ Google::Apis::ComputeBeta::FutureReservationStatus
[Output only] Represents status related to the future reservation.
-
#time_window ⇒ Google::Apis::ComputeBeta::FutureReservationTimeWindow
Time window for this Future Reservation.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservation
constructor
A new instance of FutureReservation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservation
Returns a new instance of FutureReservation.
14562 14563 14564 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14562 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregate_reservation ⇒ Google::Apis::ComputeBeta::AllocationAggregateReservation
This reservation type is specified by total resource amounts (e.g. total
count of CPUs) and can account for multiple instance SKUs. In other words,
one can create instances of varying shapes against this reservation.
Corresponds to the JSON property aggregateReservation
14392 14393 14394 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14392 def aggregate_reservation @aggregate_reservation end |
#auto_created_reservations_delete_time ⇒ String
Future timestamp when the FR auto-created reservations will be deleted by
Compute Engine. Format of this field must be a valid
href="https://www.ietf.org/rfc/rfc3339.txt">RFC3339 value.
Corresponds to the JSON property autoCreatedReservationsDeleteTime
14399 14400 14401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14399 def auto_created_reservations_delete_time @auto_created_reservations_delete_time end |
#auto_created_reservations_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property autoCreatedReservationsDuration
14407 14408 14409 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14407 def auto_created_reservations_duration @auto_created_reservations_duration end |
#auto_delete_auto_created_reservations ⇒ Boolean Also known as: auto_delete_auto_created_reservations?
Setting for enabling or disabling automatic deletion for auto-created
reservation. If set to true, auto-created reservations will be
deleted at Future Reservation's end time (default) or at user's defined
timestamp if any of the
[auto_created_reservations_delete_time, auto_created_reservations_duration]
values is specified.
For keeping auto-created reservation indefinitely, this value should be set
to false.
Corresponds to the JSON property autoDeleteAutoCreatedReservations
14419 14420 14421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14419 def auto_delete_auto_created_reservations @auto_delete_auto_created_reservations end |
#commitment_info ⇒ Google::Apis::ComputeBeta::FutureReservationCommitmentInfo
If not present, then FR will not deliver a new commitment or update an
existing commitment.
Corresponds to the JSON property commitmentInfo
14426 14427 14428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14426 def commitment_info @commitment_info end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this future reservation
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
14433 14434 14435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14433 def @creation_timestamp end |
#deployment_type ⇒ String
Type of the deployment requested as part of future reservation.
Corresponds to the JSON property deploymentType
14438 14439 14440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14438 def deployment_type @deployment_type end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the future reservation.
Corresponds to the JSON property description
14444 14445 14446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14444 def description @description end |
#enable_emergent_maintenance ⇒ Boolean Also known as: enable_emergent_maintenance?
Indicates if this group of VMs have emergent maintenance enabled.
Corresponds to the JSON property enableEmergentMaintenance
14449 14450 14451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14449 def enable_emergent_maintenance @enable_emergent_maintenance end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this future reservation.
The server
defines this identifier.
Corresponds to the JSON property id
14457 14458 14459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14457 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
futureReservation for future reservations.
Corresponds to the JSON property kind
14463 14464 14465 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14463 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
14475 14476 14477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14475 def name @name end |
#name_prefix ⇒ String
Name prefix for the reservations to be created at the time of
delivery. The name prefix must comply with RFC1035.
Maximum allowed length for name prefix is 20. Automatically created
reservations name format will be -date-####.
Corresponds to the JSON property namePrefix
14483 14484 14485 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14483 def name_prefix @name_prefix end |
#planning_status ⇒ String
Planning state before being submitted for evaluation
Corresponds to the JSON property planningStatus
14488 14489 14490 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14488 def planning_status @planning_status end |
#protection_tier ⇒ String
Protection tier for the workload.
Corresponds to the JSON property protectionTier
14493 14494 14495 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14493 def protection_tier @protection_tier end |
#reservation_mode ⇒ String
The reservation mode which determines reservation-termination behavior and
expected pricing.
Corresponds to the JSON property reservationMode
14499 14500 14501 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14499 def reservation_mode @reservation_mode end |
#reservation_name ⇒ String
Name of reservations where the capacity is provisioned at the time of
delivery of future reservations. If the reservation with the given name
does not exist already, it is created automatically at the time of Approval
with INACTIVE state till specified start-time. Either provide the
reservation_name or a name_prefix.
Corresponds to the JSON property reservationName
14508 14509 14510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14508 def reservation_name @reservation_name end |
#scheduling_type ⇒ String
Maintenance information for this reservation
Corresponds to the JSON property schedulingType
14513 14514 14515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14513 def scheduling_type @scheduling_type end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
14519 14520 14521 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14519 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
14525 14526 14527 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14525 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
14530 14531 14532 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14530 def share_settings @share_settings end |
#specific_reservation_required ⇒ Boolean Also known as: specific_reservation_required?
Indicates whether the auto-created reservation can be consumed by VMs with
affinity for "any" reservation. If the field is set, then only VMs that
target the reservation by name can consume from the delivered reservation.
Corresponds to the JSON property specificReservationRequired
14537 14538 14539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14537 def specific_reservation_required @specific_reservation_required end |
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationSpecificSkuProperties
Future Reservation configuration to indicate instance properties and
total count.
Corresponds to the JSON property specificSkuProperties
14544 14545 14546 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14544 def specific_sku_properties @specific_sku_properties end |
#status ⇒ Google::Apis::ComputeBeta::FutureReservationStatus
[Output only] Represents status related to the future reservation.
Corresponds to the JSON property status
14549 14550 14551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14549 def status @status end |
#time_window ⇒ Google::Apis::ComputeBeta::FutureReservationTimeWindow
Time window for this Future Reservation.
Corresponds to the JSON property timeWindow
14554 14555 14556 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14554 def time_window @time_window end |
#zone ⇒ String
Output only. [Output Only] URL of the Zone where this future reservation
resides.
Corresponds to the JSON property zone
14560 14561 14562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14560 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14567 14568 14569 14570 14571 14572 14573 14574 14575 14576 14577 14578 14579 14580 14581 14582 14583 14584 14585 14586 14587 14588 14589 14590 14591 14592 14593 14594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 14567 def update!(**args) @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation) @auto_created_reservations_delete_time = args[:auto_created_reservations_delete_time] if args.key?(:auto_created_reservations_delete_time) @auto_created_reservations_duration = args[:auto_created_reservations_duration] if args.key?(:auto_created_reservations_duration) @auto_delete_auto_created_reservations = args[:auto_delete_auto_created_reservations] if args.key?(:auto_delete_auto_created_reservations) @commitment_info = args[:commitment_info] if args.key?(:commitment_info) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @description = args[:description] if args.key?(:description) @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @planning_status = args[:planning_status] if args.key?(:planning_status) @protection_tier = args[:protection_tier] if args.key?(:protection_tier) @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode) @reservation_name = args[:reservation_name] if args.key?(:reservation_name) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) @status = args[:status] if args.key?(:status) @time_window = args[:time_window] if args.key?(:time_window) @zone = args[:zone] if args.key?(:zone) end |