Class: Google::Apis::ComputeBeta::FutureReservationCommitmentInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationCommitmentInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#commitment_name ⇒ String
name of the commitment where capacity is being delivered to.
-
#commitment_plan ⇒ String
Indicates if a Commitment needs to be created as part of FR delivery.
-
#previous_commitment_terms ⇒ String
Only applicable if FR is delivering to the same reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationCommitmentInfo
constructor
A new instance of FutureReservationCommitmentInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationCommitmentInfo
Returns a new instance of FutureReservationCommitmentInfo.
15859 15860 15861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commitment_name ⇒ String
name of the commitment where capacity is being delivered to.
Corresponds to the JSON property commitmentName
15843 15844 15845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15843 def commitment_name @commitment_name end |
#commitment_plan ⇒ String
Indicates if a Commitment needs to be created as part of FR delivery. If
this field is not present, then no
commitment needs to be created.
Corresponds to the JSON property commitmentPlan
15850 15851 15852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15850 def commitment_plan @commitment_plan end |
#previous_commitment_terms ⇒ String
Only applicable if FR is delivering to the same reservation. If set, all
parent commitments will be extended to match the end date of the plan for
this commitment.
Corresponds to the JSON property previousCommitmentTerms
15857 15858 15859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15857 def previous_commitment_terms @previous_commitment_terms end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15864 15865 15866 15867 15868 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15864 def update!(**args) @commitment_name = args[:commitment_name] if args.key?(:commitment_name) @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan) @previous_commitment_terms = args[:previous_commitment_terms] if args.key?(:previous_commitment_terms) end |