Class: Google::Apis::ComputeBeta::FutureReservationCommitmentInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationCommitmentInfo

Returns a new instance of FutureReservationCommitmentInfo.



15734
15735
15736
# File 'lib/google/apis/compute_beta/classes.rb', line 15734

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitment_nameString

name of the commitment where capacity is being delivered to. Corresponds to the JSON property commitmentName

Returns:

  • (String)


15718
15719
15720
# File 'lib/google/apis/compute_beta/classes.rb', line 15718

def commitment_name
  @commitment_name
end

#commitment_planString

Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Corresponds to the JSON property commitmentPlan

Returns:

  • (String)


15725
15726
15727
# File 'lib/google/apis/compute_beta/classes.rb', line 15725

def commitment_plan
  @commitment_plan
end

#previous_commitment_termsString

Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Corresponds to the JSON property previousCommitmentTerms

Returns:

  • (String)


15732
15733
15734
# File 'lib/google/apis/compute_beta/classes.rb', line 15732

def previous_commitment_terms
  @previous_commitment_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15739
15740
15741
15742
15743
# File 'lib/google/apis/compute_beta/classes.rb', line 15739

def update!(**args)
  @commitment_name = args[:commitment_name] if args.key?(:commitment_name)
  @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan)
  @previous_commitment_terms = args[:previous_commitment_terms] if args.key?(:previous_commitment_terms)
end