Class: Google::Apis::ComputeBeta::FutureReservationCommitmentInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationCommitmentInfo

Returns a new instance of FutureReservationCommitmentInfo.



14946
14947
14948
# File 'lib/google/apis/compute_beta/classes.rb', line 14946

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitment_nameString

name of the commitment where capacity is being delivered to. Corresponds to the JSON property commitmentName

Returns:

  • (String)


14930
14931
14932
# File 'lib/google/apis/compute_beta/classes.rb', line 14930

def commitment_name
  @commitment_name
end

#commitment_planString

Indicates if a Commitment needs to be created as part of FR delivery. If this field is not present, then no commitment needs to be created. Corresponds to the JSON property commitmentPlan

Returns:

  • (String)


14937
14938
14939
# File 'lib/google/apis/compute_beta/classes.rb', line 14937

def commitment_plan
  @commitment_plan
end

#previous_commitment_termsString

Only applicable if FR is delivering to the same reservation. If set, all parent commitments will be extended to match the end date of the plan for this commitment. Corresponds to the JSON property previousCommitmentTerms

Returns:

  • (String)


14944
14945
14946
# File 'lib/google/apis/compute_beta/classes.rb', line 14944

def previous_commitment_terms
  @previous_commitment_terms
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14951
14952
14953
14954
14955
# File 'lib/google/apis/compute_beta/classes.rb', line 14951

def update!(**args)
  @commitment_name = args[:commitment_name] if args.key?(:commitment_name)
  @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan)
  @previous_commitment_terms = args[:previous_commitment_terms] if args.key?(:previous_commitment_terms)
end