Class: Google::Apis::ComputeBeta::FutureReservationStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output only] Represents status related to the future reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatus

Returns a new instance of FutureReservationStatus.



15860
15861
15862
# File 'lib/google/apis/compute_beta/classes.rb', line 15860

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#amendment_statusString

Output only. [Output Only] The current status of the requested amendment. Corresponds to the JSON property amendmentStatus

Returns:

  • (String)


15813
15814
15815
# File 'lib/google/apis/compute_beta/classes.rb', line 15813

def amendment_status
  @amendment_status
end

#auto_created_reservationsArray<String>

Output only. Fully qualified urls of the automatically created reservations at start_time. Corresponds to the JSON property autoCreatedReservations

Returns:

  • (Array<String>)


15819
15820
15821
# File 'lib/google/apis/compute_beta/classes.rb', line 15819

def auto_created_reservations
  @auto_created_reservations
end

#existing_matching_usage_infoGoogle::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



15825
15826
15827
# File 'lib/google/apis/compute_beta/classes.rb', line 15825

def existing_matching_usage_info
  @existing_matching_usage_info
end

#fulfilled_countFixnum

Output only. This count indicates the fulfilled capacity so far. This is set during "PROVISIONING" state. This count also includes capacity delivered as part of existing matching reservations. Corresponds to the JSON property fulfilledCount

Returns:

  • (Fixnum)


15833
15834
15835
# File 'lib/google/apis/compute_beta/classes.rb', line 15833

def fulfilled_count
  @fulfilled_count
end

#last_known_good_stateGoogle::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState

The state that the future reservation will be reverted to should the amendment be declined. Corresponds to the JSON property lastKnownGoodState



15839
15840
15841
# File 'lib/google/apis/compute_beta/classes.rb', line 15839

def last_known_good_state
  @last_known_good_state
end

#lock_timeString

Output only. Time when Future Reservation would become LOCKED, after which no modifications to Future Reservation will be allowed. Applicable only after the Future Reservation is in the APPROVED state. The lock_time is an RFC3339 string. The procurement_status will transition to PROCURING state at this time. Corresponds to the JSON property lockTime

Returns:

  • (String)


15848
15849
15850
# File 'lib/google/apis/compute_beta/classes.rb', line 15848

def lock_time
  @lock_time
end

#procurement_statusString

Output only. Current state of this Future Reservation Corresponds to the JSON property procurementStatus

Returns:

  • (String)


15853
15854
15855
# File 'lib/google/apis/compute_beta/classes.rb', line 15853

def procurement_status
  @procurement_status
end

#specific_sku_propertiesGoogle::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties

Properties to be set for the Future Reservation. Corresponds to the JSON property specificSkuProperties



15858
15859
15860
# File 'lib/google/apis/compute_beta/classes.rb', line 15858

def specific_sku_properties
  @specific_sku_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15865
15866
15867
15868
15869
15870
15871
15872
15873
15874
# File 'lib/google/apis/compute_beta/classes.rb', line 15865

def update!(**args)
  @amendment_status = args[:amendment_status] if args.key?(:amendment_status)
  @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count)
  @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
end