Class: Google::Apis::ComputeBeta::FutureReservationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output only] Represents status related to the future reservation.
Instance Attribute Summary collapse
-
#amendment_status ⇒ String
Output only.
-
#auto_created_reservations ⇒ Array<String>
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#fulfilled_count ⇒ Fixnum
Output only.
-
#last_known_good_state ⇒ Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the amendment be declined.
-
#lock_time ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
-
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatus
constructor
A new instance of FutureReservationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatus
Returns a new instance of FutureReservationStatus.
15836 15837 15838 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15836 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amendment_status ⇒ String
Output only. [Output Only] The current status of the requested amendment.
Corresponds to the JSON property amendmentStatus
15789 15790 15791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15789 def amendment_status @amendment_status end |
#auto_created_reservations ⇒ Array<String>
Output only. Fully qualified urls of the automatically created reservations at
start_time.
Corresponds to the JSON property autoCreatedReservations
15795 15796 15797 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15795 def auto_created_reservations @auto_created_reservations end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
15801 15802 15803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15801 def existing_matching_usage_info @existing_matching_usage_info end |
#fulfilled_count ⇒ Fixnum
Output only. This count indicates the fulfilled capacity so far. This is set
during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
Corresponds to the JSON property fulfilledCount
15809 15810 15811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15809 def fulfilled_count @fulfilled_count end |
#last_known_good_state ⇒ Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the
amendment be declined.
Corresponds to the JSON property lastKnownGoodState
15815 15816 15817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15815 def last_known_good_state @last_known_good_state end |
#lock_time ⇒ String
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
Corresponds to the JSON property lockTime
15824 15825 15826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15824 def lock_time @lock_time end |
#procurement_status ⇒ String
Output only. Current state of this Future Reservation
Corresponds to the JSON property procurementStatus
15829 15830 15831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15829 def procurement_status @procurement_status end |
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Corresponds to the JSON property specificSkuProperties
15834 15835 15836 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15834 def specific_sku_properties @specific_sku_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15841 15842 15843 15844 15845 15846 15847 15848 15849 15850 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15841 def update!(**args) @amendment_status = args[:amendment_status] if args.key?(:amendment_status) @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count) @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state) @lock_time = args[:lock_time] if args.key?(:lock_time) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) end |