Class: Google::Apis::ComputeBeta::FutureReservationStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output only] Represents status related to the future reservation.
Instance Attribute Summary collapse
-
#amendment_status ⇒ String
Output only.
-
#auto_created_reservations ⇒ Array<String>
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#fulfilled_count ⇒ Fixnum
Output only.
-
#last_known_good_state ⇒ Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the amendment be declined.
-
#lock_time ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
-
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatus
constructor
A new instance of FutureReservationStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatus
Returns a new instance of FutureReservationStatus.
15252 15253 15254 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#amendment_status ⇒ String
Output only. [Output Only] The current status of the requested amendment.
Corresponds to the JSON property amendmentStatus
15205 15206 15207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15205 def amendment_status @amendment_status end |
#auto_created_reservations ⇒ Array<String>
Output only. Fully qualified urls of the automatically created reservations at
start_time.
Corresponds to the JSON property autoCreatedReservations
15211 15212 15213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15211 def auto_created_reservations @auto_created_reservations end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
15217 15218 15219 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15217 def existing_matching_usage_info @existing_matching_usage_info end |
#fulfilled_count ⇒ Fixnum
Output only. This count indicates the fulfilled capacity so far. This is set
during
"PROVISIONING" state. This count also includes capacity delivered as part
of existing matching reservations.
Corresponds to the JSON property fulfilledCount
15225 15226 15227 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15225 def fulfilled_count @fulfilled_count end |
#last_known_good_state ⇒ Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState
The state that the future reservation will be reverted to should the
amendment be declined.
Corresponds to the JSON property lastKnownGoodState
15231 15232 15233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15231 def last_known_good_state @last_known_good_state end |
#lock_time ⇒ String
Output only. Time when Future Reservation would become LOCKED, after which no
modifications to Future Reservation will be allowed. Applicable only
after the Future Reservation is in the APPROVED state. The lock_time is
an RFC3339 string. The procurement_status will transition to PROCURING
state at this time.
Corresponds to the JSON property lockTime
15240 15241 15242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15240 def lock_time @lock_time end |
#procurement_status ⇒ String
Output only. Current state of this Future Reservation
Corresponds to the JSON property procurementStatus
15245 15246 15247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15245 def procurement_status @procurement_status end |
#specific_sku_properties ⇒ Google::Apis::ComputeBeta::FutureReservationStatusSpecificSkuProperties
Properties to be set for the Future Reservation.
Corresponds to the JSON property specificSkuProperties
15250 15251 15252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15250 def specific_sku_properties @specific_sku_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15257 15258 15259 15260 15261 15262 15263 15264 15265 15266 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15257 def update!(**args) @amendment_status = args[:amendment_status] if args.key?(:amendment_status) @auto_created_reservations = args[:auto_created_reservations] if args.key?(:auto_created_reservations) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @fulfilled_count = args[:fulfilled_count] if args.key?(:fulfilled_count) @last_known_good_state = args[:last_known_good_state] if args.key?(:last_known_good_state) @lock_time = args[:lock_time] if args.key?(:lock_time) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties) end |