Class: Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The state that the future reservation will be reverted to should the amendment be declined.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState

Returns a new instance of FutureReservationStatusLastKnownGoodState.



16070
16071
16072
# File 'lib/google/apis/compute_beta/classes.rb', line 16070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. [Output Only] The description of the FutureReservation before an amendment was requested. Corresponds to the JSON property description

Returns:

  • (String)


16038
16039
16040
# File 'lib/google/apis/compute_beta/classes.rb', line 16038

def description
  @description
end

#existing_matching_usage_infoGoogle::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



16044
16045
16046
# File 'lib/google/apis/compute_beta/classes.rb', line 16044

def existing_matching_usage_info
  @existing_matching_usage_info
end

#future_reservation_specsGoogle::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

The properties of the last known good state for the Future Reservation. Corresponds to the JSON property futureReservationSpecs



16049
16050
16051
# File 'lib/google/apis/compute_beta/classes.rb', line 16049

def future_reservation_specs
  @future_reservation_specs
end

#lock_timeString

Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested. Corresponds to the JSON property lockTime

Returns:

  • (String)


16055
16056
16057
# File 'lib/google/apis/compute_beta/classes.rb', line 16055

def lock_time
  @lock_time
end

#name_prefixString

Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested. Corresponds to the JSON property namePrefix

Returns:

  • (String)


16061
16062
16063
# File 'lib/google/apis/compute_beta/classes.rb', line 16061

def name_prefix
  @name_prefix
end

#procurement_statusString

Output only. [Output Only] The status of the last known good state for the Future Reservation. Corresponds to the JSON property procurementStatus

Returns:

  • (String)


16068
16069
16070
# File 'lib/google/apis/compute_beta/classes.rb', line 16068

def procurement_status
  @procurement_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16075
16076
16077
16078
16079
16080
16081
16082
# File 'lib/google/apis/compute_beta/classes.rb', line 16075

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
end