Class: Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The state that the future reservation will be reverted to should the amendment be declined.
Instance Attribute Summary collapse
-
#description ⇒ String
Output only.
-
#existing_matching_usage_info ⇒ Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future reservation.
-
#future_reservation_specs ⇒ Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
-
#lock_time ⇒ String
Output only.
-
#name_prefix ⇒ String
Output only.
-
#procurement_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
constructor
A new instance of FutureReservationStatusLastKnownGoodState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState
Returns a new instance of FutureReservationStatusLastKnownGoodState.
15945 15946 15947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15945 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Output only. [Output Only] The description of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property description
15913 15914 15915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15913 def description @description end |
#existing_matching_usage_info ⇒ Google::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo
[Output Only] Represents the existing matching usage for the future
reservation.
Corresponds to the JSON property existingMatchingUsageInfo
15919 15920 15921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15919 def existing_matching_usage_info @existing_matching_usage_info end |
#future_reservation_specs ⇒ Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs
The properties of the last known good state for the Future Reservation.
Corresponds to the JSON property futureReservationSpecs
15924 15925 15926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15924 def future_reservation_specs @future_reservation_specs end |
#lock_time ⇒ String
Output only. [Output Only] The lock time of the FutureReservation before an
amendment was requested.
Corresponds to the JSON property lockTime
15930 15931 15932 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15930 def lock_time @lock_time end |
#name_prefix ⇒ String
Output only. [Output Only] The name prefix of the Future Reservation before an
amendment was requested.
Corresponds to the JSON property namePrefix
15936 15937 15938 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15936 def name_prefix @name_prefix end |
#procurement_status ⇒ String
Output only. [Output Only] The status of the last known good state for the
Future
Reservation.
Corresponds to the JSON property procurementStatus
15943 15944 15945 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15943 def procurement_status @procurement_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15950 15951 15952 15953 15954 15955 15956 15957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15950 def update!(**args) @description = args[:description] if args.key?(:description) @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info) @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs) @lock_time = args[:lock_time] if args.key?(:lock_time) @name_prefix = args[:name_prefix] if args.key?(:name_prefix) @procurement_status = args[:procurement_status] if args.key?(:procurement_status) end |