Class: Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The state that the future reservation will be reverted to should the amendment be declined.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodState

Returns a new instance of FutureReservationStatusLastKnownGoodState.



15337
15338
15339
# File 'lib/google/apis/compute_beta/classes.rb', line 15337

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Output only. [Output Only] The description of the FutureReservation before an amendment was requested. Corresponds to the JSON property description

Returns:

  • (String)


15305
15306
15307
# File 'lib/google/apis/compute_beta/classes.rb', line 15305

def description
  @description
end

#existing_matching_usage_infoGoogle::Apis::ComputeBeta::FutureReservationStatusExistingMatchingUsageInfo

[Output Only] Represents the existing matching usage for the future reservation. Corresponds to the JSON property existingMatchingUsageInfo



15311
15312
15313
# File 'lib/google/apis/compute_beta/classes.rb', line 15311

def existing_matching_usage_info
  @existing_matching_usage_info
end

#future_reservation_specsGoogle::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

The properties of the last known good state for the Future Reservation. Corresponds to the JSON property futureReservationSpecs



15316
15317
15318
# File 'lib/google/apis/compute_beta/classes.rb', line 15316

def future_reservation_specs
  @future_reservation_specs
end

#lock_timeString

Output only. [Output Only] The lock time of the FutureReservation before an amendment was requested. Corresponds to the JSON property lockTime

Returns:

  • (String)


15322
15323
15324
# File 'lib/google/apis/compute_beta/classes.rb', line 15322

def lock_time
  @lock_time
end

#name_prefixString

Output only. [Output Only] The name prefix of the Future Reservation before an amendment was requested. Corresponds to the JSON property namePrefix

Returns:

  • (String)


15328
15329
15330
# File 'lib/google/apis/compute_beta/classes.rb', line 15328

def name_prefix
  @name_prefix
end

#procurement_statusString

Output only. [Output Only] The status of the last known good state for the Future Reservation. Corresponds to the JSON property procurementStatus

Returns:

  • (String)


15335
15336
15337
# File 'lib/google/apis/compute_beta/classes.rb', line 15335

def procurement_status
  @procurement_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15342
15343
15344
15345
15346
15347
15348
15349
# File 'lib/google/apis/compute_beta/classes.rb', line 15342

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @existing_matching_usage_info = args[:existing_matching_usage_info] if args.key?(:existing_matching_usage_info)
  @future_reservation_specs = args[:future_reservation_specs] if args.key?(:future_reservation_specs)
  @lock_time = args[:lock_time] if args.key?(:lock_time)
  @name_prefix = args[:name_prefix] if args.key?(:name_prefix)
  @procurement_status = args[:procurement_status] if args.key?(:procurement_status)
end