Class: Google::Apis::ComputeBeta::FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The properties of the last known good state for the Future Reservation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationStatusLastKnownGoodStateFutureReservationSpecs

Returns a new instance of FutureReservationStatusLastKnownGoodStateFutureReservationSpecs.



15166
15167
15168
# File 'lib/google/apis/compute_beta/classes.rb', line 15166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



15153
15154
15155
# File 'lib/google/apis/compute_beta/classes.rb', line 15153

def share_settings
  @share_settings
end

#specific_sku_propertiesGoogle::Apis::ComputeBeta::FutureReservationSpecificSkuProperties

Output only. [Output Only] The previous instance related properties of the Future Reservation. Corresponds to the JSON property specificSkuProperties



15159
15160
15161
# File 'lib/google/apis/compute_beta/classes.rb', line 15159

def specific_sku_properties
  @specific_sku_properties
end

#time_windowGoogle::Apis::ComputeBeta::FutureReservationTimeWindow

Output only. [Output Only] The previous time window of the Future Reservation. Corresponds to the JSON property timeWindow



15164
15165
15166
# File 'lib/google/apis/compute_beta/classes.rb', line 15164

def time_window
  @time_window
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15171
15172
15173
15174
15175
# File 'lib/google/apis/compute_beta/classes.rb', line 15171

def update!(**args)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_sku_properties = args[:specific_sku_properties] if args.key?(:specific_sku_properties)
  @time_window = args[:time_window] if args.key?(:time_window)
end