Class: Google::Apis::ComputeBeta::FutureReservationTimeWindow
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationTimeWindow
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#start_time ⇒ String
Start time of the Future Reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationTimeWindow
constructor
A new instance of FutureReservationTimeWindow.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationTimeWindow
Returns a new instance of FutureReservationTimeWindow.
16236 16237 16238 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property duration
16223 16224 16225 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16223 def duration @duration end |
#end_time ⇒ String
Corresponds to the JSON property endTime
16228 16229 16230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16228 def end_time @end_time end |
#start_time ⇒ String
Start time of the Future Reservation. The start_time is an RFC3339
string.
Corresponds to the JSON property startTime
16234 16235 16236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16234 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16241 16242 16243 16244 16245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16241 def update!(**args) @duration = args[:duration] if args.key?(:duration) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |