Class: Google::Apis::ComputeBeta::FutureReservationTimeWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationTimeWindow

Returns a new instance of FutureReservationTimeWindow.



16011
16012
16013
# File 'lib/google/apis/compute_beta/classes.rb', line 16011

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property duration



15998
15999
16000
# File 'lib/google/apis/compute_beta/classes.rb', line 15998

def duration
  @duration
end

#end_timeString

Corresponds to the JSON property endTime

Returns:

  • (String)


16003
16004
16005
# File 'lib/google/apis/compute_beta/classes.rb', line 16003

def end_time
  @end_time
end

#start_timeString

Start time of the Future Reservation. The start_time is an RFC3339 string. Corresponds to the JSON property startTime

Returns:

  • (String)


16009
16010
16011
# File 'lib/google/apis/compute_beta/classes.rb', line 16009

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16016
16017
16018
16019
16020
# File 'lib/google/apis/compute_beta/classes.rb', line 16016

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end