Class: Google::Apis::ComputeBeta::FutureReservationTimeWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationTimeWindow

Returns a new instance of FutureReservationTimeWindow.



14895
14896
14897
# File 'lib/google/apis/compute_beta/classes.rb', line 14895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property duration



14882
14883
14884
# File 'lib/google/apis/compute_beta/classes.rb', line 14882

def duration
  @duration
end

#end_timeString

Corresponds to the JSON property endTime

Returns:

  • (String)


14887
14888
14889
# File 'lib/google/apis/compute_beta/classes.rb', line 14887

def end_time
  @end_time
end

#start_timeString

Start time of the Future Reservation. The start_time is an RFC3339 string. Corresponds to the JSON property startTime

Returns:

  • (String)


14893
14894
14895
# File 'lib/google/apis/compute_beta/classes.rb', line 14893

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14900
14901
14902
14903
14904
# File 'lib/google/apis/compute_beta/classes.rb', line 14900

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @end_time = args[:end_time] if args.key?(:end_time)
  @start_time = args[:start_time] if args.key?(:start_time)
end