Class: Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



16249
16250
16251
# File 'lib/google/apis/compute_beta/classes.rb', line 16249

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16205
16206
16207
# File 'lib/google/apis/compute_beta/classes.rb', line 16205

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16210
16211
16212
# File 'lib/google/apis/compute_beta/classes.rb', line 16210

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



16215
16216
16217
# File 'lib/google/apis/compute_beta/classes.rb', line 16215

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


16222
16223
16224
# File 'lib/google/apis/compute_beta/classes.rb', line 16222

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16232
16233
16234
# File 'lib/google/apis/compute_beta/classes.rb', line 16232

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16237
16238
16239
# File 'lib/google/apis/compute_beta/classes.rb', line 16237

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16242
16243
16244
# File 'lib/google/apis/compute_beta/classes.rb', line 16242

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16247
16248
16249
# File 'lib/google/apis/compute_beta/classes.rb', line 16247

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16254
16255
16256
16257
16258
16259
16260
16261
16262
16263
# File 'lib/google/apis/compute_beta/classes.rb', line 16254

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end