Class: Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of future reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::FutureReservationsScopedList>
A list of Future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
constructor
A new instance of FutureReservationsAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsAggregatedListResponse
Returns a new instance of FutureReservationsAggregatedListResponse.
16223 16224 16225 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16223 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
16179 16180 16181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16179 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
16184 16185 16186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16184 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::FutureReservationsScopedList>
A list of Future reservation resources.
Corresponds to the JSON property items
16189 16190 16191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16189 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
futureReservationsAggregatedListResponse for future
resevation aggregated list response.
Corresponds to the JSON property kind
16196 16197 16198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16196 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
16206 16207 16208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16206 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
16211 16212 16213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16211 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
16216 16217 16218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16216 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
16221 16222 16223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16221 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16228 16229 16230 16231 16232 16233 16234 16235 16236 16237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16228 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |