Class: Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



16074
16075
16076
# File 'lib/google/apis/compute_beta/classes.rb', line 16074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16030
16031
16032
# File 'lib/google/apis/compute_beta/classes.rb', line 16030

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16035
16036
16037
# File 'lib/google/apis/compute_beta/classes.rb', line 16035

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



16040
16041
16042
# File 'lib/google/apis/compute_beta/classes.rb', line 16040

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


16047
16048
16049
# File 'lib/google/apis/compute_beta/classes.rb', line 16047

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16057
16058
16059
# File 'lib/google/apis/compute_beta/classes.rb', line 16057

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16062
16063
16064
# File 'lib/google/apis/compute_beta/classes.rb', line 16062

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16067
16068
16069
# File 'lib/google/apis/compute_beta/classes.rb', line 16067

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16072
16073
16074
# File 'lib/google/apis/compute_beta/classes.rb', line 16072

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16079
16080
16081
16082
16083
16084
16085
16086
16087
16088
# File 'lib/google/apis/compute_beta/classes.rb', line 16079

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end