Class: Google::Apis::ComputeBeta::FutureReservationsAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of future reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsAggregatedListResponse

Returns a new instance of FutureReservationsAggregatedListResponse.



15490
15491
15492
# File 'lib/google/apis/compute_beta/classes.rb', line 15490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15446
15447
15448
# File 'lib/google/apis/compute_beta/classes.rb', line 15446

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15451
15452
15453
# File 'lib/google/apis/compute_beta/classes.rb', line 15451

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FutureReservationsScopedList>

A list of Future reservation resources. Corresponds to the JSON property items



15456
15457
15458
# File 'lib/google/apis/compute_beta/classes.rb', line 15456

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# futureReservationsAggregatedListResponse for future resevation aggregated list response. Corresponds to the JSON property kind

Returns:

  • (String)


15463
15464
15465
# File 'lib/google/apis/compute_beta/classes.rb', line 15463

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15473
15474
15475
# File 'lib/google/apis/compute_beta/classes.rb', line 15473

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15478
15479
15480
# File 'lib/google/apis/compute_beta/classes.rb', line 15478

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15483
15484
15485
# File 'lib/google/apis/compute_beta/classes.rb', line 15483

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15488
15489
15490
# File 'lib/google/apis/compute_beta/classes.rb', line 15488

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15495
15496
15497
15498
15499
15500
15501
15502
15503
15504
# File 'lib/google/apis/compute_beta/classes.rb', line 15495

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end