Class: Google::Apis::ComputeBeta::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



16438
16439
16440
# File 'lib/google/apis/compute_beta/classes.rb', line 16438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16393
16394
16395
# File 'lib/google/apis/compute_beta/classes.rb', line 16393

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16399
16400
16401
# File 'lib/google/apis/compute_beta/classes.rb', line 16399

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



16404
16405
16406
# File 'lib/google/apis/compute_beta/classes.rb', line 16404

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


16411
16412
16413
# File 'lib/google/apis/compute_beta/classes.rb', line 16411

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16421
16422
16423
# File 'lib/google/apis/compute_beta/classes.rb', line 16421

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16426
16427
16428
# File 'lib/google/apis/compute_beta/classes.rb', line 16426

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16431
16432
16433
# File 'lib/google/apis/compute_beta/classes.rb', line 16431

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16436
16437
16438
# File 'lib/google/apis/compute_beta/classes.rb', line 16436

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16443
16444
16445
16446
16447
16448
16449
16450
16451
16452
# File 'lib/google/apis/compute_beta/classes.rb', line 16443

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end