Class: Google::Apis::ComputeBeta::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
16388 16389 16390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16388 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
16343 16344 16345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16343 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
16349 16350 16351 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16349 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
16354 16355 16356 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16354 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
16361 16362 16363 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16361 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
16371 16372 16373 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16371 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
16376 16377 16378 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16376 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
16381 16382 16383 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16381 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
16386 16387 16388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16386 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16393 16394 16395 16396 16397 16398 16399 16400 16401 16402 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16393 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |