Class: Google::Apis::ComputeBeta::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



16213
16214
16215
# File 'lib/google/apis/compute_beta/classes.rb', line 16213

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16168
16169
16170
# File 'lib/google/apis/compute_beta/classes.rb', line 16168

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16174
16175
16176
# File 'lib/google/apis/compute_beta/classes.rb', line 16174

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



16179
16180
16181
# File 'lib/google/apis/compute_beta/classes.rb', line 16179

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


16186
16187
16188
# File 'lib/google/apis/compute_beta/classes.rb', line 16186

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16196
16197
16198
# File 'lib/google/apis/compute_beta/classes.rb', line 16196

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16201
16202
16203
# File 'lib/google/apis/compute_beta/classes.rb', line 16201

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16206
16207
16208
# File 'lib/google/apis/compute_beta/classes.rb', line 16206

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16211
16212
16213
# File 'lib/google/apis/compute_beta/classes.rb', line 16211

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16218
16219
16220
16221
16222
16223
16224
16225
16226
16227
# File 'lib/google/apis/compute_beta/classes.rb', line 16218

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end