Class: Google::Apis::ComputeBeta::FutureReservationsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureReservationsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::FutureReservation>
[Output Only] A list of future reservation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureReservationsListResponse
constructor
A new instance of FutureReservationsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureReservationsListResponse
Returns a new instance of FutureReservationsListResponse.
15629 15630 15631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
15584 15585 15586 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15584 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
15590 15591 15592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15590 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::FutureReservation>
[Output Only] A list of future reservation resources.
Corresponds to the JSON property items
15595 15596 15597 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15595 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
FutureReservationsListResponse for lists of
reservations
Corresponds to the JSON property kind
15602 15603 15604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15602 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
15612 15613 15614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15612 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
15617 15618 15619 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15617 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
15622 15623 15624 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15622 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::FutureReservationsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
15627 15628 15629 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15627 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15634 15635 15636 15637 15638 15639 15640 15641 15642 15643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15634 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |