Class: Google::Apis::ComputeBeta::FutureReservationsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureReservationsListResponse

Returns a new instance of FutureReservationsListResponse.



15423
15424
15425
# File 'lib/google/apis/compute_beta/classes.rb', line 15423

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


15378
15379
15380
# File 'lib/google/apis/compute_beta/classes.rb', line 15378

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


15384
15385
15386
# File 'lib/google/apis/compute_beta/classes.rb', line 15384

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::FutureReservation>

[Output Only] A list of future reservation resources. Corresponds to the JSON property items



15389
15390
15391
# File 'lib/google/apis/compute_beta/classes.rb', line 15389

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# FutureReservationsListResponse for lists of reservations Corresponds to the JSON property kind

Returns:

  • (String)


15396
15397
15398
# File 'lib/google/apis/compute_beta/classes.rb', line 15396

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


15406
15407
15408
# File 'lib/google/apis/compute_beta/classes.rb', line 15406

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


15411
15412
15413
# File 'lib/google/apis/compute_beta/classes.rb', line 15411

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


15416
15417
15418
# File 'lib/google/apis/compute_beta/classes.rb', line 15416

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::FutureReservationsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



15421
15422
15423
# File 'lib/google/apis/compute_beta/classes.rb', line 15421

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15428
15429
15430
15431
15432
15433
15434
15435
15436
15437
# File 'lib/google/apis/compute_beta/classes.rb', line 15428

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end