Class: Google::Apis::ComputeBeta::FutureResourcesRecommendation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Recommendation for single resources specification, to be created in the future.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendation

Returns a new instance of FutureResourcesRecommendation.



15853
15854
15855
# File 'lib/google/apis/compute_beta/classes.rb', line 15853

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#end_timeString

Corresponds to the JSON property endTime

Returns:

  • (String)


15821
15822
15823
# File 'lib/google/apis/compute_beta/classes.rb', line 15821

def end_time
  @end_time
end

#locationString

The advised location for resource usage. When a zone, in format 'zones/'. If not set, it means that no location is recommended - see other_locations for details. Corresponds to the JSON property location

Returns:

  • (String)


15829
15830
15831
# File 'lib/google/apis/compute_beta/classes.rb', line 15829

def location
  @location
end

#other_locationsHash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendationOtherLocation>

List of locations in the request scope that were not recommended. Keys of the map are zones, in format 'zones/'. The values are status information indicating the recommendation status. Corresponds to the JSON property otherLocations



15836
15837
15838
# File 'lib/google/apis/compute_beta/classes.rb', line 15836

def other_locations
  @other_locations
end

#recommendation_idString

Unique id of the recommendation, a UUID string generated by the API. Corresponds to the JSON property recommendationId

Returns:

  • (String)


15841
15842
15843
# File 'lib/google/apis/compute_beta/classes.rb', line 15841

def recommendation_id
  @recommendation_id
end

#recommendation_typeString

Type of recommendation. Currently only FUTURE_RESERVATION is supported. Corresponds to the JSON property recommendationType

Returns:

  • (String)


15846
15847
15848
# File 'lib/google/apis/compute_beta/classes.rb', line 15846

def recommendation_type
  @recommendation_type
end

#start_timeString

Corresponds to the JSON property startTime

Returns:

  • (String)


15851
15852
15853
# File 'lib/google/apis/compute_beta/classes.rb', line 15851

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15858
15859
15860
15861
15862
15863
15864
15865
# File 'lib/google/apis/compute_beta/classes.rb', line 15858

def update!(**args)
  @end_time = args[:end_time] if args.key?(:end_time)
  @location = args[:location] if args.key?(:location)
  @other_locations = args[:other_locations] if args.key?(:other_locations)
  @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id)
  @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type)
  @start_time = args[:start_time] if args.key?(:start_time)
end