Class: Google::Apis::ComputeBeta::FutureResourcesRecommendation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesRecommendation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Recommendation for single resources specification, to be created in the future.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Corresponds to the JSON property
endTime. -
#location ⇒ String
The advised location for resource usage.
-
#other_locations ⇒ Hash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not recommended.
-
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
-
#recommendation_type ⇒ String
Type of recommendation.
-
#start_time ⇒ String
Corresponds to the JSON property
startTime.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesRecommendation
constructor
A new instance of FutureResourcesRecommendation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesRecommendation
Returns a new instance of FutureResourcesRecommendation.
15321 15322 15323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Corresponds to the JSON property endTime
15289 15290 15291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15289 def end_time @end_time end |
#location ⇒ String
The advised location for resource usage. When a zone, in format
'zones/'.
If not set, it means that no location is recommended - see
other_locations for details.
Corresponds to the JSON property location
15297 15298 15299 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15297 def location @location end |
#other_locations ⇒ Hash<String,Google::Apis::ComputeBeta::FutureResourcesRecommendationOtherLocation>
List of locations in the request scope that were not
recommended. Keys of the map are zones, in format 'zones/'.
The values are status information indicating the recommendation status.
Corresponds to the JSON property otherLocations
15304 15305 15306 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15304 def other_locations @other_locations end |
#recommendation_id ⇒ String
Unique id of the recommendation, a UUID string generated by the API.
Corresponds to the JSON property recommendationId
15309 15310 15311 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15309 def recommendation_id @recommendation_id end |
#recommendation_type ⇒ String
Type of recommendation. Currently only FUTURE_RESERVATION is supported.
Corresponds to the JSON property recommendationType
15314 15315 15316 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15314 def recommendation_type @recommendation_type end |
#start_time ⇒ String
Corresponds to the JSON property startTime
15319 15320 15321 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15319 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15326 15327 15328 15329 15330 15331 15332 15333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15326 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @location = args[:location] if args.key?(:location) @other_locations = args[:other_locations] if args.key?(:other_locations) @recommendation_id = args[:recommendation_id] if args.key?(:recommendation_id) @recommendation_type = args[:recommendation_type] if args.key?(:recommendation_type) @start_time = args[:start_time] if args.key?(:start_time) end |