Class: Google::Apis::ComputeBeta::FutureResourcesRecommendationOtherLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Information about recommendation status for locations that were allowed but not used by the response.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FutureResourcesRecommendationOtherLocation

Returns a new instance of FutureResourcesRecommendationOtherLocation.



15886
15887
15888
# File 'lib/google/apis/compute_beta/classes.rb', line 15886

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Details (human readable) describing the situation. For example, if status is CONDITION_NOT_MET, then details contain information about the parameters of the time window that did not meet the required conditions. Corresponds to the JSON property details

Returns:

  • (String)


15879
15880
15881
# File 'lib/google/apis/compute_beta/classes.rb', line 15879

def details
  @details
end

#statusString

Status of recommendation in this location. Corresponds to the JSON property status

Returns:

  • (String)


15884
15885
15886
# File 'lib/google/apis/compute_beta/classes.rb', line 15884

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



15891
15892
15893
15894
# File 'lib/google/apis/compute_beta/classes.rb', line 15891

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @status = args[:status] if args.key?(:status)
end