Class: Google::Apis::ComputeBeta::FutureResourcesSpec
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesSpec
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD).
-
#location_policy ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecLocationPolicy
Specification of locations to create resources in.
-
#target_resources ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecTargetResources
Specification of reserved resources.
-
#time_range_spec ⇒ Google::Apis::ComputeBeta::FlexibleTimeRange
Specifies a flexible time range with flexible start time and duration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpec
constructor
A new instance of FutureResourcesSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpec
Returns a new instance of FutureResourcesSpec.
16658 16659 16660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16658 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_type ⇒ String
Indicates if the reservation allocation strategy is static (DENSE) or
dynamic (STANDARD). Defaults to DENSE.
Corresponds to the JSON property deploymentType
16639 16640 16641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16639 def deployment_type @deployment_type end |
#location_policy ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecLocationPolicy
Specification of locations to create resources in.
Corresponds to the JSON property locationPolicy
16644 16645 16646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16644 def location_policy @location_policy end |
#target_resources ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecTargetResources
Specification of reserved resources.
Corresponds to the JSON property targetResources
16649 16650 16651 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16649 def target_resources @target_resources end |
#time_range_spec ⇒ Google::Apis::ComputeBeta::FlexibleTimeRange
Specifies a flexible time range with flexible start time and duration.
It is possible to specify a contradictory time range that cannot be matched
by any Interval. This causes a validation error.
Corresponds to the JSON property timeRangeSpec
16656 16657 16658 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16656 def time_range_spec @time_range_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16663 16664 16665 16666 16667 16668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16663 def update!(**args) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @location_policy = args[:location_policy] if args.key?(:location_policy) @target_resources = args[:target_resources] if args.key?(:target_resources) @time_range_spec = args[:time_range_spec] if args.key?(:time_range_spec) end |