Class: Google::Apis::ComputeBeta::FutureResourcesSpec
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesSpec
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specification of resources to be created at some time in the future within an optionally specified set of locations, and within the specified time range.
Instance Attribute Summary collapse
-
#deployment_type ⇒ String
Indicates if the reservation allocation strategy is static (DENSE) or dynamic (STANDARD).
-
#location_policy ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecLocationPolicy
Specification of locations to create resources in.
-
#target_resources ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecTargetResources
Specification of reserved resources.
-
#time_range_spec ⇒ Google::Apis::ComputeBeta::FlexibleTimeRange
A flexible specification of a time range that has 3 points of flexibility: (1) a flexible start time, (2) a flexible end time, (3) a flexible duration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpec
constructor
A new instance of FutureResourcesSpec.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpec
Returns a new instance of FutureResourcesSpec.
15395 15396 15397 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_type ⇒ String
Indicates if the reservation allocation strategy is static (DENSE) or
dynamic (STANDARD). Defaults to DENSE.
Corresponds to the JSON property deploymentType
15374 15375 15376 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15374 def deployment_type @deployment_type end |
#location_policy ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecLocationPolicy
Specification of locations to create resources in.
Corresponds to the JSON property locationPolicy
15379 15380 15381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15379 def location_policy @location_policy end |
#target_resources ⇒ Google::Apis::ComputeBeta::FutureResourcesSpecTargetResources
Specification of reserved resources.
Corresponds to the JSON property targetResources
15384 15385 15386 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15384 def target_resources @target_resources end |
#time_range_spec ⇒ Google::Apis::ComputeBeta::FlexibleTimeRange
A flexible specification of a time range that has 3 points of
flexibility: (1) a flexible start time, (2) a flexible end time, (3) a
flexible duration.
It is possible to specify a contradictory time range that cannot be matched
by any Interval. This causes a validation error.
Corresponds to the JSON property timeRangeSpec
15393 15394 15395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15393 def time_range_spec @time_range_spec end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15400 15401 15402 15403 15404 15405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15400 def update!(**args) @deployment_type = args[:deployment_type] if args.key?(:deployment_type) @location_policy = args[:location_policy] if args.key?(:location_policy) @target_resources = args[:target_resources] if args.key?(:target_resources) @time_range_spec = args[:time_range_spec] if args.key?(:time_range_spec) end |