Class: Google::Apis::ComputeBeta::FutureResourcesSpecAggregateResources
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesSpecAggregateResources
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
Size of the request, in accelerator (chip) count.
-
#vm_family ⇒ String
The VM family that all instances scheduled against this reservation must belong to.
-
#workload_type ⇒ String
Workload type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpecAggregateResources
constructor
A new instance of FutureResourcesSpecAggregateResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpecAggregateResources
Returns a new instance of FutureResourcesSpecAggregateResources.
15752 15753 15754 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
Size of the request, in accelerator (chip) count.
Corresponds to the JSON property acceleratorCount
15739 15740 15741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15739 def accelerator_count @accelerator_count end |
#vm_family ⇒ String
The VM family that all instances scheduled against this reservation
must belong to. Use for TPU reservations.
Corresponds to the JSON property vmFamily
15745 15746 15747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15745 def vm_family @vm_family end |
#workload_type ⇒ String
Workload type. Use for TPU reservations.
Corresponds to the JSON property workloadType
15750 15751 15752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15750 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15757 15758 15759 15760 15761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15757 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @vm_family = args[:vm_family] if args.key?(:vm_family) @workload_type = args[:workload_type] if args.key?(:workload_type) end |