Class: Google::Apis::ComputeBeta::FutureResourcesSpecAggregateResources
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesSpecAggregateResources
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#accelerator_count ⇒ Fixnum
Size of the request, in accelerator (chip) count.
-
#vm_family ⇒ String
The VM family that all instances scheduled against this reservation must belong to.
-
#workload_type ⇒ String
Workload type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpecAggregateResources
constructor
A new instance of FutureResourcesSpecAggregateResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpecAggregateResources
Returns a new instance of FutureResourcesSpecAggregateResources.
15428 15429 15430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_count ⇒ Fixnum
Size of the request, in accelerator (chip) count.
Corresponds to the JSON property acceleratorCount
15415 15416 15417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15415 def accelerator_count @accelerator_count end |
#vm_family ⇒ String
The VM family that all instances scheduled against this reservation
must belong to. Use for TPU reservations.
Corresponds to the JSON property vmFamily
15421 15422 15423 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15421 def vm_family @vm_family end |
#workload_type ⇒ String
Workload type. Use for TPU reservations.
Corresponds to the JSON property workloadType
15426 15427 15428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15426 def workload_type @workload_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15433 15434 15435 15436 15437 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15433 def update!(**args) @accelerator_count = args[:accelerator_count] if args.key?(:accelerator_count) @vm_family = args[:vm_family] if args.key?(:vm_family) @workload_type = args[:workload_type] if args.key?(:workload_type) end |