Class: Google::Apis::ComputeBeta::FutureResourcesSpecSpecificSkuResources
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::FutureResourcesSpecSpecificSkuResources
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instance_count ⇒ Fixnum
Size of the request, in instance count.
-
#local_ssd_partitions ⇒ Array<Google::Apis::ComputeBeta::FutureResourcesSpecLocalSsdPartition>
Local SSD partitions.
-
#machine_type ⇒ String
The machine type to use for instances that will use the reservation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FutureResourcesSpecSpecificSkuResources
constructor
A new instance of FutureResourcesSpecSpecificSkuResources.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FutureResourcesSpecSpecificSkuResources
Returns a new instance of FutureResourcesSpecSpecificSkuResources.
15530 15531 15532 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15530 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_count ⇒ Fixnum
Size of the request, in instance count.
Corresponds to the JSON property instanceCount
15513 15514 15515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15513 def instance_count @instance_count end |
#local_ssd_partitions ⇒ Array<Google::Apis::ComputeBeta::FutureResourcesSpecLocalSsdPartition>
Local SSD partitions. You do not have to include SSD partitions that
are built in the machine type.
Corresponds to the JSON property localSsdPartitions
15519 15520 15521 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15519 def local_ssd_partitions @local_ssd_partitions end |
#machine_type ⇒ String
The machine type to use for instances that will use the reservation.
This field only accepts machine type names. e.g. n2-standard-4
and does not accept machine type full or partial url. e.g.
projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4.
Use for GPU reservations.
Corresponds to the JSON property machineType
15528 15529 15530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15528 def machine_type @machine_type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15535 15536 15537 15538 15539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15535 def update!(**args) @instance_count = args[:instance_count] if args.key?(:instance_count) @local_ssd_partitions = args[:local_ssd_partitions] if args.key?(:local_ssd_partitions) @machine_type = args[:machine_type] if args.key?(:machine_type) end |