Class: Google::Apis::ComputeBeta::GetVersionOperationMetadataSbomInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GetVersionOperationMetadataSbomInfo

Returns a new instance of GetVersionOperationMetadataSbomInfo.



16258
16259
16260
# File 'lib/google/apis/compute_beta/classes.rb', line 16258

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_component_versionsHash<String,String>

SBOM versions currently applied to the resource. The key is the component name and the value is the version. Corresponds to the JSON property currentComponentVersions

Returns:

  • (Hash<String,String>)


16250
16251
16252
# File 'lib/google/apis/compute_beta/classes.rb', line 16250

def current_component_versions
  @current_component_versions
end

#target_component_versionsHash<String,String>

SBOM versions scheduled for the next maintenance. The key is the component name and the value is the version. Corresponds to the JSON property targetComponentVersions

Returns:

  • (Hash<String,String>)


16256
16257
16258
# File 'lib/google/apis/compute_beta/classes.rb', line 16256

def target_component_versions
  @target_component_versions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16263
16264
16265
16266
# File 'lib/google/apis/compute_beta/classes.rb', line 16263

def update!(**args)
  @current_component_versions = args[:current_component_versions] if args.key?(:current_component_versions)
  @target_component_versions = args[:target_component_versions] if args.key?(:target_component_versions)
end