Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message describing GlobalVmExtensionPolicy object.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicy

Returns a new instance of GlobalVmExtensionPolicy.



16410
16411
16412
# File 'lib/google/apis/compute_beta/classes.rb', line 16410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


16328
16329
16330
# File 'lib/google/apis/compute_beta/classes.rb', line 16328

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


16334
16335
16336
# File 'lib/google/apis/compute_beta/classes.rb', line 16334

def description
  @description
end

#extension_policiesHash<String,Google::Apis::ComputeBeta::GlobalVmExtensionPolicyExtensionPolicy>

Required. Map from extension (eg: "cloudops") to its policy configuration. The key is the name of the extension. Corresponds to the JSON property extensionPolicies



16340
16341
16342
# File 'lib/google/apis/compute_beta/classes.rb', line 16340

def extension_policies
  @extension_policies
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


16347
16348
16349
# File 'lib/google/apis/compute_beta/classes.rb', line 16347

def id
  @id
end

#instance_selectorsArray<Google::Apis::ComputeBeta::GlobalVmExtensionPolicyInstanceSelector>

Optional. Selector to target VMs for a policy. There is a logical "AND" between instance_selectors. Corresponds to the JSON property instanceSelectors



16353
16354
16355
# File 'lib/google/apis/compute_beta/classes.rb', line 16353

def instance_selectors
  @instance_selectors
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# globalVmExtensionPolicy for globalVmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


16359
16360
16361
# File 'lib/google/apis/compute_beta/classes.rb', line 16359

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


16370
16371
16372
# File 'lib/google/apis/compute_beta/classes.rb', line 16370

def name
  @name
end

#priorityFixnum

Optional. Used to resolve conflicts when multiple policies are active for the same extension. Defaults to 0. Larger the number, higher the priority. When the priority is the same, the policy with the newer create time has higher priority. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


16379
16380
16381
# File 'lib/google/apis/compute_beta/classes.rb', line 16379

def priority
  @priority
end

#rollout_operationGoogle::Apis::ComputeBeta::GlobalVmExtensionPolicyRolloutOperation

Represents the rollout operation Corresponds to the JSON property rolloutOperation



16384
16385
16386
# File 'lib/google/apis/compute_beta/classes.rb', line 16384

def rollout_operation
  @rollout_operation
end

#scoped_resource_statusString

Output only. [Output Only] The scoped resource status. It's only for tracking the purging status of the policy. Corresponds to the JSON property scopedResourceStatus

Returns:

  • (String)


16391
16392
16393
# File 'lib/google/apis/compute_beta/classes.rb', line 16391

def scoped_resource_status
  @scoped_resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16397
16398
16399
# File 'lib/google/apis/compute_beta/classes.rb', line 16397

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


16402
16403
16404
# File 'lib/google/apis/compute_beta/classes.rb', line 16402

def self_link_with_id
  @self_link_with_id
end

#update_timestampString

Output only. [Output Only] Update timestamp inRFC3339 text format. Corresponds to the JSON property updateTimestamp

Returns:

  • (String)


16408
16409
16410
# File 'lib/google/apis/compute_beta/classes.rb', line 16408

def update_timestamp
  @update_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16415
16416
16417
16418
16419
16420
16421
16422
16423
16424
16425
16426
16427
16428
16429
# File 'lib/google/apis/compute_beta/classes.rb', line 16415

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @extension_policies = args[:extension_policies] if args.key?(:extension_policies)
  @id = args[:id] if args.key?(:id)
  @instance_selectors = args[:instance_selectors] if args.key?(:instance_selectors)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @priority = args[:priority] if args.key?(:priority)
  @rollout_operation = args[:rollout_operation] if args.key?(:rollout_operation)
  @scoped_resource_status = args[:scoped_resource_status] if args.key?(:scoped_resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp)
end