Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyLabelSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A LabelSelector is applicable for a VM only if it matches all labels in the LabelSelector.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyLabelSelector

Returns a new instance of GlobalVmExtensionPolicyLabelSelector.



16168
16169
16170
# File 'lib/google/apis/compute_beta/classes.rb', line 16168

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inclusion_labelsHash<String,String>

Optional. Labels as key value pairs. A VM should contain all the pairs specified in this map to be selected; Labels within the LabelSelector are OR'ed. Corresponds to the JSON property inclusionLabels

Returns:

  • (Hash<String,String>)


16166
16167
16168
# File 'lib/google/apis/compute_beta/classes.rb', line 16166

def inclusion_labels
  @inclusion_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16173
16174
16175
# File 'lib/google/apis/compute_beta/classes.rb', line 16173

def update!(**args)
  @inclusion_labels = args[:inclusion_labels] if args.key?(:inclusion_labels)
end