Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



17612
17613
17614
# File 'lib/google/apis/compute_beta/classes.rb', line 17612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


17570
17571
17572
# File 'lib/google/apis/compute_beta/classes.rb', line 17570

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17575
17576
17577
# File 'lib/google/apis/compute_beta/classes.rb', line 17575

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



17580
17581
17582
# File 'lib/google/apis/compute_beta/classes.rb', line 17580

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17585
17586
17587
# File 'lib/google/apis/compute_beta/classes.rb', line 17585

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17595
17596
17597
# File 'lib/google/apis/compute_beta/classes.rb', line 17595

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17600
17601
17602
# File 'lib/google/apis/compute_beta/classes.rb', line 17600

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17605
17606
17607
# File 'lib/google/apis/compute_beta/classes.rb', line 17605

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17610
17611
17612
# File 'lib/google/apis/compute_beta/classes.rb', line 17610

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17617
17618
17619
17620
17621
17622
17623
17624
17625
17626
# File 'lib/google/apis/compute_beta/classes.rb', line 17617

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end