Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
17411 17412 17413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17411 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
17369 17370 17371 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17369 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17374 17375 17376 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17374 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
17379 17380 17381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17379 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
17384 17385 17386 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17384 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17394 17395 17396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17394 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17399 17400 17401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17399 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
17404 17405 17406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17404 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17409 17410 17411 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17409 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17416 17417 17418 17419 17420 17421 17422 17423 17424 17425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17416 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |