Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
17387 17388 17389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17387 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
17345 17346 17347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17345 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17350 17351 17352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17350 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
17355 17356 17357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17355 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
17360 17361 17362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17360 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17370 17371 17372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17370 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17375 17376 17377 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17375 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
17380 17381 17382 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17380 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17385 17386 17387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17385 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17392 17393 17394 17395 17396 17397 17398 17399 17400 17401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17392 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |