Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to list global VM extension policy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
constructor
A new instance of GlobalVmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyList
Returns a new instance of GlobalVmExtensionPolicyList.
16803 16804 16805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
16761 16762 16763 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16761 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
16766 16767 16768 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16766 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>
A list of GlobalVmExtensionPolicy resources.
Corresponds to the JSON property items
16771 16772 16773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16771 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
16776 16777 16778 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16776 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
16786 16787 16788 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16786 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
16791 16792 16793 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16791 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
16796 16797 16798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16796 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
16801 16802 16803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16801 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16808 16809 16810 16811 16812 16813 16814 16815 16816 16817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16808 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |