Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to list global VM extension policy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyList

Returns a new instance of GlobalVmExtensionPolicyList.



16551
16552
16553
# File 'lib/google/apis/compute_beta/classes.rb', line 16551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


16509
16510
16511
# File 'lib/google/apis/compute_beta/classes.rb', line 16509

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


16514
16515
16516
# File 'lib/google/apis/compute_beta/classes.rb', line 16514

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::GlobalVmExtensionPolicy>

A list of GlobalVmExtensionPolicy resources. Corresponds to the JSON property items



16519
16520
16521
# File 'lib/google/apis/compute_beta/classes.rb', line 16519

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


16524
16525
16526
# File 'lib/google/apis/compute_beta/classes.rb', line 16524

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


16534
16535
16536
# File 'lib/google/apis/compute_beta/classes.rb', line 16534

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


16539
16540
16541
# File 'lib/google/apis/compute_beta/classes.rb', line 16539

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


16544
16545
16546
# File 'lib/google/apis/compute_beta/classes.rb', line 16544

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::GlobalVmExtensionPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



16549
16550
16551
# File 'lib/google/apis/compute_beta/classes.rb', line 16549

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16556
16557
16558
16559
16560
16561
16562
16563
16564
16565
# File 'lib/google/apis/compute_beta/classes.rb', line 16556

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end