Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyRolloutOperationRolloutInput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutInput

Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutInput.



17573
17574
17575
# File 'lib/google/apis/compute_beta/classes.rb', line 17573

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conflict_behaviorString

Optional. Specifies the behavior of the rollout if a conflict is detected in a project during a rollout. This only applies to insert and update methods. A conflict occurs in the following cases:

  • insert method: If the zonal policy already exists when the insert happens.
  • update method: If the zonal policy was modified by a zonal API call outside of this rollout. Possible values are the following:
  • "" (empty string): If a conflict occurs, the local value is not overwritten. This is the default behavior.
  • "overwrite": If a conflict occurs, the local value is overwritten with the rollout value. Corresponds to the JSON property conflictBehavior

Returns:

  • (String)


17542
17543
17544
# File 'lib/google/apis/compute_beta/classes.rb', line 17542

def conflict_behavior
  @conflict_behavior
end

#nameString

Optional. The name of the rollout plan. Ex. projects//locations/global/rolloutPlans/. Corresponds to the JSON property name

Returns:

  • (String)


17549
17550
17551
# File 'lib/google/apis/compute_beta/classes.rb', line 17549

def name
  @name
end

#predefined_rollout_planString

Optional. Specifies the predefined rollout plan for the policy. Valid values are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is SLOW_ROLLOUT for progressive rollout. For more information, see Rollout plans for global policies. Corresponds to the JSON property predefinedRolloutPlan

Returns:

  • (String)


17557
17558
17559
# File 'lib/google/apis/compute_beta/classes.rb', line 17557

def predefined_rollout_plan
  @predefined_rollout_plan
end

#retry_uuidString

Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.

  • update method: Lets you retry policy rollout without changes. An error occurs if you set retry_uuid but the policy is modified.
  • delete method: Lets you retry policy deletion rollout if the previous deletion rollout is not finished and the policy is in the DELETING state. If you set this field when the policy is not in the DELETING state, an error occurs. Corresponds to the JSON property retryUuid

Returns:

  • (String)


17571
17572
17573
# File 'lib/google/apis/compute_beta/classes.rb', line 17571

def retry_uuid
  @retry_uuid
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17578
17579
17580
17581
17582
17583
# File 'lib/google/apis/compute_beta/classes.rb', line 17578

def update!(**args)
  @conflict_behavior = args[:conflict_behavior] if args.key?(:conflict_behavior)
  @name = args[:name] if args.key?(:name)
  @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan)
  @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid)
end