Class: Google::Apis::ComputeBeta::GlobalVmExtensionPolicyRolloutOperationRolloutInput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GlobalVmExtensionPolicyRolloutOperationRolloutInput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#conflict_behavior ⇒ String
Optional.
-
#name ⇒ String
Optional.
-
#predefined_rollout_plan ⇒ String
Optional.
-
#retry_uuid ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutInput
constructor
A new instance of GlobalVmExtensionPolicyRolloutOperationRolloutInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GlobalVmExtensionPolicyRolloutOperationRolloutInput
Returns a new instance of GlobalVmExtensionPolicyRolloutOperationRolloutInput.
16965 16966 16967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16965 def initialize(**args) update!(**args) end |
Instance Attribute Details
#conflict_behavior ⇒ String
Optional. Specifies the behavior of the rollout if a conflict is detected in a
project during a rollout. This only applies to insert and update
methods.
A conflict occurs in the following cases:
insertmethod: If the zonal policy already exists when the insert happens.updatemethod: If the zonal policy was modified by a zonal API call outside of this rollout. Possible values are the following:""(empty string): If a conflict occurs, the local value is not overwritten. This is the default behavior."overwrite": If a conflict occurs, the local value is overwritten with the rollout value. Corresponds to the JSON propertyconflictBehavior
16934 16935 16936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16934 def conflict_behavior @conflict_behavior end |
#name ⇒ String
Optional. The name of the rollout plan.
Ex.
projects//locations/global/rolloutPlans/.
Corresponds to the JSON property name
16941 16942 16943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16941 def name @name end |
#predefined_rollout_plan ⇒ String
Optional. Specifies the predefined rollout plan for the policy. Valid values
are SLOW_ROLLOUT and FAST_ROLLOUT. The recommended value is
SLOW_ROLLOUT for progressive rollout. For more information, see Rollout
plans for global policies.
Corresponds to the JSON property predefinedRolloutPlan
16949 16950 16951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16949 def predefined_rollout_plan @predefined_rollout_plan end |
#retry_uuid ⇒ String
Optional. The UUID that identifies a policy rollout retry attempt for update and delete operations. Set this field only when retrying a rollout for an existing extension policy.
updatemethod: Lets you retry policy rollout without changes. An error occurs if you set retry_uuid but the policy is modified.deletemethod: Lets you retry policy deletion rollout if the previous deletion rollout is not finished and the policy is in the DELETING state. If you set this field when the policy is not in the DELETING state, an error occurs. Corresponds to the JSON propertyretryUuid
16963 16964 16965 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16963 def retry_uuid @retry_uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
16970 16971 16972 16973 16974 16975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 16970 def update!(**args) @conflict_behavior = args[:conflict_behavior] if args.key?(:conflict_behavior) @name = args[:name] if args.key?(:name) @predefined_rollout_plan = args[:predefined_rollout_plan] if args.key?(:predefined_rollout_plan) @retry_uuid = args[:retry_uuid] if args.key?(:retry_uuid) end |