Class: Google::Apis::ComputeBeta::GroupMaintenanceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GroupMaintenanceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Maintenance Info for ReservationBlocks.
Instance Attribute Summary collapse
-
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
-
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
-
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
-
#scheduling_type ⇒ String
The type of maintenance for the reservation.
-
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
-
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
-
#upcoming_group_maintenance ⇒ Google::Apis::ComputeBeta::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GroupMaintenanceInfo
constructor
A new instance of GroupMaintenanceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GroupMaintenanceInfo
Returns a new instance of GroupMaintenanceInfo.
17853 17854 17855 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17853 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_maintenance_ongoing_count ⇒ Fixnum
Describes number of instances that have ongoing maintenance.
Corresponds to the JSON property instanceMaintenanceOngoingCount
17808 17809 17810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17808 def instance_maintenance_ongoing_count @instance_maintenance_ongoing_count end |
#instance_maintenance_pending_count ⇒ Fixnum
Describes number of instances that have pending maintenance.
Corresponds to the JSON property instanceMaintenancePendingCount
17813 17814 17815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17813 def instance_maintenance_pending_count @instance_maintenance_pending_count end |
#maintenance_ongoing_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have ongoing maintenance.
Corresponds to the JSON property maintenanceOngoingCount
17819 17820 17821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17819 def maintenance_ongoing_count @maintenance_ongoing_count end |
#maintenance_pending_count ⇒ Fixnum
Progress for ongoing maintenance for this group of VMs/hosts.
Describes number of hosts in the block that have pending maintenance.
Corresponds to the JSON property maintenancePendingCount
17825 17826 17827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17825 def maintenance_pending_count @maintenance_pending_count end |
#scheduling_type ⇒ String
The type of maintenance for the reservation.
Corresponds to the JSON property schedulingType
17830 17831 17832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17830 def scheduling_type @scheduling_type end |
#subblock_infra_maintenance_ongoing_count ⇒ Fixnum
Describes number of subblock Infrastructure that has ongoing maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family(e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenanceOngoingCount
17838 17839 17840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17838 def subblock_infra_maintenance_ongoing_count @subblock_infra_maintenance_ongoing_count end |
#subblock_infra_maintenance_pending_count ⇒ Fixnum
Describes number of subblock Infrastructure that has pending maintenance.
Here, Subblock Infrastructure Maintenance pertains to upstream hardware
contained in the Subblock that is necessary for a VM Family (e.g. NVLink
Domains). Not all VM Families will support this field.
Corresponds to the JSON property subblockInfraMaintenancePendingCount
17846 17847 17848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17846 def subblock_infra_maintenance_pending_count @subblock_infra_maintenance_pending_count end |
#upcoming_group_maintenance ⇒ Google::Apis::ComputeBeta::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingGroupMaintenance
17851 17852 17853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17851 def upcoming_group_maintenance @upcoming_group_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17858 17859 17860 17861 17862 17863 17864 17865 17866 17867 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17858 def update!(**args) @instance_maintenance_ongoing_count = args[:instance_maintenance_ongoing_count] if args.key?(:instance_maintenance_ongoing_count) @instance_maintenance_pending_count = args[:instance_maintenance_pending_count] if args.key?(:instance_maintenance_pending_count) @maintenance_ongoing_count = args[:maintenance_ongoing_count] if args.key?(:maintenance_ongoing_count) @maintenance_pending_count = args[:maintenance_pending_count] if args.key?(:maintenance_pending_count) @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type) @subblock_infra_maintenance_ongoing_count = args[:subblock_infra_maintenance_ongoing_count] if args.key?(:subblock_infra_maintenance_ongoing_count) @subblock_infra_maintenance_pending_count = args[:subblock_infra_maintenance_pending_count] if args.key?(:subblock_infra_maintenance_pending_count) @upcoming_group_maintenance = args[:upcoming_group_maintenance] if args.key?(:upcoming_group_maintenance) end |