Class: Google::Apis::ComputeBeta::GrpcHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GrpcHealthCheck

Returns a new instance of GrpcHealthCheck.



16909
16910
16911
# File 'lib/google/apis/compute_beta/classes.rb', line 16909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#grpc_service_nameString

The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention:

  • Empty service_name means the overall status of all services at the backend.
  • Non-empty service_name means the health of that gRPC service, as defined by the owner of the service. The grpc_service_name can only be ASCII. Corresponds to the JSON property grpcServiceName

Returns:

  • (String)


16869
16870
16871
# File 'lib/google/apis/compute_beta/classes.rb', line 16869

def grpc_service_name
  @grpc_service_name
end

#portFixnum

The TCP port number to which the health check prober sends packets. Valid values are 1 through 65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


16875
16876
16877
# File 'lib/google/apis/compute_beta/classes.rb', line 16875

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


16880
16881
16882
# File 'lib/google/apis/compute_beta/classes.rb', line 16880

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


16907
16908
16909
# File 'lib/google/apis/compute_beta/classes.rb', line 16907

def port_specification
  @port_specification
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16914
16915
16916
16917
16918
16919
# File 'lib/google/apis/compute_beta/classes.rb', line 16914

def update!(**args)
  @grpc_service_name = args[:grpc_service_name] if args.key?(:grpc_service_name)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
end