Class: Google::Apis::ComputeBeta::GrpctlsHealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::GrpctlsHealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#grpc_service_name ⇒ String
The gRPC service name for the health check.
-
#port ⇒ Fixnum
The TCP port number to which the health check prober sends packets.
-
#port_specification ⇒ String
Specifies how a port is selected for health checking.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GrpctlsHealthCheck
constructor
A new instance of GrpctlsHealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GrpctlsHealthCheck
Returns a new instance of GrpctlsHealthCheck.
15681 15682 15683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#grpc_service_name ⇒ String
The gRPC service name for the health check. This field is optional. The value of grpc_service_name has the following meanings by convention:
- Empty service_name means the overall status of all services at the backend.
- Non-empty service_name means the health of that gRPC service, as defined
by the owner of the service.
The grpc_service_name can only be ASCII.
Corresponds to the JSON property
grpcServiceName
15646 15647 15648 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15646 def grpc_service_name @grpc_service_name end |
#port ⇒ Fixnum
The TCP port number to which the health check prober sends packets. Valid
values are 1 through 65535.
Corresponds to the JSON property port
15652 15653 15654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15652 def port @port end |
#port_specification ⇒ String
Specifies how a port is selected for health checking. Can be one of the
following values:
USE_FIXED_PORT: Specifies a port number explicitly using theport field in the
health check. Supported by backend services
for passthrough load balancers and backend services for proxy load
balancers. Not supported by target pools. The health check supports all
backends supported by the backend service provided the backend can be
health checked. For example, GCE_VM_IP network endpoint
groups, GCE_VM_IP_PORT network endpoint groups, and instance
group backends.
USE_NAMED_PORT: Not supported.
USE_SERVING_PORT: Provides an indirect method of specifying
the health check port by referring to the backend service. Only supported
by backend services for proxy load balancers. Not supported by target
pools. Not supported by backend services for passthrough load balancers.
Supports all backends that can be health checked; for example,GCE_VM_IP_PORT
network endpoint groups and instance group
backends.
For GCE_VM_IP_PORT network endpoint group backends, the health
check uses the port number specified for each endpoint in the network
endpoint group. For instance group backends, the health check uses the
port number determined by looking up the backend service's named port in
the instance group's list of named ports.
Corresponds to the JSON property portSpecification
15679 15680 15681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15679 def port_specification @port_specification end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
15686 15687 15688 15689 15690 |
# File 'lib/google/apis/compute_beta/classes.rb', line 15686 def update!(**args) @grpc_service_name = args[:grpc_service_name] if args.key?(:grpc_service_name) @port = args[:port] if args.key?(:port) @port_specification = args[:port_specification] if args.key?(:port_specification) end |