Class: Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



18583
18584
18585
# File 'lib/google/apis/compute_beta/classes.rb', line 18583

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18546
18547
18548
# File 'lib/google/apis/compute_beta/classes.rb', line 18546

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



18551
18552
18553
# File 'lib/google/apis/compute_beta/classes.rb', line 18551

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18556
18557
18558
# File 'lib/google/apis/compute_beta/classes.rb', line 18556

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18566
18567
18568
# File 'lib/google/apis/compute_beta/classes.rb', line 18566

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18571
18572
18573
# File 'lib/google/apis/compute_beta/classes.rb', line 18571

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18576
18577
18578
# File 'lib/google/apis/compute_beta/classes.rb', line 18576

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18581
18582
18583
# File 'lib/google/apis/compute_beta/classes.rb', line 18581

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18588
18589
18590
18591
18592
18593
18594
18595
18596
# File 'lib/google/apis/compute_beta/classes.rb', line 18588

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end