Class: Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthAggregationPoliciesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
constructor
A new instance of HealthAggregationPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
Returns a new instance of HealthAggregationPolicyAggregatedList.
18432 18433 18434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18395 18396 18397 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18395 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
Corresponds to the JSON property items
18400 18401 18402 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18400 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18405 18406 18407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18405 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18415 18416 18417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18415 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18420 18421 18422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18420 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18425 18426 18427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18425 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18430 18431 18432 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18430 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18437 18438 18439 18440 18441 18442 18443 18444 18445 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18437 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |