Class: Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



18408
18409
18410
# File 'lib/google/apis/compute_beta/classes.rb', line 18408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18371
18372
18373
# File 'lib/google/apis/compute_beta/classes.rb', line 18371

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



18376
18377
18378
# File 'lib/google/apis/compute_beta/classes.rb', line 18376

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18381
18382
18383
# File 'lib/google/apis/compute_beta/classes.rb', line 18381

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18391
18392
18393
# File 'lib/google/apis/compute_beta/classes.rb', line 18391

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18396
18397
18398
# File 'lib/google/apis/compute_beta/classes.rb', line 18396

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18401
18402
18403
# File 'lib/google/apis/compute_beta/classes.rb', line 18401

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18406
18407
18408
# File 'lib/google/apis/compute_beta/classes.rb', line 18406

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18413
18414
18415
18416
18417
18418
18419
18420
18421
# File 'lib/google/apis/compute_beta/classes.rb', line 18413

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end