Class: Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthAggregationPoliciesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList

Returns a new instance of HealthAggregationPolicyAggregatedList.



17541
17542
17543
# File 'lib/google/apis/compute_beta/classes.rb', line 17541

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17504
17505
17506
# File 'lib/google/apis/compute_beta/classes.rb', line 17504

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>

A list of HealthAggregationPoliciesScopedList resources. Corresponds to the JSON property items



17509
17510
17511
# File 'lib/google/apis/compute_beta/classes.rb', line 17509

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17514
17515
17516
# File 'lib/google/apis/compute_beta/classes.rb', line 17514

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17524
17525
17526
# File 'lib/google/apis/compute_beta/classes.rb', line 17524

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17529
17530
17531
# File 'lib/google/apis/compute_beta/classes.rb', line 17529

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


17534
17535
17536
# File 'lib/google/apis/compute_beta/classes.rb', line 17534

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17539
17540
17541
# File 'lib/google/apis/compute_beta/classes.rb', line 17539

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17546
17547
17548
17549
17550
17551
17552
17553
17554
# File 'lib/google/apis/compute_beta/classes.rb', line 17546

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end