Class: Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthAggregationPoliciesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
constructor
A new instance of HealthAggregationPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyAggregatedList
Returns a new instance of HealthAggregationPolicyAggregatedList.
17217 17218 17219 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17180 17181 17182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17180 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthAggregationPoliciesScopedList>
A list of HealthAggregationPoliciesScopedList resources.
Corresponds to the JSON property items
17185 17186 17187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17185 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
17190 17191 17192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17190 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17200 17201 17202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17200 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17205 17206 17207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17205 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
17210 17211 17212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17210 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17215 17216 17217 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17215 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17222 17223 17224 17225 17226 17227 17228 17229 17230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17222 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |