Class: Google::Apis::ComputeBeta::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



18760
18761
18762
# File 'lib/google/apis/compute_beta/classes.rb', line 18760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18726
18727
18728
# File 'lib/google/apis/compute_beta/classes.rb', line 18726

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



18731
18732
18733
# File 'lib/google/apis/compute_beta/classes.rb', line 18731

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


18738
18739
18740
# File 'lib/google/apis/compute_beta/classes.rb', line 18738

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18748
18749
18750
# File 'lib/google/apis/compute_beta/classes.rb', line 18748

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18753
18754
18755
# File 'lib/google/apis/compute_beta/classes.rb', line 18753

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18758
18759
18760
# File 'lib/google/apis/compute_beta/classes.rb', line 18758

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18765
18766
18767
18768
18769
18770
18771
18772
# File 'lib/google/apis/compute_beta/classes.rb', line 18765

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end