Class: Google::Apis::ComputeBeta::HealthAggregationPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthAggregationPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyList
constructor
A new instance of HealthAggregationPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyList
Returns a new instance of HealthAggregationPolicyList.
18535 18536 18537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18501 18502 18503 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18501 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
Corresponds to the JSON property items
18506 18507 18508 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18506 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
18513 18514 18515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18513 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18523 18524 18525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18523 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18528 18529 18530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18528 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18533 18534 18535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18533 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18540 18541 18542 18543 18544 18545 18546 18547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18540 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |