Class: Google::Apis::ComputeBeta::HealthAggregationPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthAggregationPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthAggregationPolicyList
constructor
A new instance of HealthAggregationPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthAggregationPolicyList
Returns a new instance of HealthAggregationPolicyList.
17951 17952 17953 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17951 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
17917 17918 17919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17917 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthAggregationPolicy>
A list of HealthAggregationPolicy resources.
Corresponds to the JSON property items
17922 17923 17924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17922 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
healthAggregationPolicy for health aggregation
policies.
Corresponds to the JSON property kind
17929 17930 17931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17929 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
17939 17940 17941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17939 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
17944 17945 17946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17944 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthAggregationPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
17949 17950 17951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17949 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17956 17957 17958 17959 17960 17961 17962 17963 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17956 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |