Class: Google::Apis::ComputeBeta::HealthAggregationPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthAggregationPolicyList

Returns a new instance of HealthAggregationPolicyList.



17344
17345
17346
# File 'lib/google/apis/compute_beta/classes.rb', line 17344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17310
17311
17312
# File 'lib/google/apis/compute_beta/classes.rb', line 17310

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthAggregationPolicy>

A list of HealthAggregationPolicy resources. Corresponds to the JSON property items



17315
17316
17317
# File 'lib/google/apis/compute_beta/classes.rb', line 17315

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthAggregationPolicy for health aggregation policies. Corresponds to the JSON property kind

Returns:

  • (String)


17322
17323
17324
# File 'lib/google/apis/compute_beta/classes.rb', line 17322

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17332
17333
17334
# File 'lib/google/apis/compute_beta/classes.rb', line 17332

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17337
17338
17339
# File 'lib/google/apis/compute_beta/classes.rb', line 17337

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthAggregationPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17342
17343
17344
# File 'lib/google/apis/compute_beta/classes.rb', line 17342

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17349
17350
17351
17352
17353
17354
17355
17356
# File 'lib/google/apis/compute_beta/classes.rb', line 17349

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end