Class: Google::Apis::ComputeBeta::HealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a health check resource. Google Compute Engine has two health check resources:
- Regional
- Global These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG). Load balancing Health check requirements vary depending on the type of load balancer. For details about the type of health check supported for each load balancer and corresponding backend type, see Health checks overview: Load balancer guide. Autohealing in MIGs The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing. For more information, seeHealth checks overview.
Instance Attribute Summary collapse
-
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#grpc_health_check ⇒ Google::Apis::ComputeBeta::GrpcHealthCheck
Corresponds to the JSON property
grpcHealthCheck. -
#grpc_tls_health_check ⇒ Google::Apis::ComputeBeta::GrpctlsHealthCheck
Corresponds to the JSON property
grpcTlsHealthCheck. -
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive successes.
-
#http2_health_check ⇒ Google::Apis::ComputeBeta::Http2HealthCheck
Corresponds to the JSON property
http2HealthCheck. -
#http_health_check ⇒ Google::Apis::ComputeBeta::HttpHealthCheck
Corresponds to the JSON property
httpHealthCheck. -
#https_health_check ⇒ Google::Apis::ComputeBeta::HttpsHealthCheck
Corresponds to the JSON property
httpsHealthCheck. -
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeBeta::HealthCheckLogConfig
Configuration of logging on a health check.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed.
-
#ssl_health_check ⇒ Google::Apis::ComputeBeta::SslHealthCheck
Corresponds to the JSON property
sslHealthCheck. -
#tcp_health_check ⇒ Google::Apis::ComputeBeta::TcpHealthCheck
Corresponds to the JSON property
tcpHealthCheck. -
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure.
-
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2, GRPC or GRPC_WITH_TLS.
-
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive failures.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheck
constructor
A new instance of HealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheck
Returns a new instance of HealthCheck.
19213 19214 19215 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19213 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check. The default value is 5
seconds.
Corresponds to the JSON property checkIntervalSec
19078 19079 19080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19078 def check_interval_sec @check_interval_sec end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in3339
text format.
Corresponds to the JSON property creationTimestamp
19084 19085 19086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19084 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
19090 19091 19092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19090 def description @description end |
#grpc_health_check ⇒ Google::Apis::ComputeBeta::GrpcHealthCheck
Corresponds to the JSON property grpcHealthCheck
19095 19096 19097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19095 def grpc_health_check @grpc_health_check end |
#grpc_tls_health_check ⇒ Google::Apis::ComputeBeta::GrpctlsHealthCheck
Corresponds to the JSON property grpcTlsHealthCheck
19100 19101 19102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19100 def grpc_tls_health_check @grpc_tls_health_check end |
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this
many consecutive successes. The default value is 2.
Corresponds to the JSON property healthyThreshold
19106 19107 19108 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19106 def healthy_threshold @healthy_threshold end |
#http2_health_check ⇒ Google::Apis::ComputeBeta::Http2HealthCheck
Corresponds to the JSON property http2HealthCheck
19111 19112 19113 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19111 def http2_health_check @http2_health_check end |
#http_health_check ⇒ Google::Apis::ComputeBeta::HttpHealthCheck
Corresponds to the JSON property httpHealthCheck
19116 19117 19118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19116 def http_health_check @http_health_check end |
#https_health_check ⇒ Google::Apis::ComputeBeta::HttpsHealthCheck
Corresponds to the JSON property httpsHealthCheck
19121 19122 19123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19121 def https_health_check @https_health_check end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
19127 19128 19129 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19127 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
19132 19133 19134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19132 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeBeta::HealthCheckLogConfig
Configuration of logging on a health check. If logging is enabled, logs
will be exported to Stackdriver.
Corresponds to the JSON property logConfig
19138 19139 19140 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19138 def log_config @log_config end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
For example, a name that is 1-63 characters long, matches the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with
RFC1035. This regular expression describes a name where the first
character is a lowercase letter, and all following characters are a dash,
lowercase letter, or digit, except the last character, which isn't a dash.
Corresponds to the JSON property name
19149 19150 19151 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19149 def name @name end |
#region ⇒ String
Output only. [Output Only] Region where the health check resides. Not
applicable to
global health checks.
Corresponds to the JSON property region
19156 19157 19158 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19156 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
19161 19162 19163 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19161 def self_link @self_link end |
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:
- SSL, HTTP2, GRPC, and GRPC_WITH_TLS protocols are not supported.
- The TCP request field is not supported.
- The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
- The checkIntervalSec field must be at least 30.
- The health check cannot be used with BackendService nor with managed
instance group auto-healing.
Corresponds to the JSON property
sourceRegions
19180 19181 19182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19180 def source_regions @source_regions end |
#ssl_health_check ⇒ Google::Apis::ComputeBeta::SslHealthCheck
Corresponds to the JSON property sslHealthCheck
19185 19186 19187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19185 def ssl_health_check @ssl_health_check end |
#tcp_health_check ⇒ Google::Apis::ComputeBeta::TcpHealthCheck
Corresponds to the JSON property tcpHealthCheck
19190 19191 19192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19190 def tcp_health_check @tcp_health_check end |
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure. The default value is
5 seconds. It is invalid for timeoutSec to have greater
value than checkIntervalSec.
Corresponds to the JSON property timeoutSec
19197 19198 19199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19197 def timeout_sec @timeout_sec end |
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2, GRPC
or GRPC_WITH_TLS.
Exactly one of the protocol-specific health check fields must be specified,
which must match type field.
Corresponds to the JSON property type
19205 19206 19207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19205 def type @type end |
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many
consecutive failures. The default value is 2.
Corresponds to the JSON property unhealthyThreshold
19211 19212 19213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19211 def unhealthy_threshold @unhealthy_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19218 19219 19220 19221 19222 19223 19224 19225 19226 19227 19228 19229 19230 19231 19232 19233 19234 19235 19236 19237 19238 19239 19240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19218 def update!(**args) @check_interval_sec = args[:check_interval_sec] if args.key?(:check_interval_sec) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @grpc_health_check = args[:grpc_health_check] if args.key?(:grpc_health_check) @grpc_tls_health_check = args[:grpc_tls_health_check] if args.key?(:grpc_tls_health_check) @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold) @http2_health_check = args[:http2_health_check] if args.key?(:http2_health_check) @http_health_check = args[:http_health_check] if args.key?(:http_health_check) @https_health_check = args[:https_health_check] if args.key?(:https_health_check) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @source_regions = args[:source_regions] if args.key?(:source_regions) @ssl_health_check = args[:ssl_health_check] if args.key?(:ssl_health_check) @tcp_health_check = args[:tcp_health_check] if args.key?(:tcp_health_check) @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec) @type = args[:type] if args.key?(:type) @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold) end |