Class: Google::Apis::ComputeBeta::HealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a health check resource. Google Compute Engine has two health check resources:
- Regional
- Global These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG). Load balancing Health check requirements vary depending on the type of load balancer. For details about the type of health check supported for each load balancer and corresponding backend type, see Health checks overview: Load balancer guide. Autohealing in MIGs The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing. For more information, seeHealth checks overview.
Instance Attribute Summary collapse
-
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#grpc_health_check ⇒ Google::Apis::ComputeBeta::GrpcHealthCheck
Corresponds to the JSON property
grpcHealthCheck. -
#grpc_tls_health_check ⇒ Google::Apis::ComputeBeta::GrpctlsHealthCheck
Corresponds to the JSON property
grpcTlsHealthCheck. -
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this many consecutive successes.
-
#http2_health_check ⇒ Google::Apis::ComputeBeta::Http2HealthCheck
Corresponds to the JSON property
http2HealthCheck. -
#http_health_check ⇒ Google::Apis::ComputeBeta::HttpHealthCheck
Corresponds to the JSON property
httpHealthCheck. -
#https_health_check ⇒ Google::Apis::ComputeBeta::HttpsHealthCheck
Corresponds to the JSON property
httpsHealthCheck. -
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeBeta::HealthCheckLogConfig
Configuration of logging on a health check.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed.
-
#ssl_health_check ⇒ Google::Apis::ComputeBeta::SslHealthCheck
Corresponds to the JSON property
sslHealthCheck. -
#tcp_health_check ⇒ Google::Apis::ComputeBeta::TcpHealthCheck
Corresponds to the JSON property
tcpHealthCheck. -
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure.
-
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC.
-
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many consecutive failures.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheck
constructor
A new instance of HealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheck
Returns a new instance of HealthCheck.
18196 18197 18198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#check_interval_sec ⇒ Fixnum
How often (in seconds) to send a health check. The default value is 5
seconds.
Corresponds to the JSON property checkIntervalSec
18061 18062 18063 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18061 def check_interval_sec @check_interval_sec end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in3339
text format.
Corresponds to the JSON property creationTimestamp
18067 18068 18069 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18067 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
18073 18074 18075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18073 def description @description end |
#grpc_health_check ⇒ Google::Apis::ComputeBeta::GrpcHealthCheck
Corresponds to the JSON property grpcHealthCheck
18078 18079 18080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18078 def grpc_health_check @grpc_health_check end |
#grpc_tls_health_check ⇒ Google::Apis::ComputeBeta::GrpctlsHealthCheck
Corresponds to the JSON property grpcTlsHealthCheck
18083 18084 18085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18083 def grpc_tls_health_check @grpc_tls_health_check end |
#healthy_threshold ⇒ Fixnum
A so-far unhealthy instance will be marked healthy after this
many consecutive successes. The default value is 2.
Corresponds to the JSON property healthyThreshold
18089 18090 18091 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18089 def healthy_threshold @healthy_threshold end |
#http2_health_check ⇒ Google::Apis::ComputeBeta::Http2HealthCheck
Corresponds to the JSON property http2HealthCheck
18094 18095 18096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18094 def http2_health_check @http2_health_check end |
#http_health_check ⇒ Google::Apis::ComputeBeta::HttpHealthCheck
Corresponds to the JSON property httpHealthCheck
18099 18100 18101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18099 def http_health_check @http_health_check end |
#https_health_check ⇒ Google::Apis::ComputeBeta::HttpsHealthCheck
Corresponds to the JSON property httpsHealthCheck
18104 18105 18106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18104 def https_health_check @https_health_check end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
18110 18111 18112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18110 def id @id end |
#kind ⇒ String
Output only. Type of the resource.
Corresponds to the JSON property kind
18115 18116 18117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18115 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeBeta::HealthCheckLogConfig
Configuration of logging on a health check. If logging is enabled, logs
will be exported to Stackdriver.
Corresponds to the JSON property logConfig
18121 18122 18123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18121 def log_config @log_config end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
For example, a name that is 1-63 characters long, matches the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with
RFC1035. This regular expression describes a name where the first
character is a lowercase letter, and all following characters are a dash,
lowercase letter, or digit, except the last character, which isn't a dash.
Corresponds to the JSON property name
18132 18133 18134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18132 def name @name end |
#region ⇒ String
Output only. [Output Only] Region where the health check resides. Not
applicable to
global health checks.
Corresponds to the JSON property region
18139 18140 18141 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18139 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
18144 18145 18146 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18144 def self_link @self_link end |
#source_regions ⇒ Array<String>
The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:
- SSL, HTTP2, and GRPC protocols are not supported.
- The TCP request field is not supported.
- The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
- The checkIntervalSec field must be at least 30.
- The health check cannot be used with BackendService nor with managed
instance group auto-healing.
Corresponds to the JSON property
sourceRegions
18163 18164 18165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18163 def source_regions @source_regions end |
#ssl_health_check ⇒ Google::Apis::ComputeBeta::SslHealthCheck
Corresponds to the JSON property sslHealthCheck
18168 18169 18170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18168 def ssl_health_check @ssl_health_check end |
#tcp_health_check ⇒ Google::Apis::ComputeBeta::TcpHealthCheck
Corresponds to the JSON property tcpHealthCheck
18173 18174 18175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18173 def tcp_health_check @tcp_health_check end |
#timeout_sec ⇒ Fixnum
How long (in seconds) to wait before claiming failure. The default value is
5 seconds. It is invalid for timeoutSec to have greater
value than checkIntervalSec.
Corresponds to the JSON property timeoutSec
18180 18181 18182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18180 def timeout_sec @timeout_sec end |
#type ⇒ String
Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or
GRPC. Exactly one of the
protocol-specific health check fields must be specified, which must matchtype
field.
Corresponds to the JSON property type
18188 18189 18190 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18188 def type @type end |
#unhealthy_threshold ⇒ Fixnum
A so-far healthy instance will be marked unhealthy after this many
consecutive failures. The default value is 2.
Corresponds to the JSON property unhealthyThreshold
18194 18195 18196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18194 def unhealthy_threshold @unhealthy_threshold end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18201 18202 18203 18204 18205 18206 18207 18208 18209 18210 18211 18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 18223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18201 def update!(**args) @check_interval_sec = args[:check_interval_sec] if args.key?(:check_interval_sec) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @grpc_health_check = args[:grpc_health_check] if args.key?(:grpc_health_check) @grpc_tls_health_check = args[:grpc_tls_health_check] if args.key?(:grpc_tls_health_check) @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold) @http2_health_check = args[:http2_health_check] if args.key?(:http2_health_check) @http_health_check = args[:http_health_check] if args.key?(:http_health_check) @https_health_check = args[:https_health_check] if args.key?(:https_health_check) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @source_regions = args[:source_regions] if args.key?(:source_regions) @ssl_health_check = args[:ssl_health_check] if args.key?(:ssl_health_check) @tcp_health_check = args[:tcp_health_check] if args.key?(:tcp_health_check) @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec) @type = args[:type] if args.key?(:type) @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold) end |