Class: Google::Apis::ComputeBeta::HealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a health check resource. Google Compute Engine has two health check resources:

  • Regional
  • Global These health check resources can be used for load balancing and for autohealing VMs in a managed instance group (MIG). Load balancing Health check requirements vary depending on the type of load balancer. For details about the type of health check supported for each load balancer and corresponding backend type, see Health checks overview: Load balancer guide. Autohealing in MIGs The health checks that you use for autohealing VMs in a MIG can be either regional or global. For more information, see Set up an application health check and autohealing. For more information, seeHealth checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheck

Returns a new instance of HealthCheck.



17589
17590
17591
# File 'lib/google/apis/compute_beta/classes.rb', line 17589

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_interval_secFixnum

How often (in seconds) to send a health check. The default value is 5 seconds. Corresponds to the JSON property checkIntervalSec

Returns:

  • (Fixnum)


17454
17455
17456
# File 'lib/google/apis/compute_beta/classes.rb', line 17454

def check_interval_sec
  @check_interval_sec
end

#creation_timestampString

Output only. [Output Only] Creation timestamp in3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


17460
17461
17462
# File 'lib/google/apis/compute_beta/classes.rb', line 17460

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


17466
17467
17468
# File 'lib/google/apis/compute_beta/classes.rb', line 17466

def description
  @description
end

#grpc_health_checkGoogle::Apis::ComputeBeta::GrpcHealthCheck

Corresponds to the JSON property grpcHealthCheck



17471
17472
17473
# File 'lib/google/apis/compute_beta/classes.rb', line 17471

def grpc_health_check
  @grpc_health_check
end

#grpc_tls_health_checkGoogle::Apis::ComputeBeta::GrpctlsHealthCheck

Corresponds to the JSON property grpcTlsHealthCheck



17476
17477
17478
# File 'lib/google/apis/compute_beta/classes.rb', line 17476

def grpc_tls_health_check
  @grpc_tls_health_check
end

#healthy_thresholdFixnum

A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


17482
17483
17484
# File 'lib/google/apis/compute_beta/classes.rb', line 17482

def healthy_threshold
  @healthy_threshold
end

#http2_health_checkGoogle::Apis::ComputeBeta::Http2HealthCheck

Corresponds to the JSON property http2HealthCheck



17487
17488
17489
# File 'lib/google/apis/compute_beta/classes.rb', line 17487

def http2_health_check
  @http2_health_check
end

#http_health_checkGoogle::Apis::ComputeBeta::HttpHealthCheck

Corresponds to the JSON property httpHealthCheck



17492
17493
17494
# File 'lib/google/apis/compute_beta/classes.rb', line 17492

def http_health_check
  @http_health_check
end

#https_health_checkGoogle::Apis::ComputeBeta::HttpsHealthCheck

Corresponds to the JSON property httpsHealthCheck



17497
17498
17499
# File 'lib/google/apis/compute_beta/classes.rb', line 17497

def https_health_check
  @https_health_check
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


17503
17504
17505
# File 'lib/google/apis/compute_beta/classes.rb', line 17503

def id
  @id
end

#kindString

Output only. Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


17508
17509
17510
# File 'lib/google/apis/compute_beta/classes.rb', line 17508

def kind
  @kind
end

#log_configGoogle::Apis::ComputeBeta::HealthCheckLogConfig

Configuration of logging on a health check. If logging is enabled, logs will be exported to Stackdriver. Corresponds to the JSON property logConfig



17514
17515
17516
# File 'lib/google/apis/compute_beta/classes.rb', line 17514

def log_config
  @log_config
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. For example, a name that is 1-63 characters long, matches the regular expression [a-z]([-a-z0-9]*[a-z0-9])?, and otherwise complies with RFC1035. This regular expression describes a name where the first character is a lowercase letter, and all following characters are a dash, lowercase letter, or digit, except the last character, which isn't a dash. Corresponds to the JSON property name

Returns:

  • (String)


17525
17526
17527
# File 'lib/google/apis/compute_beta/classes.rb', line 17525

def name
  @name
end

#regionString

Output only. [Output Only] Region where the health check resides. Not applicable to global health checks. Corresponds to the JSON property region

Returns:

  • (String)


17532
17533
17534
# File 'lib/google/apis/compute_beta/classes.rb', line 17532

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17537
17538
17539
# File 'lib/google/apis/compute_beta/classes.rb', line 17537

def self_link
  @self_link
end

#source_regionsArray<String>

The list of cloud regions from which health checks are performed. If any regions are specified, then exactly 3 regions should be specified. The region names must be valid names of Google Cloud regions. This can only be set for global health check. If this list is non-empty, then there are restrictions on what other health check fields are supported and what other resources can use this health check:

  • SSL, HTTP2, and GRPC protocols are not supported.
  • The TCP request field is not supported.
  • The proxyHeader field for HTTP, HTTPS, and TCP is not supported.
  • The checkIntervalSec field must be at least 30.
  • The health check cannot be used with BackendService nor with managed instance group auto-healing. Corresponds to the JSON property sourceRegions

Returns:

  • (Array<String>)


17556
17557
17558
# File 'lib/google/apis/compute_beta/classes.rb', line 17556

def source_regions
  @source_regions
end

#ssl_health_checkGoogle::Apis::ComputeBeta::SslHealthCheck

Corresponds to the JSON property sslHealthCheck



17561
17562
17563
# File 'lib/google/apis/compute_beta/classes.rb', line 17561

def ssl_health_check
  @ssl_health_check
end

#tcp_health_checkGoogle::Apis::ComputeBeta::TcpHealthCheck

Corresponds to the JSON property tcpHealthCheck



17566
17567
17568
# File 'lib/google/apis/compute_beta/classes.rb', line 17566

def tcp_health_check
  @tcp_health_check
end

#timeout_secFixnum

How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


17573
17574
17575
# File 'lib/google/apis/compute_beta/classes.rb', line 17573

def timeout_sec
  @timeout_sec
end

#typeString

Specifies the type of the healthCheck, either TCP,SSL, HTTP, HTTPS,HTTP2 or GRPC. Exactly one of the protocol-specific health check fields must be specified, which must matchtype field. Corresponds to the JSON property type

Returns:

  • (String)


17581
17582
17583
# File 'lib/google/apis/compute_beta/classes.rb', line 17581

def type
  @type
end

#unhealthy_thresholdFixnum

A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


17587
17588
17589
# File 'lib/google/apis/compute_beta/classes.rb', line 17587

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17594
17595
17596
17597
17598
17599
17600
17601
17602
17603
17604
17605
17606
17607
17608
17609
17610
17611
17612
17613
17614
17615
17616
# File 'lib/google/apis/compute_beta/classes.rb', line 17594

def update!(**args)
  @check_interval_sec = args[:check_interval_sec] if args.key?(:check_interval_sec)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @grpc_health_check = args[:grpc_health_check] if args.key?(:grpc_health_check)
  @grpc_tls_health_check = args[:grpc_tls_health_check] if args.key?(:grpc_tls_health_check)
  @healthy_threshold = args[:healthy_threshold] if args.key?(:healthy_threshold)
  @http2_health_check = args[:http2_health_check] if args.key?(:http2_health_check)
  @http_health_check = args[:http_health_check] if args.key?(:http_health_check)
  @https_health_check = args[:https_health_check] if args.key?(:https_health_check)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @source_regions = args[:source_regions] if args.key?(:source_regions)
  @ssl_health_check = args[:ssl_health_check] if args.key?(:ssl_health_check)
  @tcp_health_check = args[:tcp_health_check] if args.key?(:tcp_health_check)
  @timeout_sec = args[:timeout_sec] if args.key?(:timeout_sec)
  @type = args[:type] if args.key?(:type)
  @unhealthy_threshold = args[:unhealthy_threshold] if args.key?(:unhealthy_threshold)
end