Class: Google::Apis::ComputeBeta::HealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthCheck>
A list of HealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckList
constructor
A new instance of HealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckList
Returns a new instance of HealthCheckList.
18998 18999 19000 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18966 18967 18968 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18966 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthCheck>
A list of HealthCheck resources.
Corresponds to the JSON property items
18971 18972 18973 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18971 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18976 18977 18978 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18976 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18986 18987 18988 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18986 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18991 18992 18993 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18991 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18996 18997 18998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18996 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19003 19004 19005 19006 19007 19008 19009 19010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19003 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |