Class: Google::Apis::ComputeBeta::HealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthCheck>
A list of HealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckList
constructor
A new instance of HealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckList
Returns a new instance of HealthCheckList.
18849 18850 18851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18849 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18817 18818 18819 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18817 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthCheck>
A list of HealthCheck resources.
Corresponds to the JSON property items
18822 18823 18824 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18822 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18827 18828 18829 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18827 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18837 18838 18839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18837 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18842 18843 18844 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18842 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18847 18848 18849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18847 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18854 18855 18856 18857 18858 18859 18860 18861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18854 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |