Class: Google::Apis::ComputeBeta::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



18265
18266
18267
# File 'lib/google/apis/compute_beta/classes.rb', line 18265

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18233
18234
18235
# File 'lib/google/apis/compute_beta/classes.rb', line 18233

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



18238
18239
18240
# File 'lib/google/apis/compute_beta/classes.rb', line 18238

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18243
18244
18245
# File 'lib/google/apis/compute_beta/classes.rb', line 18243

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18253
18254
18255
# File 'lib/google/apis/compute_beta/classes.rb', line 18253

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18258
18259
18260
# File 'lib/google/apis/compute_beta/classes.rb', line 18258

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18263
18264
18265
# File 'lib/google/apis/compute_beta/classes.rb', line 18263

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18270
18271
18272
18273
18274
18275
18276
18277
# File 'lib/google/apis/compute_beta/classes.rb', line 18270

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end