Class: Google::Apis::ComputeBeta::HealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckList

Returns a new instance of HealthCheckList.



17658
17659
17660
# File 'lib/google/apis/compute_beta/classes.rb', line 17658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17626
17627
17628
# File 'lib/google/apis/compute_beta/classes.rb', line 17626

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthCheck>

A list of HealthCheck resources. Corresponds to the JSON property items



17631
17632
17633
# File 'lib/google/apis/compute_beta/classes.rb', line 17631

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


17636
17637
17638
# File 'lib/google/apis/compute_beta/classes.rb', line 17636

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


17646
17647
17648
# File 'lib/google/apis/compute_beta/classes.rb', line 17646

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


17651
17652
17653
# File 'lib/google/apis/compute_beta/classes.rb', line 17651

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



17656
17657
17658
# File 'lib/google/apis/compute_beta/classes.rb', line 17656

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



17663
17664
17665
17666
17667
17668
17669
17670
# File 'lib/google/apis/compute_beta/classes.rb', line 17663

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end