Class: Google::Apis::ComputeBeta::HealthCheckService
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheckService
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Health-Check as a Service resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_checks ⇒ Array<String>
A list of URLs to the HealthCheck resources.
-
#health_status_aggregation_policy ⇒ String
Optional.
-
#health_status_aggregation_strategy ⇒ String
This field is deprecated.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network_endpoint_groups ⇒ Array<String>
A list of URLs to the NetworkEndpointGroup resources.
-
#notification_endpoints ⇒ Array<String>
A list of URLs to the NotificationEndpoint resources.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckService
constructor
A new instance of HealthCheckService.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckService
Returns a new instance of HealthCheckService.
19116 19117 19118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19116 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
18989 18990 18991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18989 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
18995 18996 18997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18995 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthCheckService. An up-to-date fingerprint must
be provided in order to patch/update the HealthCheckService; Otherwise, the
request will fail with error 412 conditionNotMet. To see the
latest fingerprint, make a get() request to retrieve the
HealthCheckService.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
19007 19008 19009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19007 def fingerprint @fingerprint end |
#health_checks ⇒ Array<String>
A list of URLs to the HealthCheck resources. Must have
at least one HealthCheck, and not more than 10 for regionalHealthCheckService,
and not more than 1 for globalHealthCheckService.HealthCheck resources must
haveportSpecification=USE_SERVING_PORT orportSpecification=USE_FIXED_PORT. For
regional HealthCheckService, theHealthCheck must be regional and in the same
region. For global HealthCheckService,HealthCheck must be global. Mix of
regional and globalHealthChecks is not supported. Multiple
regionalHealthChecks must belong to the same region. RegionalHealthChecks must
belong to the same region as zones ofNetworkEndpointGroups. For
globalHealthCheckService using globalINTERNET_IP_PORT NetworkEndpointGroups,
the
global HealthChecks must specify sourceRegions,
and HealthChecks that specify sourceRegions can
only be used with global INTERNET_IP_PORTNetworkEndpointGroups.
Corresponds to the JSON property healthChecks
19025 19026 19027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19025 def health_checks @health_checks end |
#health_status_aggregation_policy ⇒ String
Optional. Policy for how the results from multiple health checks for the same endpoint are aggregated. Defaults to NO_AGGREGATION if unspecified.
- NO_AGGREGATION. An EndpointHealth message is returned for each pair in the health check service.
- AND. If any health check of an endpoint reportsUNHEALTHY, then UNHEALTHY
is theHealthState of the endpoint. If all health checks reportHEALTHY, the
HealthState of the endpoint isHEALTHY.
.
This is only allowed with regional HealthCheckService.
Corresponds to the JSON property
healthStatusAggregationPolicy
19041 19042 19043 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19041 def health_status_aggregation_policy @health_status_aggregation_policy end |
#health_status_aggregation_strategy ⇒ String
This field is deprecated. Use health_status_aggregation_policy instead. Policy for how the results from multiple health checks for the same endpoint are aggregated.
- NO_AGGREGATION. An EndpointHealth message is returned for each backend in the health check service.
- AND. If any backend's health check reportsUNHEALTHY, then UNHEALTHY is
theHealthState of the entire health check service. If
all backend's are healthy, the HealthState of the
health check service is HEALTHY.
.
Corresponds to the JSON property
healthStatusAggregationStrategy
19058 19059 19060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19058 def health_status_aggregation_strategy @health_status_aggregation_strategy end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
19065 19066 19067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19065 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
healthCheckServicefor health check services.
Corresponds to the JSON property kind
19071 19072 19073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19071 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
19082 19083 19084 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19082 def name @name end |
#network_endpoint_groups ⇒ Array<String>
A list of URLs to the NetworkEndpointGroup
resources. Must not have more than 100. For regionalHealthCheckService, NEGs
must be in
zones in the region of the HealthCheckService. For globalHealthCheckServices,
the NetworkEndpointGroups
must be global INTERNET_IP_PORT.
Corresponds to the JSON property networkEndpointGroups
19092 19093 19094 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19092 def network_endpoint_groups @network_endpoint_groups end |
#notification_endpoints ⇒ Array<String>
A list of URLs to the NotificationEndpoint
resources. Must not have more than 10. A list of endpoints for
receiving notifications of change in health status. For
regionalHealthCheckService,NotificationEndpoint must be regional and in the
same region. For global HealthCheckService,NotificationEndpoint must be global.
Corresponds to the JSON property notificationEndpoints
19101 19102 19103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19101 def notification_endpoints @notification_endpoints end |
#region ⇒ String
Output only. [Output Only] URL of the region where the health check service
resides. This field is not applicable to global health check services.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
19109 19110 19111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19109 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
19114 19115 19116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19114 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19121 19122 19123 19124 19125 19126 19127 19128 19129 19130 19131 19132 19133 19134 19135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19121 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_checks = args[:health_checks] if args.key?(:health_checks) @health_status_aggregation_policy = args[:health_status_aggregation_policy] if args.key?(:health_status_aggregation_policy) @health_status_aggregation_strategy = args[:health_status_aggregation_strategy] if args.key?(:health_status_aggregation_strategy) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network_endpoint_groups = args[:network_endpoint_groups] if args.key?(:network_endpoint_groups) @notification_endpoints = args[:notification_endpoints] if args.key?(:notification_endpoints) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |