Class: Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthCheckServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
constructor
A new instance of HealthCheckServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
Returns a new instance of HealthCheckServiceAggregatedList.
19615 19616 19617 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19615 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19578 19579 19580 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19578 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
Corresponds to the JSON property items
19583 19584 19585 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19583 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19588 19589 19590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19588 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19598 19599 19600 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19598 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19603 19604 19605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19603 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19608 19609 19610 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19608 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19613 19614 19615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19613 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19620 19621 19622 19623 19624 19625 19626 19627 19628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19620 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |