Class: Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



19407
19408
19409
# File 'lib/google/apis/compute_beta/classes.rb', line 19407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19370
19371
19372
# File 'lib/google/apis/compute_beta/classes.rb', line 19370

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



19375
19376
19377
# File 'lib/google/apis/compute_beta/classes.rb', line 19375

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


19380
19381
19382
# File 'lib/google/apis/compute_beta/classes.rb', line 19380

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19390
19391
19392
# File 'lib/google/apis/compute_beta/classes.rb', line 19390

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19395
19396
19397
# File 'lib/google/apis/compute_beta/classes.rb', line 19395

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


19400
19401
19402
# File 'lib/google/apis/compute_beta/classes.rb', line 19400

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



19405
19406
19407
# File 'lib/google/apis/compute_beta/classes.rb', line 19405

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19412
19413
19414
19415
19416
19417
19418
19419
19420
# File 'lib/google/apis/compute_beta/classes.rb', line 19412

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end