Class: Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthCheckServicesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
constructor
A new instance of HealthCheckServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthCheckServiceAggregatedList
Returns a new instance of HealthCheckServiceAggregatedList.
19182 19183 19184 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19182 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19145 19146 19147 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19145 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthCheckServicesScopedList>
A list of HealthCheckServicesScopedList resources.
Corresponds to the JSON property items
19150 19151 19152 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19150 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19155 19156 19157 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19155 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19165 19166 19167 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19165 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19170 19171 19172 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19170 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19175 19176 19177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19175 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19180 19181 19182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19180 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19187 19188 19189 19190 19191 19192 19193 19194 19195 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19187 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |