Class: Google::Apis::ComputeBeta::HealthCheckServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthCheckServicesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServiceAggregatedList

Returns a new instance of HealthCheckServiceAggregatedList.



18598
18599
18600
# File 'lib/google/apis/compute_beta/classes.rb', line 18598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18561
18562
18563
# File 'lib/google/apis/compute_beta/classes.rb', line 18561

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthCheckServicesScopedList>

A list of HealthCheckServicesScopedList resources. Corresponds to the JSON property items



18566
18567
18568
# File 'lib/google/apis/compute_beta/classes.rb', line 18566

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18571
18572
18573
# File 'lib/google/apis/compute_beta/classes.rb', line 18571

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18581
18582
18583
# File 'lib/google/apis/compute_beta/classes.rb', line 18581

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18586
18587
18588
# File 'lib/google/apis/compute_beta/classes.rb', line 18586

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18591
18592
18593
# File 'lib/google/apis/compute_beta/classes.rb', line 18591

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthCheckServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18596
18597
18598
# File 'lib/google/apis/compute_beta/classes.rb', line 18596

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18603
18604
18605
18606
18607
18608
18609
18610
18611
# File 'lib/google/apis/compute_beta/classes.rb', line 18603

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end