Class: Google::Apis::ComputeBeta::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



19562
19563
19564
# File 'lib/google/apis/compute_beta/classes.rb', line 19562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19527
19528
19529
# File 'lib/google/apis/compute_beta/classes.rb', line 19527

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



19532
19533
19534
# File 'lib/google/apis/compute_beta/classes.rb', line 19532

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


19539
19540
19541
# File 'lib/google/apis/compute_beta/classes.rb', line 19539

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19550
19551
19552
# File 'lib/google/apis/compute_beta/classes.rb', line 19550

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19555
19556
19557
# File 'lib/google/apis/compute_beta/classes.rb', line 19555

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



19560
19561
19562
# File 'lib/google/apis/compute_beta/classes.rb', line 19560

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19567
19568
19569
19570
19571
19572
19573
19574
# File 'lib/google/apis/compute_beta/classes.rb', line 19567

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end