Class: Google::Apis::ComputeBeta::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



19486
19487
19488
# File 'lib/google/apis/compute_beta/classes.rb', line 19486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19451
19452
19453
# File 'lib/google/apis/compute_beta/classes.rb', line 19451

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



19456
19457
19458
# File 'lib/google/apis/compute_beta/classes.rb', line 19456

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


19463
19464
19465
# File 'lib/google/apis/compute_beta/classes.rb', line 19463

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19474
19475
19476
# File 'lib/google/apis/compute_beta/classes.rb', line 19474

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19479
19480
19481
# File 'lib/google/apis/compute_beta/classes.rb', line 19479

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



19484
19485
19486
# File 'lib/google/apis/compute_beta/classes.rb', line 19484

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19491
19492
19493
19494
19495
19496
19497
19498
# File 'lib/google/apis/compute_beta/classes.rb', line 19491

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end