Class: Google::Apis::ComputeBeta::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



18340
18341
18342
# File 'lib/google/apis/compute_beta/classes.rb', line 18340

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18305
18306
18307
# File 'lib/google/apis/compute_beta/classes.rb', line 18305

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



18310
18311
18312
# File 'lib/google/apis/compute_beta/classes.rb', line 18310

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


18317
18318
18319
# File 'lib/google/apis/compute_beta/classes.rb', line 18317

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18328
18329
18330
# File 'lib/google/apis/compute_beta/classes.rb', line 18328

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18333
18334
18335
# File 'lib/google/apis/compute_beta/classes.rb', line 18333

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18338
18339
18340
# File 'lib/google/apis/compute_beta/classes.rb', line 18338

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18345
18346
18347
18348
18349
18350
18351
18352
# File 'lib/google/apis/compute_beta/classes.rb', line 18345

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end