Class: Google::Apis::ComputeBeta::HealthCheckServicesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthCheckServicesList

Returns a new instance of HealthCheckServicesList.



18016
18017
18018
# File 'lib/google/apis/compute_beta/classes.rb', line 18016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


17981
17982
17983
# File 'lib/google/apis/compute_beta/classes.rb', line 17981

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthCheckService>

Output only. A list of HealthCheckService resources. Corresponds to the JSON property items



17986
17987
17988
# File 'lib/google/apis/compute_beta/classes.rb', line 17986

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# healthCheckServicesList for lists of HealthCheckServices. Corresponds to the JSON property kind

Returns:

  • (String)


17993
17994
17995
# File 'lib/google/apis/compute_beta/classes.rb', line 17993

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18004
18005
18006
# File 'lib/google/apis/compute_beta/classes.rb', line 18004

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18009
18010
18011
# File 'lib/google/apis/compute_beta/classes.rb', line 18009

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthCheckServicesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18014
18015
18016
# File 'lib/google/apis/compute_beta/classes.rb', line 18014

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18021
18022
18023
18024
18025
18026
18027
18028
# File 'lib/google/apis/compute_beta/classes.rb', line 18021

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end