Class: Google::Apis::ComputeBeta::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
19996 19997 19998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19959 19960 19961 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19959 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
19964 19965 19966 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19964 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19969 19970 19971 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19969 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19979 19980 19981 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19979 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19984 19985 19986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19984 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19989 19990 19991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19989 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19994 19995 19996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19994 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20001 20002 20003 20004 20005 20006 20007 20008 20009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20001 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |