Class: Google::Apis::ComputeBeta::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



19788
19789
19790
# File 'lib/google/apis/compute_beta/classes.rb', line 19788

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


19751
19752
19753
# File 'lib/google/apis/compute_beta/classes.rb', line 19751

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



19756
19757
19758
# File 'lib/google/apis/compute_beta/classes.rb', line 19756

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


19761
19762
19763
# File 'lib/google/apis/compute_beta/classes.rb', line 19761

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


19771
19772
19773
# File 'lib/google/apis/compute_beta/classes.rb', line 19771

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19776
19777
19778
# File 'lib/google/apis/compute_beta/classes.rb', line 19776

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


19781
19782
19783
# File 'lib/google/apis/compute_beta/classes.rb', line 19781

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



19786
19787
19788
# File 'lib/google/apis/compute_beta/classes.rb', line 19786

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19793
19794
19795
19796
19797
19798
19799
19800
19801
# File 'lib/google/apis/compute_beta/classes.rb', line 19793

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end