Class: Google::Apis::ComputeBeta::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
19712 19713 19714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19675 19676 19677 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19675 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
19680 19681 19682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19680 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19685 19686 19687 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19685 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19695 19696 19697 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19695 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19700 19701 19702 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19700 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19705 19706 19707 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19705 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19710 19711 19712 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19710 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19717 19718 19719 19720 19721 19722 19723 19724 19725 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19717 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |