Class: Google::Apis::ComputeBeta::HealthChecksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthChecksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthChecksAggregatedList
constructor
A new instance of HealthChecksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthChecksAggregatedList
Returns a new instance of HealthChecksAggregatedList.
18979 18980 18981 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18942 18943 18944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18942 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>
A list of HealthChecksScopedList resources.
Corresponds to the JSON property items
18947 18948 18949 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18947 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18952 18953 18954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18952 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18962 18963 18964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18962 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18967 18968 18969 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18967 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18972 18973 18974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18972 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthChecksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18977 18978 18979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18977 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18984 18985 18986 18987 18988 18989 18990 18991 18992 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18984 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |