Class: Google::Apis::ComputeBeta::HealthChecksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthChecksAggregatedList

Returns a new instance of HealthChecksAggregatedList.



18469
18470
18471
# File 'lib/google/apis/compute_beta/classes.rb', line 18469

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18432
18433
18434
# File 'lib/google/apis/compute_beta/classes.rb', line 18432

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthChecksScopedList>

A list of HealthChecksScopedList resources. Corresponds to the JSON property items



18437
18438
18439
# File 'lib/google/apis/compute_beta/classes.rb', line 18437

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18442
18443
18444
# File 'lib/google/apis/compute_beta/classes.rb', line 18442

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18452
18453
18454
# File 'lib/google/apis/compute_beta/classes.rb', line 18452

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18457
18458
18459
# File 'lib/google/apis/compute_beta/classes.rb', line 18457

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18462
18463
18464
# File 'lib/google/apis/compute_beta/classes.rb', line 18462

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthChecksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18467
18468
18469
# File 'lib/google/apis/compute_beta/classes.rb', line 18467

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18474
18475
18476
18477
18478
18479
18480
18481
18482
# File 'lib/google/apis/compute_beta/classes.rb', line 18474

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end