Class: Google::Apis::ComputeBeta::HealthSource
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a health source. A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_aggregation_policy ⇒ String
URL to the HealthAggregationPolicy resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_type ⇒ String
Specifies the type of the HealthSource.
-
#sources ⇒ Array<String>
URLs to the source resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSource
constructor
A new instance of HealthSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSource
Returns a new instance of HealthSource.
20070 20071 20072 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
19982 19983 19984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19982 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
19988 19989 19990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19988 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthSource. An up-to-date fingerprint
must be provided in order to patch the HealthSource; Otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
HealthSource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
20000 20001 20002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20000 def fingerprint @fingerprint end |
#health_aggregation_policy ⇒ String
URL to the HealthAggregationPolicy resource. Must be set. Must
be regional and in the same region as the HealthSource. Can be
mutated.
Corresponds to the JSON property healthAggregationPolicy
20007 20008 20009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20007 def health_aggregation_policy @health_aggregation_policy end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
20014 20015 20016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20014 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
20020 20021 20022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20020 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
20031 20032 20033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20031 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the health source resides.
This field applies only to the regional resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
20039 20040 20041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20039 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
20044 20045 20046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20044 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
20049 20050 20051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20049 def self_link_with_id @self_link_with_id end |
#source_type ⇒ String
Specifies the type of the HealthSource. The only allowed value
is BACKEND_SERVICE. Must be specified when theHealthSource is created, and
cannot be mutated.
Corresponds to the JSON property sourceType
20056 20057 20058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20056 def source_type @source_type end |
#sources ⇒ Array<String>
URLs to the source resources. Must be size 1. Must be aBackendService if
the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing
schemeINTERNAL or INTERNAL_MANAGED and must be regional
and in the same region as the HealthSource (cross-region
deployment for INTERNAL_MANAGED is not supported). TheBackendService may use
only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService
may not use haPolicy. Can be
mutated.
Corresponds to the JSON property sources
20068 20069 20070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20068 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20075 20076 20077 20078 20079 20080 20081 20082 20083 20084 20085 20086 20087 20088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20075 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_aggregation_policy = args[:health_aggregation_policy] if args.key?(:health_aggregation_policy) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_type = args[:source_type] if args.key?(:source_type) @sources = args[:sources] if args.key?(:sources) end |