Class: Google::Apis::ComputeBeta::HealthSource
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSource
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a health source. A health source resource specifies the source resources and the health aggregation policy applied to the source resources to determine the aggregated health status.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#health_aggregation_policy ⇒ String
URL to the HealthAggregationPolicy resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_type ⇒ String
Specifies the type of the HealthSource.
-
#sources ⇒ Array<String>
URLs to the source resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSource
constructor
A new instance of HealthSource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSource
Returns a new instance of HealthSource.
19994 19995 19996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
19906 19907 19908 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19906 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
19912 19913 19914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19912 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a HealthSource. An up-to-date fingerprint
must be provided in order to patch the HealthSource; Otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
HealthSource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
19924 19925 19926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19924 def fingerprint @fingerprint end |
#health_aggregation_policy ⇒ String
URL to the HealthAggregationPolicy resource. Must be set. Must
be regional and in the same region as the HealthSource. Can be
mutated.
Corresponds to the JSON property healthAggregationPolicy
19931 19932 19933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19931 def health_aggregation_policy @health_aggregation_policy end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
19938 19939 19940 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19938 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
19944 19945 19946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19944 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
19955 19956 19957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19955 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the health source resides.
This field applies only to the regional resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
19963 19964 19965 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19963 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
19968 19969 19970 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19968 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL with id for the resource.
Corresponds to the JSON property selfLinkWithId
19973 19974 19975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19973 def self_link_with_id @self_link_with_id end |
#source_type ⇒ String
Specifies the type of the HealthSource. The only allowed value
is BACKEND_SERVICE. Must be specified when theHealthSource is created, and
cannot be mutated.
Corresponds to the JSON property sourceType
19980 19981 19982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19980 def source_type @source_type end |
#sources ⇒ Array<String>
URLs to the source resources. Must be size 1. Must be aBackendService if
the sourceType is BACKEND_SERVICE. TheBackendService must have load balancing
schemeINTERNAL or INTERNAL_MANAGED and must be regional
and in the same region as the HealthSource (cross-region
deployment for INTERNAL_MANAGED is not supported). TheBackendService may use
only IGs, MIGs, or NEGs of typeGCE_VM_IP or GCE_VM_IP_PORT. TheBackendService
may not use haPolicy. Can be
mutated.
Corresponds to the JSON property sources
19992 19993 19994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19992 def sources @sources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19999 20000 20001 20002 20003 20004 20005 20006 20007 20008 20009 20010 20011 20012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19999 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @health_aggregation_policy = args[:health_aggregation_policy] if args.key?(:health_aggregation_policy) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_type = args[:source_type] if args.key?(:source_type) @sources = args[:sources] if args.key?(:sources) end |