Class: Google::Apis::ComputeBeta::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
20135 20136 20137 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20098 20099 20100 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20098 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
20103 20104 20105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20103 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
20108 20109 20110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20108 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20118 20119 20120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20118 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20123 20124 20125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20123 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
20128 20129 20130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20128 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20133 20134 20135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20133 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20140 20141 20142 20143 20144 20145 20146 20147 20148 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20140 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |