Class: Google::Apis::ComputeBeta::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



20085
20086
20087
# File 'lib/google/apis/compute_beta/classes.rb', line 20085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20048
20049
20050
# File 'lib/google/apis/compute_beta/classes.rb', line 20048

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



20053
20054
20055
# File 'lib/google/apis/compute_beta/classes.rb', line 20053

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20058
20059
20060
# File 'lib/google/apis/compute_beta/classes.rb', line 20058

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20068
20069
20070
# File 'lib/google/apis/compute_beta/classes.rb', line 20068

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20073
20074
20075
# File 'lib/google/apis/compute_beta/classes.rb', line 20073

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20078
20079
20080
# File 'lib/google/apis/compute_beta/classes.rb', line 20078

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20083
20084
20085
# File 'lib/google/apis/compute_beta/classes.rb', line 20083

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20090
20091
20092
20093
20094
20095
20096
20097
20098
# File 'lib/google/apis/compute_beta/classes.rb', line 20090

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end