Class: Google::Apis::ComputeBeta::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



20059
20060
20061
# File 'lib/google/apis/compute_beta/classes.rb', line 20059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20022
20023
20024
# File 'lib/google/apis/compute_beta/classes.rb', line 20022

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



20027
20028
20029
# File 'lib/google/apis/compute_beta/classes.rb', line 20027

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20032
20033
20034
# File 'lib/google/apis/compute_beta/classes.rb', line 20032

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20042
20043
20044
# File 'lib/google/apis/compute_beta/classes.rb', line 20042

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20047
20048
20049
# File 'lib/google/apis/compute_beta/classes.rb', line 20047

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20052
20053
20054
# File 'lib/google/apis/compute_beta/classes.rb', line 20052

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20057
20058
20059
# File 'lib/google/apis/compute_beta/classes.rb', line 20057

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20064
20065
20066
20067
20068
20069
20070
20071
20072
# File 'lib/google/apis/compute_beta/classes.rb', line 20064

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end