Class: Google::Apis::ComputeBeta::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
19934 19935 19936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19897 19898 19899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19897 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
19902 19903 19904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19902 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19907 19908 19909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19907 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19917 19918 19919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19917 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19922 19923 19924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19922 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
19927 19928 19929 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19927 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19932 19933 19934 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19932 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19939 19940 19941 19942 19943 19944 19945 19946 19947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19939 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |