Class: Google::Apis::ComputeBeta::HealthSourceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HealthSourcesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceAggregatedList

Returns a new instance of HealthSourceAggregatedList.



18492
18493
18494
# File 'lib/google/apis/compute_beta/classes.rb', line 18492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18455
18456
18457
# File 'lib/google/apis/compute_beta/classes.rb', line 18455

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>

A list of HealthSourcesScopedList resources. Corresponds to the JSON property items



18460
18461
18462
# File 'lib/google/apis/compute_beta/classes.rb', line 18460

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


18465
18466
18467
# File 'lib/google/apis/compute_beta/classes.rb', line 18465

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18475
18476
18477
# File 'lib/google/apis/compute_beta/classes.rb', line 18475

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18480
18481
18482
# File 'lib/google/apis/compute_beta/classes.rb', line 18480

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


18485
18486
18487
# File 'lib/google/apis/compute_beta/classes.rb', line 18485

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HealthSourceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18490
18491
18492
# File 'lib/google/apis/compute_beta/classes.rb', line 18490

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18497
18498
18499
18500
18501
18502
18503
18504
18505
# File 'lib/google/apis/compute_beta/classes.rb', line 18497

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end