Class: Google::Apis::ComputeBeta::HealthSourceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HealthSourcesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceAggregatedList
constructor
A new instance of HealthSourceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceAggregatedList
Returns a new instance of HealthSourceAggregatedList.
18492 18493 18494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
18455 18456 18457 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18455 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::HealthSourcesScopedList>
A list of HealthSourcesScopedList resources.
Corresponds to the JSON property items
18460 18461 18462 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18460 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
18465 18466 18467 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18465 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
18475 18476 18477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18475 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
18480 18481 18482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18480 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
18485 18486 18487 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18485 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
18490 18491 18492 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18490 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
18497 18498 18499 18500 18501 18502 18503 18504 18505 |
# File 'lib/google/apis/compute_beta/classes.rb', line 18497 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |