Class: Google::Apis::ComputeBeta::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
20501 20502 20503 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20501 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20468 20469 20470 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20468 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
20473 20474 20475 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20473 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
20479 20480 20481 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20479 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20489 20490 20491 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20489 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20494 20495 20496 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20494 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20499 20500 20501 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20499 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20506 20507 20508 20509 20510 20511 20512 20513 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20506 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |