Class: Google::Apis::ComputeBeta::HealthSourceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HealthSource>
A list of HealthSource resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourceList
constructor
A new instance of HealthSourceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourceList
Returns a new instance of HealthSourceList.
20243 20244 20245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20210 20211 20212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20210 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HealthSource>
A list of HealthSource resources.
Corresponds to the JSON property items
20215 20216 20217 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20215 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#healthSource
for health sources.
Corresponds to the JSON property kind
20221 20222 20223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20221 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20231 20232 20233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20231 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20236 20237 20238 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20236 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HealthSourceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20241 20242 20243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20241 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20248 20249 20250 20251 20252 20253 20254 20255 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20248 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |