Class: Google::Apis::ComputeBeta::HealthSourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceList

Returns a new instance of HealthSourceList.



18942
18943
18944
# File 'lib/google/apis/compute_beta/classes.rb', line 18942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18909
18910
18911
# File 'lib/google/apis/compute_beta/classes.rb', line 18909

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthSource>

A list of HealthSource resources. Corresponds to the JSON property items



18914
18915
18916
# File 'lib/google/apis/compute_beta/classes.rb', line 18914

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources. Corresponds to the JSON property kind

Returns:

  • (String)


18920
18921
18922
# File 'lib/google/apis/compute_beta/classes.rb', line 18920

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18930
18931
18932
# File 'lib/google/apis/compute_beta/classes.rb', line 18930

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18935
18936
18937
# File 'lib/google/apis/compute_beta/classes.rb', line 18935

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthSourceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18940
18941
18942
# File 'lib/google/apis/compute_beta/classes.rb', line 18940

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18947
18948
18949
18950
18951
18952
18953
18954
# File 'lib/google/apis/compute_beta/classes.rb', line 18947

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end