Class: Google::Apis::ComputeBeta::HealthSourceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourceList

Returns a new instance of HealthSourceList.



18618
18619
18620
# File 'lib/google/apis/compute_beta/classes.rb', line 18618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


18585
18586
18587
# File 'lib/google/apis/compute_beta/classes.rb', line 18585

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HealthSource>

A list of HealthSource resources. Corresponds to the JSON property items



18590
18591
18592
# File 'lib/google/apis/compute_beta/classes.rb', line 18590

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#healthSource for health sources. Corresponds to the JSON property kind

Returns:

  • (String)


18596
18597
18598
# File 'lib/google/apis/compute_beta/classes.rb', line 18596

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


18606
18607
18608
# File 'lib/google/apis/compute_beta/classes.rb', line 18606

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


18611
18612
18613
# File 'lib/google/apis/compute_beta/classes.rb', line 18611

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HealthSourceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



18616
18617
18618
# File 'lib/google/apis/compute_beta/classes.rb', line 18616

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18623
18624
18625
18626
18627
18628
18629
18630
# File 'lib/google/apis/compute_beta/classes.rb', line 18623

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end