Class: Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfoBackendInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfoBackendInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#endpoint_count ⇒ Fixnum
Total number of endpoints when determining the health of the regionHealthSource.
-
#group ⇒ String
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
-
#healthy_endpoint_count ⇒ Fixnum
Number of endpoints considered healthy when determining health of the regionHealthSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo
constructor
A new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo
Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.
20359 20360 20361 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20359 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_count ⇒ Fixnum
Total number of endpoints when determining the health of the
regionHealthSource.
Corresponds to the JSON property endpointCount
20345 20346 20347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20345 def endpoint_count @endpoint_count end |
#group ⇒ String
Fully qualified URL of an instance group or network endpoint group
behind the source backend service.
Corresponds to the JSON property group
20351 20352 20353 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20351 def group @group end |
#healthy_endpoint_count ⇒ Fixnum
Number of endpoints considered healthy when determining health of the
regionHealthSource.
Corresponds to the JSON property healthyEndpointCount
20357 20358 20359 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20357 def healthy_endpoint_count @healthy_endpoint_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20364 20365 20366 20367 20368 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20364 def update!(**args) @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count) @group = args[:group] if args.key?(:group) @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count) end |