Class: Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfoBackendInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo

Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.



20234
20235
20236
# File 'lib/google/apis/compute_beta/classes.rb', line 20234

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endpoint_countFixnum

Total number of endpoints when determining the health of the regionHealthSource. Corresponds to the JSON property endpointCount

Returns:

  • (Fixnum)


20220
20221
20222
# File 'lib/google/apis/compute_beta/classes.rb', line 20220

def endpoint_count
  @endpoint_count
end

#groupString

Fully qualified URL of an instance group or network endpoint group behind the source backend service. Corresponds to the JSON property group

Returns:

  • (String)


20226
20227
20228
# File 'lib/google/apis/compute_beta/classes.rb', line 20226

def group
  @group
end

#healthy_endpoint_countFixnum

Number of endpoints considered healthy when determining health of the regionHealthSource. Corresponds to the JSON property healthyEndpointCount

Returns:

  • (Fixnum)


20232
20233
20234
# File 'lib/google/apis/compute_beta/classes.rb', line 20232

def healthy_endpoint_count
  @healthy_endpoint_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20239
20240
20241
20242
20243
# File 'lib/google/apis/compute_beta/classes.rb', line 20239

def update!(**args)
  @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count)
  @group = args[:group] if args.key?(:group)
  @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count)
end