Class: Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfoBackendInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthSourcesGetHealthResponseSourceInfoBackendInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#endpoint_count ⇒ Fixnum
Total number of endpoints when determining the health of the regionHealthSource.
-
#group ⇒ String
Fully qualified URL of an instance group or network endpoint group behind the source backend service.
-
#healthy_endpoint_count ⇒ Fixnum
Number of endpoints considered healthy when determining health of the regionHealthSource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo
constructor
A new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthSourcesGetHealthResponseSourceInfoBackendInfo
Returns a new instance of HealthSourcesGetHealthResponseSourceInfoBackendInfo.
19626 19627 19628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#endpoint_count ⇒ Fixnum
Total number of endpoints when determining the health of the
regionHealthSource.
Corresponds to the JSON property endpointCount
19612 19613 19614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19612 def endpoint_count @endpoint_count end |
#group ⇒ String
Fully qualified URL of an instance group or network endpoint group
behind the source backend service.
Corresponds to the JSON property group
19618 19619 19620 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19618 def group @group end |
#healthy_endpoint_count ⇒ Fixnum
Number of endpoints considered healthy when determining health of the
regionHealthSource.
Corresponds to the JSON property healthyEndpointCount
19624 19625 19626 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19624 def healthy_endpoint_count @healthy_endpoint_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19631 19632 19633 19634 19635 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19631 def update!(**args) @endpoint_count = args[:endpoint_count] if args.key?(:endpoint_count) @group = args[:group] if args.key?(:group) @healthy_endpoint_count = args[:healthy_endpoint_count] if args.key?(:healthy_endpoint_count) end |