Class: Google::Apis::ComputeBeta::HealthStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
-
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the instance.
-
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
-
#health_state ⇒ String
Health state of the IPv4 address of the instance.
-
#instance ⇒ String
URL of the instance resource.
-
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance.
-
#ipv6_address ⇒ String
Corresponds to the JSON property
ipv6Address. -
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
-
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is health-checked.
-
#weight ⇒ String
Corresponds to the JSON property
weight. -
#weight_error ⇒ String
Corresponds to the JSON property
weightError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatus
constructor
A new instance of HealthStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatus
Returns a new instance of HealthStatus.
20815 20816 20817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
Corresponds to the JSON property annotations
20759 20760 20761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20759 def annotations @annotations end |
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the
instance.
Corresponds to the JSON property forwardingRule
20765 20766 20767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20765 def forwarding_rule @forwarding_rule end |
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
Corresponds to the JSON property forwardingRuleIp
20770 20771 20772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20770 def forwarding_rule_ip @forwarding_rule_ip end |
#health_state ⇒ String
Health state of the IPv4 address of the instance.
Corresponds to the JSON property healthState
20775 20776 20777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20775 def health_state @health_state end |
#instance ⇒ String
URL of the instance resource.
Corresponds to the JSON property instance
20780 20781 20782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20780 def instance @instance end |
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding
rule's IP address assigned to this instance. For other types of load
balancing, the field indicates VM internal ip.
Corresponds to the JSON property ipAddress
20787 20788 20789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20787 def ip_address @ip_address end |
#ipv6_address ⇒ String
Corresponds to the JSON property ipv6Address
20792 20793 20794 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20792 def ipv6_address @ipv6_address end |
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
Corresponds to the JSON property ipv6HealthState
20797 20798 20799 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20797 def ipv6_health_state @ipv6_health_state end |
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is
health-checked.
Corresponds to the JSON property port
20803 20804 20805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20803 def port @port end |
#weight ⇒ String
Corresponds to the JSON property weight
20808 20809 20810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20808 def weight @weight end |
#weight_error ⇒ String
Corresponds to the JSON property weightError
20813 20814 20815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20813 def weight_error @weight_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20820 20821 20822 20823 20824 20825 20826 20827 20828 20829 20830 20831 20832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20820 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip) @health_state = args[:health_state] if args.key?(:health_state) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) @port = args[:port] if args.key?(:port) @weight = args[:weight] if args.key?(:weight) @weight_error = args[:weight_error] if args.key?(:weight_error) end |