Class: Google::Apis::ComputeBeta::HealthStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
-
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the instance.
-
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
-
#health_state ⇒ String
Health state of the IPv4 address of the instance.
-
#instance ⇒ String
URL of the instance resource.
-
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance.
-
#ipv6_address ⇒ String
Corresponds to the JSON property
ipv6Address. -
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
-
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is health-checked.
-
#weight ⇒ String
Corresponds to the JSON property
weight. -
#weight_error ⇒ String
Corresponds to the JSON property
weightError.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatus
constructor
A new instance of HealthStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatus
Returns a new instance of HealthStatus.
20607 20608 20609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20607 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Metadata defined as annotations for network endpoint.
Corresponds to the JSON property annotations
20551 20552 20553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20551 def annotations @annotations end |
#forwarding_rule ⇒ String
URL of the forwarding rule associated with the health status of the
instance.
Corresponds to the JSON property forwardingRule
20557 20558 20559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20557 def forwarding_rule @forwarding_rule end |
#forwarding_rule_ip ⇒ String
A forwarding rule IP address assigned to this instance.
Corresponds to the JSON property forwardingRuleIp
20562 20563 20564 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20562 def forwarding_rule_ip @forwarding_rule_ip end |
#health_state ⇒ String
Health state of the IPv4 address of the instance.
Corresponds to the JSON property healthState
20567 20568 20569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20567 def health_state @health_state end |
#instance ⇒ String
URL of the instance resource.
Corresponds to the JSON property instance
20572 20573 20574 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20572 def instance @instance end |
#ip_address ⇒ String
For target pool based Network Load Balancing, it indicates the forwarding
rule's IP address assigned to this instance. For other types of load
balancing, the field indicates VM internal ip.
Corresponds to the JSON property ipAddress
20579 20580 20581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20579 def ip_address @ip_address end |
#ipv6_address ⇒ String
Corresponds to the JSON property ipv6Address
20584 20585 20586 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20584 def ipv6_address @ipv6_address end |
#ipv6_health_state ⇒ String
Health state of the IPv6 address of the instance.
Corresponds to the JSON property ipv6HealthState
20589 20590 20591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20589 def ipv6_health_state @ipv6_health_state end |
#port ⇒ Fixnum
The named port of the instance group, not necessarily the port that is
health-checked.
Corresponds to the JSON property port
20595 20596 20597 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20595 def port @port end |
#weight ⇒ String
Corresponds to the JSON property weight
20600 20601 20602 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20600 def weight @weight end |
#weight_error ⇒ String
Corresponds to the JSON property weightError
20605 20606 20607 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20605 def weight_error @weight_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20612 20613 20614 20615 20616 20617 20618 20619 20620 20621 20622 20623 20624 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20612 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip) @health_state = args[:health_state] if args.key?(:health_state) @instance = args[:instance] if args.key?(:instance) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) @port = args[:port] if args.key?(:port) @weight = args[:weight] if args.key?(:weight) @weight_error = args[:weight_error] if args.key?(:weight_error) end |