Class: Google::Apis::ComputeBeta::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



20406
20407
20408
# File 'lib/google/apis/compute_beta/classes.rb', line 20406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


20350
20351
20352
# File 'lib/google/apis/compute_beta/classes.rb', line 20350

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


20356
20357
20358
# File 'lib/google/apis/compute_beta/classes.rb', line 20356

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


20361
20362
20363
# File 'lib/google/apis/compute_beta/classes.rb', line 20361

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


20366
20367
20368
# File 'lib/google/apis/compute_beta/classes.rb', line 20366

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


20371
20372
20373
# File 'lib/google/apis/compute_beta/classes.rb', line 20371

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


20378
20379
20380
# File 'lib/google/apis/compute_beta/classes.rb', line 20378

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


20383
20384
20385
# File 'lib/google/apis/compute_beta/classes.rb', line 20383

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


20388
20389
20390
# File 'lib/google/apis/compute_beta/classes.rb', line 20388

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


20394
20395
20396
# File 'lib/google/apis/compute_beta/classes.rb', line 20394

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


20399
20400
20401
# File 'lib/google/apis/compute_beta/classes.rb', line 20399

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


20404
20405
20406
# File 'lib/google/apis/compute_beta/classes.rb', line 20404

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20411
20412
20413
20414
20415
20416
20417
20418
20419
20420
20421
20422
20423
# File 'lib/google/apis/compute_beta/classes.rb', line 20411

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end