Class: Google::Apis::ComputeBeta::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



20382
20383
20384
# File 'lib/google/apis/compute_beta/classes.rb', line 20382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


20326
20327
20328
# File 'lib/google/apis/compute_beta/classes.rb', line 20326

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


20332
20333
20334
# File 'lib/google/apis/compute_beta/classes.rb', line 20332

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


20337
20338
20339
# File 'lib/google/apis/compute_beta/classes.rb', line 20337

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


20342
20343
20344
# File 'lib/google/apis/compute_beta/classes.rb', line 20342

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


20347
20348
20349
# File 'lib/google/apis/compute_beta/classes.rb', line 20347

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


20354
20355
20356
# File 'lib/google/apis/compute_beta/classes.rb', line 20354

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


20359
20360
20361
# File 'lib/google/apis/compute_beta/classes.rb', line 20359

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


20364
20365
20366
# File 'lib/google/apis/compute_beta/classes.rb', line 20364

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


20370
20371
20372
# File 'lib/google/apis/compute_beta/classes.rb', line 20370

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


20375
20376
20377
# File 'lib/google/apis/compute_beta/classes.rb', line 20375

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


20380
20381
20382
# File 'lib/google/apis/compute_beta/classes.rb', line 20380

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20387
20388
20389
20390
20391
20392
20393
20394
20395
20396
20397
20398
20399
# File 'lib/google/apis/compute_beta/classes.rb', line 20387

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end