Class: Google::Apis::ComputeBeta::HealthStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatus

Returns a new instance of HealthStatus.



19187
19188
19189
# File 'lib/google/apis/compute_beta/classes.rb', line 19187

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Metadata defined as annotations for network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


19131
19132
19133
# File 'lib/google/apis/compute_beta/classes.rb', line 19131

def annotations
  @annotations
end

#forwarding_ruleString

URL of the forwarding rule associated with the health status of the instance. Corresponds to the JSON property forwardingRule

Returns:

  • (String)


19137
19138
19139
# File 'lib/google/apis/compute_beta/classes.rb', line 19137

def forwarding_rule
  @forwarding_rule
end

#forwarding_rule_ipString

A forwarding rule IP address assigned to this instance. Corresponds to the JSON property forwardingRuleIp

Returns:

  • (String)


19142
19143
19144
# File 'lib/google/apis/compute_beta/classes.rb', line 19142

def forwarding_rule_ip
  @forwarding_rule_ip
end

#health_stateString

Health state of the IPv4 address of the instance. Corresponds to the JSON property healthState

Returns:

  • (String)


19147
19148
19149
# File 'lib/google/apis/compute_beta/classes.rb', line 19147

def health_state
  @health_state
end

#instanceString

URL of the instance resource. Corresponds to the JSON property instance

Returns:

  • (String)


19152
19153
19154
# File 'lib/google/apis/compute_beta/classes.rb', line 19152

def instance
  @instance
end

#ip_addressString

For target pool based Network Load Balancing, it indicates the forwarding rule's IP address assigned to this instance. For other types of load balancing, the field indicates VM internal ip. Corresponds to the JSON property ipAddress

Returns:

  • (String)


19159
19160
19161
# File 'lib/google/apis/compute_beta/classes.rb', line 19159

def ip_address
  @ip_address
end

#ipv6_addressString

Corresponds to the JSON property ipv6Address

Returns:

  • (String)


19164
19165
19166
# File 'lib/google/apis/compute_beta/classes.rb', line 19164

def ipv6_address
  @ipv6_address
end

#ipv6_health_stateString

Health state of the IPv6 address of the instance. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


19169
19170
19171
# File 'lib/google/apis/compute_beta/classes.rb', line 19169

def ipv6_health_state
  @ipv6_health_state
end

#portFixnum

The named port of the instance group, not necessarily the port that is health-checked. Corresponds to the JSON property port

Returns:

  • (Fixnum)


19175
19176
19177
# File 'lib/google/apis/compute_beta/classes.rb', line 19175

def port
  @port
end

#weightString

Corresponds to the JSON property weight

Returns:

  • (String)


19180
19181
19182
# File 'lib/google/apis/compute_beta/classes.rb', line 19180

def weight
  @weight
end

#weight_errorString

Corresponds to the JSON property weightError

Returns:

  • (String)


19185
19186
19187
# File 'lib/google/apis/compute_beta/classes.rb', line 19185

def weight_error
  @weight_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19192
19193
19194
19195
19196
19197
19198
19199
19200
19201
19202
19203
19204
# File 'lib/google/apis/compute_beta/classes.rb', line 19192

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @forwarding_rule_ip = args[:forwarding_rule_ip] if args.key?(:forwarding_rule_ip)
  @health_state = args[:health_state] if args.key?(:health_state)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
  @port = args[:port] if args.key?(:port)
  @weight = args[:weight] if args.key?(:weight)
  @weight_error = args[:weight_error] if args.key?(:weight_error)
end