Class: Google::Apis::ComputeBeta::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



20602
20603
20604
# File 'lib/google/apis/compute_beta/classes.rb', line 20602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeBeta::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



20559
20560
20561
# File 'lib/google/apis/compute_beta/classes.rb', line 20559

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeBeta::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



20565
20566
20567
# File 'lib/google/apis/compute_beta/classes.rb', line 20565

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeBeta::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



20576
20577
20578
# File 'lib/google/apis/compute_beta/classes.rb', line 20576

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeBeta::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



20588
20589
20590
# File 'lib/google/apis/compute_beta/classes.rb', line 20588

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


20594
20595
20596
# File 'lib/google/apis/compute_beta/classes.rb', line 20594

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


20600
20601
20602
# File 'lib/google/apis/compute_beta/classes.rb', line 20600

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20607
20608
20609
20610
20611
20612
20613
20614
# File 'lib/google/apis/compute_beta/classes.rb', line 20607

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end