Class: Google::Apis::ComputeBeta::HealthStatusForNetworkEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HealthStatusForNetworkEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#backend_service ⇒ Google::Apis::ComputeBeta::BackendServiceReference
URL of the backend service associated with the health state of the network endpoint.
-
#forwarding_rule ⇒ Google::Apis::ComputeBeta::ForwardingRuleReference
URL of the forwarding rule associated with the health state of the network endpoint.
-
#health_check ⇒ Google::Apis::ComputeBeta::HealthCheckReference
A full or valid partial URL to a health check.
-
#health_check_service ⇒ Google::Apis::ComputeBeta::HealthCheckServiceReference
A full or valid partial URL to a health check service.
-
#health_state ⇒ String
Health state of the network endpoint determined based on the health checks configured.
-
#ipv6_health_state ⇒ String
Health state of the ipv6 network endpoint determined based on the health checks configured.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HealthStatusForNetworkEndpoint
constructor
A new instance of HealthStatusForNetworkEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HealthStatusForNetworkEndpoint
Returns a new instance of HealthStatusForNetworkEndpoint.
20453 20454 20455 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20453 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backend_service ⇒ Google::Apis::ComputeBeta::BackendServiceReference
URL of the backend service associated with the health state of the network
endpoint.
Corresponds to the JSON property backendService
20410 20411 20412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20410 def backend_service @backend_service end |
#forwarding_rule ⇒ Google::Apis::ComputeBeta::ForwardingRuleReference
URL of the forwarding rule associated with the health state of the network
endpoint.
Corresponds to the JSON property forwardingRule
20416 20417 20418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20416 def forwarding_rule @forwarding_rule end |
#health_check ⇒ Google::Apis::ComputeBeta::HealthCheckReference
A full or valid partial URL to a health check. For example, the following are valid URLs:
- https://www.googleapis.com/compute/beta/projects/project-id/global/ httpHealthChecks/health-check
- projects/project-id/global/httpHealthChecks/health-check
- global/httpHealthChecks/health-check
Corresponds to the JSON property
healthCheck
20427 20428 20429 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20427 def health_check @health_check end |
#health_check_service ⇒ Google::Apis::ComputeBeta::HealthCheckServiceReference
A full or valid partial URL to a health check service. For example, the following are valid URLs:
- https://www.googleapis.com/compute/beta/projects/project-id/regions/us- west1/healthCheckServices/health-check-service
- projects/project-id/regions/us-west1/healthCheckServices/health-check- service
- regions/us-west1/healthCheckServices/health-check-service
Corresponds to the JSON property
healthCheckService
20439 20440 20441 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20439 def health_check_service @health_check_service end |
#health_state ⇒ String
Health state of the network endpoint determined based on the health checks
configured.
Corresponds to the JSON property healthState
20445 20446 20447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20445 def health_state @health_state end |
#ipv6_health_state ⇒ String
Health state of the ipv6 network endpoint determined based on the health
checks configured.
Corresponds to the JSON property ipv6HealthState
20451 20452 20453 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20451 def ipv6_health_state @ipv6_health_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20458 20459 20460 20461 20462 20463 20464 20465 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20458 def update!(**args) @backend_service = args[:backend_service] if args.key?(:backend_service) @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule) @health_check = args[:health_check] if args.key?(:health_check) @health_check_service = args[:health_check_service] if args.key?(:health_check_service) @health_state = args[:health_state] if args.key?(:health_state) @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state) end |