Class: Google::Apis::ComputeBeta::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



19869
19870
19871
# File 'lib/google/apis/compute_beta/classes.rb', line 19869

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeBeta::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



19826
19827
19828
# File 'lib/google/apis/compute_beta/classes.rb', line 19826

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeBeta::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



19832
19833
19834
# File 'lib/google/apis/compute_beta/classes.rb', line 19832

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeBeta::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



19843
19844
19845
# File 'lib/google/apis/compute_beta/classes.rb', line 19843

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeBeta::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



19855
19856
19857
# File 'lib/google/apis/compute_beta/classes.rb', line 19855

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


19861
19862
19863
# File 'lib/google/apis/compute_beta/classes.rb', line 19861

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


19867
19868
19869
# File 'lib/google/apis/compute_beta/classes.rb', line 19867

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19874
19875
19876
19877
19878
19879
19880
19881
# File 'lib/google/apis/compute_beta/classes.rb', line 19874

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end