Class: Google::Apis::ComputeBeta::HealthStatusForNetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HealthStatusForNetworkEndpoint

Returns a new instance of HealthStatusForNetworkEndpoint.



18934
18935
18936
# File 'lib/google/apis/compute_beta/classes.rb', line 18934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceGoogle::Apis::ComputeBeta::BackendServiceReference

URL of the backend service associated with the health state of the network endpoint. Corresponds to the JSON property backendService



18891
18892
18893
# File 'lib/google/apis/compute_beta/classes.rb', line 18891

def backend_service
  @backend_service
end

#forwarding_ruleGoogle::Apis::ComputeBeta::ForwardingRuleReference

URL of the forwarding rule associated with the health state of the network endpoint. Corresponds to the JSON property forwardingRule



18897
18898
18899
# File 'lib/google/apis/compute_beta/classes.rb', line 18897

def forwarding_rule
  @forwarding_rule
end

#health_checkGoogle::Apis::ComputeBeta::HealthCheckReference

A full or valid partial URL to a health check. For example, the following are valid URLs:



18908
18909
18910
# File 'lib/google/apis/compute_beta/classes.rb', line 18908

def health_check
  @health_check
end

#health_check_serviceGoogle::Apis::ComputeBeta::HealthCheckServiceReference

A full or valid partial URL to a health check service. For example, the following are valid URLs:



18920
18921
18922
# File 'lib/google/apis/compute_beta/classes.rb', line 18920

def health_check_service
  @health_check_service
end

#health_stateString

Health state of the network endpoint determined based on the health checks configured. Corresponds to the JSON property healthState

Returns:

  • (String)


18926
18927
18928
# File 'lib/google/apis/compute_beta/classes.rb', line 18926

def health_state
  @health_state
end

#ipv6_health_stateString

Health state of the ipv6 network endpoint determined based on the health checks configured. Corresponds to the JSON property ipv6HealthState

Returns:

  • (String)


18932
18933
18934
# File 'lib/google/apis/compute_beta/classes.rb', line 18932

def ipv6_health_state
  @ipv6_health_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18939
18940
18941
18942
18943
18944
18945
18946
# File 'lib/google/apis/compute_beta/classes.rb', line 18939

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @forwarding_rule = args[:forwarding_rule] if args.key?(:forwarding_rule)
  @health_check = args[:health_check] if args.key?(:health_check)
  @health_check_service = args[:health_check_service] if args.key?(:health_check_service)
  @health_state = args[:health_state] if args.key?(:health_state)
  @ipv6_health_state = args[:ipv6_health_state] if args.key?(:ipv6_health_state)
end