Class: Google::Apis::ComputeBeta::HostPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HostPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The unique identifier of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation sub-block.
-
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
-
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostPhysicalTopology
constructor
A new instance of HostPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostPhysicalTopology
Returns a new instance of HostPhysicalTopology.
20771 20772 20773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The unique identifier of the capacity block within the cluster.
Corresponds to the JSON property block
20753 20754 20755 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20753 def block @block end |
#cluster ⇒ String
The cluster name of the reservation sub-block.
Corresponds to the JSON property cluster
20758 20759 20760 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20758 def cluster @cluster end |
#host ⇒ String
The unique identifier of the capacity host within the capacity sub-block.
Corresponds to the JSON property host
20763 20764 20765 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20763 def host @host end |
#sub_block ⇒ String
The unique identifier of the capacity sub-block within the capacity
block.
Corresponds to the JSON property subBlock
20769 20770 20771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20769 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20776 20777 20778 20779 20780 20781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20776 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @sub_block = args[:sub_block] if args.key?(:sub_block) end |