Class: Google::Apis::ComputeBeta::HostRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HostRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
UrlMaps A host-matching rule for a URL. If matched, will use the namedPathMatcher to select the BackendService.
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of this resource.
-
#hosts ⇒ Array<String>
The list of host patterns to match.
-
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostRule
constructor
A new instance of HostRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostRule
Returns a new instance of HostRule.
20891 20892 20893 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20891 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
20870 20871 20872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20870 def description @description end |
#hosts ⇒ Array<String>
The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port.* matches any string of ([a-z0-9- .]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or ..
- based matching is not supported when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property
hosts
20883 20884 20885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20883 def hosts @hosts end |
#path_matcher ⇒ String
The name of the PathMatcher to use to match the path portion
of the URL if the hostRule matches the URL's host portion.
Corresponds to the JSON property pathMatcher
20889 20890 20891 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20889 def path_matcher @path_matcher end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20896 20897 20898 20899 20900 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20896 def update!(**args) @description = args[:description] if args.key?(:description) @hosts = args[:hosts] if args.key?(:hosts) @path_matcher = args[:path_matcher] if args.key?(:path_matcher) end |