Class: Google::Apis::ComputeBeta::HostRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

UrlMaps A host-matching rule for a URL. If matched, will use the namedPathMatcher to select the BackendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostRule

Returns a new instance of HostRule.



19962
19963
19964
# File 'lib/google/apis/compute_beta/classes.rb', line 19962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


19941
19942
19943
# File 'lib/google/apis/compute_beta/classes.rb', line 19941

def description
  @description
end

#hostsArray<String>

The list of host patterns to match. They must be valid hostnames with optional port numbers in the format host:port.* matches any string of ([a-z0-9- .]*). In that case, * must be the first character, and if followed by anything, the immediate following character must be either - or ..

  • based matching is not supported when the URL map is bound to a target gRPC proxy that has the validateForProxyless field set to true. Corresponds to the JSON property hosts

Returns:

  • (Array<String>)


19954
19955
19956
# File 'lib/google/apis/compute_beta/classes.rb', line 19954

def hosts
  @hosts
end

#path_matcherString

The name of the PathMatcher to use to match the path portion of the URL if the hostRule matches the URL's host portion. Corresponds to the JSON property pathMatcher

Returns:

  • (String)


19960
19961
19962
# File 'lib/google/apis/compute_beta/classes.rb', line 19960

def path_matcher
  @path_matcher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19967
19968
19969
19970
19971
# File 'lib/google/apis/compute_beta/classes.rb', line 19967

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @hosts = args[:hosts] if args.key?(:hosts)
  @path_matcher = args[:path_matcher] if args.key?(:path_matcher)
end