Class: Google::Apis::ComputeBeta::HostsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HostsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Host>
A list of host resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeBeta::HostsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostsListResponse
constructor
A new instance of HostsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostsListResponse
Returns a new instance of HostsListResponse.
21206 21207 21208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
21163 21164 21165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21163 def etag @etag end |
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21168 21169 21170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21168 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Host>
A list of host resources.
Corresponds to the JSON property items
21173 21174 21175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21173 def items @items end |
#kind ⇒ String
The type of resource. Always compute#host for a list of hosts.
Corresponds to the JSON property kind
21178 21179 21180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21178 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21188 21189 21190 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21188 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
21193 21194 21195 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21193 def self_link @self_link end |
#unreachables ⇒ Array<String>
Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
21199 21200 21201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21199 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HostsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
21204 21205 21206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21204 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21211 21212 21213 21214 21215 21216 21217 21218 21219 21220 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21211 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |