Class: Google::Apis::ComputeBeta::HostsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HostsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Host>
A list of host resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Unreachable resources.
-
#warning ⇒ Google::Apis::ComputeBeta::HostsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostsListResponse
constructor
A new instance of HostsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostsListResponse
Returns a new instance of HostsListResponse.
20998 20999 21000 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20998 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
20955 20956 20957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20955 def etag @etag end |
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20960 20961 20962 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20960 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Host>
A list of host resources.
Corresponds to the JSON property items
20965 20966 20967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20965 def items @items end |
#kind ⇒ String
The type of resource. Always compute#host for a list of hosts.
Corresponds to the JSON property kind
20970 20971 20972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20970 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20980 20981 20982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20980 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
20985 20986 20987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20985 def self_link @self_link end |
#unreachables ⇒ Array<String>
Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
20991 20992 20993 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20991 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::HostsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
20996 20997 20998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20996 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21003 21004 21005 21006 21007 21008 21009 21010 21011 21012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21003 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |