Class: Google::Apis::ComputeBeta::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



20948
20949
20950
# File 'lib/google/apis/compute_beta/classes.rb', line 20948

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20905
20906
20907
# File 'lib/google/apis/compute_beta/classes.rb', line 20905

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20910
20911
20912
# File 'lib/google/apis/compute_beta/classes.rb', line 20910

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Host>

A list of host resources. Corresponds to the JSON property items



20915
20916
20917
# File 'lib/google/apis/compute_beta/classes.rb', line 20915

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


20920
20921
20922
# File 'lib/google/apis/compute_beta/classes.rb', line 20920

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20930
20931
20932
# File 'lib/google/apis/compute_beta/classes.rb', line 20930

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20935
20936
20937
# File 'lib/google/apis/compute_beta/classes.rb', line 20935

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20941
20942
20943
# File 'lib/google/apis/compute_beta/classes.rb', line 20941

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



20946
20947
20948
# File 'lib/google/apis/compute_beta/classes.rb', line 20946

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20953
20954
20955
20956
20957
20958
20959
20960
20961
20962
# File 'lib/google/apis/compute_beta/classes.rb', line 20953

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end