Class: Google::Apis::ComputeBeta::HostsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HostsListResponse

Returns a new instance of HostsListResponse.



20922
20923
20924
# File 'lib/google/apis/compute_beta/classes.rb', line 20922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


20879
20880
20881
# File 'lib/google/apis/compute_beta/classes.rb', line 20879

def etag
  @etag
end

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20884
20885
20886
# File 'lib/google/apis/compute_beta/classes.rb', line 20884

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Host>

A list of host resources. Corresponds to the JSON property items



20889
20890
20891
# File 'lib/google/apis/compute_beta/classes.rb', line 20889

def items
  @items
end

#kindString

The type of resource. Always compute#host for a list of hosts. Corresponds to the JSON property kind

Returns:

  • (String)


20894
20895
20896
# File 'lib/google/apis/compute_beta/classes.rb', line 20894

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20904
20905
20906
# File 'lib/google/apis/compute_beta/classes.rb', line 20904

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20909
20910
20911
# File 'lib/google/apis/compute_beta/classes.rb', line 20909

def self_link
  @self_link
end

#unreachablesArray<String>

Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


20915
20916
20917
# File 'lib/google/apis/compute_beta/classes.rb', line 20915

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::HostsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



20920
20921
20922
# File 'lib/google/apis/compute_beta/classes.rb', line 20920

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20927
20928
20929
20930
20931
20932
20933
20934
20935
20936
# File 'lib/google/apis/compute_beta/classes.rb', line 20927

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end