Class: Google::Apis::ComputeBeta::Http2HealthCheck
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Http2HealthCheck
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#host ⇒ String
The value of the host header in the HTTP/2 health check request.
-
#port ⇒ Fixnum
The TCP port number to which the health check prober sends packets.
-
#port_name ⇒ String
Not supported.
-
#port_specification ⇒ String
Specifies how a port is selected for health checking.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#request_path ⇒ String
The request path of the HTTP/2 health check request.
-
#response ⇒ String
Creates a content-based HTTP/2 health check.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Http2HealthCheck
constructor
A new instance of Http2HealthCheck.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Http2HealthCheck
Returns a new instance of Http2HealthCheck.
17934 17935 17936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17934 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host ⇒ String
The value of the host header in the HTTP/2 health check request. If left
empty (default value), the host header is set to the destination IP address
to which health check packets are sent. The destination IP address depends
on the type of load balancer. For details, see:
https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet-
dest
Corresponds to the JSON property host
17871 17872 17873 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17871 def host @host end |
#port ⇒ Fixnum
The TCP port number to which the health check prober sends packets. The
default value is 443. Valid values are 1 through65535.
Corresponds to the JSON property port
17877 17878 17879 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17877 def port @port end |
#port_name ⇒ String
Not supported.
Corresponds to the JSON property portName
17882 17883 17884 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17882 def port_name @port_name end |
#port_specification ⇒ String
Specifies how a port is selected for health checking. Can be one of the
following values:
USE_FIXED_PORT: Specifies a port number explicitly using theport field in the
health check. Supported by backend services
for passthrough load balancers and backend services for proxy load
balancers. Not supported by target pools. The health check supports all
backends supported by the backend service provided the backend can be
health checked. For example, GCE_VM_IP network endpoint
groups, GCE_VM_IP_PORT network endpoint groups, and instance
group backends.
USE_NAMED_PORT: Not supported.
USE_SERVING_PORT: Provides an indirect method of specifying
the health check port by referring to the backend service. Only supported
by backend services for proxy load balancers. Not supported by target
pools. Not supported by backend services for passthrough load balancers.
Supports all backends that can be health checked; for example,GCE_VM_IP_PORT
network endpoint groups and instance group
backends.
For GCE_VM_IP_PORT network endpoint group backends, the health
check uses the port number specified for each endpoint in the network
endpoint group. For instance group backends, the health check uses the
port number determined by looking up the backend service's named port in
the instance group's list of named ports.
Corresponds to the JSON property portSpecification
17909 17910 17911 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17909 def port_specification @port_specification end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default
is NONE.
Corresponds to the JSON property proxyHeader
17916 17917 17918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17916 def proxy_header @proxy_header end |
#request_path ⇒ String
The request path of the HTTP/2 health check request. The default value is/.
Must comply withRFC3986.
Corresponds to the JSON property requestPath
17922 17923 17924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17922 def request_path @request_path end |
#response ⇒ String
Creates a content-based HTTP/2 health check. In addition to the required
HTTP 200 (OK) status code, you can configure the health check to pass only
when the backend sends this specific ASCII response string within the first
1024 bytes of the HTTP response body. For details, see:
https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria-
protocol-http
Corresponds to the JSON property response
17932 17933 17934 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17932 def response @response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
17939 17940 17941 17942 17943 17944 17945 17946 17947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 17939 def update!(**args) @host = args[:host] if args.key?(:host) @port = args[:port] if args.key?(:port) @port_name = args[:port_name] if args.key?(:port_name) @port_specification = args[:port_specification] if args.key?(:port_specification) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @request_path = args[:request_path] if args.key?(:request_path) @response = args[:response] if args.key?(:response) end |