Class: Google::Apis::ComputeBeta::Http2HealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Http2HealthCheck

Returns a new instance of Http2HealthCheck.



16743
16744
16745
# File 'lib/google/apis/compute_beta/classes.rb', line 16743

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

The value of the host header in the HTTP/2 health check request. If left empty (default value), the host header is set to the destination IP address to which health check packets are sent. The destination IP address depends on the type of load balancer. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#hc-packet- dest Corresponds to the JSON property host

Returns:

  • (String)


16680
16681
16682
# File 'lib/google/apis/compute_beta/classes.rb', line 16680

def host
  @host
end

#portFixnum

The TCP port number to which the health check prober sends packets. The default value is 443. Valid values are 1 through65535. Corresponds to the JSON property port

Returns:

  • (Fixnum)


16686
16687
16688
# File 'lib/google/apis/compute_beta/classes.rb', line 16686

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


16691
16692
16693
# File 'lib/google/apis/compute_beta/classes.rb', line 16691

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


16718
16719
16720
# File 'lib/google/apis/compute_beta/classes.rb', line 16718

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


16725
16726
16727
# File 'lib/google/apis/compute_beta/classes.rb', line 16725

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTP/2 health check request. The default value is/. Must comply withRFC3986. Corresponds to the JSON property requestPath

Returns:

  • (String)


16731
16732
16733
# File 'lib/google/apis/compute_beta/classes.rb', line 16731

def request_path
  @request_path
end

#responseString

Creates a content-based HTTP/2 health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-http Corresponds to the JSON property response

Returns:

  • (String)


16741
16742
16743
# File 'lib/google/apis/compute_beta/classes.rb', line 16741

def response
  @response
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16748
16749
16750
16751
16752
16753
16754
16755
16756
# File 'lib/google/apis/compute_beta/classes.rb', line 16748

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
  @response = args[:response] if args.key?(:response)
end