Class: Google::Apis::ComputeBeta::HttpFaultDelay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultDelay

Returns a new instance of HttpFaultDelay.



21062
21063
21064
# File 'lib/google/apis/compute_beta/classes.rb', line 21062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_delayGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property fixedDelay



21053
21054
21055
# File 'lib/google/apis/compute_beta/classes.rb', line 21053

def fixed_delay
  @fixed_delay
end

#percentageFloat

The percentage of traffic for connections, operations, or requests for which a delay is introduced as part of fault injection. The value must be from 0.0 to 100.0 inclusive. Corresponds to the JSON property percentage

Returns:

  • (Float)


21060
21061
21062
# File 'lib/google/apis/compute_beta/classes.rb', line 21060

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21067
21068
21069
21070
# File 'lib/google/apis/compute_beta/classes.rb', line 21067

def update!(**args)
  @fixed_delay = args[:fixed_delay] if args.key?(:fixed_delay)
  @percentage = args[:percentage] if args.key?(:percentage)
end