Class: Google::Apis::ComputeBeta::HttpFaultDelay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultDelay

Returns a new instance of HttpFaultDelay.



20611
20612
20613
# File 'lib/google/apis/compute_beta/classes.rb', line 20611

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fixed_delayGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property fixedDelay



20602
20603
20604
# File 'lib/google/apis/compute_beta/classes.rb', line 20602

def fixed_delay
  @fixed_delay
end

#percentageFloat

The percentage of traffic for connections, operations, or requests for which a delay is introduced as part of fault injection. The value must be from 0.0 to 100.0 inclusive. Corresponds to the JSON property percentage

Returns:

  • (Float)


20609
20610
20611
# File 'lib/google/apis/compute_beta/classes.rb', line 20609

def percentage
  @percentage
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20616
20617
20618
20619
# File 'lib/google/apis/compute_beta/classes.rb', line 20616

def update!(**args)
  @fixed_delay = args[:fixed_delay] if args.key?(:fixed_delay)
  @percentage = args[:percentage] if args.key?(:percentage)
end