Class: Google::Apis::ComputeBeta::HttpFaultInjection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultInjection

Returns a new instance of HttpFaultInjection.



20666
20667
20668
# File 'lib/google/apis/compute_beta/classes.rb', line 20666

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abortGoogle::Apis::ComputeBeta::HttpFaultAbort

Specification for how requests are aborted as part of fault injection. Corresponds to the JSON property abort



20658
20659
20660
# File 'lib/google/apis/compute_beta/classes.rb', line 20658

def abort
  @abort
end

#delayGoogle::Apis::ComputeBeta::HttpFaultDelay

Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection. Corresponds to the JSON property delay



20664
20665
20666
# File 'lib/google/apis/compute_beta/classes.rb', line 20664

def delay
  @delay
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20671
20672
20673
20674
# File 'lib/google/apis/compute_beta/classes.rb', line 20671

def update!(**args)
  @abort = args[:abort] if args.key?(:abort)
  @delay = args[:delay] if args.key?(:delay)
end