Class: Google::Apis::ComputeBeta::HttpFaultInjection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFaultInjection

Returns a new instance of HttpFaultInjection.



19447
19448
19449
# File 'lib/google/apis/compute_beta/classes.rb', line 19447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abortGoogle::Apis::ComputeBeta::HttpFaultAbort

Specification for how requests are aborted as part of fault injection. Corresponds to the JSON property abort



19439
19440
19441
# File 'lib/google/apis/compute_beta/classes.rb', line 19439

def abort
  @abort
end

#delayGoogle::Apis::ComputeBeta::HttpFaultDelay

Specifies the delay introduced by the load balancer before forwarding the request to the backend service as part of fault injection. Corresponds to the JSON property delay



19445
19446
19447
# File 'lib/google/apis/compute_beta/classes.rb', line 19445

def delay
  @delay
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19452
19453
19454
19455
# File 'lib/google/apis/compute_beta/classes.rb', line 19452

def update!(**args)
  @abort = args[:abort] if args.key?(:abort)
  @delay = args[:delay] if args.key?(:delay)
end