Class: Google::Apis::ComputeBeta::HttpFilterConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpFilterConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
HttpFilterConfiguration supplies additional contextual settings for networkservices.HttpFilter resources enabled by Traffic Director.
Instance Attribute Summary collapse
-
#config ⇒ String
The configuration needed to enable thenetworkservices.HttpFilter resource.
-
#config_type_url ⇒ String
The fully qualified versioned proto3 type url of the protobuf that the filter expects for its contextual settings, for example:type.googleapis.com/ google.protobuf.Struct Corresponds to the JSON property
configTypeUrl. -
#filter_name ⇒ String
Name of the networkservices.HttpFilter resource this configuration belongs to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpFilterConfig
constructor
A new instance of HttpFilterConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpFilterConfig
Returns a new instance of HttpFilterConfig.
21416 21417 21418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#config ⇒ String
The configuration needed to enable thenetworkservices.HttpFilter resource. The
configuration must be
YAML formatted and only contain fields defined in the protobuf identified
in configTypeUrl
Corresponds to the JSON property config
21400 21401 21402 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21400 def config @config end |
#config_type_url ⇒ String
The fully qualified versioned proto3 type url of the protobuf that the
filter expects for its contextual settings, for example:type.googleapis.com/
google.protobuf.Struct
Corresponds to the JSON property configTypeUrl
21407 21408 21409 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21407 def config_type_url @config_type_url end |
#filter_name ⇒ String
Name of the networkservices.HttpFilter resource this
configuration belongs to. This name must be known to the xDS client.
Example: envoy.wasm
Corresponds to the JSON property filterName
21414 21415 21416 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21414 def filter_name @filter_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21421 21422 21423 21424 21425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21421 def update!(**args) @config = args[:config] if args.key?(:config) @config_type_url = args[:config_type_url] if args.key?(:config_type_url) @filter_name = args[:filter_name] if args.key?(:filter_name) end |