Class: Google::Apis::ComputeBeta::HttpFilterConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

HttpFilterConfiguration supplies additional contextual settings for networkservices.HttpFilter resources enabled by Traffic Director.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFilterConfig

Returns a new instance of HttpFilterConfig.



21132
21133
21134
# File 'lib/google/apis/compute_beta/classes.rb', line 21132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configString

The configuration needed to enable thenetworkservices.HttpFilter resource. The configuration must be YAML formatted and only contain fields defined in the protobuf identified in configTypeUrl Corresponds to the JSON property config

Returns:

  • (String)


21116
21117
21118
# File 'lib/google/apis/compute_beta/classes.rb', line 21116

def config
  @config
end

#config_type_urlString

The fully qualified versioned proto3 type url of the protobuf that the filter expects for its contextual settings, for example:type.googleapis.com/ google.protobuf.Struct Corresponds to the JSON property configTypeUrl

Returns:

  • (String)


21123
21124
21125
# File 'lib/google/apis/compute_beta/classes.rb', line 21123

def config_type_url
  @config_type_url
end

#filter_nameString

Name of the networkservices.HttpFilter resource this configuration belongs to. This name must be known to the xDS client. Example: envoy.wasm Corresponds to the JSON property filterName

Returns:

  • (String)


21130
21131
21132
# File 'lib/google/apis/compute_beta/classes.rb', line 21130

def filter_name
  @filter_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21137
21138
21139
21140
21141
# File 'lib/google/apis/compute_beta/classes.rb', line 21137

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @config_type_url = args[:config_type_url] if args.key?(:config_type_url)
  @filter_name = args[:filter_name] if args.key?(:filter_name)
end