Class: Google::Apis::ComputeBeta::HttpFilterConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

HttpFilterConfiguration supplies additional contextual settings for networkservices.HttpFilter resources enabled by Traffic Director.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpFilterConfig

Returns a new instance of HttpFilterConfig.



19486
19487
19488
# File 'lib/google/apis/compute_beta/classes.rb', line 19486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configString

The configuration needed to enable thenetworkservices.HttpFilter resource. The configuration must be YAML formatted and only contain fields defined in the protobuf identified in configTypeUrl Corresponds to the JSON property config

Returns:

  • (String)


19470
19471
19472
# File 'lib/google/apis/compute_beta/classes.rb', line 19470

def config
  @config
end

#config_type_urlString

The fully qualified versioned proto3 type url of the protobuf that the filter expects for its contextual settings, for example:type.googleapis.com/ google.protobuf.Struct Corresponds to the JSON property configTypeUrl

Returns:

  • (String)


19477
19478
19479
# File 'lib/google/apis/compute_beta/classes.rb', line 19477

def config_type_url
  @config_type_url
end

#filter_nameString

Name of the networkservices.HttpFilter resource this configuration belongs to. This name must be known to the xDS client. Example: envoy.wasm Corresponds to the JSON property filterName

Returns:

  • (String)


19484
19485
19486
# File 'lib/google/apis/compute_beta/classes.rb', line 19484

def filter_name
  @filter_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19491
19492
19493
19494
19495
# File 'lib/google/apis/compute_beta/classes.rb', line 19491

def update!(**args)
  @config = args[:config] if args.key?(:config)
  @config_type_url = args[:config_type_url] if args.key?(:config_type_url)
  @filter_name = args[:filter_name] if args.key?(:filter_name)
end