Class: Google::Apis::ComputeBeta::HttpHeaderAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpHeaderAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The request and response header transformations that take effect before the request is passed along to the selected backendService.
Instance Attribute Summary collapse
-
#request_headers_to_add ⇒ Array<Google::Apis::ComputeBeta::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to thebackendService.
-
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the request before forwarding the request to the backendService.
-
#response_headers_to_add ⇒ Array<Google::Apis::ComputeBeta::HttpHeaderOption>
Headers to add the response before sending the response back to the client.
-
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the response before sending the response back to the client.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderAction
constructor
A new instance of HttpHeaderAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderAction
Returns a new instance of HttpHeaderAction.
21249 21250 21251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21249 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_headers_to_add ⇒ Array<Google::Apis::ComputeBeta::HttpHeaderOption>
Headers to add to a matching request before forwarding the request to
thebackendService.
Corresponds to the JSON property requestHeadersToAdd
21229 21230 21231 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21229 def request_headers_to_add @request_headers_to_add end |
#request_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
request before forwarding the request to the backendService.
Corresponds to the JSON property requestHeadersToRemove
21235 21236 21237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21235 def request_headers_to_remove @request_headers_to_remove end |
#response_headers_to_add ⇒ Array<Google::Apis::ComputeBeta::HttpHeaderOption>
Headers to add the response before sending the response back to the
client.
Corresponds to the JSON property responseHeadersToAdd
21241 21242 21243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21241 def response_headers_to_add @response_headers_to_add end |
#response_headers_to_remove ⇒ Array<String>
A list of header names for headers that need to be removed from the
response before sending the response back to the client.
Corresponds to the JSON property responseHeadersToRemove
21247 21248 21249 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21247 def response_headers_to_remove @response_headers_to_remove end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21254 21255 21256 21257 21258 21259 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21254 def update!(**args) @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add) @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove) @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add) @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove) end |