Class: Google::Apis::ComputeBeta::HttpHeaderAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The request and response header transformations that take effect before the request is passed along to the selected backendService.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderAction

Returns a new instance of HttpHeaderAction.



21173
21174
21175
# File 'lib/google/apis/compute_beta/classes.rb', line 21173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_headers_to_addArray<Google::Apis::ComputeBeta::HttpHeaderOption>

Headers to add to a matching request before forwarding the request to thebackendService. Corresponds to the JSON property requestHeadersToAdd



21153
21154
21155
# File 'lib/google/apis/compute_beta/classes.rb', line 21153

def request_headers_to_add
  @request_headers_to_add
end

#request_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the request before forwarding the request to the backendService. Corresponds to the JSON property requestHeadersToRemove

Returns:

  • (Array<String>)


21159
21160
21161
# File 'lib/google/apis/compute_beta/classes.rb', line 21159

def request_headers_to_remove
  @request_headers_to_remove
end

#response_headers_to_addArray<Google::Apis::ComputeBeta::HttpHeaderOption>

Headers to add the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToAdd



21165
21166
21167
# File 'lib/google/apis/compute_beta/classes.rb', line 21165

def response_headers_to_add
  @response_headers_to_add
end

#response_headers_to_removeArray<String>

A list of header names for headers that need to be removed from the response before sending the response back to the client. Corresponds to the JSON property responseHeadersToRemove

Returns:

  • (Array<String>)


21171
21172
21173
# File 'lib/google/apis/compute_beta/classes.rb', line 21171

def response_headers_to_remove
  @response_headers_to_remove
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21178
21179
21180
21181
21182
21183
# File 'lib/google/apis/compute_beta/classes.rb', line 21178

def update!(**args)
  @request_headers_to_add = args[:request_headers_to_add] if args.key?(:request_headers_to_add)
  @request_headers_to_remove = args[:request_headers_to_remove] if args.key?(:request_headers_to_remove)
  @response_headers_to_add = args[:response_headers_to_add] if args.key?(:response_headers_to_add)
  @response_headers_to_remove = args[:response_headers_to_remove] if args.key?(:response_headers_to_remove)
end