Class: Google::Apis::ComputeBeta::HttpHeaderOption
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpHeaderOption
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specification determining how headers are added to requests or responses.
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the header.
-
#header_value ⇒ String
The value of the header to add.
-
#replace ⇒ Boolean
(also: #replace?)
If false, headerValue is appended to any values that already exist for the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderOption
constructor
A new instance of HttpHeaderOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderOption
Returns a new instance of HttpHeaderOption.
21389 21390 21391 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21389 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_name ⇒ String
The name of the header.
Corresponds to the JSON property headerName
21369 21370 21371 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21369 def header_name @header_name end |
#header_value ⇒ String
The value of the header to add.
Corresponds to the JSON property headerValue
21374 21375 21376 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21374 def header_value @header_value end |
#replace ⇒ Boolean Also known as: replace?
If false, headerValue is appended to any values
that already
exist for the header. If true, headerValue is set for the
header, discarding any values that were set for that header.
The default value is true,
unless a variable is present in headerValue,
in which case the default value is false.
.
Corresponds to the JSON property replace
21386 21387 21388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21386 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21394 21395 21396 21397 21398 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21394 def update!(**args) @header_name = args[:header_name] if args.key?(:header_name) @header_value = args[:header_value] if args.key?(:header_value) @replace = args[:replace] if args.key?(:replace) end |