Class: Google::Apis::ComputeBeta::HttpHeaderOption

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specification determining how headers are added to requests or responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderOption

Returns a new instance of HttpHeaderOption.



21313
21314
21315
# File 'lib/google/apis/compute_beta/classes.rb', line 21313

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The name of the header. Corresponds to the JSON property headerName

Returns:

  • (String)


21293
21294
21295
# File 'lib/google/apis/compute_beta/classes.rb', line 21293

def header_name
  @header_name
end

#header_valueString

The value of the header to add. Corresponds to the JSON property headerValue

Returns:

  • (String)


21298
21299
21300
# File 'lib/google/apis/compute_beta/classes.rb', line 21298

def header_value
  @header_value
end

#replaceBoolean Also known as: replace?

If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is true, unless a variable is present in headerValue, in which case the default value is false. . Corresponds to the JSON property replace

Returns:

  • (Boolean)


21310
21311
21312
# File 'lib/google/apis/compute_beta/classes.rb', line 21310

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21318
21319
21320
21321
21322
# File 'lib/google/apis/compute_beta/classes.rb', line 21318

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
  @header_value = args[:header_value] if args.key?(:header_value)
  @replace = args[:replace] if args.key?(:replace)
end