Class: Google::Apis::ComputeBeta::HttpHeaderOption
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpHeaderOption
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specification determining how headers are added to requests or responses.
Instance Attribute Summary collapse
-
#header_name ⇒ String
The name of the header.
-
#header_value ⇒ String
The value of the header to add.
-
#replace ⇒ Boolean
(also: #replace?)
If false, headerValue is appended to any values that already exist for the header.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHeaderOption
constructor
A new instance of HttpHeaderOption.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHeaderOption
Returns a new instance of HttpHeaderOption.
20862 20863 20864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20862 def initialize(**args) update!(**args) end |
Instance Attribute Details
#header_name ⇒ String
The name of the header.
Corresponds to the JSON property headerName
20842 20843 20844 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20842 def header_name @header_name end |
#header_value ⇒ String
The value of the header to add.
Corresponds to the JSON property headerValue
20847 20848 20849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20847 def header_value @header_value end |
#replace ⇒ Boolean Also known as: replace?
If false, headerValue is appended to any values
that already
exist for the header. If true, headerValue is set for the
header, discarding any values that were set for that header.
The default value is true,
unless a variable is present in headerValue,
in which case the default value is false.
.
Corresponds to the JSON property replace
20859 20860 20861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20859 def replace @replace end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20867 20868 20869 20870 20871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20867 def update!(**args) @header_name = args[:header_name] if args.key?(:header_name) @header_value = args[:header_value] if args.key?(:header_value) @replace = args[:replace] if args.key?(:replace) end |