Class: Google::Apis::ComputeBeta::HttpHeaderOption

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specification determining how headers are added to requests or responses.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHeaderOption

Returns a new instance of HttpHeaderOption.



19343
19344
19345
# File 'lib/google/apis/compute_beta/classes.rb', line 19343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#header_nameString

The name of the header. Corresponds to the JSON property headerName

Returns:

  • (String)


19323
19324
19325
# File 'lib/google/apis/compute_beta/classes.rb', line 19323

def header_name
  @header_name
end

#header_valueString

The value of the header to add. Corresponds to the JSON property headerValue

Returns:

  • (String)


19328
19329
19330
# File 'lib/google/apis/compute_beta/classes.rb', line 19328

def header_value
  @header_value
end

#replaceBoolean Also known as: replace?

If false, headerValue is appended to any values that already exist for the header. If true, headerValue is set for the header, discarding any values that were set for that header. The default value is true, unless a variable is present in headerValue, in which case the default value is false. . Corresponds to the JSON property replace

Returns:

  • (Boolean)


19340
19341
19342
# File 'lib/google/apis/compute_beta/classes.rb', line 19340

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



19348
19349
19350
19351
19352
# File 'lib/google/apis/compute_beta/classes.rb', line 19348

def update!(**args)
  @header_name = args[:header_name] if args.key?(:header_name)
  @header_value = args[:header_value] if args.key?(:header_value)
  @replace = args[:replace] if args.key?(:replace)
end