Class: Google::Apis::ComputeBeta::HttpHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a legacy HTTP Health Check resource. Legacy HTTP health checks are now only required by target pool-based network load balancers. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, seeHealth checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheck

Returns a new instance of HttpHealthCheck.



16834
16835
16836
# File 'lib/google/apis/compute_beta/classes.rb', line 16834

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_interval_secFixnum

How often (in seconds) to send a health check. The default value is5 seconds. Corresponds to the JSON property checkIntervalSec

Returns:

  • (Fixnum)


19368
19369
19370
# File 'lib/google/apis/compute_beta/classes.rb', line 19368

def check_interval_sec
  @check_interval_sec
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


19374
19375
19376
# File 'lib/google/apis/compute_beta/classes.rb', line 19374

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


19380
19381
19382
# File 'lib/google/apis/compute_beta/classes.rb', line 19380

def description
  @description
end

#healthy_thresholdFixnum

A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


19386
19387
19388
# File 'lib/google/apis/compute_beta/classes.rb', line 19386

def healthy_threshold
  @healthy_threshold
end

#hostString

The value of the host header in the HTTP health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used. Corresponds to the JSON property host

Returns:

  • (String)


16771
16772
16773
# File 'lib/google/apis/compute_beta/classes.rb', line 16771

def host
  @host
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


19399
19400
19401
# File 'lib/google/apis/compute_beta/classes.rb', line 19399

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#httpHealthCheck for HTTP health checks. Corresponds to the JSON property kind

Returns:

  • (String)


19405
19406
19407
# File 'lib/google/apis/compute_beta/classes.rb', line 19405

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


19416
19417
19418
# File 'lib/google/apis/compute_beta/classes.rb', line 19416

def name
  @name
end

#portFixnum

The TCP port number for the HTTP health check request. The default value is80. Corresponds to the JSON property port

Returns:

  • (Fixnum)


16777
16778
16779
# File 'lib/google/apis/compute_beta/classes.rb', line 16777

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


16782
16783
16784
# File 'lib/google/apis/compute_beta/classes.rb', line 16782

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Also supported in legacy HTTP health checks for target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example,GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for pass-through load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


16809
16810
16811
# File 'lib/google/apis/compute_beta/classes.rb', line 16809

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


16816
16817
16818
# File 'lib/google/apis/compute_beta/classes.rb', line 16816

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTP health check request. The default value is/. This field does not support query parameters. Must comply withRFC3986. Corresponds to the JSON property requestPath

Returns:

  • (String)


16822
16823
16824
# File 'lib/google/apis/compute_beta/classes.rb', line 16822

def request_path
  @request_path
end

#responseString

Creates a content-based HTTP health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-http Corresponds to the JSON property response

Returns:

  • (String)


16832
16833
16834
# File 'lib/google/apis/compute_beta/classes.rb', line 16832

def response
  @response
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


19433
19434
19435
# File 'lib/google/apis/compute_beta/classes.rb', line 19433

def self_link
  @self_link
end

#timeout_secFixnum

How long (in seconds) to wait before claiming failure. The default value is5 seconds. It is invalid for timeoutSec to have greater value than checkIntervalSec. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


19440
19441
19442
# File 'lib/google/apis/compute_beta/classes.rb', line 19440

def timeout_sec
  @timeout_sec
end

#unhealthy_thresholdFixnum

A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


19446
19447
19448
# File 'lib/google/apis/compute_beta/classes.rb', line 19446

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



16839
16840
16841
16842
16843
16844
16845
16846
16847
# File 'lib/google/apis/compute_beta/classes.rb', line 16839

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
  @response = args[:response] if args.key?(:response)
end