Class: Google::Apis::ComputeBeta::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



21555
21556
21557
# File 'lib/google/apis/compute_beta/classes.rb', line 21555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21523
21524
21525
# File 'lib/google/apis/compute_beta/classes.rb', line 21523

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



21528
21529
21530
# File 'lib/google/apis/compute_beta/classes.rb', line 21528

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21533
21534
21535
# File 'lib/google/apis/compute_beta/classes.rb', line 21533

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21543
21544
21545
# File 'lib/google/apis/compute_beta/classes.rb', line 21543

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21548
21549
21550
# File 'lib/google/apis/compute_beta/classes.rb', line 21548

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21553
21554
21555
# File 'lib/google/apis/compute_beta/classes.rb', line 21553

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21560
21561
21562
21563
21564
21565
21566
21567
# File 'lib/google/apis/compute_beta/classes.rb', line 21560

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end