Class: Google::Apis::ComputeBeta::HttpHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HttpHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpHealthCheckList

Returns a new instance of HttpHealthCheckList.



21505
21506
21507
# File 'lib/google/apis/compute_beta/classes.rb', line 21505

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21473
21474
21475
# File 'lib/google/apis/compute_beta/classes.rb', line 21473

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HttpHealthCheck>

A list of HttpHealthCheck resources. Corresponds to the JSON property items



21478
21479
21480
# File 'lib/google/apis/compute_beta/classes.rb', line 21478

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21483
21484
21485
# File 'lib/google/apis/compute_beta/classes.rb', line 21483

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21493
21494
21495
# File 'lib/google/apis/compute_beta/classes.rb', line 21493

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21498
21499
21500
# File 'lib/google/apis/compute_beta/classes.rb', line 21498

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HttpHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21503
21504
21505
# File 'lib/google/apis/compute_beta/classes.rb', line 21503

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21510
21511
21512
21513
21514
21515
21516
21517
# File 'lib/google/apis/compute_beta/classes.rb', line 21510

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end