Class: Google::Apis::ComputeBeta::HttpHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HttpHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HttpHealthCheck>
A list of HttpHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHealthCheckList
constructor
A new instance of HttpHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHealthCheckList
Returns a new instance of HttpHealthCheckList.
20444 20445 20446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20444 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20412 20413 20414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20412 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HttpHealthCheck>
A list of HttpHealthCheck resources.
Corresponds to the JSON property items
20417 20418 20419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20417 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
20422 20423 20424 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20422 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20432 20433 20434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20432 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20437 20438 20439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20437 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20442 20443 20444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20442 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20449 20450 20451 20452 20453 20454 20455 20456 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20449 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |