Class: Google::Apis::ComputeBeta::HttpHealthCheckList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpHealthCheckList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of HttpHealthCheck resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::HttpHealthCheck>
A list of HttpHealthCheck resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpHealthCheckList
constructor
A new instance of HttpHealthCheckList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpHealthCheckList
Returns a new instance of HttpHealthCheckList.
19833 19834 19835 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19833 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
19801 19802 19803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19801 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::HttpHealthCheck>
A list of HttpHealthCheck resources.
Corresponds to the JSON property items
19806 19807 19808 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19806 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
19811 19812 19813 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19811 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
19821 19822 19823 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19821 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
19826 19827 19828 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19826 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::HttpHealthCheckList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
19831 19832 19833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19831 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19838 19839 19840 19841 19842 19843 19844 19845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19838 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |