Class: Google::Apis::ComputeBeta::HttpRedirectAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpRedirectAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifies settings for an HTTP redirect.
Instance Attribute Summary collapse
-
#host_redirect ⇒ String
The host that is used in the redirect response instead of the one that was supplied in the request.
-
#https_redirect ⇒ Boolean
(also: #https_redirect?)
If set to true, the URL scheme in the redirected request is set to HTTPS.
-
#path_redirect ⇒ String
The path that is used in the redirect response instead of the one that was supplied in the request.
-
#prefix_redirect ⇒ String
The prefix that replaces the prefixMatch specified in the HttpRouteRuleMatch, retaining the remaining portion of the URL before redirecting the request.
-
#redirect_response_code ⇒ String
The HTTP Status code to use for this RedirectAction.
-
#strip_query ⇒ Boolean
(also: #strip_query?)
If set to true, any accompanying query portion of the original URL is removed before redirecting the request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRedirectAction
constructor
A new instance of HttpRedirectAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRedirectAction
Returns a new instance of HttpRedirectAction.
20038 20039 20040 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20038 def initialize(**args) update!(**args) end |
Instance Attribute Details
#host_redirect ⇒ String
The host that is used in the redirect response instead of the one that
was supplied in the request.
The value must be from 1 to 255
characters.
Corresponds to the JSON property hostRedirect
19978 19979 19980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19978 def host_redirect @host_redirect end |
#https_redirect ⇒ Boolean Also known as: https_redirect?
If set to true, the URL scheme in the redirected request is
set to HTTPS.
If set to false, the URL scheme of the redirected request
remains the same as that of the request.
This must only be set for URL maps used inTargetHttpProxys. Setting this true
forTargetHttpsProxy is not permitted.
The default is set to false.
Corresponds to the JSON property httpsRedirect
19989 19990 19991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19989 def https_redirect @https_redirect end |
#path_redirect ⇒ String
The path that is used in the redirect response instead of the one
that was supplied in the request.
pathRedirect cannot be supplied together withprefixRedirect. Supply one alone
or neither. If neither is
supplied, the path of the original request is used for the redirect.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property pathRedirect
20000 20001 20002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20000 def path_redirect @path_redirect end |
#prefix_redirect ⇒ String
The prefix that replaces the prefixMatch specified in
the HttpRouteRuleMatch, retaining the remaining portion
of the URL before redirecting the request.
prefixRedirect cannot be supplied together withpathRedirect. Supply one alone
or neither. If neither is
supplied, the path of the original request is used for the redirect.
The value must be from 1 to 1024 characters.
Corresponds to the JSON property prefixRedirect
20011 20012 20013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20011 def prefix_redirect @prefix_redirect end |
#redirect_response_code ⇒ String
The HTTP Status code to use for this RedirectAction. Supported values are:
- MOVED_PERMANENTLY_DEFAULT, which is the default value and corresponds to 301.
- FOUND, which corresponds to 302.
- SEE_OTHER which corresponds to 303.
- TEMPORARY_REDIRECT, which corresponds to 307. In this case, the request method is retained.
- PERMANENT_REDIRECT, which corresponds to 308. In this case, the request
method is retained.
Corresponds to the JSON property
redirectResponseCode
20026 20027 20028 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20026 def redirect_response_code @redirect_response_code end |
#strip_query ⇒ Boolean Also known as: strip_query?
If set to true, any accompanying query portion of the original
URL is
removed before redirecting the request. If set to false, the
query portion of the original URL is retained.
The default is set to false.
Corresponds to the JSON property stripQuery
20035 20036 20037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20035 def strip_query @strip_query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20043 20044 20045 20046 20047 20048 20049 20050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20043 def update!(**args) @host_redirect = args[:host_redirect] if args.key?(:host_redirect) @https_redirect = args[:https_redirect] if args.key?(:https_redirect) @path_redirect = args[:path_redirect] if args.key?(:path_redirect) @prefix_redirect = args[:prefix_redirect] if args.key?(:prefix_redirect) @redirect_response_code = args[:redirect_response_code] if args.key?(:redirect_response_code) @strip_query = args[:strip_query] if args.key?(:strip_query) end |