Class: Google::Apis::ComputeBeta::HttpRetryPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::HttpRetryPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The retry policy associates with HttpRouteRule
Instance Attribute Summary collapse
-
#num_retries ⇒ Fixnum
Specifies the allowed number retries.
-
#per_try_timeout ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#retry_conditions ⇒ Array<String>
Specifies one or more conditions when this retry policy applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HttpRetryPolicy
constructor
A new instance of HttpRetryPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HttpRetryPolicy
Returns a new instance of HttpRetryPolicy.
19787 19788 19789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#num_retries ⇒ Fixnum
Specifies the allowed number retries. This number must be > 0.
If not specified, defaults to 1.
Corresponds to the JSON property numRetries
19737 19738 19739 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19737 def num_retries @num_retries end |
#per_try_timeout ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property perTryTimeout
19745 19746 19747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19745 def per_try_timeout @per_try_timeout end |
#retry_conditions ⇒ Array<String>
Specifies one or more conditions when this retry policy applies. Valid values are:
- 5xx: retry is attempted if the instance or endpoint responds with any 5xx response code, or if the instance or endpoint does not respond at all. For example, disconnects, reset, read timeout, connection failure, and refused streams.
- gateway-error: Similar to 5xx, but only applies to response codes 502, 503 or504.
- connect-failure: a retry is attempted on failures connecting to the instance or endpoint. For example, connection timeouts.
- retriable-4xx: a retry is attempted if the instance or endpoint responds with a 4xx response code. The only error that you can retry is error code 409.
- refused-stream: a retry is attempted if the instance or endpoint resets the stream with a REFUSED_STREAM error code. This reset type indicates that it is safe to retry.
- cancelled: a retry is attempted if the gRPC status code in the response header is set to cancelled.
- deadline-exceeded: a retry is attempted if the gRPC status code in the response header is set todeadline-exceeded.
- internal: a retry is attempted if the gRPC status code in the response header is set tointernal.
- resource-exhausted: a retry is attempted if the gRPC status code in the response header is set toresource-exhausted.
unavailable: a retry is attempted if the gRPC status code in the response header is set tounavailable. Only the following codes are supported when the URL map is bound to target gRPC proxy that has validateForProxyless field set to true.
cancelled
deadline-exceeded
internal
resource-exhausted
unavailable Corresponds to the JSON property
retryConditions
19785 19786 19787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19785 def retry_conditions @retry_conditions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
19792 19793 19794 19795 19796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 19792 def update!(**args) @num_retries = args[:num_retries] if args.key?(:num_retries) @per_try_timeout = args[:per_try_timeout] if args.key?(:per_try_timeout) @retry_conditions = args[:retry_conditions] if args.key?(:retry_conditions) end |