Class: Google::Apis::ComputeBeta::HttpRouteAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteAction

Returns a new instance of HttpRouteAction.



21931
21932
21933
# File 'lib/google/apis/compute_beta/classes.rb', line 21931

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_policyGoogle::Apis::ComputeBeta::CachePolicy

Message containing CachePolicy configuration for URL Map's Route Action. Corresponds to the JSON property cachePolicy



21852
21853
21854
# File 'lib/google/apis/compute_beta/classes.rb', line 21852

def cache_policy
  @cache_policy
end

#cors_policyGoogle::Apis::ComputeBeta::CorsPolicy

The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard. Corresponds to the JSON property corsPolicy



21860
21861
21862
# File 'lib/google/apis/compute_beta/classes.rb', line 21860

def cors_policy
  @cors_policy
end

#fault_injection_policyGoogle::Apis::ComputeBeta::HttpFaultInjection

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests. Corresponds to the JSON property faultInjectionPolicy



21870
21871
21872
# File 'lib/google/apis/compute_beta/classes.rb', line 21870

def fault_injection_policy
  @fault_injection_policy
end

#image_optimization_policyGoogle::Apis::ComputeBeta::ImageOptimizationPolicy

The configuration for Cloud CDN's image optimization feature. This feature dynamically processes and delivers images from the network edge. Image Optimization is only available for Global External Application Load Balancers. Either Cloud CDN must be enabled on the backend service or backend bucket serving the route, or cache policy must be configured on the same route. Corresponds to the JSON property imageOptimizationPolicy



21880
21881
21882
# File 'lib/google/apis/compute_beta/classes.rb', line 21880

def image_optimization_policy
  @image_optimization_policy
end

#max_stream_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxStreamDuration



21888
21889
21890
# File 'lib/google/apis/compute_beta/classes.rb', line 21888

def max_stream_duration
  @max_stream_duration
end

#request_mirror_policyGoogle::Apis::ComputeBeta::RequestMirrorPolicy

A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer doesn't wait for responses from the shadow service. Before sending traffic to the shadow service, the host or authority header is suffixed with-shadow. Corresponds to the JSON property requestMirrorPolicy



21896
21897
21898
# File 'lib/google/apis/compute_beta/classes.rb', line 21896

def request_mirror_policy
  @request_mirror_policy
end

#retry_policyGoogle::Apis::ComputeBeta::HttpRetryPolicy

The retry policy associates with HttpRouteRule Corresponds to the JSON property retryPolicy



21901
21902
21903
# File 'lib/google/apis/compute_beta/classes.rb', line 21901

def retry_policy
  @retry_policy
end

#timeoutGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property timeout



21909
21910
21911
# File 'lib/google/apis/compute_beta/classes.rb', line 21909

def timeout
  @timeout
end

#url_rewriteGoogle::Apis::ComputeBeta::UrlRewrite

The spec for modifying the path before sending the request to the matched backend service. Corresponds to the JSON property urlRewrite



21915
21916
21917
# File 'lib/google/apis/compute_beta/classes.rb', line 21915

def url_rewrite
  @url_rewrite
end

#weighted_backend_servicesArray<Google::Apis::ComputeBeta::WeightedBackendService>

A list of weighted backend services to send traffic to when a route match occurs. The weights determine the fraction of traffic that flows to their corresponding backend service. If all traffic needs to go to a single backend service, there must be oneweightedBackendService with weight set to a non-zero number. After a backend service is identified and before forwarding the request to the backend service, advanced routing actions such as URL rewrites and header transformations are applied depending on additional settings specified in this HttpRouteAction. Corresponds to the JSON property weightedBackendServices



21929
21930
21931
# File 'lib/google/apis/compute_beta/classes.rb', line 21929

def weighted_backend_services
  @weighted_backend_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21936
21937
21938
21939
21940
21941
21942
21943
21944
21945
21946
21947
# File 'lib/google/apis/compute_beta/classes.rb', line 21936

def update!(**args)
  @cache_policy = args[:cache_policy] if args.key?(:cache_policy)
  @cors_policy = args[:cors_policy] if args.key?(:cors_policy)
  @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy)
  @image_optimization_policy = args[:image_optimization_policy] if args.key?(:image_optimization_policy)
  @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration)
  @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy)
  @retry_policy = args[:retry_policy] if args.key?(:retry_policy)
  @timeout = args[:timeout] if args.key?(:timeout)
  @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite)
  @weighted_backend_services = args[:weighted_backend_services] if args.key?(:weighted_backend_services)
end