Class: Google::Apis::ComputeBeta::HttpRouteAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteAction

Returns a new instance of HttpRouteAction.



20810
20811
20812
# File 'lib/google/apis/compute_beta/classes.rb', line 20810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cache_policyGoogle::Apis::ComputeBeta::CachePolicy

Message containing CachePolicy configuration for URL Map's Route Action. Corresponds to the JSON property cachePolicy



20741
20742
20743
# File 'lib/google/apis/compute_beta/classes.rb', line 20741

def cache_policy
  @cache_policy
end

#cors_policyGoogle::Apis::ComputeBeta::CorsPolicy

The specification for allowing client-side cross-origin requests. For more information about the W3C recommendation for cross-origin resource sharing (CORS), see Fetch API Living Standard. Corresponds to the JSON property corsPolicy



20749
20750
20751
# File 'lib/google/apis/compute_beta/classes.rb', line 20749

def cors_policy
  @cors_policy
end

#fault_injection_policyGoogle::Apis::ComputeBeta::HttpFaultInjection

The specification for fault injection introduced into traffic to test the resiliency of clients to backend service failure. As part of fault injection, when clients send requests to a backend service, delays can be introduced by the load balancer on a percentage of requests before sending those request to the backend service. Similarly requests from clients can be aborted by the load balancer for a percentage of requests. Corresponds to the JSON property faultInjectionPolicy



20759
20760
20761
# File 'lib/google/apis/compute_beta/classes.rb', line 20759

def fault_injection_policy
  @fault_injection_policy
end

#max_stream_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxStreamDuration



20767
20768
20769
# File 'lib/google/apis/compute_beta/classes.rb', line 20767

def max_stream_duration
  @max_stream_duration
end

#request_mirror_policyGoogle::Apis::ComputeBeta::RequestMirrorPolicy

A policy that specifies how requests intended for the route's backends are shadowed to a separate mirrored backend service. The load balancer doesn't wait for responses from the shadow service. Before sending traffic to the shadow service, the host or authority header is suffixed with-shadow. Corresponds to the JSON property requestMirrorPolicy



20775
20776
20777
# File 'lib/google/apis/compute_beta/classes.rb', line 20775

def request_mirror_policy
  @request_mirror_policy
end

#retry_policyGoogle::Apis::ComputeBeta::HttpRetryPolicy

The retry policy associates with HttpRouteRule Corresponds to the JSON property retryPolicy



20780
20781
20782
# File 'lib/google/apis/compute_beta/classes.rb', line 20780

def retry_policy
  @retry_policy
end

#timeoutGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property timeout



20788
20789
20790
# File 'lib/google/apis/compute_beta/classes.rb', line 20788

def timeout
  @timeout
end

#url_rewriteGoogle::Apis::ComputeBeta::UrlRewrite

The spec for modifying the path before sending the request to the matched backend service. Corresponds to the JSON property urlRewrite



20794
20795
20796
# File 'lib/google/apis/compute_beta/classes.rb', line 20794

def url_rewrite
  @url_rewrite
end

#weighted_backend_servicesArray<Google::Apis::ComputeBeta::WeightedBackendService>

A list of weighted backend services to send traffic to when a route match occurs. The weights determine the fraction of traffic that flows to their corresponding backend service. If all traffic needs to go to a single backend service, there must be oneweightedBackendService with weight set to a non-zero number. After a backend service is identified and before forwarding the request to the backend service, advanced routing actions such as URL rewrites and header transformations are applied depending on additional settings specified in this HttpRouteAction. Corresponds to the JSON property weightedBackendServices



20808
20809
20810
# File 'lib/google/apis/compute_beta/classes.rb', line 20808

def weighted_backend_services
  @weighted_backend_services
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20815
20816
20817
20818
20819
20820
20821
20822
20823
20824
20825
# File 'lib/google/apis/compute_beta/classes.rb', line 20815

def update!(**args)
  @cache_policy = args[:cache_policy] if args.key?(:cache_policy)
  @cors_policy = args[:cors_policy] if args.key?(:cors_policy)
  @fault_injection_policy = args[:fault_injection_policy] if args.key?(:fault_injection_policy)
  @max_stream_duration = args[:max_stream_duration] if args.key?(:max_stream_duration)
  @request_mirror_policy = args[:request_mirror_policy] if args.key?(:request_mirror_policy)
  @retry_policy = args[:retry_policy] if args.key?(:retry_policy)
  @timeout = args[:timeout] if args.key?(:timeout)
  @url_rewrite = args[:url_rewrite] if args.key?(:url_rewrite)
  @weighted_backend_services = args[:weighted_backend_services] if args.key?(:weighted_backend_services)
end