Class: Google::Apis::ComputeBeta::HttpRouteRule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The HttpRouteRule setting specifies how to match an HTTP request and the corresponding routing action that load balancing proxies perform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpRouteRule

Returns a new instance of HttpRouteRule.



21975
21976
21977
# File 'lib/google/apis/compute_beta/classes.rb', line 21975

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#custom_error_response_policyGoogle::Apis::ComputeBeta::CustomErrorResponsePolicy

Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error. Corresponds to the JSON property customErrorResponsePolicy



21883
21884
21885
# File 'lib/google/apis/compute_beta/classes.rb', line 21883

def custom_error_response_policy
  @custom_error_response_policy
end

#descriptionString

The short description conveying the intent of this routeRule. The description can have a maximum length of 1024 characters. Corresponds to the JSON property description

Returns:

  • (String)


21889
21890
21891
# File 'lib/google/apis/compute_beta/classes.rb', line 21889

def description
  @description
end

#header_actionGoogle::Apis::ComputeBeta::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



21895
21896
21897
# File 'lib/google/apis/compute_beta/classes.rb', line 21895

def header_action
  @header_action
end

#http_filter_configsArray<Google::Apis::ComputeBeta::HttpFilterConfig>

Outbound route specific configuration fornetworkservices.HttpFilter resources enabled by Traffic Director. httpFilterConfigs only applies for load balancers with loadBalancingScheme set toINTERNAL_SELF_MANAGED. See ForwardingRule for more details. Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property httpFilterConfigs



21906
21907
21908
# File 'lib/google/apis/compute_beta/classes.rb', line 21906

def http_filter_configs
  @http_filter_configs
end

#http_filter_metadataArray<Google::Apis::ComputeBeta::HttpFilterConfig>

Outbound route specific metadata supplied tonetworkservices.HttpFilter resources enabled by Traffic Director. httpFilterMetadata only applies for load balancers with loadBalancingScheme set toINTERNAL_SELF_MANAGED. See ForwardingRule for more details. The only configTypeUrl supported istype.googleapis.com/google.protobuf.Struct Not supported when the URL map is bound to a target gRPC proxy that has validateForProxyless field set to true. Corresponds to the JSON property httpFilterMetadata



21918
21919
21920
# File 'lib/google/apis/compute_beta/classes.rb', line 21918

def 
  @http_filter_metadata
end

#match_rulesArray<Google::Apis::ComputeBeta::HttpRouteRuleMatch>

The list of criteria for matching attributes of a request to thisrouteRule. This list has OR semantics: the request matches this routeRule when any of thematchRules are satisfied. However predicates within a given matchRule have AND semantics. All predicates within a matchRule must match for the request to match the rule. Corresponds to the JSON property matchRules



21929
21930
21931
# File 'lib/google/apis/compute_beta/classes.rb', line 21929

def match_rules
  @match_rules
end

#priorityFixnum

For routeRules within a given pathMatcher, priority determines the order in which a load balancer interpretsrouteRules. RouteRules are evaluated in order of priority, from the lowest to highest number. The priority of a rule decreases as its number increases (1, 2, 3, N+1). The first rule that matches the request is applied. You cannot configure two or more routeRules with the same priority. Priority for each rule must be set to a number from 0 to 2147483647 inclusive. Priority numbers can have gaps, which enable you to add or remove rules in the future without affecting the rest of the rules. For example, 1, 2, 3, 4, 5, 9, 12, 16 is a valid series of priority numbers to which you could add rules numbered from 6 to 8, 10 to 11, and 13 to 15 in the future without any impact on existing rules. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


21947
21948
21949
# File 'lib/google/apis/compute_beta/classes.rb', line 21947

def priority
  @priority
end

#route_actionGoogle::Apis::ComputeBeta::HttpRouteAction

In response to a matching matchRule, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend. Only one of urlRedirect, service orrouteAction.weightedBackendService can be set. URL maps for classic Application Load Balancers only support the urlRewrite action within a route rule'srouteAction. Corresponds to the JSON property routeAction



21958
21959
21960
# File 'lib/google/apis/compute_beta/classes.rb', line 21958

def route_action
  @route_action
end

#serviceString

The full or partial URL of the backend service resource to which traffic is directed if this rule is matched. If routeAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of urlRedirect, service orrouteAction.weightedBackendService can be set. Corresponds to the JSON property service

Returns:

  • (String)


21968
21969
21970
# File 'lib/google/apis/compute_beta/classes.rb', line 21968

def service
  @service
end

#url_redirectGoogle::Apis::ComputeBeta::HttpRedirectAction

Specifies settings for an HTTP redirect. Corresponds to the JSON property urlRedirect



21973
21974
21975
# File 'lib/google/apis/compute_beta/classes.rb', line 21973

def url_redirect
  @url_redirect
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21980
21981
21982
21983
21984
21985
21986
21987
21988
21989
21990
21991
# File 'lib/google/apis/compute_beta/classes.rb', line 21980

def update!(**args)
  @custom_error_response_policy = args[:custom_error_response_policy] if args.key?(:custom_error_response_policy)
  @description = args[:description] if args.key?(:description)
  @header_action = args[:header_action] if args.key?(:header_action)
  @http_filter_configs = args[:http_filter_configs] if args.key?(:http_filter_configs)
  @http_filter_metadata = args[:http_filter_metadata] if args.key?(:http_filter_metadata)
  @match_rules = args[:match_rules] if args.key?(:match_rules)
  @priority = args[:priority] if args.key?(:priority)
  @route_action = args[:route_action] if args.key?(:route_action)
  @service = args[:service] if args.key?(:service)
  @url_redirect = args[:url_redirect] if args.key?(:url_redirect)
end