Class: Google::Apis::ComputeBeta::HttpsHealthCheck

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a legacy HTTPS Health Check resource. Legacy HTTPS health checks have been deprecated. If you are using a target pool-based network load balancer, you must use a legacy HTTP (not HTTPS) health check. For all other load balancers, including backend service-based network load balancers, and for managed instance group auto-healing, you must use modern (non-legacy) health checks. For more information, seeHealth checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheck

Returns a new instance of HttpsHealthCheck.



18140
18141
18142
# File 'lib/google/apis/compute_beta/classes.rb', line 18140

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#check_interval_secFixnum

How often (in seconds) to send a health check. The default value is 5 seconds. Corresponds to the JSON property checkIntervalSec

Returns:

  • (Fixnum)


21700
21701
21702
# File 'lib/google/apis/compute_beta/classes.rb', line 21700

def check_interval_sec
  @check_interval_sec
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


21706
21707
21708
# File 'lib/google/apis/compute_beta/classes.rb', line 21706

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


21712
21713
21714
# File 'lib/google/apis/compute_beta/classes.rb', line 21712

def description
  @description
end

#healthy_thresholdFixnum

A so-far unhealthy instance will be marked healthy after this many consecutive successes. The default value is 2. Corresponds to the JSON property healthyThreshold

Returns:

  • (Fixnum)


21718
21719
21720
# File 'lib/google/apis/compute_beta/classes.rb', line 21718

def healthy_threshold
  @healthy_threshold
end

#hostString

The value of the host header in the HTTPS health check request. If left empty (default value), the public IP on behalf of which this health check is performed will be used. Corresponds to the JSON property host

Returns:

  • (String)


18077
18078
18079
# File 'lib/google/apis/compute_beta/classes.rb', line 18077

def host
  @host
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


21731
21732
21733
# File 'lib/google/apis/compute_beta/classes.rb', line 21731

def id
  @id
end

#kindString

Output only. Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


21736
21737
21738
# File 'lib/google/apis/compute_beta/classes.rb', line 21736

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


21747
21748
21749
# File 'lib/google/apis/compute_beta/classes.rb', line 21747

def name
  @name
end

#portFixnum

The TCP port number for the HTTPS health check request. The default value is 443. Corresponds to the JSON property port

Returns:

  • (Fixnum)


18083
18084
18085
# File 'lib/google/apis/compute_beta/classes.rb', line 18083

def port
  @port
end

#port_nameString

Not supported. Corresponds to the JSON property portName

Returns:

  • (String)


18088
18089
18090
# File 'lib/google/apis/compute_beta/classes.rb', line 18088

def port_name
  @port_name
end

#port_specificationString

Specifies how a port is selected for health checking. Can be one of the following values: USE_FIXED_PORT: Specifies a port number explicitly using theport field in the health check. Supported by backend services for passthrough load balancers and backend services for proxy load balancers. Not supported by target pools. The health check supports all backends supported by the backend service provided the backend can be health checked. For example, GCE_VM_IP network endpoint groups, GCE_VM_IP_PORT network endpoint groups, and instance group backends. USE_NAMED_PORT: Not supported. USE_SERVING_PORT: Provides an indirect method of specifying the health check port by referring to the backend service. Only supported by backend services for proxy load balancers. Not supported by target pools. Not supported by backend services for passthrough load balancers. Supports all backends that can be health checked; for example,GCE_VM_IP_PORT network endpoint groups and instance group backends. For GCE_VM_IP_PORT network endpoint group backends, the health check uses the port number specified for each endpoint in the network endpoint group. For instance group backends, the health check uses the port number determined by looking up the backend service's named port in the instance group's list of named ports. Corresponds to the JSON property portSpecification

Returns:

  • (String)


18115
18116
18117
# File 'lib/google/apis/compute_beta/classes.rb', line 18115

def port_specification
  @port_specification
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


18122
18123
18124
# File 'lib/google/apis/compute_beta/classes.rb', line 18122

def proxy_header
  @proxy_header
end

#request_pathString

The request path of the HTTPS health check request. The default value is "/". Must comply withRFC3986. Corresponds to the JSON property requestPath

Returns:

  • (String)


18128
18129
18130
# File 'lib/google/apis/compute_beta/classes.rb', line 18128

def request_path
  @request_path
end

#responseString

Creates a content-based HTTPS health check. In addition to the required HTTP 200 (OK) status code, you can configure the health check to pass only when the backend sends this specific ASCII response string within the first 1024 bytes of the HTTP response body. For details, see: https://cloud.google.com/load-balancing/docs/health-check-concepts#criteria- protocol-http Corresponds to the JSON property response

Returns:

  • (String)


18138
18139
18140
# File 'lib/google/apis/compute_beta/classes.rb', line 18138

def response
  @response
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21764
21765
21766
# File 'lib/google/apis/compute_beta/classes.rb', line 21764

def self_link
  @self_link
end

#timeout_secFixnum

How long (in seconds) to wait before claiming failure. The default value is 5 seconds. It is invalid for timeoutSec to have a greater value than checkIntervalSec. Corresponds to the JSON property timeoutSec

Returns:

  • (Fixnum)


21771
21772
21773
# File 'lib/google/apis/compute_beta/classes.rb', line 21771

def timeout_sec
  @timeout_sec
end

#unhealthy_thresholdFixnum

A so-far healthy instance will be marked unhealthy after this many consecutive failures. The default value is 2. Corresponds to the JSON property unhealthyThreshold

Returns:

  • (Fixnum)


21777
21778
21779
# File 'lib/google/apis/compute_beta/classes.rb', line 21777

def unhealthy_threshold
  @unhealthy_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



18145
18146
18147
18148
18149
18150
18151
18152
18153
# File 'lib/google/apis/compute_beta/classes.rb', line 18145

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @port = args[:port] if args.key?(:port)
  @port_name = args[:port_name] if args.key?(:port_name)
  @port_specification = args[:port_specification] if args.key?(:port_specification)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @request_path = args[:request_path] if args.key?(:request_path)
  @response = args[:response] if args.key?(:response)
end