Class: Google::Apis::ComputeBeta::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



22304
22305
22306
# File 'lib/google/apis/compute_beta/classes.rb', line 22304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22272
22273
22274
# File 'lib/google/apis/compute_beta/classes.rb', line 22272

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



22277
22278
22279
# File 'lib/google/apis/compute_beta/classes.rb', line 22277

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22282
22283
22284
# File 'lib/google/apis/compute_beta/classes.rb', line 22282

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22292
22293
22294
# File 'lib/google/apis/compute_beta/classes.rb', line 22292

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22297
22298
22299
# File 'lib/google/apis/compute_beta/classes.rb', line 22297

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22302
22303
22304
# File 'lib/google/apis/compute_beta/classes.rb', line 22302

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22309
22310
22311
22312
22313
22314
22315
22316
# File 'lib/google/apis/compute_beta/classes.rb', line 22309

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end