Class: Google::Apis::ComputeBeta::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



21840
21841
21842
# File 'lib/google/apis/compute_beta/classes.rb', line 21840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21808
21809
21810
# File 'lib/google/apis/compute_beta/classes.rb', line 21808

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



21813
21814
21815
# File 'lib/google/apis/compute_beta/classes.rb', line 21813

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21818
21819
21820
# File 'lib/google/apis/compute_beta/classes.rb', line 21818

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21828
21829
21830
# File 'lib/google/apis/compute_beta/classes.rb', line 21828

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21833
21834
21835
# File 'lib/google/apis/compute_beta/classes.rb', line 21833

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21838
21839
21840
# File 'lib/google/apis/compute_beta/classes.rb', line 21838

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21845
21846
21847
21848
21849
21850
21851
21852
# File 'lib/google/apis/compute_beta/classes.rb', line 21845

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end