Class: Google::Apis::ComputeBeta::HttpsHealthCheckList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of HttpsHealthCheck resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ HttpsHealthCheckList

Returns a new instance of HttpsHealthCheckList.



20291
20292
20293
# File 'lib/google/apis/compute_beta/classes.rb', line 20291

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


20259
20260
20261
# File 'lib/google/apis/compute_beta/classes.rb', line 20259

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::HttpsHealthCheck>

A list of HttpsHealthCheck resources. Corresponds to the JSON property items



20264
20265
20266
# File 'lib/google/apis/compute_beta/classes.rb', line 20264

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


20269
20270
20271
# File 'lib/google/apis/compute_beta/classes.rb', line 20269

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


20279
20280
20281
# File 'lib/google/apis/compute_beta/classes.rb', line 20279

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


20284
20285
20286
# File 'lib/google/apis/compute_beta/classes.rb', line 20284

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::HttpsHealthCheckList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



20289
20290
20291
# File 'lib/google/apis/compute_beta/classes.rb', line 20289

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



20296
20297
20298
20299
20300
20301
20302
20303
# File 'lib/google/apis/compute_beta/classes.rb', line 20296

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end