Class: Google::Apis::ComputeBeta::Image::RawDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The parameters of the raw disk image.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RawDisk

Returns a new instance of RawDisk.



21105
21106
21107
# File 'lib/google/apis/compute_beta/classes.rb', line 21105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#container_typeString

The format used to encode and transmit the block device, which should beTAR. This is just a container and transmission format and not a runtime format. Provided by the client when the disk image is created. Corresponds to the JSON property containerType

Returns:

  • (String)


21079
21080
21081
# File 'lib/google/apis/compute_beta/classes.rb', line 21079

def container_type
  @container_type
end

#sha1_checksumString

[Deprecated] This field is deprecated. An optional SHA1 checksum of the disk image before unpackaging provided by the client when the disk image is created. Corresponds to the JSON property sha1Checksum

Returns:

  • (String)


21086
21087
21088
# File 'lib/google/apis/compute_beta/classes.rb', line 21086

def sha1_checksum
  @sha1_checksum
end

#sourceString

The full Google Cloud Storage URL where the raw disk image archive is stored. The following are valid formats for the URL:

Returns:

  • (String)


21103
21104
21105
# File 'lib/google/apis/compute_beta/classes.rb', line 21103

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21110
21111
21112
21113
21114
# File 'lib/google/apis/compute_beta/classes.rb', line 21110

def update!(**args)
  @container_type = args[:container_type] if args.key?(:container_type)
  @sha1_checksum = args[:sha1_checksum] if args.key?(:sha1_checksum)
  @source = args[:source] if args.key?(:source)
end