Class: Google::Apis::ComputeBeta::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



22915
22916
22917
# File 'lib/google/apis/compute_beta/classes.rb', line 22915

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22883
22884
22885
# File 'lib/google/apis/compute_beta/classes.rb', line 22883

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Image>

A list of Image resources. Corresponds to the JSON property items



22888
22889
22890
# File 'lib/google/apis/compute_beta/classes.rb', line 22888

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22893
22894
22895
# File 'lib/google/apis/compute_beta/classes.rb', line 22893

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22903
22904
22905
# File 'lib/google/apis/compute_beta/classes.rb', line 22903

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22908
22909
22910
# File 'lib/google/apis/compute_beta/classes.rb', line 22908

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22913
22914
22915
# File 'lib/google/apis/compute_beta/classes.rb', line 22913

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22920
22921
22922
22923
22924
22925
22926
22927
# File 'lib/google/apis/compute_beta/classes.rb', line 22920

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end