Class: Google::Apis::ComputeBeta::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



22839
22840
22841
# File 'lib/google/apis/compute_beta/classes.rb', line 22839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22807
22808
22809
# File 'lib/google/apis/compute_beta/classes.rb', line 22807

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Image>

A list of Image resources. Corresponds to the JSON property items



22812
22813
22814
# File 'lib/google/apis/compute_beta/classes.rb', line 22812

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


22817
22818
22819
# File 'lib/google/apis/compute_beta/classes.rb', line 22817

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22827
22828
22829
# File 'lib/google/apis/compute_beta/classes.rb', line 22827

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22832
22833
22834
# File 'lib/google/apis/compute_beta/classes.rb', line 22832

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22837
22838
22839
# File 'lib/google/apis/compute_beta/classes.rb', line 22837

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22844
22845
22846
22847
22848
22849
22850
22851
# File 'lib/google/apis/compute_beta/classes.rb', line 22844

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end