Class: Google::Apis::ComputeBeta::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
22401 22402 22403 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22401 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22369 22370 22371 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22369 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
Corresponds to the JSON property items
22374 22375 22376 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22374 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22379 22380 22381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22379 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22389 22390 22391 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22389 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22394 22395 22396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22394 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22399 22400 22401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22399 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22406 22407 22408 22409 22410 22411 22412 22413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22406 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |