Class: Google::Apis::ComputeBeta::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
22377 22378 22379 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
22345 22346 22347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22345 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
Corresponds to the JSON property items
22350 22351 22352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22350 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
22355 22356 22357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22355 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
22365 22366 22367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22365 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
22370 22371 22372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22370 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
22375 22376 22377 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22375 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22382 22383 22384 22385 22386 22387 22388 22389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22382 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |