Class: Google::Apis::ComputeBeta::ImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageList

Returns a new instance of ImageList.



21793
21794
21795
# File 'lib/google/apis/compute_beta/classes.rb', line 21793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21761
21762
21763
# File 'lib/google/apis/compute_beta/classes.rb', line 21761

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Image>

A list of Image resources. Corresponds to the JSON property items



21766
21767
21768
# File 'lib/google/apis/compute_beta/classes.rb', line 21766

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


21771
21772
21773
# File 'lib/google/apis/compute_beta/classes.rb', line 21771

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21781
21782
21783
# File 'lib/google/apis/compute_beta/classes.rb', line 21781

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21786
21787
21788
# File 'lib/google/apis/compute_beta/classes.rb', line 21786

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21791
21792
21793
# File 'lib/google/apis/compute_beta/classes.rb', line 21791

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21798
21799
21800
21801
21802
21803
21804
21805
# File 'lib/google/apis/compute_beta/classes.rb', line 21798

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end