Class: Google::Apis::ComputeBeta::ImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImageList
constructor
A new instance of ImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImageList
Returns a new instance of ImageList.
20859 20860 20861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
20827 20828 20829 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20827 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Image>
A list of Image resources.
Corresponds to the JSON property items
20832 20833 20834 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20832 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
20837 20838 20839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20837 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
20847 20848 20849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20847 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
20852 20853 20854 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20852 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
20857 20858 20859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20857 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
20864 20865 20866 20867 20868 20869 20870 20871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 20864 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |