Class: Google::Apis::ComputeBeta::ImageOptimizationPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The configuration for Cloud CDN's image optimization feature. This feature dynamically processes and delivers images from the network edge. Image Optimization is only available for Global External Application Load Balancers. Either Cloud CDN must be enabled on the backend service or backend bucket serving the route, or cache policy must be configured on the same route.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageOptimizationPolicy

Returns a new instance of ImageOptimizationPolicy.



22938
22939
22940
# File 'lib/google/apis/compute_beta/classes.rb', line 22938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#query_parameter_interpretationString

Specifies whether to interpret query parameters for image optimization. Corresponds to the JSON property queryParameterInterpretation

Returns:

  • (String)


22936
22937
22938
# File 'lib/google/apis/compute_beta/classes.rb', line 22936

def query_parameter_interpretation
  @query_parameter_interpretation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22943
22944
22945
# File 'lib/google/apis/compute_beta/classes.rb', line 22943

def update!(**args)
  @query_parameter_interpretation = args[:query_parameter_interpretation] if args.key?(:query_parameter_interpretation)
end