Class: Google::Apis::ComputeBeta::Instance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Instance

Returns a new instance of Instance.



22304
22305
22306
# File 'lib/google/apis/compute_beta/classes.rb', line 22304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeBeta::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



21956
21957
21958
# File 'lib/google/apis/compute_beta/classes.rb', line 21956

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Allows this instance to send and receive packets with non-matching destination or source IPs. This is required if you plan to use this instance to forward routes. For more information, seeEnabling IP Forwarding. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


21963
21964
21965
# File 'lib/google/apis/compute_beta/classes.rb', line 21963

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeBeta::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



21969
21970
21971
# File 'lib/google/apis/compute_beta/classes.rb', line 21969

def confidential_instance_config
  @confidential_instance_config
end

#cpu_platformString

Output only. [Output Only] The CPU platform used by this instance. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


21974
21975
21976
# File 'lib/google/apis/compute_beta/classes.rb', line 21974

def cpu_platform
  @cpu_platform
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


21979
21980
21981
# File 'lib/google/apis/compute_beta/classes.rb', line 21979

def creation_timestamp
  @creation_timestamp
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the resource should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


21984
21985
21986
# File 'lib/google/apis/compute_beta/classes.rb', line 21984

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


21991
21992
21993
# File 'lib/google/apis/compute_beta/classes.rb', line 21991

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::AttachedDisk>

Array of disks associated with this instance. Persistent disks must be created before you can assign them. Corresponds to the JSON property disks



21997
21998
21999
# File 'lib/google/apis/compute_beta/classes.rb', line 21997

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeBeta::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



22002
22003
22004
# File 'lib/google/apis/compute_beta/classes.rb', line 22002

def display_device
  @display_device
end

#erase_windows_vss_signatureBoolean Also known as: erase_windows_vss_signature?

Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature. Corresponds to the JSON property eraseWindowsVssSignature

Returns:

  • (Boolean)


22008
22009
22010
# File 'lib/google/apis/compute_beta/classes.rb', line 22008

def erase_windows_vss_signature
  @erase_windows_vss_signature
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance. You must always provide an up-to-date fingerprint hash in order to update the instance. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22021
22022
22023
# File 'lib/google/apis/compute_beta/classes.rb', line 22021

def fingerprint
  @fingerprint
end

#guest_acceleratorsArray<Google::Apis::ComputeBeta::AcceleratorConfig>

A list of the type and count of accelerator cards attached to the instance. Corresponds to the JSON property guestAccelerators



22026
22027
22028
# File 'lib/google/apis/compute_beta/classes.rb', line 22026

def guest_accelerators
  @guest_accelerators
end

#hostnameString

Specifies the hostname of the instance. The specified hostname must be RFC1035 compliant. If hostname is not specified, the default hostname is [INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and [INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS. Corresponds to the JSON property hostname

Returns:

  • (String)


22034
22035
22036
# File 'lib/google/apis/compute_beta/classes.rb', line 22034

def hostname
  @hostname
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22041
22042
22043
# File 'lib/google/apis/compute_beta/classes.rb', line 22041

def id
  @id
end

#instance_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Encrypts suspended data for an instance with acustomer-managed encryption key. If you are creating a new instance, this field will encrypt the local SSD and in-memory contents of the instance during the suspend operation. If you do not provide an encryption key when creating the instance, then the local SSD and in-memory contents will be encrypted using an automatically generated key during the suspend operation. Corresponds to the JSON property instanceEncryptionKey



22052
22053
22054
# File 'lib/google/apis/compute_beta/classes.rb', line 22052

def instance_encryption_key
  @instance_encryption_key
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


22058
22059
22060
# File 'lib/google/apis/compute_beta/classes.rb', line 22058

def key_revocation_action_type
  @key_revocation_action_type
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#instance for instances. Corresponds to the JSON property kind

Returns:

  • (String)


22064
22065
22066
# File 'lib/google/apis/compute_beta/classes.rb', line 22064

def kind
  @kind
end

#label_fingerprintString

A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the instance. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22076
22077
22078
# File 'lib/google/apis/compute_beta/classes.rb', line 22076

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this instance. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


22082
22083
22084
# File 'lib/google/apis/compute_beta/classes.rb', line 22082

def labels
  @labels
end

#last_start_timestampString

Output only. [Output Only] Last start timestamp inRFC3339 text format. Corresponds to the JSON property lastStartTimestamp

Returns:

  • (String)


22087
22088
22089
# File 'lib/google/apis/compute_beta/classes.rb', line 22087

def last_start_timestamp
  @last_start_timestamp
end

#last_stop_timestampString

Output only. [Output Only] Last stop timestamp inRFC3339 text format. Corresponds to the JSON property lastStopTimestamp

Returns:

  • (String)


22092
22093
22094
# File 'lib/google/apis/compute_beta/classes.rb', line 22092

def last_stop_timestamp
  @last_stop_timestamp
end

#last_suspended_timestampString

Output only. [Output Only] Last suspended timestamp inRFC3339 text format. Corresponds to the JSON property lastSuspendedTimestamp

Returns:

  • (String)


22097
22098
22099
# File 'lib/google/apis/compute_beta/classes.rb', line 22097

def last_suspended_timestamp
  @last_suspended_timestamp
end

#machine_typeString

Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type. This is provided by the client when the instance is created. For example, the following is a valid partial url to a predefined machine type: zones/us-central1-f/machineTypes/n1-standard-1 To create acustom machine type, provide a URL to a machine type in the following format, where CPUS is 1 or an even number up to 32 (2, 4, 6, ... 24, etc), and MEMORY is the total memory for this instance. Memory must be a multiple of 256 MB and must be supplied in MB (e.g. 5 GB of memory is 5120 MB): zones/zone/machineTypes/custom-CPUS-MEMORY For example: zones/us-central1-f/machineTypes/custom-4-5120 For a full list of restrictions, read theSpecifications for custom machine types. Corresponds to the JSON property machineType

Returns:

  • (String)


22118
22119
22120
# File 'lib/google/apis/compute_beta/classes.rb', line 22118

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



22123
22124
22125
# File 'lib/google/apis/compute_beta/classes.rb', line 22123

def 
  @metadata
end

#min_cpu_platformString

Specifies aminimum CPU platform for the VM instance. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" or minCpuPlatform: "Intel Sandy Bridge". Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


22132
22133
22134
# File 'lib/google/apis/compute_beta/classes.rb', line 22132

def min_cpu_platform
  @min_cpu_platform
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


22144
22145
22146
# File 'lib/google/apis/compute_beta/classes.rb', line 22144

def name
  @name
end

#network_interfacesArray<Google::Apis::ComputeBeta::NetworkInterface>

An array of network configurations for this instance. These specify how interfaces are configured to interact with other network services, such as connecting to the internet. Multiple interfaces are supported per instance. Corresponds to the JSON property networkInterfaces



22152
22153
22154
# File 'lib/google/apis/compute_beta/classes.rb', line 22152

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeBeta::NetworkPerformanceConfig

Corresponds to the JSON property networkPerformanceConfig



22157
22158
22159
# File 'lib/google/apis/compute_beta/classes.rb', line 22157

def network_performance_config
  @network_performance_config
end

#paramsGoogle::Apis::ComputeBeta::InstanceParams

Additional instance params. Corresponds to the JSON property params



22162
22163
22164
# File 'lib/google/apis/compute_beta/classes.rb', line 22162

def params
  @params
end

#partner_metadataHash<String,Google::Apis::ComputeBeta::StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



22168
22169
22170
# File 'lib/google/apis/compute_beta/classes.rb', line 22168

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


22173
22174
22175
# File 'lib/google/apis/compute_beta/classes.rb', line 22173

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#private_ipv6_google_accessString

The private IPv6 google access type for the VM. If not specified, use INHERIT_FROM_SUBNETWORK as default. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


22179
22180
22181
# File 'lib/google/apis/compute_beta/classes.rb', line 22179

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeBeta::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



22184
22185
22186
# File 'lib/google/apis/compute_beta/classes.rb', line 22184

def reservation_affinity
  @reservation_affinity
end

#resource_policiesArray<String>

Resource policies applied to this instance. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


22189
22190
22191
# File 'lib/google/apis/compute_beta/classes.rb', line 22189

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeBeta::ResourceStatus

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls. Corresponds to the JSON property resourceStatus



22196
22197
22198
# File 'lib/google/apis/compute_beta/classes.rb', line 22196

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


22201
22202
22203
# File 'lib/google/apis/compute_beta/classes.rb', line 22201

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


22207
22208
22209
# File 'lib/google/apis/compute_beta/classes.rb', line 22207

def satisfies_pzs
  @satisfies_pzs
end

#schedulingGoogle::Apis::ComputeBeta::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



22213
22214
22215
# File 'lib/google/apis/compute_beta/classes.rb', line 22213

def scheduling
  @scheduling
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22218
22219
22220
# File 'lib/google/apis/compute_beta/classes.rb', line 22218

def self_link
  @self_link
end

#service_accountsArray<Google::Apis::ComputeBeta::ServiceAccount>

A list of service accounts, with their specified scopes, authorized for this instance. Only one service account per VM instance is supported. Service accounts generate access tokens that can be accessed through the metadata server and used to authenticate applications on the instance. SeeService Accounts for more information. Corresponds to the JSON property serviceAccounts



22228
22229
22230
# File 'lib/google/apis/compute_beta/classes.rb', line 22228

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeBeta::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



22233
22234
22235
# File 'lib/google/apis/compute_beta/classes.rb', line 22233

def shielded_instance_config
  @shielded_instance_config
end

#shielded_instance_integrity_policyGoogle::Apis::ComputeBeta::ShieldedInstanceIntegrityPolicy

The policy describes the baseline against which Instance boot integrity is measured. Corresponds to the JSON property shieldedInstanceIntegrityPolicy



22239
22240
22241
# File 'lib/google/apis/compute_beta/classes.rb', line 22239

def shielded_instance_integrity_policy
  @shielded_instance_integrity_policy
end

#shielded_vm_configGoogle::Apis::ComputeBeta::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



22244
22245
22246
# File 'lib/google/apis/compute_beta/classes.rb', line 22244

def shielded_vm_config
  @shielded_vm_config
end

#shielded_vm_integrity_policyGoogle::Apis::ComputeBeta::ShieldedVmIntegrityPolicy

The policy describes the baseline against which VM instance boot integrity is measured. Corresponds to the JSON property shieldedVmIntegrityPolicy



22250
22251
22252
# File 'lib/google/apis/compute_beta/classes.rb', line 22250

def shielded_vm_integrity_policy
  @shielded_vm_integrity_policy
end

#source_machine_imageString

Source machine image Corresponds to the JSON property sourceMachineImage

Returns:

  • (String)


22255
22256
22257
# File 'lib/google/apis/compute_beta/classes.rb', line 22255

def source_machine_image
  @source_machine_image
end

#source_machine_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Source machine image encryption key when creating an instance from a machine image. Corresponds to the JSON property sourceMachineImageEncryptionKey



22261
22262
22263
# File 'lib/google/apis/compute_beta/classes.rb', line 22261

def source_machine_image_encryption_key
  @source_machine_image_encryption_key
end

#start_restrictedBoolean Also known as: start_restricted?

Output only. [Output Only] Whether a VM has been restricted for start because Compute Engine has detected suspicious activity. Corresponds to the JSON property startRestricted

Returns:

  • (Boolean)


22268
22269
22270
# File 'lib/google/apis/compute_beta/classes.rb', line 22268

def start_restricted
  @start_restricted
end

#statusString

Output only. [Output Only] The status of the instance. One of the following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING, SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of the instance, see Instance life cycle. Corresponds to the JSON property status

Returns:

  • (String)


22279
22280
22281
# File 'lib/google/apis/compute_beta/classes.rb', line 22279

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


22285
22286
22287
# File 'lib/google/apis/compute_beta/classes.rb', line 22285

def status_message
  @status_message
end

#tagsGoogle::Apis::ComputeBeta::Tags

A set of instance tags. Corresponds to the JSON property tags



22290
22291
22292
# File 'lib/google/apis/compute_beta/classes.rb', line 22290

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeBeta::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



22295
22296
22297
# File 'lib/google/apis/compute_beta/classes.rb', line 22295

def workload_identity_config
  @workload_identity_config
end

#zoneString

Output only. [Output Only] URL of the zone where the instance resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


22302
22303
22304
# File 'lib/google/apis/compute_beta/classes.rb', line 22302

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
22320
22321
22322
22323
22324
22325
22326
22327
22328
22329
22330
22331
22332
22333
22334
22335
22336
22337
22338
22339
22340
22341
22342
22343
22344
22345
22346
22347
22348
22349
22350
22351
22352
22353
22354
22355
22356
22357
22358
22359
22360
22361
22362
# File 'lib/google/apis/compute_beta/classes.rb', line 22309

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @hostname = args[:hostname] if args.key?(:hostname)
  @id = args[:id] if args.key?(:id)
  @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp)
  @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp)
  @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @name = args[:name] if args.key?(:name)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @params = args[:params] if args.key?(:params)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @shielded_vm_integrity_policy = args[:shielded_vm_integrity_policy] if args.key?(:shielded_vm_integrity_policy)
  @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image)
  @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key)
  @start_restricted = args[:start_restricted] if args.key?(:start_restricted)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
  @zone = args[:zone] if args.key?(:zone)
end