Class: Google::Apis::ComputeBeta::Instance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Instance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an Instance resource. An instance is a virtual machine that is hosted on Google Cloud Platform. For more information, readVirtual Machine Instances.
Instance Attribute Summary collapse
-
#advanced_machine_features ⇒ Google::Apis::ComputeBeta::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Allows this instance to send and receive packets with non-matching destination or source IPs.
-
#confidential_instance_config ⇒ Google::Apis::ComputeBeta::ConfidentialInstanceConfig
A set of Confidential Instance options.
-
#cpu_platform ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Whether the resource should be protected against deletion.
-
#description ⇒ String
An optional description of this resource.
-
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
Array of disks associated with this instance.
-
#display_device ⇒ Google::Apis::ComputeBeta::DisplayDevice
A set of Display Device options Corresponds to the JSON property
displayDevice. -
#erase_windows_vss_signature ⇒ Boolean
(also: #erase_windows_vss_signature?)
Specifies whether the disks restored from source snapshots or source machine image should erase Windows specific VSS signature.
-
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the instance's contents and used for optimistic locking.
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
-
#hostname ⇒ String
Specifies the hostname of the instance.
-
#id ⇒ Fixnum
Output only.
-
#instance_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Encrypts suspended data for an instance with acustomer-managed encryption key.
-
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for this request, which is essentially a hash of the label's contents and used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this instance.
-
#last_start_timestamp ⇒ String
Output only.
-
#last_stop_timestamp ⇒ String
Output only.
-
#last_suspended_timestamp ⇒ String
Output only.
-
#machine_type ⇒ String
Full or partial URL of the machine type resource to use for this instance, in the format:zones/zone/machineTypes/machine-type.
-
#metadata ⇒ Google::Apis::ComputeBeta::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Specifies aminimum CPU platform for the VM instance.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeBeta::NetworkInterface>
An array of network configurations for this instance.
-
#network_performance_config ⇒ Google::Apis::ComputeBeta::NetworkPerformanceConfig
Corresponds to the JSON property
networkPerformanceConfig. -
#params ⇒ Google::Apis::ComputeBeta::InstanceParams
Additional instance params.
-
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeBeta::StructuredEntries>
Partner Metadata assigned to the instance.
-
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
-
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for the VM.
-
#reservation_affinity ⇒ Google::Apis::ComputeBeta::ReservationAffinity
Specifies the reservations that this instance can consume from.
-
#resource_policies ⇒ Array<String>
Resource policies applied to this instance.
-
#resource_status ⇒ Google::Apis::ComputeBeta::ResourceStatus
Contains output only fields.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#scheduling ⇒ Google::Apis::ComputeBeta::Scheduling
Sets the scheduling options for an Instance.
-
#self_link ⇒ String
Output only.
-
#service_accounts ⇒ Array<Google::Apis::ComputeBeta::ServiceAccount>
A list of service accounts, with their specified scopes, authorized for this instance.
-
#shielded_instance_config ⇒ Google::Apis::ComputeBeta::ShieldedInstanceConfig
A set of Shielded Instance options.
-
#shielded_instance_integrity_policy ⇒ Google::Apis::ComputeBeta::ShieldedInstanceIntegrityPolicy
The policy describes the baseline against which Instance boot integrity is measured.
-
#shielded_vm_config ⇒ Google::Apis::ComputeBeta::ShieldedVmConfig
A set of Shielded VM options.
-
#shielded_vm_integrity_policy ⇒ Google::Apis::ComputeBeta::ShieldedVmIntegrityPolicy
The policy describes the baseline against which VM instance boot integrity is measured.
-
#source_machine_image ⇒ String
Source machine image Corresponds to the JSON property
sourceMachineImage. -
#source_machine_image_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Source machine image encryption key when creating an instance from a machine image.
-
#start_restricted ⇒ Boolean
(also: #start_restricted?)
Output only.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
-
#tags ⇒ Google::Apis::ComputeBeta::Tags
A set of instance tags.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Instance
constructor
A new instance of Instance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Instance
Returns a new instance of Instance.
21364 21365 21366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advanced_machine_features ⇒ Google::Apis::ComputeBeta::AdvancedMachineFeatures
Specifies options for controlling advanced machine features.
Options that would traditionally be configured in a BIOS belong
here. Features that require operating system support may have
corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not
the OS in theImage supports nested virtualization being enabled or
disabled).
Corresponds to the JSON property advancedMachineFeatures
21021 21022 21023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21021 def advanced_machine_features @advanced_machine_features end |
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Allows this instance to send and receive packets with non-matching
destination or source IPs. This is required if you plan to use this
instance to forward routes. For more information, seeEnabling IP Forwarding.
Corresponds to the JSON property canIpForward
21028 21029 21030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21028 def can_ip_forward @can_ip_forward end |
#confidential_instance_config ⇒ Google::Apis::ComputeBeta::ConfidentialInstanceConfig
A set of Confidential Instance options.
Corresponds to the JSON property confidentialInstanceConfig
21034 21035 21036 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21034 def confidential_instance_config @confidential_instance_config end |
#cpu_platform ⇒ String
Output only. [Output Only] The CPU platform used by this instance.
Corresponds to the JSON property cpuPlatform
21039 21040 21041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21039 def cpu_platform @cpu_platform end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
21044 21045 21046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21044 def @creation_timestamp end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Whether the resource should be protected against deletion.
Corresponds to the JSON property deletionProtection
21049 21050 21051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21049 def deletion_protection @deletion_protection end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
21056 21057 21058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21056 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
Array of disks associated with this instance. Persistent disks must be
created before you can assign them.
Corresponds to the JSON property disks
21062 21063 21064 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21062 def disks @disks end |
#display_device ⇒ Google::Apis::ComputeBeta::DisplayDevice
A set of Display Device options
Corresponds to the JSON property displayDevice
21067 21068 21069 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21067 def display_device @display_device end |
#erase_windows_vss_signature ⇒ Boolean Also known as: erase_windows_vss_signature?
Specifies whether the disks restored from source snapshots or source
machine image should erase Windows specific VSS signature.
Corresponds to the JSON property eraseWindowsVssSignature
21073 21074 21075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21073 def erase_windows_vss_signature @erase_windows_vss_signature end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of
the instance's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update the instance. You must always provide an
up-to-date fingerprint hash in order to update the instance.
To see the latest fingerprint, make get() request to the
instance.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
21086 21087 21088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21086 def fingerprint @fingerprint end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
A list of the type and count of accelerator cards attached to the instance.
Corresponds to the JSON property guestAccelerators
21091 21092 21093 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21091 def guest_accelerators @guest_accelerators end |
#hostname ⇒ String
Specifies the hostname of the instance. The specified hostname must be
RFC1035 compliant. If hostname is not specified, the default hostname is
[INSTANCE_NAME].c.[PROJECT_ID].internal when using the global DNS, and
[INSTANCE_NAME].[ZONE].c.[PROJECT_ID].internal when using zonal DNS.
Corresponds to the JSON property hostname
21099 21100 21101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21099 def hostname @hostname end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
21106 21107 21108 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21106 def id @id end |
#instance_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Encrypts suspended data for an instance with acustomer-managed
encryption key.
If you are creating a new instance, this field will encrypt the local SSD
and in-memory contents of the instance during the suspend operation.
If you do not provide an encryption key when creating the instance, then
the local SSD and in-memory contents will be encrypted using
an automatically generated key during the suspend operation.
Corresponds to the JSON property instanceEncryptionKey
21117 21118 21119 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21117 def instance_encryption_key @instance_encryption_key end |
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance. Supported options are "STOP" and
"NONE". The default value is "NONE" if it is not specified.
Corresponds to the JSON property keyRevocationActionType
21123 21124 21125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21123 def key_revocation_action_type @key_revocation_action_type end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#instance
for instances.
Corresponds to the JSON property kind
21129 21130 21131 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21129 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for this request, which is essentially a hash of
the label's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make get() request to the
instance.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
21141 21142 21143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21141 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this instance. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
21147 21148 21149 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21147 def labels @labels end |
#last_start_timestamp ⇒ String
Output only. [Output Only] Last start timestamp inRFC3339 text format.
Corresponds to the JSON property lastStartTimestamp
21152 21153 21154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21152 def @last_start_timestamp end |
#last_stop_timestamp ⇒ String
Output only. [Output Only] Last stop timestamp inRFC3339 text format.
Corresponds to the JSON property lastStopTimestamp
21157 21158 21159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21157 def @last_stop_timestamp end |
#last_suspended_timestamp ⇒ String
Output only. [Output Only] Last suspended timestamp inRFC3339 text format.
Corresponds to the JSON property lastSuspendedTimestamp
21162 21163 21164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21162 def @last_suspended_timestamp end |
#machine_type ⇒ String
Full or partial URL of the machine type resource to use for this instance,
in the format:zones/zone/machineTypes/machine-type. This is provided by the
client
when the instance is created. For example, the following is a valid partial
url to a predefined
machine type:
zones/us-central1-f/machineTypes/n1-standard-1
To create acustom
machine type, provide a URL to a machine type in the following format,
where CPUS is 1 or an even number up to 32 (2,
4, 6, ... 24, etc), and MEMORY is the total
memory for this instance. Memory must be a multiple of 256 MB and must
be supplied in MB (e.g. 5 GB of memory is 5120 MB):
zones/zone/machineTypes/custom-CPUS-MEMORY
For example: zones/us-central1-f/machineTypes/custom-4-5120
For a full list of restrictions, read theSpecifications
for custom machine types.
Corresponds to the JSON property machineType
21183 21184 21185 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21183 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeBeta::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
21188 21189 21190 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21188 def @metadata end |
#min_cpu_platform ⇒ String
Specifies aminimum CPU
platform for the VM instance. Applicable values are the friendly names
of CPU platforms, such as minCpuPlatform: "Intel
Haswell" or minCpuPlatform: "Intel Sandy
Bridge".
Corresponds to the JSON property minCpuPlatform
21197 21198 21199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21197 def min_cpu_platform @min_cpu_platform end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
21209 21210 21211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21209 def name @name end |
#network_interfaces ⇒ Array<Google::Apis::ComputeBeta::NetworkInterface>
An array of network configurations for this instance. These specify how
interfaces are configured to interact with other network services, such as
connecting to the internet. Multiple interfaces are supported
per instance.
Corresponds to the JSON property networkInterfaces
21217 21218 21219 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21217 def network_interfaces @network_interfaces end |
#network_performance_config ⇒ Google::Apis::ComputeBeta::NetworkPerformanceConfig
Corresponds to the JSON property networkPerformanceConfig
21222 21223 21224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21222 def network_performance_config @network_performance_config end |
#params ⇒ Google::Apis::ComputeBeta::InstanceParams
Additional instance params.
Corresponds to the JSON property params
21227 21228 21229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21227 def params @params end |
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeBeta::StructuredEntries>
Partner Metadata assigned to the instance. A map from a subdomain
(namespace) to entries map.
Corresponds to the JSON property partnerMetadata
21233 21234 21235 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21233 def @partner_metadata end |
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
Corresponds to the JSON property postKeyRevocationActionType
21238 21239 21240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21238 def post_key_revocation_action_type @post_key_revocation_action_type end |
#private_ipv6_google_access ⇒ String
The private IPv6 google access type for the VM.
If not specified, use INHERIT_FROM_SUBNETWORK as default.
Corresponds to the JSON property privateIpv6GoogleAccess
21244 21245 21246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21244 def private_ipv6_google_access @private_ipv6_google_access end |
#reservation_affinity ⇒ Google::Apis::ComputeBeta::ReservationAffinity
Specifies the reservations that this instance can consume from.
Corresponds to the JSON property reservationAffinity
21249 21250 21251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21249 def reservation_affinity @reservation_affinity end |
#resource_policies ⇒ Array<String>
Resource policies applied to this instance.
Corresponds to the JSON property resourcePolicies
21254 21255 21256 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21254 def resource_policies @resource_policies end |
#resource_status ⇒ Google::Apis::ComputeBeta::ResourceStatus
Contains output only fields.
Use this sub-message for actual values set on Instance attributes as compared
to the value requested by the user (intent) in their instance CRUD calls.
Corresponds to the JSON property resourceStatus
21261 21262 21263 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21261 def resource_status @resource_status end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
21266 21267 21268 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21266 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
21272 21273 21274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21272 def satisfies_pzs @satisfies_pzs end |
#scheduling ⇒ Google::Apis::ComputeBeta::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
21278 21279 21280 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21278 def scheduling @scheduling end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21283 21284 21285 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21283 def self_link @self_link end |
#service_accounts ⇒ Array<Google::Apis::ComputeBeta::ServiceAccount>
A list of service accounts, with their specified scopes, authorized for
this instance. Only one service account per VM instance is supported.
Service accounts generate access tokens that can be accessed
through the metadata server and used to authenticate applications on the
instance. SeeService Accounts
for more information.
Corresponds to the JSON property serviceAccounts
21293 21294 21295 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21293 def service_accounts @service_accounts end |
#shielded_instance_config ⇒ Google::Apis::ComputeBeta::ShieldedInstanceConfig
A set of Shielded Instance options.
Corresponds to the JSON property shieldedInstanceConfig
21298 21299 21300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21298 def shielded_instance_config @shielded_instance_config end |
#shielded_instance_integrity_policy ⇒ Google::Apis::ComputeBeta::ShieldedInstanceIntegrityPolicy
The policy describes the baseline against which
Instance boot integrity is measured.
Corresponds to the JSON property shieldedInstanceIntegrityPolicy
21304 21305 21306 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21304 def shielded_instance_integrity_policy @shielded_instance_integrity_policy end |
#shielded_vm_config ⇒ Google::Apis::ComputeBeta::ShieldedVmConfig
A set of Shielded VM options.
Corresponds to the JSON property shieldedVmConfig
21309 21310 21311 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21309 def shielded_vm_config @shielded_vm_config end |
#shielded_vm_integrity_policy ⇒ Google::Apis::ComputeBeta::ShieldedVmIntegrityPolicy
The policy describes the baseline against which
VM instance boot integrity is measured.
Corresponds to the JSON property shieldedVmIntegrityPolicy
21315 21316 21317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21315 def shielded_vm_integrity_policy @shielded_vm_integrity_policy end |
#source_machine_image ⇒ String
Source machine image
Corresponds to the JSON property sourceMachineImage
21320 21321 21322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21320 def source_machine_image @source_machine_image end |
#source_machine_image_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Source machine image encryption key when creating an instance from a
machine image.
Corresponds to the JSON property sourceMachineImageEncryptionKey
21326 21327 21328 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21326 def source_machine_image_encryption_key @source_machine_image_encryption_key end |
#start_restricted ⇒ Boolean Also known as: start_restricted?
Output only. [Output Only] Whether a VM has been restricted for start because
Compute
Engine has detected suspicious activity.
Corresponds to the JSON property startRestricted
21333 21334 21335 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21333 def start_restricted @start_restricted end |
#status ⇒ String
Output only. [Output Only] The status of the instance. One of the
following values: PROVISIONING, STAGING,RUNNING, STOPPING, SUSPENDING,
SUSPENDED, REPAIRING, andTERMINATED. For more information about the status of
the
instance, see
Instance life cycle.
Corresponds to the JSON property status
21344 21345 21346 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21344 def status @status end |
#status_message ⇒ String
Output only. [Output Only] An optional, human-readable explanation of the
status.
Corresponds to the JSON property statusMessage
21350 21351 21352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21350 def @status_message end |
#tags ⇒ Google::Apis::ComputeBeta::Tags
A set of instance tags.
Corresponds to the JSON property tags
21355 21356 21357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21355 def @tags end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the instance resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
21362 21363 21364 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21362 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21369 21370 21371 21372 21373 21374 21375 21376 21377 21378 21379 21380 21381 21382 21383 21384 21385 21386 21387 21388 21389 21390 21391 21392 21393 21394 21395 21396 21397 21398 21399 21400 21401 21402 21403 21404 21405 21406 21407 21408 21409 21410 21411 21412 21413 21414 21415 21416 21417 21418 21419 21420 21421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21369 def update!(**args) @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config) @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @display_device = args[:display_device] if args.key?(:display_device) @erase_windows_vss_signature = args[:erase_windows_vss_signature] if args.key?(:erase_windows_vss_signature) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @hostname = args[:hostname] if args.key?(:hostname) @id = args[:id] if args.key?(:id) @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key) @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @last_start_timestamp = args[:last_start_timestamp] if args.key?(:last_start_timestamp) @last_stop_timestamp = args[:last_stop_timestamp] if args.key?(:last_stop_timestamp) @last_suspended_timestamp = args[:last_suspended_timestamp] if args.key?(:last_suspended_timestamp) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @name = args[:name] if args.key?(:name) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config) @params = args[:params] if args.key?(:params) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @resource_status = args[:resource_status] if args.key?(:resource_status) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @scheduling = args[:scheduling] if args.key?(:scheduling) @self_link = args[:self_link] if args.key?(:self_link) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config) @shielded_instance_integrity_policy = args[:shielded_instance_integrity_policy] if args.key?(:shielded_instance_integrity_policy) @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config) @shielded_vm_integrity_policy = args[:shielded_vm_integrity_policy] if args.key?(:shielded_vm_integrity_policy) @source_machine_image = args[:source_machine_image] if args.key?(:source_machine_image) @source_machine_image_encryption_key = args[:source_machine_image_encryption_key] if args.key?(:source_machine_image_encryption_key) @start_restricted = args[:start_restricted] if args.key?(:start_restricted) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @tags = args[:tags] if args.key?(:tags) @zone = args[:zone] if args.key?(:zone) end |