Class: Google::Apis::ComputeBeta::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
23535 23536 23537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23535 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23496 23497 23498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23496 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
23501 23502 23503 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23501 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
23508 23509 23510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23508 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23518 23519 23520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23518 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23523 23524 23525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23523 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
23528 23529 23530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23528 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23533 23534 23535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23533 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23540 23541 23542 23543 23544 23545 23546 23547 23548 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23540 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |