Class: Google::Apis::ComputeBeta::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
23481 23482 23483 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23481 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
23442 23443 23444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23442 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
23447 23448 23449 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23447 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
23454 23455 23456 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23454 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
23464 23465 23466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23464 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
23469 23470 23471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23469 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
23474 23475 23476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23474 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
23479 23480 23481 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23479 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23486 23487 23488 23489 23490 23491 23492 23493 23494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23486 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |