Class: Google::Apis::ComputeBeta::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



23019
23020
23021
# File 'lib/google/apis/compute_beta/classes.rb', line 23019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22980
22981
22982
# File 'lib/google/apis/compute_beta/classes.rb', line 22980

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



22985
22986
22987
# File 'lib/google/apis/compute_beta/classes.rb', line 22985

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


22992
22993
22994
# File 'lib/google/apis/compute_beta/classes.rb', line 22992

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23002
23003
23004
# File 'lib/google/apis/compute_beta/classes.rb', line 23002

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23007
23008
23009
# File 'lib/google/apis/compute_beta/classes.rb', line 23007

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23012
23013
23014
# File 'lib/google/apis/compute_beta/classes.rb', line 23012

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



23017
23018
23019
# File 'lib/google/apis/compute_beta/classes.rb', line 23017

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23024
23025
23026
23027
23028
23029
23030
23031
23032
# File 'lib/google/apis/compute_beta/classes.rb', line 23024

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end