Class: Google::Apis::ComputeBeta::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



22995
22996
22997
# File 'lib/google/apis/compute_beta/classes.rb', line 22995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22956
22957
22958
# File 'lib/google/apis/compute_beta/classes.rb', line 22956

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



22961
22962
22963
# File 'lib/google/apis/compute_beta/classes.rb', line 22961

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


22968
22969
22970
# File 'lib/google/apis/compute_beta/classes.rb', line 22968

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22978
22979
22980
# File 'lib/google/apis/compute_beta/classes.rb', line 22978

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22983
22984
22985
# File 'lib/google/apis/compute_beta/classes.rb', line 22983

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22988
22989
22990
# File 'lib/google/apis/compute_beta/classes.rb', line 22988

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22993
22994
22995
# File 'lib/google/apis/compute_beta/classes.rb', line 22993

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23000
23001
23002
23003
23004
23005
23006
23007
23008
# File 'lib/google/apis/compute_beta/classes.rb', line 23000

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end