Class: Google::Apis::ComputeBeta::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



22411
22412
22413
# File 'lib/google/apis/compute_beta/classes.rb', line 22411

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22372
22373
22374
# File 'lib/google/apis/compute_beta/classes.rb', line 22372

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



22377
22378
22379
# File 'lib/google/apis/compute_beta/classes.rb', line 22377

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


22384
22385
22386
# File 'lib/google/apis/compute_beta/classes.rb', line 22384

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22394
22395
22396
# File 'lib/google/apis/compute_beta/classes.rb', line 22394

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22399
22400
22401
# File 'lib/google/apis/compute_beta/classes.rb', line 22399

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22404
22405
22406
# File 'lib/google/apis/compute_beta/classes.rb', line 22404

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



22409
22410
22411
# File 'lib/google/apis/compute_beta/classes.rb', line 22409

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22416
22417
22418
22419
22420
22421
22422
22423
22424
# File 'lib/google/apis/compute_beta/classes.rb', line 22416

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end