Class: Google::Apis::ComputeBeta::InstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
An object that contains a list of instances scoped by zone.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceAggregatedList
constructor
A new instance of InstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceAggregatedList
Returns a new instance of InstanceAggregatedList.
21796 21797 21798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21796 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
21757 21758 21759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21757 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstancesScopedList>
An object that contains a list of instances scoped by zone.
Corresponds to the JSON property items
21762 21763 21764 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21762 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceAggregatedList for aggregated lists of
Instance resources.
Corresponds to the JSON property kind
21769 21770 21771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21769 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
21779 21780 21781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21779 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
21784 21785 21786 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21784 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
21789 21790 21791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21789 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
21794 21795 21796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21794 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
21801 21802 21803 21804 21805 21806 21807 21808 21809 |
# File 'lib/google/apis/compute_beta/classes.rb', line 21801 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |