Class: Google::Apis::ComputeBeta::InstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceAggregatedList

Returns a new instance of InstanceAggregatedList.



21470
21471
21472
# File 'lib/google/apis/compute_beta/classes.rb', line 21470

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


21431
21432
21433
# File 'lib/google/apis/compute_beta/classes.rb', line 21431

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstancesScopedList>

An object that contains a list of instances scoped by zone. Corresponds to the JSON property items



21436
21437
21438
# File 'lib/google/apis/compute_beta/classes.rb', line 21436

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceAggregatedList for aggregated lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


21443
21444
21445
# File 'lib/google/apis/compute_beta/classes.rb', line 21443

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


21453
21454
21455
# File 'lib/google/apis/compute_beta/classes.rb', line 21453

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


21458
21459
21460
# File 'lib/google/apis/compute_beta/classes.rb', line 21458

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


21463
21464
21465
# File 'lib/google/apis/compute_beta/classes.rb', line 21463

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



21468
21469
21470
# File 'lib/google/apis/compute_beta/classes.rb', line 21468

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



21475
21476
21477
21478
21479
21480
21481
21482
21483
# File 'lib/google/apis/compute_beta/classes.rb', line 21475

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end