Class: Google::Apis::ComputeBeta::InstanceFlexibilityPolicyInstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceFlexibilityPolicyInstanceSelection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specification of machine type to use. Every position inside this message is an alternative. The count specified in the shape flexibility must not exceed the number of entries in per_instance_properties or the capacity of the name_pattern, if used.
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
Disks to be attached to the instances created from in this selection.
-
#machine_types ⇒ Array<String>
Alternative machine types to use for instances that are created from these properties.
-
#rank ⇒ Fixnum
Rank when prioritizing the shape flexibilities.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceFlexibilityPolicyInstanceSelection
constructor
A new instance of InstanceFlexibilityPolicyInstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceFlexibilityPolicyInstanceSelection
Returns a new instance of InstanceFlexibilityPolicyInstanceSelection.
23710 23711 23712 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23710 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
Disks to be attached to the instances created from in this selection.
They override the disks specified in the instance properties.
Corresponds to the JSON property disks
23693 23694 23695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23693 def disks @disks end |
#machine_types ⇒ Array<String>
Alternative machine types to use for instances that are created from
these properties. This field only accepts a machine type names, for
example n2-standard-4 and not URLs or partial URLs.
Corresponds to the JSON property machineTypes
23700 23701 23702 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23700 def machine_types @machine_types end |
#rank ⇒ Fixnum
Rank when prioritizing the shape flexibilities.
The instance selections with rank are considered
first, in the ascending order of the rank.
If not set, defaults to 0.
Corresponds to the JSON property rank
23708 23709 23710 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23708 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23715 23716 23717 23718 23719 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23715 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_types = args[:machine_types] if args.key?(:machine_types) @rank = args[:rank] if args.key?(:rank) end |