Class: Google::Apis::ComputeBeta::InstanceGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an Instance Group resource. Instance Groups can be used to configure a target forload balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager orregionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to applyload balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, readInstance groups.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
Optional.
-
#network ⇒ String
[Output Only] The URL of the network to which all instances in the instance group belong.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#size ⇒ Fixnum
Output only.
-
#subnetwork ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroup
constructor
A new instance of InstanceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroup
Returns a new instance of InstanceGroup.
23913 23914 23915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this instance group
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
23825 23826 23827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23825 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
23831 23832 23833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23831 def description @description end |
#fingerprint ⇒ String
Output only. [Output Only] The fingerprint of the named ports. The system
uses this fingerprint to detect conflicts when multiple users change the
named ports concurrently.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
23839 23840 23841 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23839 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this instance group,
generated
by the server.
Corresponds to the JSON property id
23846 23847 23848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23846 def id @id end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroup for instance groups.
Corresponds to the JSON property kind
23852 23853 23854 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23852 def kind @kind end |
#name ⇒ String
The name of the instance group. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
23858 23859 23860 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23858 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
Optional. Assigns a name to a port number. For example:name: "http", port: 80
This
allows the system to reference ports by the assigned name instead of a
port number. Named ports can also contain multiple ports. For example:[name: "
app1", port: 8080, name:
"app1", port: 8081, name: "app2", port:
8082]
Named ports apply to all instances in this instance group.
Corresponds to the JSON property namedPorts
23870 23871 23872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23870 def named_ports @named_ports end |
#network ⇒ String
[Output Only] The URL of the network to which all instances in the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Corresponds to the JSON property network
23878 23879 23880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23878 def network @network end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the instance group is located (for regional resources).
Corresponds to the JSON property region
23884 23885 23886 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23884 def region @region end |
#self_link ⇒ String
Output only. [Output Only] The URL for this instance group. The server
generates
this URL.
Corresponds to the JSON property selfLink
23891 23892 23893 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23891 def self_link @self_link end |
#size ⇒ Fixnum
Output only. [Output Only] The total number of instances in the instance group.
Corresponds to the JSON property size
23896 23897 23898 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23896 def size @size end |
#subnetwork ⇒ String
Output only. [Output Only] The URL of the subnetwork to which all instances in
the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Corresponds to the JSON property subnetwork
23905 23906 23907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23905 def subnetwork @subnetwork end |
#zone ⇒ String
Output only. [Output Only] The URL of thezone
where the instance group is located (for zonal resources).
Corresponds to the JSON property zone
23911 23912 23913 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23911 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23918 23919 23920 23921 23922 23923 23924 23925 23926 23927 23928 23929 23930 23931 23932 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23918 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |