Class: Google::Apis::ComputeBeta::InstanceGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an Instance Group resource. Instance Groups can be used to configure a target forload balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager orregionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to applyload balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, readInstance groups.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
Optional.
-
#network ⇒ String
[Output Only] The URL of the network to which all instances in the instance group belong.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#size ⇒ Fixnum
Output only.
-
#subnetwork ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroup
constructor
A new instance of InstanceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroup
Returns a new instance of InstanceGroup.
23323 23324 23325 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23323 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this instance group
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
23235 23236 23237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23235 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
23241 23242 23243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23241 def description @description end |
#fingerprint ⇒ String
Output only. [Output Only] The fingerprint of the named ports. The system
uses this fingerprint to detect conflicts when multiple users change the
named ports concurrently.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
23249 23250 23251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23249 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this instance group,
generated
by the server.
Corresponds to the JSON property id
23256 23257 23258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23256 def id @id end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroup for instance groups.
Corresponds to the JSON property kind
23262 23263 23264 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23262 def kind @kind end |
#name ⇒ String
The name of the instance group. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
23268 23269 23270 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23268 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
Optional. Assigns a name to a port number. For example:name: "http", port: 80
This
allows the system to reference ports by the assigned name instead of a
port number. Named ports can also contain multiple ports. For example:[name: "
app1", port: 8080, name:
"app1", port: 8081, name: "app2", port:
8082]
Named ports apply to all instances in this instance group.
Corresponds to the JSON property namedPorts
23280 23281 23282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23280 def named_ports @named_ports end |
#network ⇒ String
[Output Only] The URL of the network to which all instances in the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Corresponds to the JSON property network
23288 23289 23290 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23288 def network @network end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the instance group is located (for regional resources).
Corresponds to the JSON property region
23294 23295 23296 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23294 def region @region end |
#self_link ⇒ String
Output only. [Output Only] The URL for this instance group. The server
generates
this URL.
Corresponds to the JSON property selfLink
23301 23302 23303 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23301 def self_link @self_link end |
#size ⇒ Fixnum
Output only. [Output Only] The total number of instances in the instance group.
Corresponds to the JSON property size
23306 23307 23308 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23306 def size @size end |
#subnetwork ⇒ String
Output only. [Output Only] The URL of the subnetwork to which all instances in
the
instance group belong. If your instance has multiple network interfaces,
then the network and subnetwork fields only refer to the
network and subnet used by your primary interface (nic0).
Corresponds to the JSON property subnetwork
23315 23316 23317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23315 def subnetwork @subnetwork end |
#zone ⇒ String
Output only. [Output Only] The URL of thezone
where the instance group is located (for zonal resources).
Corresponds to the JSON property zone
23321 23322 23323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23321 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23328 23329 23330 23331 23332 23333 23334 23335 23336 23337 23338 23339 23340 23341 23342 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23328 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @network = args[:network] if args.key?(:network) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |