Class: Google::Apis::ComputeBeta::InstanceGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Instance Group resource. Instance Groups can be used to configure a target forload balancing. Instance groups can either be managed or unmanaged. To create managed instance groups, use the instanceGroupManager orregionInstanceGroupManager resource instead. Use zonal unmanaged instance groups if you need to applyload balancing to groups of heterogeneous instances or if you need to manage the instances yourself. You cannot create regional unmanaged instance groups. For more information, readInstance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroup

Returns a new instance of InstanceGroup.



22739
22740
22741
# File 'lib/google/apis/compute_beta/classes.rb', line 22739

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] The creation timestamp for this instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


22651
22652
22653
# File 'lib/google/apis/compute_beta/classes.rb', line 22651

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


22657
22658
22659
# File 'lib/google/apis/compute_beta/classes.rb', line 22657

def description
  @description
end

#fingerprintString

Output only. [Output Only] The fingerprint of the named ports. The system uses this fingerprint to detect conflicts when multiple users change the named ports concurrently. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22665
22666
22667
# File 'lib/google/apis/compute_beta/classes.rb', line 22665

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] A unique identifier for this instance group, generated by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22672
22673
22674
# File 'lib/google/apis/compute_beta/classes.rb', line 22672

def id
  @id
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroup for instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22678
22679
22680
# File 'lib/google/apis/compute_beta/classes.rb', line 22678

def kind
  @kind
end

#nameString

The name of the instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


22684
22685
22686
# File 'lib/google/apis/compute_beta/classes.rb', line 22684

def name
  @name
end

#named_portsArray<Google::Apis::ComputeBeta::NamedPort>

Optional. Assigns a name to a port number. For example:name: "http", port: 80 This allows the system to reference ports by the assigned name instead of a port number. Named ports can also contain multiple ports. For example:[name: " app1", port: 8080, name: "app1", port: 8081, name: "app2", port: 8082] Named ports apply to all instances in this instance group. Corresponds to the JSON property namedPorts



22696
22697
22698
# File 'lib/google/apis/compute_beta/classes.rb', line 22696

def named_ports
  @named_ports
end

#networkString

[Output Only] The URL of the network to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0). Corresponds to the JSON property network

Returns:

  • (String)


22704
22705
22706
# File 'lib/google/apis/compute_beta/classes.rb', line 22704

def network
  @network
end

#regionString

Output only. [Output Only] The URL of theregion where the instance group is located (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


22710
22711
22712
# File 'lib/google/apis/compute_beta/classes.rb', line 22710

def region
  @region
end

Output only. [Output Only] The URL for this instance group. The server generates this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


22717
22718
22719
# File 'lib/google/apis/compute_beta/classes.rb', line 22717

def self_link
  @self_link
end

#sizeFixnum

Output only. [Output Only] The total number of instances in the instance group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


22722
22723
22724
# File 'lib/google/apis/compute_beta/classes.rb', line 22722

def size
  @size
end

#subnetworkString

Output only. [Output Only] The URL of the subnetwork to which all instances in the instance group belong. If your instance has multiple network interfaces, then the network and subnetwork fields only refer to the network and subnet used by your primary interface (nic0). Corresponds to the JSON property subnetwork

Returns:

  • (String)


22731
22732
22733
# File 'lib/google/apis/compute_beta/classes.rb', line 22731

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


22737
22738
22739
# File 'lib/google/apis/compute_beta/classes.rb', line 22737

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22744
22745
22746
22747
22748
22749
22750
22751
22752
22753
22754
22755
22756
22757
22758
# File 'lib/google/apis/compute_beta/classes.rb', line 22744

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @network = args[:network] if args.key?(:network)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @size = args[:size] if args.key?(:size)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end