Class: Google::Apis::ComputeBeta::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



23983
23984
23985
# File 'lib/google/apis/compute_beta/classes.rb', line 23983

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23943
23944
23945
# File 'lib/google/apis/compute_beta/classes.rb', line 23943

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



23948
23949
23950
# File 'lib/google/apis/compute_beta/classes.rb', line 23948

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


23955
23956
23957
# File 'lib/google/apis/compute_beta/classes.rb', line 23955

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23966
23967
23968
# File 'lib/google/apis/compute_beta/classes.rb', line 23966

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23971
23972
23973
# File 'lib/google/apis/compute_beta/classes.rb', line 23971

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23976
23977
23978
# File 'lib/google/apis/compute_beta/classes.rb', line 23976

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



23981
23982
23983
# File 'lib/google/apis/compute_beta/classes.rb', line 23981

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23988
23989
23990
23991
23992
23993
23994
23995
23996
# File 'lib/google/apis/compute_beta/classes.rb', line 23988

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end