Class: Google::Apis::ComputeBeta::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



23933
23934
23935
# File 'lib/google/apis/compute_beta/classes.rb', line 23933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23893
23894
23895
# File 'lib/google/apis/compute_beta/classes.rb', line 23893

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



23898
23899
23900
# File 'lib/google/apis/compute_beta/classes.rb', line 23898

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


23905
23906
23907
# File 'lib/google/apis/compute_beta/classes.rb', line 23905

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23916
23917
23918
# File 'lib/google/apis/compute_beta/classes.rb', line 23916

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23921
23922
23923
# File 'lib/google/apis/compute_beta/classes.rb', line 23921

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23926
23927
23928
# File 'lib/google/apis/compute_beta/classes.rb', line 23926

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



23931
23932
23933
# File 'lib/google/apis/compute_beta/classes.rb', line 23931

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23938
23939
23940
23941
23942
23943
23944
23945
23946
# File 'lib/google/apis/compute_beta/classes.rb', line 23938

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end