Class: Google::Apis::ComputeBeta::InstanceGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupAggregatedList

Returns a new instance of InstanceGroupAggregatedList.



22809
22810
22811
# File 'lib/google/apis/compute_beta/classes.rb', line 22809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22769
22770
22771
# File 'lib/google/apis/compute_beta/classes.rb', line 22769

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupsScopedList>

A list of InstanceGroupsScopedList resources. Corresponds to the JSON property items



22774
22775
22776
# File 'lib/google/apis/compute_beta/classes.rb', line 22774

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupAggregatedList for aggregated lists of instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22781
22782
22783
# File 'lib/google/apis/compute_beta/classes.rb', line 22781

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22792
22793
22794
# File 'lib/google/apis/compute_beta/classes.rb', line 22792

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22797
22798
22799
# File 'lib/google/apis/compute_beta/classes.rb', line 22797

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22802
22803
22804
# File 'lib/google/apis/compute_beta/classes.rb', line 22802

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22807
22808
22809
# File 'lib/google/apis/compute_beta/classes.rb', line 22807

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22814
22815
22816
22817
22818
22819
22820
22821
22822
# File 'lib/google/apis/compute_beta/classes.rb', line 22814

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end