Class: Google::Apis::ComputeBeta::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



24007
24008
24009
# File 'lib/google/apis/compute_beta/classes.rb', line 24007

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23973
23974
23975
# File 'lib/google/apis/compute_beta/classes.rb', line 23973

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



23978
23979
23980
# File 'lib/google/apis/compute_beta/classes.rb', line 23978

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


23984
23985
23986
# File 'lib/google/apis/compute_beta/classes.rb', line 23984

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23995
23996
23997
# File 'lib/google/apis/compute_beta/classes.rb', line 23995

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24000
24001
24002
# File 'lib/google/apis/compute_beta/classes.rb', line 24000

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



24005
24006
24007
# File 'lib/google/apis/compute_beta/classes.rb', line 24005

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24012
24013
24014
24015
24016
24017
24018
24019
# File 'lib/google/apis/compute_beta/classes.rb', line 24012

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end