Class: Google::Apis::ComputeBeta::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



22937
22938
22939
# File 'lib/google/apis/compute_beta/classes.rb', line 22937

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22903
22904
22905
# File 'lib/google/apis/compute_beta/classes.rb', line 22903

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



22908
22909
22910
# File 'lib/google/apis/compute_beta/classes.rb', line 22908

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


22914
22915
22916
# File 'lib/google/apis/compute_beta/classes.rb', line 22914

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22925
22926
22927
# File 'lib/google/apis/compute_beta/classes.rb', line 22925

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22930
22931
22932
# File 'lib/google/apis/compute_beta/classes.rb', line 22930

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22935
22936
22937
# File 'lib/google/apis/compute_beta/classes.rb', line 22935

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22942
22943
22944
22945
22946
22947
22948
22949
# File 'lib/google/apis/compute_beta/classes.rb', line 22942

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end