Class: Google::Apis::ComputeBeta::InstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupList

Returns a new instance of InstanceGroupList.



22322
22323
22324
# File 'lib/google/apis/compute_beta/classes.rb', line 22322

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22288
22289
22290
# File 'lib/google/apis/compute_beta/classes.rb', line 22288

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



22293
22294
22295
# File 'lib/google/apis/compute_beta/classes.rb', line 22293

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupList for instance group lists. Corresponds to the JSON property kind

Returns:

  • (String)


22299
22300
22301
# File 'lib/google/apis/compute_beta/classes.rb', line 22299

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22310
22311
22312
# File 'lib/google/apis/compute_beta/classes.rb', line 22310

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22315
22316
22317
# File 'lib/google/apis/compute_beta/classes.rb', line 22315

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22320
22321
22322
# File 'lib/google/apis/compute_beta/classes.rb', line 22320

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22327
22328
22329
22330
22331
22332
22333
22334
# File 'lib/google/apis/compute_beta/classes.rb', line 22327

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end