Class: Google::Apis::ComputeBeta::InstanceGroupManager

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManager

Returns a new instance of InstanceGroupManager.



22679
22680
22681
# File 'lib/google/apis/compute_beta/classes.rb', line 22679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::InstanceGroupManagerAllInstancesConfig

Specifies configuration that overrides the instance template configuration for the group. Corresponds to the JSON property allInstancesConfig



22421
22422
22423
# File 'lib/google/apis/compute_beta/classes.rb', line 22421

def all_instances_config
  @all_instances_config
end

#auto_healing_policiesArray<Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy>

The autohealing policy for this managed instance group. You can specify only one value. Corresponds to the JSON property autoHealingPolicies



22427
22428
22429
# File 'lib/google/apis/compute_beta/classes.rb', line 22427

def auto_healing_policies
  @auto_healing_policies
end

#base_instance_nameString

The base instance name is a prefix that you want to attach to the names of all VMs in a MIG. The maximum character length is 58 and the name must comply with RFC1035 format. When a VM is created in the group, the MIG appends a hyphen and a random four-character string to the base instance name. If you want the MIG to assign sequential numbers instead of a random string, then end the base instance name with a hyphen followed by one or more hash symbols. The hash symbols indicate the number of digits. For example, a base instance name of "vm-###" results in "vm-001" as a VM name. a-z Corresponds to the JSON property baseInstanceName

Returns:

  • (String)


22442
22443
22444
# File 'lib/google/apis/compute_beta/classes.rb', line 22442

def base_instance_name
  @base_instance_name
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this managed instance group inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


22449
22450
22451
# File 'lib/google/apis/compute_beta/classes.rb', line 22449

def creation_timestamp
  @creation_timestamp
end

#current_actionsGoogle::Apis::ComputeBeta::InstanceGroupManagerActionsSummary

Output only. [Output Only] The list of instance actions and the number of instances in this managed instance group that are scheduled for each of those actions. Corresponds to the JSON property currentActions



22457
22458
22459
# File 'lib/google/apis/compute_beta/classes.rb', line 22457

def current_actions
  @current_actions
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


22462
22463
22464
# File 'lib/google/apis/compute_beta/classes.rb', line 22462

def description
  @description
end

#distribution_policyGoogle::Apis::ComputeBeta::DistributionPolicy

Policy specifying the intended distribution of managed instances across zones in a regional managed instance group. Corresponds to the JSON property distributionPolicy



22468
22469
22470
# File 'lib/google/apis/compute_beta/classes.rb', line 22468

def distribution_policy
  @distribution_policy
end

#failover_actionString

The action to perform in case of zone failure. Only one value is supported, NO_FAILOVER. The default is NO_FAILOVER. Corresponds to the JSON property failoverAction

Returns:

  • (String)


22474
22475
22476
# File 'lib/google/apis/compute_beta/classes.rb', line 22474

def failover_action
  @failover_action
end

#fingerprintString

Fingerprint of this resource. This field may be used in optimistic locking. It will be ignored when inserting an InstanceGroupManager. An up-to-date fingerprint must be provided in order to update the InstanceGroupManager, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InstanceGroupManager. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


22485
22486
22487
# File 'lib/google/apis/compute_beta/classes.rb', line 22485

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


22492
22493
22494
# File 'lib/google/apis/compute_beta/classes.rb', line 22492

def id
  @id
end

#instance_flexibility_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicy

Instance flexibility allowing MIG to create VMs from multiple types of machines. Instance flexibility configuration on MIG overrides instance template configuration. Corresponds to the JSON property instanceFlexibilityPolicy



22500
22501
22502
# File 'lib/google/apis/compute_beta/classes.rb', line 22500

def instance_flexibility_policy
  @instance_flexibility_policy
end

#instance_groupString

Output only. [Output Only] The URL of the Instance Group resource. Corresponds to the JSON property instanceGroup

Returns:

  • (String)


22505
22506
22507
# File 'lib/google/apis/compute_beta/classes.rb', line 22505

def instance_group
  @instance_group
end

#instance_lifecycle_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerInstanceLifecyclePolicy

The repair policy for this managed instance group. Corresponds to the JSON property instanceLifecyclePolicy



22510
22511
22512
# File 'lib/google/apis/compute_beta/classes.rb', line 22510

def instance_lifecycle_policy
  @instance_lifecycle_policy
end

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


22519
22520
22521
# File 'lib/google/apis/compute_beta/classes.rb', line 22519

def instance_template
  @instance_template
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManager for managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22525
22526
22527
# File 'lib/google/apis/compute_beta/classes.rb', line 22525

def kind
  @kind
end

#list_managed_instances_resultsString

Pagination behavior of the listManagedInstances API method for this managed instance group. Corresponds to the JSON property listManagedInstancesResults

Returns:

  • (String)


22531
22532
22533
# File 'lib/google/apis/compute_beta/classes.rb', line 22531

def list_managed_instances_results
  @list_managed_instances_results
end

#multi_migString

URL to the multi-MIG that this Managed Instance Group belongs to. Corresponds to the JSON property multiMig

Returns:

  • (String)


22536
22537
22538
# File 'lib/google/apis/compute_beta/classes.rb', line 22536

def multi_mig
  @multi_mig
end

#nameString

The name of the managed instance group. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


22542
22543
22544
# File 'lib/google/apis/compute_beta/classes.rb', line 22542

def name
  @name
end

#named_portsArray<Google::Apis::ComputeBeta::NamedPort>

[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager. Corresponds to the JSON property namedPorts



22548
22549
22550
# File 'lib/google/apis/compute_beta/classes.rb', line 22548

def named_ports
  @named_ports
end

#paramsGoogle::Apis::ComputeBeta::InstanceGroupManagerParams

Input only additional params for instance group manager creation. Corresponds to the JSON property params



22553
22554
22555
# File 'lib/google/apis/compute_beta/classes.rb', line 22553

def params
  @params
end

#regionString

Output only. [Output Only] The URL of theregion where the managed instance group resides (for regional resources). Corresponds to the JSON property region

Returns:

  • (String)


22559
22560
22561
# File 'lib/google/apis/compute_beta/classes.rb', line 22559

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeBeta::InstanceGroupManagerResourcePolicies

Resource policies for this managed instance group. Corresponds to the JSON property resourcePolicies



22564
22565
22566
# File 'lib/google/apis/compute_beta/classes.rb', line 22564

def resource_policies
  @resource_policies
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


22569
22570
22571
# File 'lib/google/apis/compute_beta/classes.rb', line 22569

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


22575
22576
22577
# File 'lib/google/apis/compute_beta/classes.rb', line 22575

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] The URL for this managed instance group. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


22583
22584
22585
# File 'lib/google/apis/compute_beta/classes.rb', line 22583

def self_link
  @self_link
end

#service_accountString

The service account to be used as credentials for all operations performed by the managed instance group on instances. The service accounts needs all permissions required to create and delete instances. By default, the service account projectNumber@cloudservices.gserviceaccount.com is used. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


22592
22593
22594
# File 'lib/google/apis/compute_beta/classes.rb', line 22592

def 
  @service_account
end

#standby_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy

Standby policy for stopped and suspended instances. Corresponds to the JSON property standbyPolicy



22597
22598
22599
# File 'lib/google/apis/compute_beta/classes.rb', line 22597

def standby_policy
  @standby_policy
end

#stateful_policyGoogle::Apis::ComputeBeta::StatefulPolicy

Stateful configuration for this Instanced Group Manager Corresponds to the JSON property statefulPolicy



22602
22603
22604
# File 'lib/google/apis/compute_beta/classes.rb', line 22602

def stateful_policy
  @stateful_policy
end

#statusGoogle::Apis::ComputeBeta::InstanceGroupManagerStatus

Output only. [Output Only] The status of this managed instance group. Corresponds to the JSON property status



22607
22608
22609
# File 'lib/google/apis/compute_beta/classes.rb', line 22607

def status
  @status
end

#target_poolsArray<String>

The URLs for all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


22614
22615
22616
# File 'lib/google/apis/compute_beta/classes.rb', line 22614

def target_pools
  @target_pools
end

#target_sizeFixnum

The target number of running instances for this managed instance group. You can reduce this number by using the instanceGroupManager deleteInstances or abandonInstances methods. Resizing the group also changes this number. Corresponds to the JSON property targetSize

Returns:

  • (Fixnum)


22622
22623
22624
# File 'lib/google/apis/compute_beta/classes.rb', line 22622

def target_size
  @target_size
end

#target_size_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerTargetSizePolicy

The policy that specifies how the MIG creates its VMs to achieve the target size. Corresponds to the JSON property targetSizePolicy



22628
22629
22630
# File 'lib/google/apis/compute_beta/classes.rb', line 22628

def target_size_policy
  @target_size_policy
end

#target_stopped_sizeFixnum

The target number of stopped instances for this managed instance group. This number changes when you:

  • Stop instance using the stopInstances method or start instances using the startInstances method.
  • Manually change the targetStoppedSize using the update method. Corresponds to the JSON property targetStoppedSize

Returns:

  • (Fixnum)


22640
22641
22642
# File 'lib/google/apis/compute_beta/classes.rb', line 22640

def target_stopped_size
  @target_stopped_size
end

#target_suspended_sizeFixnum

The target number of suspended instances for this managed instance group. This number changes when you:

  • Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
  • Manually change the targetSuspendedSize using the update method. Corresponds to the JSON property targetSuspendedSize

Returns:

  • (Fixnum)


22652
22653
22654
# File 'lib/google/apis/compute_beta/classes.rb', line 22652

def target_suspended_size
  @target_suspended_size
end

#update_policyGoogle::Apis::ComputeBeta::InstanceGroupManagerUpdatePolicy

The update policy for this managed instance group. Corresponds to the JSON property updatePolicy



22657
22658
22659
# File 'lib/google/apis/compute_beta/classes.rb', line 22657

def update_policy
  @update_policy
end

#versionsArray<Google::Apis::ComputeBeta::InstanceGroupManagerVersion>

Specifies the instance templates used by this managed instance group to create instances. Each version is defined by an instanceTemplate and aname. Every version can appear at most once per instance group. This field overrides the top-level instanceTemplate field. Read more about therelationships between these fields. Exactly one version must leave thetargetSize field unset. That version will be applied to all remaining instances. For more information, read aboutcanary updates. Corresponds to the JSON property versions



22671
22672
22673
# File 'lib/google/apis/compute_beta/classes.rb', line 22671

def versions
  @versions
end

#zoneString

Output only. [Output Only] The URL of azone where the managed instance group is located (for zonal resources). Corresponds to the JSON property zone

Returns:

  • (String)


22677
22678
22679
# File 'lib/google/apis/compute_beta/classes.rb', line 22677

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22684
22685
22686
22687
22688
22689
22690
22691
22692
22693
22694
22695
22696
22697
22698
22699
22700
22701
22702
22703
22704
22705
22706
22707
22708
22709
22710
22711
22712
22713
22714
22715
22716
22717
22718
22719
22720
22721
22722
# File 'lib/google/apis/compute_beta/classes.rb', line 22684

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies)
  @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_actions = args[:current_actions] if args.key?(:current_actions)
  @description = args[:description] if args.key?(:description)
  @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy)
  @failover_action = args[:failover_action] if args.key?(:failover_action)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy)
  @instance_group = args[:instance_group] if args.key?(:instance_group)
  @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @kind = args[:kind] if args.key?(:kind)
  @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results)
  @multi_mig = args[:multi_mig] if args.key?(:multi_mig)
  @name = args[:name] if args.key?(:name)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service_account = args[:service_account] if args.key?(:service_account)
  @standby_policy = args[:standby_policy] if args.key?(:standby_policy)
  @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy)
  @status = args[:status] if args.key?(:status)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
  @target_size = args[:target_size] if args.key?(:target_size)
  @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy)
  @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size)
  @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size)
  @update_policy = args[:update_policy] if args.key?(:update_policy)
  @versions = args[:versions] if args.key?(:versions)
  @zone = args[:zone] if args.key?(:zone)
end