Class: Google::Apis::ComputeBeta::InstanceGroupManager
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManager
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Managed Instance Group resource. An instance group is a collection of VM instances that you can manage as a single entity. For more information, readInstance groups. For zonal Managed Instance Group, use the instanceGroupManagers resource. For regional Managed Instance Group, use theregionInstanceGroupManagers resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration for the group.
-
#auto_healing_policies ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group.
-
#base_instance_name ⇒ String
The base instance name is a prefix that you want to attach to the names of all VMs in a MIG.
-
#creation_timestamp ⇒ String
Output only.
-
#current_actions ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#distribution_policy ⇒ Google::Apis::ComputeBeta::DistributionPolicy
Policy specifying the intended distribution of managed instances across zones in a regional managed instance group.
-
#failover_action ⇒ String
The action to perform in case of zone failure.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instance_flexibility_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple types of machines.
-
#instance_group ⇒ String
Output only.
-
#instance_lifecycle_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
-
#kind ⇒ String
Output only.
-
#list_managed_instances_results ⇒ String
Pagination behavior of the listManagedInstances API method for this managed instance group.
-
#multi_mig ⇒ String
URL to the multi-MIG that this Managed Instance Group belongs to.
-
#name ⇒ String
The name of the managed instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary to this Instance Group Manager.
-
#params ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerParams
Input only additional params for instance group manager creation.
-
#region ⇒ String
Output only.
-
#resource_policies ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
-
#satisfies_pzi ⇒ Boolean
(also: #satisfies_pzi?)
Output only.
-
#satisfies_pzs ⇒ Boolean
(also: #satisfies_pzs?)
Output only.
-
#self_link ⇒ String
Output only.
-
#service_account ⇒ String
The service account to be used as credentials for all operations performed by the managed instance group on instances.
-
#standby_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
-
#stateful_policy ⇒ Google::Apis::ComputeBeta::StatefulPolicy
Stateful configuration for this Instanced Group Manager Corresponds to the JSON property
statefulPolicy. -
#status ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatus
Output only.
-
#target_pools ⇒ Array<String>
The URLs for all TargetPool resources to which instances in theinstanceGroup field are added.
-
#target_size ⇒ Fixnum
The target number of running instances for this managed instance group.
-
#target_size_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target size.
-
#target_stopped_size ⇒ Fixnum
The target number of stopped instances for this managed instance group.
-
#target_suspended_size ⇒ Fixnum
The target number of suspended instances for this managed instance group.
-
#update_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
-
#versions ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to create instances.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManager
constructor
A new instance of InstanceGroupManager.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManager
Returns a new instance of InstanceGroupManager.
22283 22284 22285 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerAllInstancesConfig
Specifies configuration that overrides the instance template configuration
for the group.
Corresponds to the JSON property allInstancesConfig
22025 22026 22027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22025 def all_instances_config @all_instances_config end |
#auto_healing_policies ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerAutoHealingPolicy>
The autohealing policy for this managed instance group. You can specify
only one value.
Corresponds to the JSON property autoHealingPolicies
22031 22032 22033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22031 def auto_healing_policies @auto_healing_policies end |
#base_instance_name ⇒ String
The base instance name is a prefix that you want to attach to the names of
all VMs in a MIG. The maximum character length is 58 and the name must
comply with RFC1035 format.
When a VM is created in the group, the MIG appends a hyphen and a random
four-character string to the base instance name. If you want the MIG to
assign sequential numbers instead of a random string, then end the base
instance name with a hyphen followed by one or more hash symbols. The hash
symbols indicate the number of digits. For example, a base instance name of
"vm-###" results in "vm-001" as a VM name.
a-z
Corresponds to the JSON property baseInstanceName
22046 22047 22048 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22046 def base_instance_name @base_instance_name end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this managed instance
group inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
22053 22054 22055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22053 def @creation_timestamp end |
#current_actions ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary
Output only. [Output Only] The list of instance actions and the number of
instances
in this managed instance group that are scheduled for each of those
actions.
Corresponds to the JSON property currentActions
22061 22062 22063 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22061 def current_actions @current_actions end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
22066 22067 22068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22066 def description @description end |
#distribution_policy ⇒ Google::Apis::ComputeBeta::DistributionPolicy
Policy specifying the intended distribution of managed instances across
zones in a regional managed instance group.
Corresponds to the JSON property distributionPolicy
22072 22073 22074 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22072 def distribution_policy @distribution_policy end |
#failover_action ⇒ String
The action to perform in case of zone failure. Only one value is supported,
NO_FAILOVER. The default is NO_FAILOVER.
Corresponds to the JSON property failoverAction
22078 22079 22080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22078 def failover_action @failover_action end |
#fingerprint ⇒ String
Fingerprint of this resource. This field may be used in optimistic locking.
It will be ignored when inserting an InstanceGroupManager. An up-to-date
fingerprint must be provided in order to update the InstanceGroupManager,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an InstanceGroupManager.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
22089 22090 22091 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22089 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
22096 22097 22098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22096 def id @id end |
#instance_flexibility_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicy
Instance flexibility allowing MIG to create VMs from multiple
types of machines.
Instance flexibility configuration on MIG overrides instance
template configuration.
Corresponds to the JSON property instanceFlexibilityPolicy
22104 22105 22106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22104 def instance_flexibility_policy @instance_flexibility_policy end |
#instance_group ⇒ String
Output only. [Output Only] The URL of the Instance Group resource.
Corresponds to the JSON property instanceGroup
22109 22110 22111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22109 def instance_group @instance_group end |
#instance_lifecycle_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerInstanceLifecyclePolicy
The repair policy for this managed instance group.
Corresponds to the JSON property instanceLifecyclePolicy
22114 22115 22116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22114 def instance_lifecycle_policy @instance_lifecycle_policy end |
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create all new instances
in the managed instance group. The templates for existing instances in the
group do not change unless you run recreateInstances,
runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
Corresponds to the JSON property instanceTemplate
22123 22124 22125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22123 def instance_template @instance_template end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroupManager for managed instance groups.
Corresponds to the JSON property kind
22129 22130 22131 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22129 def kind @kind end |
#list_managed_instances_results ⇒ String
Pagination behavior of the listManagedInstances API method for
this managed instance group.
Corresponds to the JSON property listManagedInstancesResults
22135 22136 22137 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22135 def list_managed_instances_results @list_managed_instances_results end |
#multi_mig ⇒ String
URL to the multi-MIG that this Managed Instance Group belongs to.
Corresponds to the JSON property multiMig
22140 22141 22142 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22140 def multi_mig @multi_mig end |
#name ⇒ String
The name of the managed instance group. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
22146 22147 22148 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22146 def name @name end |
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
[Output Only] Named ports configured on the Instance Groups complementary
to this Instance Group Manager.
Corresponds to the JSON property namedPorts
22152 22153 22154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22152 def named_ports @named_ports end |
#params ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerParams
Input only additional params for instance group manager creation.
Corresponds to the JSON property params
22157 22158 22159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22157 def params @params end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the managed instance group resides (for regional resources).
Corresponds to the JSON property region
22163 22164 22165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22163 def region @region end |
#resource_policies ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResourcePolicies
Resource policies for this managed instance group.
Corresponds to the JSON property resourcePolicies
22168 22169 22170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22168 def resource_policies @resource_policies end |
#satisfies_pzi ⇒ Boolean Also known as: satisfies_pzi?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzi
22173 22174 22175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22173 def satisfies_pzi @satisfies_pzi end |
#satisfies_pzs ⇒ Boolean Also known as: satisfies_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property satisfiesPzs
22179 22180 22181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22179 def satisfies_pzs @satisfies_pzs end |
#self_link ⇒ String
Output only. [Output Only] The URL for this managed instance group. The server
defines
this URL.
Corresponds to the JSON property selfLink
22187 22188 22189 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22187 def self_link @self_link end |
#service_account ⇒ String
The service account to be used as credentials for all operations performed
by the managed instance group on instances. The service accounts needs all
permissions required to create and delete instances.
By default, the service account
projectNumber@cloudservices.gserviceaccount.com is used.
Corresponds to the JSON property serviceAccount
22196 22197 22198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22196 def service_account @service_account end |
#standby_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy
Standby policy for stopped and suspended instances.
Corresponds to the JSON property standbyPolicy
22201 22202 22203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22201 def standby_policy @standby_policy end |
#stateful_policy ⇒ Google::Apis::ComputeBeta::StatefulPolicy
Stateful configuration for this Instanced Group Manager
Corresponds to the JSON property statefulPolicy
22206 22207 22208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22206 def stateful_policy @stateful_policy end |
#status ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatus
Output only. [Output Only] The status of this managed instance group.
Corresponds to the JSON property status
22211 22212 22213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22211 def status @status end |
#target_pools ⇒ Array<String>
The URLs for all TargetPool resources to which instances in theinstanceGroup
field are added. The target pools automatically
apply to all of the instances in the managed instance group.
Corresponds to the JSON property targetPools
22218 22219 22220 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22218 def target_pools @target_pools end |
#target_size ⇒ Fixnum
The target number of running instances for this managed instance group.
You can reduce this number by using the instanceGroupManager
deleteInstances or abandonInstances methods. Resizing the group also
changes this number.
Corresponds to the JSON property targetSize
22226 22227 22228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22226 def target_size @target_size end |
#target_size_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerTargetSizePolicy
The policy that specifies how the MIG creates its VMs to achieve the target
size.
Corresponds to the JSON property targetSizePolicy
22232 22233 22234 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22232 def target_size_policy @target_size_policy end |
#target_stopped_size ⇒ Fixnum
The target number of stopped instances for this managed instance group. This number changes when you:
- Stop instance using the stopInstances method or start instances using the startInstances method.
- Manually change the targetStoppedSize using the update
method.
Corresponds to the JSON property
targetStoppedSize
22244 22245 22246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22244 def target_stopped_size @target_stopped_size end |
#target_suspended_size ⇒ Fixnum
The target number of suspended instances for this managed instance group. This number changes when you:
- Suspend instance using the suspendInstances method or resume instances using the resumeInstances method.
- Manually change the targetSuspendedSize using the update
method.
Corresponds to the JSON property
targetSuspendedSize
22256 22257 22258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22256 def target_suspended_size @target_suspended_size end |
#update_policy ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerUpdatePolicy
The update policy for this managed instance group.
Corresponds to the JSON property updatePolicy
22261 22262 22263 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22261 def update_policy @update_policy end |
#versions ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerVersion>
Specifies the instance templates used by this managed instance group to
create instances.
Each version is defined by an instanceTemplate and aname. Every version can
appear at most once per instance
group. This field overrides the top-level instanceTemplate
field. Read more about therelationships
between these fields. Exactly one version must leave thetargetSize field unset.
That version will be applied to all
remaining instances. For more information, read aboutcanary
updates.
Corresponds to the JSON property versions
22275 22276 22277 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22275 def versions @versions end |
#zone ⇒ String
Output only. [Output Only] The URL of azone
where the managed instance group is located (for zonal resources).
Corresponds to the JSON property zone
22281 22282 22283 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22281 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22288 22289 22290 22291 22292 22293 22294 22295 22296 22297 22298 22299 22300 22301 22302 22303 22304 22305 22306 22307 22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 22320 22321 22322 22323 22324 22325 22326 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22288 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @auto_healing_policies = args[:auto_healing_policies] if args.key?(:auto_healing_policies) @base_instance_name = args[:base_instance_name] if args.key?(:base_instance_name) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @current_actions = args[:current_actions] if args.key?(:current_actions) @description = args[:description] if args.key?(:description) @distribution_policy = args[:distribution_policy] if args.key?(:distribution_policy) @failover_action = args[:failover_action] if args.key?(:failover_action) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @instance_flexibility_policy = args[:instance_flexibility_policy] if args.key?(:instance_flexibility_policy) @instance_group = args[:instance_group] if args.key?(:instance_group) @instance_lifecycle_policy = args[:instance_lifecycle_policy] if args.key?(:instance_lifecycle_policy) @instance_template = args[:instance_template] if args.key?(:instance_template) @kind = args[:kind] if args.key?(:kind) @list_managed_instances_results = args[:list_managed_instances_results] if args.key?(:list_managed_instances_results) @multi_mig = args[:multi_mig] if args.key?(:multi_mig) @name = args[:name] if args.key?(:name) @named_ports = args[:named_ports] if args.key?(:named_ports) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @resource_policies = args[:resource_policies] if args.key?(:resource_policies) @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi) @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs) @self_link = args[:self_link] if args.key?(:self_link) @service_account = args[:service_account] if args.key?(:service_account) @standby_policy = args[:standby_policy] if args.key?(:standby_policy) @stateful_policy = args[:stateful_policy] if args.key?(:stateful_policy) @status = args[:status] if args.key?(:status) @target_pools = args[:target_pools] if args.key?(:target_pools) @target_size = args[:target_size] if args.key?(:target_size) @target_size_policy = args[:target_size_policy] if args.key?(:target_size_policy) @target_stopped_size = args[:target_stopped_size] if args.key?(:target_stopped_size) @target_suspended_size = args[:target_suspended_size] if args.key?(:target_suspended_size) @update_policy = args[:update_policy] if args.key?(:update_policy) @versions = args[:versions] if args.key?(:versions) @zone = args[:zone] if args.key?(:zone) end |