Class: Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



24567
24568
24569
# File 'lib/google/apis/compute_beta/classes.rb', line 24567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


24469
24470
24471
# File 'lib/google/apis/compute_beta/classes.rb', line 24469

def abandoning
  @abandoning
end

#adoptingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted. Corresponds to the JSON property adopting

Returns:

  • (Fixnum)


24475
24476
24477
# File 'lib/google/apis/compute_beta/classes.rb', line 24475

def adopting
  @adopting
end

#creatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


24485
24486
24487
# File 'lib/google/apis/compute_beta/classes.rb', line 24485

def creating
  @creating
end

#creating_without_retriesFixnum

Output only. The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


24493
24494
24495
# File 'lib/google/apis/compute_beta/classes.rb', line 24493

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


24499
24500
24501
# File 'lib/google/apis/compute_beta/classes.rb', line 24499

def deleting
  @deleting
end

#noneFixnum

Output only. The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


24505
24506
24507
# File 'lib/google/apis/compute_beta/classes.rb', line 24505

def none
  @none
end

#recreatingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


24514
24515
24516
# File 'lib/google/apis/compute_beta/classes.rb', line 24514

def recreating
  @recreating
end

#refreshingFixnum

Output only. The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


24522
24523
24524
# File 'lib/google/apis/compute_beta/classes.rb', line 24522

def refreshing
  @refreshing
end

#restartingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


24528
24529
24530
# File 'lib/google/apis/compute_beta/classes.rb', line 24528

def restarting
  @restarting
end

#restarting_in_placeFixnum

Output only. The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restartingInPlace

Returns:

  • (Fixnum)


24534
24535
24536
# File 'lib/google/apis/compute_beta/classes.rb', line 24534

def restarting_in_place
  @restarting_in_place
end

#resumingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


24540
24541
24542
# File 'lib/google/apis/compute_beta/classes.rb', line 24540

def resuming
  @resuming
end

#startingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


24546
24547
24548
# File 'lib/google/apis/compute_beta/classes.rb', line 24546

def starting
  @starting
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


24552
24553
24554
# File 'lib/google/apis/compute_beta/classes.rb', line 24552

def stopping
  @stopping
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


24558
24559
24560
# File 'lib/google/apis/compute_beta/classes.rb', line 24558

def suspending
  @suspending
end

#verifyingFixnum

Output only. The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


24565
24566
24567
# File 'lib/google/apis/compute_beta/classes.rb', line 24565

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24572
24573
24574
24575
24576
24577
24578
24579
24580
24581
24582
24583
24584
24585
24586
24587
24588
# File 'lib/google/apis/compute_beta/classes.rb', line 24572

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @adopting = args[:adopting] if args.key?(:adopting)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @restarting_in_place = args[:restarting_in_place] if args.key?(:restarting_in_place)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end