Class: Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerActionsSummary

Returns a new instance of InstanceGroupManagerActionsSummary.



22839
22840
22841
# File 'lib/google/apis/compute_beta/classes.rb', line 22839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#abandoningFixnum

Output only. [Output Only] The total number of instances in the managed instance group that are scheduled to be abandoned. Abandoning an instance removes it from the managed instance group without deleting it. Corresponds to the JSON property abandoning

Returns:

  • (Fixnum)


22735
22736
22737
# File 'lib/google/apis/compute_beta/classes.rb', line 22735

def abandoning
  @abandoning
end

#adoptingFixnum

[Output Only] The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted. Corresponds to the JSON property adopting

Returns:

  • (Fixnum)


22741
22742
22743
# File 'lib/google/apis/compute_beta/classes.rb', line 22741

def adopting
  @adopting
end

#creatingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be created or are currently being created. If the group fails to create any of these instances, it tries again until it creates the instance successfully. If you have disabled creation retries, this field will not be populated; instead, the creatingWithoutRetries field will be populated. Corresponds to the JSON property creating

Returns:

  • (Fixnum)


22752
22753
22754
# File 'lib/google/apis/compute_beta/classes.rb', line 22752

def creating
  @creating
end

#creating_without_retriesFixnum

Output only. [Output Only] The number of instances that the managed instance group will attempt to create. The group attempts to create each instance only once. If the group fails to create any of these instances, it decreases the group's targetSize value accordingly. Corresponds to the JSON property creatingWithoutRetries

Returns:

  • (Fixnum)


22761
22762
22763
# File 'lib/google/apis/compute_beta/classes.rb', line 22761

def creating_without_retries
  @creating_without_retries
end

#deletingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be deleted or are currently being deleted. Corresponds to the JSON property deleting

Returns:

  • (Fixnum)


22768
22769
22770
# File 'lib/google/apis/compute_beta/classes.rb', line 22768

def deleting
  @deleting
end

#noneFixnum

Output only. [Output Only] The number of instances in the managed instance group that are running and have no scheduled actions. Corresponds to the JSON property none

Returns:

  • (Fixnum)


22775
22776
22777
# File 'lib/google/apis/compute_beta/classes.rb', line 22775

def none
  @none
end

#recreatingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be recreated or are currently being being recreated. Recreating an instance deletes the existing root persistent disk and creates a new disk from the image that is defined in the instance template. Corresponds to the JSON property recreating

Returns:

  • (Fixnum)


22785
22786
22787
# File 'lib/google/apis/compute_beta/classes.rb', line 22785

def recreating
  @recreating
end

#refreshingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are being reconfigured with properties that do not require a restart or a recreate action. For example, setting or removing target pools for the instance. Corresponds to the JSON property refreshing

Returns:

  • (Fixnum)


22794
22795
22796
# File 'lib/google/apis/compute_beta/classes.rb', line 22794

def refreshing
  @refreshing
end

#restartingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be restarted or are currently being restarted. Corresponds to the JSON property restarting

Returns:

  • (Fixnum)


22801
22802
22803
# File 'lib/google/apis/compute_beta/classes.rb', line 22801

def restarting
  @restarting
end

#resumingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be resumed or are currently being resumed. Corresponds to the JSON property resuming

Returns:

  • (Fixnum)


22808
22809
22810
# File 'lib/google/apis/compute_beta/classes.rb', line 22808

def resuming
  @resuming
end

#startingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be started or are currently being started. Corresponds to the JSON property starting

Returns:

  • (Fixnum)


22815
22816
22817
# File 'lib/google/apis/compute_beta/classes.rb', line 22815

def starting
  @starting
end

#stoppingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be stopped or are currently being stopped. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


22822
22823
22824
# File 'lib/google/apis/compute_beta/classes.rb', line 22822

def stopping
  @stopping
end

#suspendingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are scheduled to be suspended or are currently being suspended. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


22829
22830
22831
# File 'lib/google/apis/compute_beta/classes.rb', line 22829

def suspending
  @suspending
end

#verifyingFixnum

Output only. [Output Only] The number of instances in the managed instance group that are being verified. See the managedInstances[].currentAction property in the listManagedInstances method documentation. Corresponds to the JSON property verifying

Returns:

  • (Fixnum)


22837
22838
22839
# File 'lib/google/apis/compute_beta/classes.rb', line 22837

def verifying
  @verifying
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22844
22845
22846
22847
22848
22849
22850
22851
22852
22853
22854
22855
22856
22857
22858
22859
# File 'lib/google/apis/compute_beta/classes.rb', line 22844

def update!(**args)
  @abandoning = args[:abandoning] if args.key?(:abandoning)
  @adopting = args[:adopting] if args.key?(:adopting)
  @creating = args[:creating] if args.key?(:creating)
  @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries)
  @deleting = args[:deleting] if args.key?(:deleting)
  @none = args[:none] if args.key?(:none)
  @recreating = args[:recreating] if args.key?(:recreating)
  @refreshing = args[:refreshing] if args.key?(:refreshing)
  @restarting = args[:restarting] if args.key?(:restarting)
  @resuming = args[:resuming] if args.key?(:resuming)
  @starting = args[:starting] if args.key?(:starting)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspending = args[:suspending] if args.key?(:suspending)
  @verifying = args[:verifying] if args.key?(:verifying)
end