Class: Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#adopting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted.
-
#creating ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
22839 22840 22841 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. [Output Only] The total number of instances in the managed
instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
22735 22736 22737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22735 def abandoning @abandoning end |
#adopting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that
are scheduled to be adopted or are currently being adopted.
Corresponds to the JSON property adopting
22741 22742 22743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22741 def adopting @adopting end |
#creating ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
22752 22753 22754 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22752 def creating @creating end |
#creating_without_retries ⇒ Fixnum
Output only. [Output Only] The number of instances that the managed instance
group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
22761 22762 22763 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22761 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
22768 22769 22770 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22768 def deleting @deleting end |
#none ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are running and have no scheduled actions.
Corresponds to the JSON property none
22775 22776 22777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22775 def none @none end |
#recreating ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
22785 22786 22787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22785 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
22794 22795 22796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22794 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
22801 22802 22803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22801 def restarting @restarting end |
#resuming ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
22808 22809 22810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22808 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
22815 22816 22817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22815 def starting @starting end |
#stopping ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
22822 22823 22824 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22822 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
22829 22830 22831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22829 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
22837 22838 22839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22837 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22844 22845 22846 22847 22848 22849 22850 22851 22852 22853 22854 22855 22856 22857 22858 22859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22844 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @adopting = args[:adopting] if args.key?(:adopting) @creating = args[:creating] if args.key?(:creating) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |