Class: Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerActionsSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#abandoning ⇒ Fixnum
Output only.
-
#adopting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that are scheduled to be adopted or are currently being adopted.
-
#creating ⇒ Fixnum
Output only.
-
#creating_without_retries ⇒ Fixnum
Output only.
-
#deleting ⇒ Fixnum
Output only.
-
#none ⇒ Fixnum
Output only.
-
#recreating ⇒ Fixnum
Output only.
-
#refreshing ⇒ Fixnum
Output only.
-
#restarting ⇒ Fixnum
Output only.
-
#resuming ⇒ Fixnum
Output only.
-
#starting ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#verifying ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
constructor
A new instance of InstanceGroupManagerActionsSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerActionsSummary
Returns a new instance of InstanceGroupManagerActionsSummary.
22443 22444 22445 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22443 def initialize(**args) update!(**args) end |
Instance Attribute Details
#abandoning ⇒ Fixnum
Output only. [Output Only] The total number of instances in the managed
instance group
that are scheduled to be abandoned. Abandoning an instance removes it
from the managed instance group without deleting it.
Corresponds to the JSON property abandoning
22339 22340 22341 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22339 def abandoning @abandoning end |
#adopting ⇒ Fixnum
[Output Only] The number of instances in the managed instance group that
are scheduled to be adopted or are currently being adopted.
Corresponds to the JSON property adopting
22345 22346 22347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22345 def adopting @adopting end |
#creating ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be created or are currently being created. If the group
fails to create any of these instances, it tries again until it creates
the instance successfully.
If you have disabled creation retries, this field will not be populated;
instead, the creatingWithoutRetries field will be populated.
Corresponds to the JSON property creating
22356 22357 22358 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22356 def creating @creating end |
#creating_without_retries ⇒ Fixnum
Output only. [Output Only] The number of instances that the managed instance
group
will attempt to create. The group attempts to create each instance
only once. If the group fails to create any of these instances, it
decreases the group's targetSize value accordingly.
Corresponds to the JSON property creatingWithoutRetries
22365 22366 22367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22365 def creating_without_retries @creating_without_retries end |
#deleting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be deleted or are currently being deleted.
Corresponds to the JSON property deleting
22372 22373 22374 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22372 def deleting @deleting end |
#none ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are running and have no scheduled actions.
Corresponds to the JSON property none
22379 22380 22381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22379 def none @none end |
#recreating ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be recreated or are currently being being recreated.
Recreating an instance deletes the existing root persistent disk
and creates a new disk from the image that is defined in the
instance template.
Corresponds to the JSON property recreating
22389 22390 22391 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22389 def recreating @recreating end |
#refreshing ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are being reconfigured with properties that do not require a restart
or a recreate action. For example, setting or removing target
pools for the instance.
Corresponds to the JSON property refreshing
22398 22399 22400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22398 def refreshing @refreshing end |
#restarting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be restarted or are currently being restarted.
Corresponds to the JSON property restarting
22405 22406 22407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22405 def restarting @restarting end |
#resuming ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be resumed or are currently being resumed.
Corresponds to the JSON property resuming
22412 22413 22414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22412 def resuming @resuming end |
#starting ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be started or are currently being started.
Corresponds to the JSON property starting
22419 22420 22421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22419 def starting @starting end |
#stopping ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be stopped or are currently being stopped.
Corresponds to the JSON property stopping
22426 22427 22428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22426 def stopping @stopping end |
#suspending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are scheduled to be suspended or are currently being suspended.
Corresponds to the JSON property suspending
22433 22434 22435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22433 def suspending @suspending end |
#verifying ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group that
are being verified. See the managedInstances[].currentAction
property in the listManagedInstances method documentation.
Corresponds to the JSON property verifying
22441 22442 22443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22441 def @verifying end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22448 22449 22450 22451 22452 22453 22454 22455 22456 22457 22458 22459 22460 22461 22462 22463 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22448 def update!(**args) @abandoning = args[:abandoning] if args.key?(:abandoning) @adopting = args[:adopting] if args.key?(:adopting) @creating = args[:creating] if args.key?(:creating) @creating_without_retries = args[:creating_without_retries] if args.key?(:creating_without_retries) @deleting = args[:deleting] if args.key?(:deleting) @none = args[:none] if args.key?(:none) @recreating = args[:recreating] if args.key?(:recreating) @refreshing = args[:refreshing] if args.key?(:refreshing) @restarting = args[:restarting] if args.key?(:restarting) @resuming = args[:resuming] if args.key?(:resuming) @starting = args[:starting] if args.key?(:starting) @stopping = args[:stopping] if args.key?(:stopping) @suspending = args[:suspending] if args.key?(:suspending) @verifying = args[:verifying] if args.key?(:verifying) end |