Class: Google::Apis::ComputeBeta::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



24604
24605
24606
# File 'lib/google/apis/compute_beta/classes.rb', line 24604

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24565
24566
24567
# File 'lib/google/apis/compute_beta/classes.rb', line 24565

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



24570
24571
24572
# File 'lib/google/apis/compute_beta/classes.rb', line 24570

def items
  @items
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24577
24578
24579
# File 'lib/google/apis/compute_beta/classes.rb', line 24577

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24587
24588
24589
# File 'lib/google/apis/compute_beta/classes.rb', line 24587

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24592
24593
24594
# File 'lib/google/apis/compute_beta/classes.rb', line 24592

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


24597
24598
24599
# File 'lib/google/apis/compute_beta/classes.rb', line 24597

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerAggregatedList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



24602
24603
24604
# File 'lib/google/apis/compute_beta/classes.rb', line 24602

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24609
24610
24611
24612
24613
24614
24615
24616
24617
# File 'lib/google/apis/compute_beta/classes.rb', line 24609

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end