Class: Google::Apis::ComputeBeta::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



23508
23509
23510
# File 'lib/google/apis/compute_beta/classes.rb', line 23508

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23468
23469
23470
# File 'lib/google/apis/compute_beta/classes.rb', line 23468

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



23473
23474
23475
# File 'lib/google/apis/compute_beta/classes.rb', line 23473

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


23480
23481
23482
# File 'lib/google/apis/compute_beta/classes.rb', line 23480

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23491
23492
23493
# File 'lib/google/apis/compute_beta/classes.rb', line 23491

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23496
23497
23498
# File 'lib/google/apis/compute_beta/classes.rb', line 23496

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


23501
23502
23503
# File 'lib/google/apis/compute_beta/classes.rb', line 23501

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



23506
23507
23508
# File 'lib/google/apis/compute_beta/classes.rb', line 23506

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23513
23514
23515
23516
23517
23518
23519
23520
23521
# File 'lib/google/apis/compute_beta/classes.rb', line 23513

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end