Class: Google::Apis::ComputeBeta::InstanceGroupManagerAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerAggregatedList

Returns a new instance of InstanceGroupManagerAggregatedList.



22910
22911
22912
# File 'lib/google/apis/compute_beta/classes.rb', line 22910

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22870
22871
22872
# File 'lib/google/apis/compute_beta/classes.rb', line 22870

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceGroupManagersScopedList>

A list of InstanceGroupManagersScopedList resources. Corresponds to the JSON property items



22875
22876
22877
# File 'lib/google/apis/compute_beta/classes.rb', line 22875

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManagerAggregatedList for an aggregated list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22882
22883
22884
# File 'lib/google/apis/compute_beta/classes.rb', line 22882

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22893
22894
22895
# File 'lib/google/apis/compute_beta/classes.rb', line 22893

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22898
22899
22900
# File 'lib/google/apis/compute_beta/classes.rb', line 22898

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


22903
22904
22905
# File 'lib/google/apis/compute_beta/classes.rb', line 22903

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerAggregatedList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22908
22909
22910
# File 'lib/google/apis/compute_beta/classes.rb', line 22908

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22915
22916
22917
22918
22919
22920
22921
22922
22923
# File 'lib/google/apis/compute_beta/classes.rb', line 22915

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end