Class: Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
List of disks to be attached to the instances created from this selection.
-
#machine_types ⇒ Array<String>
Full machine-type names, e.g.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance selection.
-
#rank ⇒ Fixnum
Preference of this instance selection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
constructor
A new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection
Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.
24881 24882 24883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
List of disks to be attached to the instances created from this
selection.
Corresponds to the JSON property disks
24859 24860 24861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24859 def disks @disks end |
#machine_types ⇒ Array<String>
Full machine-type names, e.g. "n1-standard-16".
Corresponds to the JSON property machineTypes
24864 24865 24866 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24864 def machine_types @machine_types end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance selection.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
24870 24871 24872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24870 def min_cpu_platform @min_cpu_platform end |
#rank ⇒ Fixnum
Preference of this instance selection. Lower number means higher
preference. MIG will first try to create a VM based on the machine-type
with lowest rank and fallback to next rank based on availability.
Machine types and instance selections with the same rank have the same
preference.
Corresponds to the JSON property rank
24879 24880 24881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24879 def rank @rank end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24886 24887 24888 24889 24890 24891 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24886 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_types = args[:machine_types] if args.key?(:machine_types) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @rank = args[:rank] if args.key?(:rank) end |