Class: Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection

Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyInstanceSelection.



24284
24285
24286
# File 'lib/google/apis/compute_beta/classes.rb', line 24284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksArray<Google::Apis::ComputeBeta::AttachedDisk>

List of disks to be attached to the instances created from this selection. Corresponds to the JSON property disks



24262
24263
24264
# File 'lib/google/apis/compute_beta/classes.rb', line 24262

def disks
  @disks
end

#machine_typesArray<String>

Full machine-type names, e.g. "n1-standard-16". Corresponds to the JSON property machineTypes

Returns:

  • (Array<String>)


24267
24268
24269
# File 'lib/google/apis/compute_beta/classes.rb', line 24267

def machine_types
  @machine_types
end

#min_cpu_platformString

Name of the minimum CPU platform to be used by this instance selection. e.g. 'Intel Ice Lake'. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


24273
24274
24275
# File 'lib/google/apis/compute_beta/classes.rb', line 24273

def min_cpu_platform
  @min_cpu_platform
end

#rankFixnum

Preference of this instance selection. Lower number means higher preference. MIG will first try to create a VM based on the machine-type with lowest rank and fallback to next rank based on availability. Machine types and instance selections with the same rank have the same preference. Corresponds to the JSON property rank

Returns:

  • (Fixnum)


24282
24283
24284
# File 'lib/google/apis/compute_beta/classes.rb', line 24282

def rank
  @rank
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24289
24290
24291
24292
24293
24294
# File 'lib/google/apis/compute_beta/classes.rb', line 24289

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @machine_types = args[:machine_types] if args.key?(:machine_types)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @rank = args[:rank] if args.key?(:rank)
end