Class: Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#standard_capacity_base ⇒ Fixnum
The base capacity that will always use Standard VMs to avoid risk of more preemption than the minimum capacity user needs.
-
#standard_capacity_percent_above_base ⇒ Fixnum
The percentage of target capacity that should use Standard VM.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix
constructor
A new instance of InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix
Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix.
24810 24811 24812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#standard_capacity_base ⇒ Fixnum
The base capacity that will always use Standard VMs to avoid risk of
more preemption than the minimum capacity user needs. MIG will create
only Standard VMs until it reaches standard_capacity_base and only
then will start using standard_capacity_percent_above_base to mix Spot
with Standard VMs.
Corresponds to the JSON property standardCapacityBase
24801 24802 24803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24801 def standard_capacity_base @standard_capacity_base end |
#standard_capacity_percent_above_base ⇒ Fixnum
The percentage of target capacity that should use Standard VM. The
remaining percentage will use Spot VMs. The percentage applies only to
the capacity above standard_capacity_base.
Corresponds to the JSON property standardCapacityPercentAboveBase
24808 24809 24810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24808 def standard_capacity_percent_above_base @standard_capacity_percent_above_base end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24815 24816 24817 24818 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24815 def update!(**args) @standard_capacity_base = args[:standard_capacity_base] if args.key?(:standard_capacity_base) @standard_capacity_percent_above_base = args[:standard_capacity_percent_above_base] if args.key?(:standard_capacity_percent_above_base) end |