Class: Google::Apis::ComputeBeta::InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix

Returns a new instance of InstanceGroupManagerInstanceFlexibilityPolicyProvisioningModelMix.



22741
22742
22743
# File 'lib/google/apis/compute_beta/classes.rb', line 22741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#standard_capacity_baseFixnum

The base capacity that will always use Standard VMs to avoid risk of more preemption than the minimum capacity user needs. MIG will create only Standard VMs until it reaches standard_capacity_base and only then will start using standard_capacity_percent_above_base to mix Spot with Standard VMs. Corresponds to the JSON property standardCapacityBase

Returns:

  • (Fixnum)


22732
22733
22734
# File 'lib/google/apis/compute_beta/classes.rb', line 22732

def standard_capacity_base
  @standard_capacity_base
end

#standard_capacity_percent_above_baseFixnum

The percentage of target capacity that should use Standard VM. The remaining percentage will use Spot VMs. The percentage applies only to the capacity above standard_capacity_base. Corresponds to the JSON property standardCapacityPercentAboveBase

Returns:

  • (Fixnum)


22739
22740
22741
# File 'lib/google/apis/compute_beta/classes.rb', line 22739

def standard_capacity_percent_above_base
  @standard_capacity_percent_above_base
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22746
22747
22748
22749
# File 'lib/google/apis/compute_beta/classes.rb', line 22746

def update!(**args)
  @standard_capacity_base = args[:standard_capacity_base] if args.key?(:standard_capacity_base)
  @standard_capacity_percent_above_base = args[:standard_capacity_percent_above_base] if args.key?(:standard_capacity_percent_above_base)
end