Class: Google::Apis::ComputeBeta::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



24972
24973
24974
# File 'lib/google/apis/compute_beta/classes.rb', line 24972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24938
24939
24940
# File 'lib/google/apis/compute_beta/classes.rb', line 24938

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



24943
24944
24945
# File 'lib/google/apis/compute_beta/classes.rb', line 24943

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24950
24951
24952
# File 'lib/google/apis/compute_beta/classes.rb', line 24950

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24960
24961
24962
# File 'lib/google/apis/compute_beta/classes.rb', line 24960

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24965
24966
24967
# File 'lib/google/apis/compute_beta/classes.rb', line 24965

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



24970
24971
24972
# File 'lib/google/apis/compute_beta/classes.rb', line 24970

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24977
24978
24979
24980
24981
24982
24983
24984
# File 'lib/google/apis/compute_beta/classes.rb', line 24977

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end