Class: Google::Apis::ComputeBeta::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



24950
24951
24952
# File 'lib/google/apis/compute_beta/classes.rb', line 24950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24916
24917
24918
# File 'lib/google/apis/compute_beta/classes.rb', line 24916

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



24921
24922
24923
# File 'lib/google/apis/compute_beta/classes.rb', line 24921

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24928
24929
24930
# File 'lib/google/apis/compute_beta/classes.rb', line 24928

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24938
24939
24940
# File 'lib/google/apis/compute_beta/classes.rb', line 24938

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24943
24944
24945
# File 'lib/google/apis/compute_beta/classes.rb', line 24943

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



24948
24949
24950
# File 'lib/google/apis/compute_beta/classes.rb', line 24948

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24955
24956
24957
24958
24959
24960
24961
24962
# File 'lib/google/apis/compute_beta/classes.rb', line 24955

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end