Class: Google::Apis::ComputeBeta::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



24457
24458
24459
# File 'lib/google/apis/compute_beta/classes.rb', line 24457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24423
24424
24425
# File 'lib/google/apis/compute_beta/classes.rb', line 24423

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



24428
24429
24430
# File 'lib/google/apis/compute_beta/classes.rb', line 24428

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


24435
24436
24437
# File 'lib/google/apis/compute_beta/classes.rb', line 24435

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24445
24446
24447
# File 'lib/google/apis/compute_beta/classes.rb', line 24445

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24450
24451
24452
# File 'lib/google/apis/compute_beta/classes.rb', line 24450

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



24455
24456
24457
# File 'lib/google/apis/compute_beta/classes.rb', line 24455

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24462
24463
24464
24465
24466
24467
24468
24469
# File 'lib/google/apis/compute_beta/classes.rb', line 24462

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end