Class: Google::Apis::ComputeBeta::InstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerList

Returns a new instance of InstanceGroupManagerList.



22882
22883
22884
# File 'lib/google/apis/compute_beta/classes.rb', line 22882

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


22848
22849
22850
# File 'lib/google/apis/compute_beta/classes.rb', line 22848

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



22853
22854
22855
# File 'lib/google/apis/compute_beta/classes.rb', line 22853

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is always compute#instanceGroupManagerList for a list of managed instance groups. Corresponds to the JSON property kind

Returns:

  • (String)


22859
22860
22861
# File 'lib/google/apis/compute_beta/classes.rb', line 22859

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


22870
22871
22872
# File 'lib/google/apis/compute_beta/classes.rb', line 22870

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


22875
22876
22877
# File 'lib/google/apis/compute_beta/classes.rb', line 22875

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



22880
22881
22882
# File 'lib/google/apis/compute_beta/classes.rb', line 22880

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



22887
22888
22889
22890
22891
22892
22893
22894
# File 'lib/google/apis/compute_beta/classes.rb', line 22887

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end