Class: Google::Apis::ComputeBeta::InstanceGroupManagerParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Input only additional params for instance group manager creation.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to bind to the managed instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerParams
constructor
A new instance of InstanceGroupManagerParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerParams
Returns a new instance of InstanceGroupManagerParams.
22981 22982 22983 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22981 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Resource manager tags to bind to the managed instance group. The tags are
key-value pairs. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/456` or in namespaced
format such asorg_id|project_id/tag_key_short_nameand
tag_value_short_name`. For more information, seeManage tags
for resources.
Corresponds to the JSON propertyresourceManagerTags`
22979 22980 22981 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22979 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
22986 22987 22988 |
# File 'lib/google/apis/compute_beta/classes.rb', line 22986 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |