Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



25266
25267
25268
# File 'lib/google/apis/compute_beta/classes.rb', line 25266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

This field is deprecated, please use resize_by instead. The count of instances to create as part of this resize request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


25177
25178
25179
# File 'lib/google/apis/compute_beta/classes.rb', line 25177

def count
  @count
end

#creation_timestampString

Output only. The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


25183
25184
25185
# File 'lib/google/apis/compute_beta/classes.rb', line 25183

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


25188
25189
25190
# File 'lib/google/apis/compute_beta/classes.rb', line 25188

def description
  @description
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25195
25196
25197
# File 'lib/google/apis/compute_beta/classes.rb', line 25195

def id
  @id
end

#instancesArray<Google::Apis::ComputeBeta::PerInstanceConfig>

The names of instances to be created by this resize request. The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'. Corresponds to the JSON property instances



25203
25204
25205
# File 'lib/google/apis/compute_beta/classes.rb', line 25203

def instances
  @instances
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


25209
25210
25211
# File 'lib/google/apis/compute_beta/classes.rb', line 25209

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


25215
25216
25217
# File 'lib/google/apis/compute_beta/classes.rb', line 25215

def name
  @name
end

#regionString

Output only. The URL of a region where the resize request is located. Populated only for regional resize requests. Corresponds to the JSON property region

Returns:

  • (String)


25222
25223
25224
# File 'lib/google/apis/compute_beta/classes.rb', line 25222

def region
  @region
end

#requested_run_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



25230
25231
25232
# File 'lib/google/apis/compute_beta/classes.rb', line 25230

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


25237
25238
25239
# File 'lib/google/apis/compute_beta/classes.rb', line 25237

def resize_by
  @resize_by
end

Output only. The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


25242
25243
25244
# File 'lib/google/apis/compute_beta/classes.rb', line 25242

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


25247
25248
25249
# File 'lib/google/apis/compute_beta/classes.rb', line 25247

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


25252
25253
25254
# File 'lib/google/apis/compute_beta/classes.rb', line 25252

def state
  @state
end

#statusGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus

Output only. Status of the request. Corresponds to the JSON property status



25257
25258
25259
# File 'lib/google/apis/compute_beta/classes.rb', line 25257

def status
  @status
end

#zoneString

Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


25264
25265
25266
# File 'lib/google/apis/compute_beta/classes.rb', line 25264

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25271
25272
25273
25274
25275
25276
25277
25278
25279
25280
25281
25282
25283
25284
25285
25286
25287
# File 'lib/google/apis/compute_beta/classes.rb', line 25271

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end