Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



25216
25217
25218
# File 'lib/google/apis/compute_beta/classes.rb', line 25216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

This field is deprecated, please use resize_by instead. The count of instances to create as part of this resize request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


25127
25128
25129
# File 'lib/google/apis/compute_beta/classes.rb', line 25127

def count
  @count
end

#creation_timestampString

Output only. The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


25133
25134
25135
# File 'lib/google/apis/compute_beta/classes.rb', line 25133

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


25138
25139
25140
# File 'lib/google/apis/compute_beta/classes.rb', line 25138

def description
  @description
end

#idFixnum

Output only. A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


25145
25146
25147
# File 'lib/google/apis/compute_beta/classes.rb', line 25145

def id
  @id
end

#instancesArray<Google::Apis::ComputeBeta::PerInstanceConfig>

The names of instances to be created by this resize request. The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'. Corresponds to the JSON property instances



25153
25154
25155
# File 'lib/google/apis/compute_beta/classes.rb', line 25153

def instances
  @instances
end

#kindString

Output only. The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


25159
25160
25161
# File 'lib/google/apis/compute_beta/classes.rb', line 25159

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


25165
25166
25167
# File 'lib/google/apis/compute_beta/classes.rb', line 25165

def name
  @name
end

#regionString

Output only. The URL of a region where the resize request is located. Populated only for regional resize requests. Corresponds to the JSON property region

Returns:

  • (String)


25172
25173
25174
# File 'lib/google/apis/compute_beta/classes.rb', line 25172

def region
  @region
end

#requested_run_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



25180
25181
25182
# File 'lib/google/apis/compute_beta/classes.rb', line 25180

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


25187
25188
25189
# File 'lib/google/apis/compute_beta/classes.rb', line 25187

def resize_by
  @resize_by
end

Output only. The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


25192
25193
25194
# File 'lib/google/apis/compute_beta/classes.rb', line 25192

def self_link
  @self_link
end

Output only. Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


25197
25198
25199
# File 'lib/google/apis/compute_beta/classes.rb', line 25197

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


25202
25203
25204
# File 'lib/google/apis/compute_beta/classes.rb', line 25202

def state
  @state
end

#statusGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus

Output only. Status of the request. Corresponds to the JSON property status



25207
25208
25209
# File 'lib/google/apis/compute_beta/classes.rb', line 25207

def status
  @status
end

#zoneString

Output only. The URL of a zone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


25214
25215
25216
# File 'lib/google/apis/compute_beta/classes.rb', line 25214

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25221
25222
25223
25224
25225
25226
25227
25228
25229
25230
25231
25232
25233
25234
25235
25236
25237
# File 'lib/google/apis/compute_beta/classes.rb', line 25221

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end