Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instances ⇒ Array<Google::Apis::ComputeBeta::PerInstanceConfig>
The names of instances to be created by this resize request.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of this resize request.
-
#region ⇒ String
Output only.
-
#requested_run_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
constructor
A new instance of InstanceGroupManagerResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
Returns a new instance of InstanceGroupManagerResizeRequest.
24692 24693 24694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24692 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
The count of instances to create as part of this resize request.
Corresponds to the JSON property count
24603 24604 24605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24603 def count @count end |
#creation_timestamp ⇒ String
Output only. The creation timestamp for this resize request inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
24609 24610 24611 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24609 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
24614 24615 24616 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24614 def description @description end |
#id ⇒ Fixnum
Output only. A unique identifier for this resource type. The server generates
this
identifier.
Corresponds to the JSON property id
24621 24622 24623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24621 def id @id end |
#instances ⇒ Array<Google::Apis::ComputeBeta::PerInstanceConfig>
The names of instances to be created by this resize request. The number of
names specified determines the number of instances to create. The group's
target size will be increased by this number. This field cannot be used
together with 'resize_by'.
Corresponds to the JSON property instances
24629 24630 24631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24629 def instances @instances end |
#kind ⇒ String
Output only. The resource type, which is alwayscompute#
instanceGroupManagerResizeRequest for resize requests.
Corresponds to the JSON property kind
24635 24636 24637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24635 def kind @kind end |
#name ⇒ String
The name of this resize request. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
24641 24642 24643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24641 def name @name end |
#region ⇒ String
Output only. The URL of a region
where the resize request is located. Populated only for regional resize
requests.
Corresponds to the JSON property region
24648 24649 24650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24648 def region @region end |
#requested_run_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property requestedRunDuration
24656 24657 24658 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24656 def requested_run_duration @requested_run_duration end |
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request. The group's
target size will be increased by this number. This field cannot be used
together with 'instances'.
Corresponds to the JSON property resizeBy
24663 24664 24665 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24663 def resize_by @resize_by end |
#self_link ⇒ String
Output only. The URL for this resize request. The server defines this URL.
Corresponds to the JSON property selfLink
24668 24669 24670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24668 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. Server-defined URL for this resource with the resource id.
Corresponds to the JSON property selfLinkWithId
24673 24674 24675 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24673 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. Current state of the request.
Corresponds to the JSON property state
24678 24679 24680 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24678 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
Output only. Status of the request.
Corresponds to the JSON property status
24683 24684 24685 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24683 def status @status end |
#zone ⇒ String
Output only. The URL of a zone
where the resize request is located. Populated only for zonal resize
requests.
Corresponds to the JSON property zone
24690 24691 24692 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24690 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24697 24698 24699 24700 24701 24702 24703 24704 24705 24706 24707 24708 24709 24710 24711 24712 24713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24697 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration) @resize_by = args[:resize_by] if args.key?(:resize_by) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |