Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequest

Returns a new instance of InstanceGroupManagerResizeRequest.



23493
23494
23495
# File 'lib/google/apis/compute_beta/classes.rb', line 23493

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

This field is deprecated, please use resize_by instead. The count of instances to create as part of this resize request. Corresponds to the JSON property count

Returns:

  • (Fixnum)


23400
23401
23402
# File 'lib/google/apis/compute_beta/classes.rb', line 23400

def count
  @count
end

#creation_timestampString

Output only. [Output Only] The creation timestamp for this resize request inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


23407
23408
23409
# File 'lib/google/apis/compute_beta/classes.rb', line 23407

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


23412
23413
23414
# File 'lib/google/apis/compute_beta/classes.rb', line 23412

def description
  @description
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


23419
23420
23421
# File 'lib/google/apis/compute_beta/classes.rb', line 23419

def id
  @id
end

#instancesArray<Google::Apis::ComputeBeta::PerInstanceConfig>

The names of instances to be created by this resize request. The number of names specified determines the number of instances to create. The group's target size will be increased by this number. This field cannot be used together with 'resize_by'. Corresponds to the JSON property instances



23427
23428
23429
# File 'lib/google/apis/compute_beta/classes.rb', line 23427

def instances
  @instances
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupManagerResizeRequest for resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


23434
23435
23436
# File 'lib/google/apis/compute_beta/classes.rb', line 23434

def kind
  @kind
end

#nameString

The name of this resize request. The name must be 1-63 characters long, and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


23440
23441
23442
# File 'lib/google/apis/compute_beta/classes.rb', line 23440

def name
  @name
end

#regionString

Output only. [Output Only] The URL of aregion where the resize request is located. Populated only for regional resize requests. Corresponds to the JSON property region

Returns:

  • (String)


23447
23448
23449
# File 'lib/google/apis/compute_beta/classes.rb', line 23447

def region
  @region
end

#requested_run_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestedRunDuration



23455
23456
23457
# File 'lib/google/apis/compute_beta/classes.rb', line 23455

def requested_run_duration
  @requested_run_duration
end

#resize_byFixnum

The number of instances to be created by this resize request. The group's target size will be increased by this number. This field cannot be used together with 'instances'. Corresponds to the JSON property resizeBy

Returns:

  • (Fixnum)


23462
23463
23464
# File 'lib/google/apis/compute_beta/classes.rb', line 23462

def resize_by
  @resize_by
end

Output only. [Output Only] The URL for this resize request. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


23468
23469
23470
# File 'lib/google/apis/compute_beta/classes.rb', line 23468

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


23474
23475
23476
# File 'lib/google/apis/compute_beta/classes.rb', line 23474

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. [Output only] Current state of the request. Corresponds to the JSON property state

Returns:

  • (String)


23479
23480
23481
# File 'lib/google/apis/compute_beta/classes.rb', line 23479

def state
  @state
end

#statusGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus

Output only. [Output only] Status of the request. Corresponds to the JSON property status



23484
23485
23486
# File 'lib/google/apis/compute_beta/classes.rb', line 23484

def status
  @status
end

#zoneString

Output only. [Output Only] The URL of azone where the resize request is located. Populated only for zonal resize requests. Corresponds to the JSON property zone

Returns:

  • (String)


23491
23492
23493
# File 'lib/google/apis/compute_beta/classes.rb', line 23491

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23498
23499
23500
23501
23502
23503
23504
23505
23506
23507
23508
23509
23510
23511
23512
23513
23514
# File 'lib/google/apis/compute_beta/classes.rb', line 23498

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @instances = args[:instances] if args.key?(:instances)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration)
  @resize_by = args[:resize_by] if args.key?(:resize_by)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end