Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
InstanceGroupManagerResizeRequest represents a request to create a number of VMs: either immediately or by queuing the request for the specified time. This resize request is nested under InstanceGroupManager and the VMs created by this request are added to the owning InstanceGroupManager.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#instances ⇒ Array<Google::Apis::ComputeBeta::PerInstanceConfig>
The names of instances to be created by this resize request.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of this resize request.
-
#region ⇒ String
Output only.
-
#requested_run_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
constructor
A new instance of InstanceGroupManagerResizeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequest
Returns a new instance of InstanceGroupManagerResizeRequest.
23096 23097 23098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
This field is deprecated, please use resize_by instead.
The count of instances to create as part of this resize request.
Corresponds to the JSON property count
23003 23004 23005 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23003 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp for this resize request
inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
23010 23011 23012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23010 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
23015 23016 23017 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23015 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] A unique identifier for this resource type. The
server
generates this identifier.
Corresponds to the JSON property id
23022 23023 23024 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23022 def id @id end |
#instances ⇒ Array<Google::Apis::ComputeBeta::PerInstanceConfig>
The names of instances to be created by this resize request. The number of
names specified determines the number of instances to create. The group's
target size will be increased by this number. This field cannot be used
together with 'resize_by'.
Corresponds to the JSON property instances
23030 23031 23032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23030 def instances @instances end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceGroupManagerResizeRequest for
resize requests.
Corresponds to the JSON property kind
23037 23038 23039 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23037 def kind @kind end |
#name ⇒ String
The name of this resize request. The name must be 1-63 characters
long, and comply withRFC1035.
Corresponds to the JSON property name
23043 23044 23045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23043 def name @name end |
#region ⇒ String
Output only. [Output Only] The URL of aregion
where the resize request is located. Populated only for regional resize
requests.
Corresponds to the JSON property region
23050 23051 23052 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23050 def region @region end |
#requested_run_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property requestedRunDuration
23058 23059 23060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23058 def requested_run_duration @requested_run_duration end |
#resize_by ⇒ Fixnum
The number of instances to be created by this resize request. The group's
target size will be increased by this number. This field cannot be used
together with 'instances'.
Corresponds to the JSON property resizeBy
23065 23066 23067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23065 def resize_by @resize_by end |
#self_link ⇒ String
Output only. [Output Only] The URL for this resize request. The server defines
this URL.
Corresponds to the JSON property selfLink
23071 23072 23073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23071 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
23077 23078 23079 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23077 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Output only. [Output only] Current state of the request.
Corresponds to the JSON property state
23082 23083 23084 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23082 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
Output only. [Output only] Status of the request.
Corresponds to the JSON property status
23087 23088 23089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23087 def status @status end |
#zone ⇒ String
Output only. [Output Only] The URL of azone
where the resize request is located. Populated only for zonal resize
requests.
Corresponds to the JSON property zone
23094 23095 23096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23094 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23101 23102 23103 23104 23105 23106 23107 23108 23109 23110 23111 23112 23113 23114 23115 23116 23117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23101 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @requested_run_duration = args[:requested_run_duration] if args.key?(:requested_run_duration) @resize_by = args[:resize_by] if args.key?(:resize_by) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |