Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus

Returns a new instance of InstanceGroupManagerResizeRequestStatus.



25266
25267
25268
# File 'lib/google/apis/compute_beta/classes.rb', line 25266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error

Output only. Fatal errors encountered during the queueing or provisioning phases of the ResizeRequest that caused the transition to the FAILED state. Contrary to the last_attempt errors, this field is final and errors are never removed from here, as the ResizeRequest is not going to retry. Corresponds to the JSON property error



25251
25252
25253
# File 'lib/google/apis/compute_beta/classes.rb', line 25251

def error
  @error
end

#last_attemptGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt

Output only. Information about the last attempt to fulfill the request. The value is temporary since the ResizeRequest can retry, as long as it's still active and the last attempt value can either be cleared or replaced with a different error. Since ResizeRequest retries infrequently, the value may be stale and no longer show an active problem. The value is cleared when ResizeRequest transitions to the final state (becomes inactive). If the final state is FAILED the error describing it will be stored in the "error" field only. Corresponds to the JSON property lastAttempt



25264
25265
25266
# File 'lib/google/apis/compute_beta/classes.rb', line 25264

def last_attempt
  @last_attempt
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25271
25272
25273
25274
# File 'lib/google/apis/compute_beta/classes.rb', line 25271

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
end