Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus
constructor
A new instance of InstanceGroupManagerResizeRequestStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus
Returns a new instance of InstanceGroupManagerResizeRequestStatus.
25211 25212 25213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error
Output only. Fatal errors encountered during the queueing or provisioning
phases of
the ResizeRequest that caused the transition to the FAILED state.
Contrary to the last_attempt errors, this field is final and errors are
never removed from here, as the ResizeRequest is not going to retry.
Corresponds to the JSON property error
25196 25197 25198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25196 def error @error end |
#last_attempt ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only. Information about the last attempt to fulfill the request. The
value is
temporary since the ResizeRequest can retry, as long as it's still active
and the last attempt value can either be cleared or replaced with a
different error. Since ResizeRequest retries infrequently, the value may
be stale and no longer show an active problem. The value is cleared when
ResizeRequest transitions to the final state (becomes inactive). If the
final state is FAILED the error describing it will be stored in the
"error" field only.
Corresponds to the JSON property lastAttempt
25209 25210 25211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25209 def last_attempt @last_attempt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25216 25217 25218 25219 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25216 def update!(**args) @error = args[:error] if args.key?(:error) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) end |