Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus
constructor
A new instance of InstanceGroupManagerResizeRequestStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestStatus
Returns a new instance of InstanceGroupManagerResizeRequestStatus.
23146 23147 23148 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23146 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error
Output only. [Output only] Fatal errors encountered during the queueing or
provisioning phases of the ResizeRequest that caused the transition to
the FAILED state. Contrary to the last_attempt errors, this field is
final and errors are never removed from here, as the ResizeRequest is not
going to retry.
Corresponds to the JSON property error
23131 23132 23133 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23131 def error @error end |
#last_attempt ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt
Output only. [Output only] Information about the last attempt to fulfill the
request.
The value is temporary since the ResizeRequest can retry, as long as it's
still active and the last attempt value can either be cleared or replaced
with a different error. Since ResizeRequest retries infrequently, the
value may be stale and no longer show an active problem. The value is
cleared when ResizeRequest transitions to the final state (becomes
inactive). If the final state is FAILED the error describing it will be
storred in the "error" field only.
Corresponds to the JSON property lastAttempt
23144 23145 23146 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23144 def last_attempt @last_attempt end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23151 23152 23153 23154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23151 def update!(**args) @error = args[:error] if args.key?(:error) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) end |