Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



24804
24805
24806
# File 'lib/google/apis/compute_beta/classes.rb', line 24804

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


24782
24783
24784
# File 'lib/google/apis/compute_beta/classes.rb', line 24782

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatus::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



24791
24792
24793
# File 'lib/google/apis/compute_beta/classes.rb', line 24791

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


24797
24798
24799
# File 'lib/google/apis/compute_beta/classes.rb', line 24797

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


24802
24803
24804
# File 'lib/google/apis/compute_beta/classes.rb', line 24802

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24809
24810
24811
24812
24813
24814
# File 'lib/google/apis/compute_beta/classes.rb', line 24809

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end