Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt::Error::Error

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: ErrorDetail

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Error

Returns a new instance of Error.



23745
23746
23747
# File 'lib/google/apis/compute_beta/classes.rb', line 23745

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] The error type identifier for this error. Corresponds to the JSON property code

Returns:

  • (String)


23723
23724
23725
# File 'lib/google/apis/compute_beta/classes.rb', line 23723

def code
  @code
end

#error_detailsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestStatusLastAttempt::Error::Error::ErrorDetail>

[Output Only] An optional list of messages that contain the error details. There is a set of defined message types to use for providing details.The syntax depends on the error code. For example, QuotaExceededInfo will have details when the error code is QUOTA_EXCEEDED. Corresponds to the JSON property errorDetails



23732
23733
23734
# File 'lib/google/apis/compute_beta/classes.rb', line 23732

def error_details
  @error_details
end

#locationString

[Output Only] Indicates the field in the request that caused the error. This property is optional. Corresponds to the JSON property location

Returns:

  • (String)


23738
23739
23740
# File 'lib/google/apis/compute_beta/classes.rb', line 23738

def location
  @location
end

#messageString

[Output Only] An optional, human-readable error message. Corresponds to the JSON property message

Returns:

  • (String)


23743
23744
23745
# File 'lib/google/apis/compute_beta/classes.rb', line 23743

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23750
23751
23752
23753
23754
23755
# File 'lib/google/apis/compute_beta/classes.rb', line 23750

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_details = args[:error_details] if args.key?(:error_details)
  @location = args[:location] if args.key?(:location)
  @message = args[:message] if args.key?(:message)
end