Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
25637 25638 25639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25603 25604 25605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25603 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
25608 25609 25610 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25608 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
25615 25616 25617 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25615 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25625 25626 25627 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25625 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25630 25631 25632 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25630 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
25635 25636 25637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25635 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25642 25643 25644 25645 25646 25647 25648 25649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25642 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |