Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



25587
25588
25589
# File 'lib/google/apis/compute_beta/classes.rb', line 25587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25553
25554
25555
# File 'lib/google/apis/compute_beta/classes.rb', line 25553

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



25558
25559
25560
# File 'lib/google/apis/compute_beta/classes.rb', line 25558

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


25565
25566
25567
# File 'lib/google/apis/compute_beta/classes.rb', line 25565

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25575
25576
25577
# File 'lib/google/apis/compute_beta/classes.rb', line 25575

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25580
25581
25582
# File 'lib/google/apis/compute_beta/classes.rb', line 25580

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



25585
25586
25587
# File 'lib/google/apis/compute_beta/classes.rb', line 25585

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25592
25593
25594
25595
25596
25597
25598
25599
# File 'lib/google/apis/compute_beta/classes.rb', line 25592

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end