Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] A list of resize requests.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>
A list of resize request resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
constructor
A new instance of InstanceGroupManagerResizeRequestsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse
Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.
25583 25584 25585 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25583 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25549 25550 25551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25549 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>
A list of resize request resources.
Corresponds to the JSON property items
25554 25555 25556 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25554 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#
instanceGroupManagerResizeRequestList for
a list of resize requests.
Corresponds to the JSON property kind
25561 25562 25563 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25561 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for list
requests.
If the number of results is larger than maxResults, use thenextPageToken as a
value for the query parameterpageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25571 25572 25573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25571 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25576 25577 25578 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25576 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
25581 25582 25583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25581 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25588 25589 25590 25591 25592 25593 25594 25595 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25588 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |