Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



25528
25529
25530
# File 'lib/google/apis/compute_beta/classes.rb', line 25528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25494
25495
25496
# File 'lib/google/apis/compute_beta/classes.rb', line 25494

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



25499
25500
25501
# File 'lib/google/apis/compute_beta/classes.rb', line 25499

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


25506
25507
25508
# File 'lib/google/apis/compute_beta/classes.rb', line 25506

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use thenextPageToken as a value for the query parameterpageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25516
25517
25518
# File 'lib/google/apis/compute_beta/classes.rb', line 25516

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25521
25522
25523
# File 'lib/google/apis/compute_beta/classes.rb', line 25521

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



25526
25527
25528
# File 'lib/google/apis/compute_beta/classes.rb', line 25526

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25533
25534
25535
25536
25537
25538
25539
25540
# File 'lib/google/apis/compute_beta/classes.rb', line 25533

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end