Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



24456
24457
24458
# File 'lib/google/apis/compute_beta/classes.rb', line 24456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24421
24422
24423
# File 'lib/google/apis/compute_beta/classes.rb', line 24421

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



24426
24427
24428
# File 'lib/google/apis/compute_beta/classes.rb', line 24426

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


24433
24434
24435
# File 'lib/google/apis/compute_beta/classes.rb', line 24433

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24444
24445
24446
# File 'lib/google/apis/compute_beta/classes.rb', line 24444

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24449
24450
24451
# File 'lib/google/apis/compute_beta/classes.rb', line 24449

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



24454
24455
24456
# File 'lib/google/apis/compute_beta/classes.rb', line 24454

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24461
24462
24463
24464
24465
24466
24467
24468
# File 'lib/google/apis/compute_beta/classes.rb', line 24461

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end