Class: Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A list of resize requests.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerResizeRequestsListResponse

Returns a new instance of InstanceGroupManagerResizeRequestsListResponse.



23465
23466
23467
# File 'lib/google/apis/compute_beta/classes.rb', line 23465

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


23430
23431
23432
# File 'lib/google/apis/compute_beta/classes.rb', line 23430

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of resize request resources. Corresponds to the JSON property items



23435
23436
23437
# File 'lib/google/apis/compute_beta/classes.rb', line 23435

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instanceGroupManagerResizeRequestList for a list of resize requests. Corresponds to the JSON property kind

Returns:

  • (String)


23442
23443
23444
# File 'lib/google/apis/compute_beta/classes.rb', line 23442

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


23453
23454
23455
# File 'lib/google/apis/compute_beta/classes.rb', line 23453

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


23458
23459
23460
# File 'lib/google/apis/compute_beta/classes.rb', line 23458

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagerResizeRequestsListResponse::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



23463
23464
23465
# File 'lib/google/apis/compute_beta/classes.rb', line 23463

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23470
23471
23472
23473
23474
23475
23476
23477
# File 'lib/google/apis/compute_beta/classes.rb', line 23470

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end