Class: Google::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerStandbyPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#initial_delay_sec ⇒ Fixnum
Specifies the number of seconds that the MIG should wait to suspend or stop a VM after that VM was created.
-
#mode ⇒ String
Defines how a MIG resumes or starts VMs from a standby pool when the group scales out.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy
constructor
A new instance of InstanceGroupManagerStandbyPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStandbyPolicy
Returns a new instance of InstanceGroupManagerStandbyPolicy.
23994 23995 23996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23994 def initialize(**args) update!(**args) end |
Instance Attribute Details
#initial_delay_sec ⇒ Fixnum
Specifies the number of seconds that the MIG should wait to suspend or
stop a VM after that VM was created. The initial delay gives the
initialization script the time to prepare your VM for a quick scale out.
The value of initial delay must be between 0 and 3600 seconds. The
default value is 0.
Corresponds to the JSON property initialDelaySec
23986 23987 23988 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23986 def initial_delay_sec @initial_delay_sec end |
#mode ⇒ String
Defines how a MIG resumes or starts VMs from a standby pool when the
group scales out. The default mode is MANUAL.
Corresponds to the JSON property mode
23992 23993 23994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23992 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
23999 24000 24001 24002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 23999 def update!(**args) @initial_delay_sec = args[:initial_delay_sec] if args.key?(:initial_delay_sec) @mode = args[:mode] if args.key?(:mode) end |