Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatus

Returns a new instance of InstanceGroupManagerStatus.



25838
25839
25840
# File 'lib/google/apis/compute_beta/classes.rb', line 25838

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusAllInstancesConfig

Output only. Status of all-instances configuration on the group. Corresponds to the JSON property allInstancesConfig



25787
25788
25789
# File 'lib/google/apis/compute_beta/classes.rb', line 25787

def all_instances_config
  @all_instances_config
end

#applied_accelerator_topologiesArray<Google::Apis::ComputeBeta::InstanceGroupManagerStatusAcceleratorTopology>

Output only. The accelerator topology applied to this MIG. Currently only one accelerator topology is supported. Corresponds to the JSON property appliedAcceleratorTopologies



25793
25794
25795
# File 'lib/google/apis/compute_beta/classes.rb', line 25793

def applied_accelerator_topologies
  @applied_accelerator_topologies
end

#autoscalerString

Output only. The URL of theAutoscaler that targets this instance group manager. Corresponds to the JSON property autoscaler

Returns:

  • (String)


25799
25800
25801
# File 'lib/google/apis/compute_beta/classes.rb', line 25799

def autoscaler
  @autoscaler
end

#bulk_instance_operationGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusBulkInstanceOperation

Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK. Corresponds to the JSON property bulkInstanceOperation



25805
25806
25807
# File 'lib/google/apis/compute_beta/classes.rb', line 25805

def bulk_instance_operation
  @bulk_instance_operation
end

#current_instance_statusesGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs. Corresponds to the JSON property currentInstanceStatuses



25813
25814
25815
# File 'lib/google/apis/compute_beta/classes.rb', line 25813

def current_instance_statuses
  @current_instance_statuses
end

#is_stableBoolean Also known as: is_stable?

Output only. A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified. Corresponds to the JSON property isStable

Returns:

  • (Boolean)


25823
25824
25825
# File 'lib/google/apis/compute_beta/classes.rb', line 25823

def is_stable
  @is_stable
end

#statefulGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusStateful

Output only. Stateful status of the given Instance Group Manager. Corresponds to the JSON property stateful



25829
25830
25831
# File 'lib/google/apis/compute_beta/classes.rb', line 25829

def stateful
  @stateful
end

#version_targetGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget

Output only. A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager. Corresponds to the JSON property versionTarget



25836
25837
25838
# File 'lib/google/apis/compute_beta/classes.rb', line 25836

def version_target
  @version_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25843
25844
25845
25846
25847
25848
25849
25850
25851
25852
# File 'lib/google/apis/compute_beta/classes.rb', line 25843

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @applied_accelerator_topologies = args[:applied_accelerator_topologies] if args.key?(:applied_accelerator_topologies)
  @autoscaler = args[:autoscaler] if args.key?(:autoscaler)
  @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation)
  @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses)
  @is_stable = args[:is_stable] if args.key?(:is_stable)
  @stateful = args[:stateful] if args.key?(:stateful)
  @version_target = args[:version_target] if args.key?(:version_target)
end