Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatus

Returns a new instance of InstanceGroupManagerStatus.



25729
25730
25731
# File 'lib/google/apis/compute_beta/classes.rb', line 25729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusAllInstancesConfig

Output only. Status of all-instances configuration on the group. Corresponds to the JSON property allInstancesConfig



25678
25679
25680
# File 'lib/google/apis/compute_beta/classes.rb', line 25678

def all_instances_config
  @all_instances_config
end

#applied_accelerator_topologiesArray<Google::Apis::ComputeBeta::InstanceGroupManagerStatusAcceleratorTopology>

Output only. The accelerator topology applied to this MIG. Currently only one accelerator topology is supported. Corresponds to the JSON property appliedAcceleratorTopologies



25684
25685
25686
# File 'lib/google/apis/compute_beta/classes.rb', line 25684

def applied_accelerator_topologies
  @applied_accelerator_topologies
end

#autoscalerString

Output only. The URL of theAutoscaler that targets this instance group manager. Corresponds to the JSON property autoscaler

Returns:

  • (String)


25690
25691
25692
# File 'lib/google/apis/compute_beta/classes.rb', line 25690

def autoscaler
  @autoscaler
end

#bulk_instance_operationGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusBulkInstanceOperation

Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK. Corresponds to the JSON property bulkInstanceOperation



25696
25697
25698
# File 'lib/google/apis/compute_beta/classes.rb', line 25696

def bulk_instance_operation
  @bulk_instance_operation
end

#current_instance_statusesGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs. Corresponds to the JSON property currentInstanceStatuses



25704
25705
25706
# File 'lib/google/apis/compute_beta/classes.rb', line 25704

def current_instance_statuses
  @current_instance_statuses
end

#is_stableBoolean Also known as: is_stable?

Output only. A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified. Corresponds to the JSON property isStable

Returns:

  • (Boolean)


25714
25715
25716
# File 'lib/google/apis/compute_beta/classes.rb', line 25714

def is_stable
  @is_stable
end

#statefulGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusStateful

Output only. Stateful status of the given Instance Group Manager. Corresponds to the JSON property stateful



25720
25721
25722
# File 'lib/google/apis/compute_beta/classes.rb', line 25720

def stateful
  @stateful
end

#version_targetGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget

Output only. A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager. Corresponds to the JSON property versionTarget



25727
25728
25729
# File 'lib/google/apis/compute_beta/classes.rb', line 25727

def version_target
  @version_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25734
25735
25736
25737
25738
25739
25740
25741
25742
25743
# File 'lib/google/apis/compute_beta/classes.rb', line 25734

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @applied_accelerator_topologies = args[:applied_accelerator_topologies] if args.key?(:applied_accelerator_topologies)
  @autoscaler = args[:autoscaler] if args.key?(:autoscaler)
  @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation)
  @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses)
  @is_stable = args[:is_stable] if args.key?(:is_stable)
  @stateful = args[:stateful] if args.key?(:stateful)
  @version_target = args[:version_target] if args.key?(:version_target)
end