Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusAllInstancesConfig
Output only.
-
#applied_accelerator_topologies ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerStatusAcceleratorTopology>
Output only.
-
#autoscaler ⇒ String
Output only.
-
#bulk_instance_operation ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusBulkInstanceOperation
Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK.
-
#current_instance_statuses ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary
The list of instance statuses and the number of instances in this managed instance group that have the status.
-
#is_stable ⇒ Boolean
(also: #is_stable?)
Output only.
-
#stateful ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusStateful
Output only.
-
#version_target ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatus
constructor
A new instance of InstanceGroupManagerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatus
Returns a new instance of InstanceGroupManagerStatus.
25236 25237 25238 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25236 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusAllInstancesConfig
Output only. Status of all-instances configuration on the group.
Corresponds to the JSON property allInstancesConfig
25185 25186 25187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25185 def all_instances_config @all_instances_config end |
#applied_accelerator_topologies ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManagerStatusAcceleratorTopology>
Output only. The accelerator topology applied to this MIG.
Currently only one accelerator topology is supported.
Corresponds to the JSON property appliedAcceleratorTopologies
25191 25192 25193 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25191 def applied_accelerator_topologies @applied_accelerator_topologies end |
#autoscaler ⇒ String
Output only. The URL of theAutoscaler
that targets this instance group manager.
Corresponds to the JSON property autoscaler
25197 25198 25199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25197 def autoscaler @autoscaler end |
#bulk_instance_operation ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusBulkInstanceOperation
Bulk instance operation is the creation of VMs in a MIG when the
targetSizePolicy.mode is set to BULK.
Corresponds to the JSON property bulkInstanceOperation
25203 25204 25205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25203 def bulk_instance_operation @bulk_instance_operation end |
#current_instance_statuses ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary
The list of instance statuses and the number of instances in this managed
instance group that have the status. For more information about how to
interpret each status check the instance lifecycle documentation.
Currently only shown for TPU MIGs.
Corresponds to the JSON property currentInstanceStatuses
25211 25212 25213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25211 def current_instance_statuses @current_instance_statuses end |
#is_stable ⇒ Boolean Also known as: is_stable?
Output only. A bit indicating whether the managed instance group is in a
stable state. A stable state means that: none of the instances in the
managed instance group is currently undergoing any type of change (for
example, creation, restart, or deletion); no future changes are scheduled
for instances in the managed instance group; and the managed instance
group itself is not being modified.
Corresponds to the JSON property isStable
25221 25222 25223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25221 def is_stable @is_stable end |
#stateful ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusStateful
Output only. Stateful status of the given Instance Group Manager.
Corresponds to the JSON property stateful
25227 25228 25229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25227 def stateful @stateful end |
#version_target ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget
Output only. A status of consistency of Instances' versions with their
target version specified by version field on Instance Group
Manager.
Corresponds to the JSON property versionTarget
25234 25235 25236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25234 def version_target @version_target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25241 25242 25243 25244 25245 25246 25247 25248 25249 25250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25241 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @applied_accelerator_topologies = args[:applied_accelerator_topologies] if args.key?(:applied_accelerator_topologies) @autoscaler = args[:autoscaler] if args.key?(:autoscaler) @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation) @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses) @is_stable = args[:is_stable] if args.key?(:is_stable) @stateful = args[:stateful] if args.key?(:stateful) @version_target = args[:version_target] if args.key?(:version_target) end |