Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatus

Returns a new instance of InstanceGroupManagerStatus.



24059
24060
24061
# File 'lib/google/apis/compute_beta/classes.rb', line 24059

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusAllInstancesConfig

Output only. [Output only] Status of all-instances configuration on the group. Corresponds to the JSON property allInstancesConfig



24012
24013
24014
# File 'lib/google/apis/compute_beta/classes.rb', line 24012

def all_instances_config
  @all_instances_config
end

#autoscalerString

Output only. [Output Only] The URL of theAutoscaler that targets this instance group manager. Corresponds to the JSON property autoscaler

Returns:

  • (String)


24018
24019
24020
# File 'lib/google/apis/compute_beta/classes.rb', line 24018

def autoscaler
  @autoscaler
end

#bulk_instance_operationGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusBulkInstanceOperation

Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK. Corresponds to the JSON property bulkInstanceOperation



24024
24025
24026
# File 'lib/google/apis/compute_beta/classes.rb', line 24024

def bulk_instance_operation
  @bulk_instance_operation
end

#current_instance_statusesGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs. Corresponds to the JSON property currentInstanceStatuses



24032
24033
24034
# File 'lib/google/apis/compute_beta/classes.rb', line 24032

def current_instance_statuses
  @current_instance_statuses
end

#is_stableBoolean Also known as: is_stable?

Output only. [Output Only] A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified. Corresponds to the JSON property isStable

Returns:

  • (Boolean)


24043
24044
24045
# File 'lib/google/apis/compute_beta/classes.rb', line 24043

def is_stable
  @is_stable
end

#statefulGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusStateful

Output only. [Output Only] Stateful status of the given Instance Group Manager. Corresponds to the JSON property stateful



24049
24050
24051
# File 'lib/google/apis/compute_beta/classes.rb', line 24049

def stateful
  @stateful
end

#version_targetGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget

Output only. [Output Only] A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager. Corresponds to the JSON property versionTarget



24057
24058
24059
# File 'lib/google/apis/compute_beta/classes.rb', line 24057

def version_target
  @version_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24064
24065
24066
24067
24068
24069
24070
24071
24072
# File 'lib/google/apis/compute_beta/classes.rb', line 24064

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @autoscaler = args[:autoscaler] if args.key?(:autoscaler)
  @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation)
  @current_instance_statuses = args[:current_instance_statuses] if args.key?(:current_instance_statuses)
  @is_stable = args[:is_stable] if args.key?(:is_stable)
  @stateful = args[:stateful] if args.key?(:stateful)
  @version_target = args[:version_target] if args.key?(:version_target)
end