Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatus

Returns a new instance of InstanceGroupManagerStatus.



23654
23655
23656
# File 'lib/google/apis/compute_beta/classes.rb', line 23654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusAllInstancesConfig

Output only. [Output only] Status of all-instances configuration on the group. Corresponds to the JSON property allInstancesConfig



23615
23616
23617
# File 'lib/google/apis/compute_beta/classes.rb', line 23615

def all_instances_config
  @all_instances_config
end

#autoscalerString

Output only. [Output Only] The URL of theAutoscaler that targets this instance group manager. Corresponds to the JSON property autoscaler

Returns:

  • (String)


23621
23622
23623
# File 'lib/google/apis/compute_beta/classes.rb', line 23621

def autoscaler
  @autoscaler
end

#bulk_instance_operationGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusBulkInstanceOperation

Bulk instance operation is the creation of VMs in a MIG when the targetSizePolicy.mode is set to BULK. Corresponds to the JSON property bulkInstanceOperation



23627
23628
23629
# File 'lib/google/apis/compute_beta/classes.rb', line 23627

def bulk_instance_operation
  @bulk_instance_operation
end

#is_stableBoolean Also known as: is_stable?

Output only. [Output Only] A bit indicating whether the managed instance group is in a stable state. A stable state means that: none of the instances in the managed instance group is currently undergoing any type of change (for example, creation, restart, or deletion); no future changes are scheduled for instances in the managed instance group; and the managed instance group itself is not being modified. Corresponds to the JSON property isStable

Returns:

  • (Boolean)


23638
23639
23640
# File 'lib/google/apis/compute_beta/classes.rb', line 23638

def is_stable
  @is_stable
end

#statefulGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusStateful

Output only. [Output Only] Stateful status of the given Instance Group Manager. Corresponds to the JSON property stateful



23644
23645
23646
# File 'lib/google/apis/compute_beta/classes.rb', line 23644

def stateful
  @stateful
end

#version_targetGoogle::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget

Output only. [Output Only] A status of consistency of Instances' versions with their target version specified by version field on Instance Group Manager. Corresponds to the JSON property versionTarget



23652
23653
23654
# File 'lib/google/apis/compute_beta/classes.rb', line 23652

def version_target
  @version_target
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



23659
23660
23661
23662
23663
23664
23665
23666
# File 'lib/google/apis/compute_beta/classes.rb', line 23659

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @autoscaler = args[:autoscaler] if args.key?(:autoscaler)
  @bulk_instance_operation = args[:bulk_instance_operation] if args.key?(:bulk_instance_operation)
  @is_stable = args[:is_stable] if args.key?(:is_stable)
  @stateful = args[:stateful] if args.key?(:stateful)
  @version_target = args[:version_target] if args.key?(:version_target)
end