Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary

Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.



26284
26285
26286
# File 'lib/google/apis/compute_beta/classes.rb', line 26284

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprovisioningFixnum

Output only. The number of instances in the managed instance group that have DEPROVISIONING status. Corresponds to the JSON property deprovisioning

Returns:

  • (Fixnum)


26204
26205
26206
# File 'lib/google/apis/compute_beta/classes.rb', line 26204

def deprovisioning
  @deprovisioning
end

#non_existentFixnum

Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'. Corresponds to the JSON property nonExistent

Returns:

  • (Fixnum)


26214
26215
26216
# File 'lib/google/apis/compute_beta/classes.rb', line 26214

def non_existent
  @non_existent
end

#pendingFixnum

Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


26222
26223
26224
# File 'lib/google/apis/compute_beta/classes.rb', line 26222

def pending
  @pending
end

#pending_stopFixnum

Output only. The number of instances in the managed instance group that have PENDING_STOP status. Corresponds to the JSON property pendingStop

Returns:

  • (Fixnum)


26228
26229
26230
# File 'lib/google/apis/compute_beta/classes.rb', line 26228

def pending_stop
  @pending_stop
end

#provisioningFixnum

Output only. The number of instances in the managed instance group that have PROVISIONING status. Corresponds to the JSON property provisioning

Returns:

  • (Fixnum)


26234
26235
26236
# File 'lib/google/apis/compute_beta/classes.rb', line 26234

def provisioning
  @provisioning
end

#repairingFixnum

Output only. The number of instances in the managed instance group that have REPAIRING status. Corresponds to the JSON property repairing

Returns:

  • (Fixnum)


26240
26241
26242
# File 'lib/google/apis/compute_beta/classes.rb', line 26240

def repairing
  @repairing
end

#runningFixnum

Output only. The number of instances in the managed instance group that have RUNNING status. Corresponds to the JSON property running

Returns:

  • (Fixnum)


26246
26247
26248
# File 'lib/google/apis/compute_beta/classes.rb', line 26246

def running
  @running
end

#stagingFixnum

Output only. The number of instances in the managed instance group that have STAGING status. Corresponds to the JSON property staging

Returns:

  • (Fixnum)


26252
26253
26254
# File 'lib/google/apis/compute_beta/classes.rb', line 26252

def staging
  @staging
end

#stoppedFixnum

Output only. The number of instances in the managed instance group that have STOPPED status. Corresponds to the JSON property stopped

Returns:

  • (Fixnum)


26258
26259
26260
# File 'lib/google/apis/compute_beta/classes.rb', line 26258

def stopped
  @stopped
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that have STOPPING status. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


26264
26265
26266
# File 'lib/google/apis/compute_beta/classes.rb', line 26264

def stopping
  @stopping
end

#suspendedFixnum

Output only. The number of instances in the managed instance group that have SUSPENDED status. Corresponds to the JSON property suspended

Returns:

  • (Fixnum)


26270
26271
26272
# File 'lib/google/apis/compute_beta/classes.rb', line 26270

def suspended
  @suspended
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that have SUSPENDING status. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


26276
26277
26278
# File 'lib/google/apis/compute_beta/classes.rb', line 26276

def suspending
  @suspending
end

#terminatedFixnum

Output only. The number of instances in the managed instance group that have TERMINATED status. Corresponds to the JSON property terminated

Returns:

  • (Fixnum)


26282
26283
26284
# File 'lib/google/apis/compute_beta/classes.rb', line 26282

def terminated
  @terminated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26289
26290
26291
26292
26293
26294
26295
26296
26297
26298
26299
26300
26301
26302
26303
# File 'lib/google/apis/compute_beta/classes.rb', line 26289

def update!(**args)
  @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning)
  @non_existent = args[:non_existent] if args.key?(:non_existent)
  @pending = args[:pending] if args.key?(:pending)
  @pending_stop = args[:pending_stop] if args.key?(:pending_stop)
  @provisioning = args[:provisioning] if args.key?(:provisioning)
  @repairing = args[:repairing] if args.key?(:repairing)
  @running = args[:running] if args.key?(:running)
  @staging = args[:staging] if args.key?(:staging)
  @stopped = args[:stopped] if args.key?(:stopped)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspended = args[:suspended] if args.key?(:suspended)
  @suspending = args[:suspending] if args.key?(:suspending)
  @terminated = args[:terminated] if args.key?(:terminated)
end