Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary

Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.



25149
25150
25151
# File 'lib/google/apis/compute_beta/classes.rb', line 25149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deprovisioningFixnum

Output only. The number of instances in the managed instance group that have DEPROVISIONING status. Corresponds to the JSON property deprovisioning

Returns:

  • (Fixnum)


25069
25070
25071
# File 'lib/google/apis/compute_beta/classes.rb', line 25069

def deprovisioning
  @deprovisioning
end

#non_existentFixnum

Output only. The number of instances that have not been created yet or have been deleted. Includes only instances that would be shown in the listManagedInstances method and not all instances that have been deleted in the lifetime of the MIG. Does not include FlexStart instances that are waiting for the resources availability, they are considered as 'pending'. Corresponds to the JSON property nonExistent

Returns:

  • (Fixnum)


25079
25080
25081
# File 'lib/google/apis/compute_beta/classes.rb', line 25079

def non_existent
  @non_existent
end

#pendingFixnum

Output only. The number of instances in the managed instance group that have PENDING status, that is FlexStart instances that are waiting for resources. Instances that do not exist because of the other reasons are counted as 'non_existent'. Corresponds to the JSON property pending

Returns:

  • (Fixnum)


25087
25088
25089
# File 'lib/google/apis/compute_beta/classes.rb', line 25087

def pending
  @pending
end

#pending_stopFixnum

Output only. The number of instances in the managed instance group that have PENDING_STOP status. Corresponds to the JSON property pendingStop

Returns:

  • (Fixnum)


25093
25094
25095
# File 'lib/google/apis/compute_beta/classes.rb', line 25093

def pending_stop
  @pending_stop
end

#provisioningFixnum

Output only. The number of instances in the managed instance group that have PROVISIONING status. Corresponds to the JSON property provisioning

Returns:

  • (Fixnum)


25099
25100
25101
# File 'lib/google/apis/compute_beta/classes.rb', line 25099

def provisioning
  @provisioning
end

#repairingFixnum

Output only. The number of instances in the managed instance group that have REPAIRING status. Corresponds to the JSON property repairing

Returns:

  • (Fixnum)


25105
25106
25107
# File 'lib/google/apis/compute_beta/classes.rb', line 25105

def repairing
  @repairing
end

#runningFixnum

Output only. The number of instances in the managed instance group that have RUNNING status. Corresponds to the JSON property running

Returns:

  • (Fixnum)


25111
25112
25113
# File 'lib/google/apis/compute_beta/classes.rb', line 25111

def running
  @running
end

#stagingFixnum

Output only. The number of instances in the managed instance group that have STAGING status. Corresponds to the JSON property staging

Returns:

  • (Fixnum)


25117
25118
25119
# File 'lib/google/apis/compute_beta/classes.rb', line 25117

def staging
  @staging
end

#stoppedFixnum

Output only. The number of instances in the managed instance group that have STOPPED status. Corresponds to the JSON property stopped

Returns:

  • (Fixnum)


25123
25124
25125
# File 'lib/google/apis/compute_beta/classes.rb', line 25123

def stopped
  @stopped
end

#stoppingFixnum

Output only. The number of instances in the managed instance group that have STOPPING status. Corresponds to the JSON property stopping

Returns:

  • (Fixnum)


25129
25130
25131
# File 'lib/google/apis/compute_beta/classes.rb', line 25129

def stopping
  @stopping
end

#suspendedFixnum

Output only. The number of instances in the managed instance group that have SUSPENDED status. Corresponds to the JSON property suspended

Returns:

  • (Fixnum)


25135
25136
25137
# File 'lib/google/apis/compute_beta/classes.rb', line 25135

def suspended
  @suspended
end

#suspendingFixnum

Output only. The number of instances in the managed instance group that have SUSPENDING status. Corresponds to the JSON property suspending

Returns:

  • (Fixnum)


25141
25142
25143
# File 'lib/google/apis/compute_beta/classes.rb', line 25141

def suspending
  @suspending
end

#terminatedFixnum

Output only. The number of instances in the managed instance group that have TERMINATED status. Corresponds to the JSON property terminated

Returns:

  • (Fixnum)


25147
25148
25149
# File 'lib/google/apis/compute_beta/classes.rb', line 25147

def terminated
  @terminated
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25154
25155
25156
25157
25158
25159
25160
25161
25162
25163
25164
25165
25166
25167
25168
# File 'lib/google/apis/compute_beta/classes.rb', line 25154

def update!(**args)
  @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning)
  @non_existent = args[:non_existent] if args.key?(:non_existent)
  @pending = args[:pending] if args.key?(:pending)
  @pending_stop = args[:pending_stop] if args.key?(:pending_stop)
  @provisioning = args[:provisioning] if args.key?(:provisioning)
  @repairing = args[:repairing] if args.key?(:repairing)
  @running = args[:running] if args.key?(:running)
  @staging = args[:staging] if args.key?(:staging)
  @stopped = args[:stopped] if args.key?(:stopped)
  @stopping = args[:stopping] if args.key?(:stopping)
  @suspended = args[:suspended] if args.key?(:suspended)
  @suspending = args[:suspending] if args.key?(:suspending)
  @terminated = args[:terminated] if args.key?(:terminated)
end