Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerStatusInstanceStatusSummary
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The list of instance statuses and the number of instances in this managed instance group that have the status. For more information about how to interpret each status check the instance lifecycle documentation. Currently only shown for TPU MIGs.
Instance Attribute Summary collapse
-
#deprovisioning ⇒ Fixnum
Output only.
-
#non_existent ⇒ Fixnum
Output only.
-
#pending ⇒ Fixnum
Output only.
-
#pending_stop ⇒ Fixnum
Output only.
-
#provisioning ⇒ Fixnum
Output only.
-
#repairing ⇒ Fixnum
Output only.
-
#running ⇒ Fixnum
Output only.
-
#staging ⇒ Fixnum
Output only.
-
#stopped ⇒ Fixnum
Output only.
-
#stopping ⇒ Fixnum
Output only.
-
#suspended ⇒ Fixnum
Output only.
-
#suspending ⇒ Fixnum
Output only.
-
#terminated ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary
constructor
A new instance of InstanceGroupManagerStatusInstanceStatusSummary.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatusInstanceStatusSummary
Returns a new instance of InstanceGroupManagerStatusInstanceStatusSummary.
24385 24386 24387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deprovisioning ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have DEPROVISIONING status.
Corresponds to the JSON property deprovisioning
24293 24294 24295 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24293 def deprovisioning @deprovisioning end |
#non_existent ⇒ Fixnum
Output only. [Output Only] The number of instances that have not been created
yet or
have been deleted. Includes only instances that would be shown in the
listManagedInstances method and not all instances that have been
deleted in the lifetime of the MIG.
Does not include FlexStart instances that are waiting for the resources
availability, they are considered as 'pending'.
Corresponds to the JSON property nonExistent
24304 24305 24306 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24304 def non_existent @non_existent end |
#pending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have PENDING status, that is FlexStart instances that are waiting
for resources. Instances that do not exist because of the other reasons
are counted as 'non_existent'.
Corresponds to the JSON property pending
24313 24314 24315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24313 def pending @pending end |
#pending_stop ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have PENDING_STOP status.
Corresponds to the JSON property pendingStop
24320 24321 24322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24320 def pending_stop @pending_stop end |
#provisioning ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have PROVISIONING status.
Corresponds to the JSON property provisioning
24327 24328 24329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24327 def provisioning @provisioning end |
#repairing ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have REPAIRING status.
Corresponds to the JSON property repairing
24334 24335 24336 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24334 def repairing @repairing end |
#running ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have RUNNING status.
Corresponds to the JSON property running
24341 24342 24343 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24341 def running @running end |
#staging ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have STAGING status.
Corresponds to the JSON property staging
24348 24349 24350 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24348 def staging @staging end |
#stopped ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have STOPPED status.
Corresponds to the JSON property stopped
24355 24356 24357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24355 def stopped @stopped end |
#stopping ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have STOPPING status.
Corresponds to the JSON property stopping
24362 24363 24364 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24362 def stopping @stopping end |
#suspended ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have SUSPENDED status.
Corresponds to the JSON property suspended
24369 24370 24371 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24369 def suspended @suspended end |
#suspending ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have SUSPENDING status.
Corresponds to the JSON property suspending
24376 24377 24378 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24376 def suspending @suspending end |
#terminated ⇒ Fixnum
Output only. [Output Only] The number of instances in the managed instance
group
that have TERMINATED status.
Corresponds to the JSON property terminated
24383 24384 24385 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24383 def terminated @terminated end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24390 24391 24392 24393 24394 24395 24396 24397 24398 24399 24400 24401 24402 24403 24404 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24390 def update!(**args) @deprovisioning = args[:deprovisioning] if args.key?(:deprovisioning) @non_existent = args[:non_existent] if args.key?(:non_existent) @pending = args[:pending] if args.key?(:pending) @pending_stop = args[:pending_stop] if args.key?(:pending_stop) @provisioning = args[:provisioning] if args.key?(:provisioning) @repairing = args[:repairing] if args.key?(:repairing) @running = args[:running] if args.key?(:running) @staging = args[:staging] if args.key?(:staging) @stopped = args[:stopped] if args.key?(:stopped) @stopping = args[:stopping] if args.key?(:stopping) @suspended = args[:suspended] if args.key?(:suspended) @suspending = args[:suspending] if args.key?(:suspending) @terminated = args[:terminated] if args.key?(:terminated) end |