Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatusStateful
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerStatusStateful
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#has_stateful_config ⇒ Boolean
(also: #has_stateful_config?)
Output only.
-
#is_stateful ⇒ Boolean
(also: #is_stateful?)
Output only.
-
#per_instance_configs ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusStatefulPerInstanceConfigs
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerStatusStateful
constructor
A new instance of InstanceGroupManagerStatusStateful.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerStatusStateful
Returns a new instance of InstanceGroupManagerStatusStateful.
25203 25204 25205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#has_stateful_config ⇒ Boolean Also known as: has_stateful_config?
Output only. A bit indicating whether the managed instance group
has stateful configuration, that is, if you have configured any items
in a stateful policy or in per-instance configs.
The group might report that it has no stateful configuration even when
there is still some preserved state on a managed instance, for example,
if you have deleted all PICs but not yet applied those deletions.
Corresponds to the JSON property hasStatefulConfig
25183 25184 25185 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25183 def has_stateful_config @has_stateful_config end |
#is_stateful ⇒ Boolean Also known as: is_stateful?
Output only. A bit indicating whether the managed instance group
has stateful configuration, that is, if you have configured any items
in a stateful policy or in per-instance configs.
The group might report that it has no stateful configuration even when
there is still some preserved state on a managed instance, for example,
if you have deleted all PICs but not yet applied those deletions. This
field is deprecated in favor of has_stateful_config.
Corresponds to the JSON property isStateful
25195 25196 25197 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25195 def is_stateful @is_stateful end |
#per_instance_configs ⇒ Google::Apis::ComputeBeta::InstanceGroupManagerStatusStatefulPerInstanceConfigs
Output only. Status of per-instance configurations on the instances.
Corresponds to the JSON property perInstanceConfigs
25201 25202 25203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25201 def per_instance_configs @per_instance_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25208 25209 25210 25211 25212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25208 def update!(**args) @has_stateful_config = args[:has_stateful_config] if args.key?(:has_stateful_config) @is_stateful = args[:is_stateful] if args.key?(:is_stateful) @per_instance_configs = args[:per_instance_configs] if args.key?(:per_instance_configs) end |