Class: Google::Apis::ComputeBeta::InstanceGroupManagerStatusVersionTarget

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerStatusVersionTarget

Returns a new instance of InstanceGroupManagerStatusVersionTarget.



24489
24490
24491
# File 'lib/google/apis/compute_beta/classes.rb', line 24489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#is_reachedBoolean Also known as: is_reached?

Output only. [Output Only] A bit indicating whether version target has been reached in this managed instance group, i.e. all instances are in their target version. Instances' target version are specified byversion field on Instance Group Manager. Corresponds to the JSON property isReached

Returns:

  • (Boolean)


24486
24487
24488
# File 'lib/google/apis/compute_beta/classes.rb', line 24486

def is_reached
  @is_reached
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24494
24495
24496
# File 'lib/google/apis/compute_beta/classes.rb', line 24494

def update!(**args)
  @is_reached = args[:is_reached] if args.key?(:is_reached)
end