Class: Google::Apis::ComputeBeta::InstanceGroupManagerVersion
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagerVersion
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
-
#name ⇒ String
Name of the version.
-
#target_size ⇒ Google::Apis::ComputeBeta::FixedOrPercent
Encapsulates numeric value that can be either absolute or relative.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagerVersion
constructor
A new instance of InstanceGroupManagerVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagerVersion
Returns a new instance of InstanceGroupManagerVersion.
26534 26535 26536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26534 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create new instances in
the managed instance group until the targetSize for this version is
reached. The templates for existing instances in the group do not change
unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'
supdatePolicy.type to PROACTIVE; in those cases,
existing instances are updated until the targetSize for this version is
reached.
Corresponds to the JSON property instanceTemplate
26521 26522 26523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26521 def instance_template @instance_template end |
#name ⇒ String
Name of the version. Unique among all versions in the scope of this
managed instance group.
Corresponds to the JSON property name
26527 26528 26529 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26527 def name @name end |
#target_size ⇒ Google::Apis::ComputeBeta::FixedOrPercent
Encapsulates numeric value that can be either absolute or relative.
Corresponds to the JSON property targetSize
26532 26533 26534 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26532 def target_size @target_size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26539 26540 26541 26542 26543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26539 def update!(**args) @instance_template = args[:instance_template] if args.key?(:instance_template) @name = args[:name] if args.key?(:name) @target_size = args[:target_size] if args.key?(:target_size) end |