Class: Google::Apis::ComputeBeta::InstanceGroupManagerVersion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagerVersion

Returns a new instance of InstanceGroupManagerVersion.



24639
24640
24641
# File 'lib/google/apis/compute_beta/classes.rb', line 24639

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create new instances in the managed instance group until the targetSize for this version is reached. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group' supdatePolicy.type to PROACTIVE; in those cases, existing instances are updated until the targetSize for this version is reached. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


24626
24627
24628
# File 'lib/google/apis/compute_beta/classes.rb', line 24626

def instance_template
  @instance_template
end

#nameString

Name of the version. Unique among all versions in the scope of this managed instance group. Corresponds to the JSON property name

Returns:

  • (String)


24632
24633
24634
# File 'lib/google/apis/compute_beta/classes.rb', line 24632

def name
  @name
end

#target_sizeGoogle::Apis::ComputeBeta::FixedOrPercent

Encapsulates numeric value that can be either absolute or relative. Corresponds to the JSON property targetSize



24637
24638
24639
# File 'lib/google/apis/compute_beta/classes.rb', line 24637

def target_size
  @target_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24644
24645
24646
24647
24648
# File 'lib/google/apis/compute_beta/classes.rb', line 24644

def update!(**args)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
  @name = args[:name] if args.key?(:name)
  @target_size = args[:target_size] if args.key?(:target_size)
end