Class: Google::Apis::ComputeBeta::InstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

InstanceGroupManagers.applyUpdatesToInstances

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersApplyUpdatesRequest

Returns a new instance of InstanceGroupManagersApplyUpdatesRequest.



26593
26594
26595
# File 'lib/google/apis/compute_beta/classes.rb', line 26593

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instancesBoolean Also known as: all_instances?

Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request. Corresponds to the JSON property allInstances

Returns:

  • (Boolean)


26542
26543
26544
# File 'lib/google/apis/compute_beta/classes.rb', line 26542

def all_instances
  @all_instances
end

#allowed_actionsArray<String>

Actions that are allowed to update instances within MIG. Corresponds to the JSON property allowedActions

Returns:

  • (Array<String>)


26548
26549
26550
# File 'lib/google/apis/compute_beta/classes.rb', line 26548

def allowed_actions
  @allowed_actions
end

#instancesArray<String>

The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/ instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


26555
26556
26557
# File 'lib/google/apis/compute_beta/classes.rb', line 26555

def instances
  @instances
end

#minimal_actionString

The minimal action that you want to perform on each instance during the update:

  • REPLACE: At minimum, delete the instance and create it again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Corresponds to the JSON property minimalAction

Returns:

  • (String)


26574
26575
26576
# File 'lib/google/apis/compute_beta/classes.rb', line 26574

def minimal_action
  @minimal_action
end

#most_disruptive_allowed_actionString

The most disruptive action that you want to perform on each instance during the update:

  • REPLACE: Delete the instance and create it again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Corresponds to the JSON property mostDisruptiveAllowedAction

Returns:

  • (String)


26591
26592
26593
# File 'lib/google/apis/compute_beta/classes.rb', line 26591

def most_disruptive_allowed_action
  @most_disruptive_allowed_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26598
26599
26600
26601
26602
26603
26604
# File 'lib/google/apis/compute_beta/classes.rb', line 26598

def update!(**args)
  @all_instances = args[:all_instances] if args.key?(:all_instances)
  @allowed_actions = args[:allowed_actions] if args.key?(:allowed_actions)
  @instances = args[:instances] if args.key?(:instances)
  @minimal_action = args[:minimal_action] if args.key?(:minimal_action)
  @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action)
end