Class: Google::Apis::ComputeBeta::InstanceGroupManagersApplyUpdatesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersApplyUpdatesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
InstanceGroupManagers.applyUpdatesToInstances
Instance Attribute Summary collapse
-
#all_instances ⇒ Boolean
(also: #all_instances?)
Flag to update all instances instead of specified list of “instances”.
-
#allowed_actions ⇒ Array<String>
Actions that are allowed to update instances within MIG.
-
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply updates.
-
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:.
-
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersApplyUpdatesRequest
constructor
A new instance of InstanceGroupManagersApplyUpdatesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersApplyUpdatesRequest
Returns a new instance of InstanceGroupManagersApplyUpdatesRequest.
26571 26572 26573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances ⇒ Boolean Also known as: all_instances?
Flag to update all instances instead of specified list of “instances”.
If the flag is set to true then the instances may not be specified
in the request.
Corresponds to the JSON property allInstances
26520 26521 26522 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26520 def all_instances @all_instances end |
#allowed_actions ⇒ Array<String>
Actions that are allowed to update instances within MIG.
Corresponds to the JSON property allowedActions
26526 26527 26528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26526 def allowed_actions @allowed_actions end |
#instances ⇒ Array<String>
The list of URLs of one or more instances for which you want to apply
updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/
instances/[INSTANCE_NAME].
Corresponds to the JSON property instances
26533 26534 26535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26533 def instances @instances end |
#minimal_action ⇒ String
The minimal action that you want to perform on each instance during the update:
- REPLACE: At minimum, delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not
disrupt the instance at all.
By default, the minimum action is NONE. If your update
requires a more disruptive action than you set with this flag, the
necessary action is performed to execute the update.
Corresponds to the JSON property
minimalAction
26552 26553 26554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26552 def minimal_action @minimal_action end |
#most_disruptive_allowed_action ⇒ String
The most disruptive action that you want to perform on each instance during the update:
- REPLACE: Delete the instance and create it again.
- RESTART: Stop the instance and start it again.
- REFRESH: Do not stop the instance and limit disruption as much as possible.
- NONE: Do not disrupt the
instance at all.
By default, the most disruptive allowed action is REPLACE. If
your update requires a more disruptive action than you set with this flag,
the update request will fail.
Corresponds to the JSON property
mostDisruptiveAllowedAction
26569 26570 26571 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26569 def most_disruptive_allowed_action @most_disruptive_allowed_action end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26576 26577 26578 26579 26580 26581 26582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26576 def update!(**args) @all_instances = args[:all_instances] if args.key?(:all_instances) @allowed_actions = args[:allowed_actions] if args.key?(:allowed_actions) @instances = args[:instances] if args.key?(:instances) @minimal_action = args[:minimal_action] if args.key?(:minimal_action) @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action) end |