Class: Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

InstanceGroupManagers.ConfigureAcceleratorTopologies

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest

Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.



26625
26626
26627
# File 'lib/google/apis/compute_beta/classes.rb', line 26625

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_actionsHash<String,String>

Map of accelerator topologies that should have their state changed to the specified value. The key is the hashed topology locus id. It can be obtained from the GetAvailableAcceleratorTopologies rpc. Corresponds to the JSON property acceleratorTopologyActions

Returns:

  • (Hash<String,String>)


26616
26617
26618
# File 'lib/google/apis/compute_beta/classes.rb', line 26616

def accelerator_topology_actions
  @accelerator_topology_actions
end

#accelerator_topology_configurationsHash<String,Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>

Map of accelerator topologies that should have their state changed to the specified configuration. The map key is the hashed topology locus id. It can be obtained from the GetAvailableAcceleratorTopologies rpc. Corresponds to the JSON property acceleratorTopologyConfigurations



26623
26624
26625
# File 'lib/google/apis/compute_beta/classes.rb', line 26623

def accelerator_topology_configurations
  @accelerator_topology_configurations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26630
26631
26632
26633
# File 'lib/google/apis/compute_beta/classes.rb', line 26630

def update!(**args)
  @accelerator_topology_actions = args[:accelerator_topology_actions] if args.key?(:accelerator_topology_actions)
  @accelerator_topology_configurations = args[:accelerator_topology_configurations] if args.key?(:accelerator_topology_configurations)
end