Class: Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
InstanceGroupManagers.ConfigureAcceleratorTopologies
Instance Attribute Summary collapse
-
#accelerator_topology_actions ⇒ Hash<String,String>
Map of accelerator topologies that should have their state changed to the specified value.
-
#accelerator_topology_configurations ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>
Map of accelerator topologies that should have their state changed to the specified configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest
constructor
A new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequest
Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequest.
26603 26604 26605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26603 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology_actions ⇒ Hash<String,String>
Map of accelerator topologies that should have their state changed to
the specified value. The key is the hashed topology locus id. It can be
obtained from the GetAvailableAcceleratorTopologies rpc.
Corresponds to the JSON property acceleratorTopologyActions
26594 26595 26596 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26594 def accelerator_topology_actions @accelerator_topology_actions end |
#accelerator_topology_configurations ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration>
Map of accelerator topologies that should have their state changed to
the specified configuration. The map key is the hashed topology locus id.
It can be obtained from the GetAvailableAcceleratorTopologies rpc.
Corresponds to the JSON property acceleratorTopologyConfigurations
26601 26602 26603 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26601 def accelerator_topology_configurations @accelerator_topology_configurations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26608 26609 26610 26611 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26608 def update!(**args) @accelerator_topology_actions = args[:accelerator_topology_actions] if args.key?(:accelerator_topology_actions) @accelerator_topology_configurations = args[:accelerator_topology_configurations] if args.key?(:accelerator_topology_configurations) end |