Class: Google::Apis::ComputeBeta::InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration for a single accelerator topology.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration

Returns a new instance of InstanceGroupManagersConfigureAcceleratorTopologiesRequestAcceleratorTopologyConfiguration.



26655
26656
26657
# File 'lib/google/apis/compute_beta/classes.rb', line 26655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Corresponds to the JSON property action

Returns:

  • (String)


26643
26644
26645
# File 'lib/google/apis/compute_beta/classes.rb', line 26643

def action
  @action
end

#external_idString

Identifier of the accelerator topology assigned externally to differentiate who is the owner of the topology. The format needs to conform to RFC1035 and be unique. The uniqueness is guaranteed by the requestor. If it is provided on activating the sub-slice it will have to be provided on deactivating as well. This identifier is cleared on successful deform of a sub-slice. Corresponds to the JSON property externalId

Returns:

  • (String)


26653
26654
26655
# File 'lib/google/apis/compute_beta/classes.rb', line 26653

def external_id
  @external_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26660
26661
26662
26663
# File 'lib/google/apis/compute_beta/classes.rb', line 26660

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @external_id = args[:external_id] if args.key?(:external_id)
end