Class: Google::Apis::ComputeBeta::InstanceGroupManagersDeleteInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersDeleteInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<String>
The URLs of one or more instances to delete.
-
#skip_instances_on_validation_error ⇒ Boolean
(also: #skip_instances_on_validation_error?)
Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersDeleteInstancesRequest
constructor
A new instance of InstanceGroupManagersDeleteInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersDeleteInstancesRequest
Returns a new instance of InstanceGroupManagersDeleteInstancesRequest.
26709 26710 26711 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26709 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<String>
The URLs of one or more instances to delete. This can be a full URL or
a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME].
Queued instances do not have URL and can be deleted only by name.
One cannot specify both URLs and names in a single request.
Corresponds to the JSON property instances
26695 26696 26697 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26695 def instances @instances end |
#skip_instances_on_validation_error ⇒ Boolean Also known as: skip_instances_on_validation_error?
Specifies whether the request should proceed despite the inclusion of
instances that are not members of the group or that are already in the
process of being deleted or abandoned. If this field is set to false and
such an instance is specified in the request, the operation fails. The
operation always fails if the request contains a malformed instance URL or
a reference to an instance that exists in a zone or region other than the
group's zone or region.
Corresponds to the JSON property skipInstancesOnValidationError
26706 26707 26708 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26706 def skip_instances_on_validation_error @skip_instances_on_validation_error end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26714 26715 26716 26717 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26714 def update!(**args) @instances = args[:instances] if args.key?(:instances) @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error) end |