Class: Google::Apis::ComputeBeta::InstanceGroupManagersDeleteInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersDeleteInstancesRequest

Returns a new instance of InstanceGroupManagersDeleteInstancesRequest.



26182
26183
26184
# File 'lib/google/apis/compute_beta/classes.rb', line 26182

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instancesArray<String>

The URLs of one or more instances to delete. This can be a full URL or a partial URL, such as zones/[ZONE]/instances/[INSTANCE_NAME]. Queued instances do not have URL and can be deleted only by name. One cannot specify both URLs and names in a single request. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


26168
26169
26170
# File 'lib/google/apis/compute_beta/classes.rb', line 26168

def instances
  @instances
end

#skip_instances_on_validation_errorBoolean Also known as: skip_instances_on_validation_error?

Specifies whether the request should proceed despite the inclusion of instances that are not members of the group or that are already in the process of being deleted or abandoned. If this field is set to false and such an instance is specified in the request, the operation fails. The operation always fails if the request contains a malformed instance URL or a reference to an instance that exists in a zone or region other than the group's zone or region. Corresponds to the JSON property skipInstancesOnValidationError

Returns:

  • (Boolean)


26179
26180
26181
# File 'lib/google/apis/compute_beta/classes.rb', line 26179

def skip_instances_on_validation_error
  @skip_instances_on_validation_error
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26187
26188
26189
26190
# File 'lib/google/apis/compute_beta/classes.rb', line 26187

def update!(**args)
  @instances = args[:instances] if args.key?(:instances)
  @skip_instances_on_validation_error = args[:skip_instances_on_validation_error] if args.key?(:skip_instances_on_validation_error)
end