Class: Google::Apis::ComputeBeta::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifies the topology state
Defined Under Namespace
Classes: Error
Instance Attribute Summary collapse
-
#current_state ⇒ String
Corresponds to the JSON property
currentState. -
#error ⇒ Google::Apis::ComputeBeta::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error
Reason why the topology state change failed Corresponds to the JSON property
error. -
#error_timestamp ⇒ String
Timestamp when the last error happened Corresponds to the JSON property
errorTimestamp. -
#external_id ⇒ String
Identifier of the accelerator topology assigned externally to differentiate who is the owner of the topology.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState
constructor
A new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState
Returns a new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState.
26311 26312 26313 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26311 def initialize(**args) update!(**args) end |
Instance Attribute Details
#current_state ⇒ String
Corresponds to the JSON property currentState
26290 26291 26292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26290 def current_state @current_state end |
#error ⇒ Google::Apis::ComputeBeta::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error
Reason why the topology state change failed
Corresponds to the JSON property error
26295 26296 26297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26295 def error @error end |
#error_timestamp ⇒ String
Timestamp when the last error happened
Corresponds to the JSON property errorTimestamp
26300 26301 26302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26300 def @error_timestamp end |
#external_id ⇒ String
Identifier of the accelerator topology assigned externally to
differentiate who is the owner of the topology. This is set in
ConfigureAcceleratorTopologies. If it is provided on activating the
sub-slice it will have to be provided on deactivating as well.
This identifier is cleared on successful deform of a sub-slice.
Corresponds to the JSON property externalId
26309 26310 26311 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26309 def external_id @external_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26316 26317 26318 26319 26320 26321 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26316 def update!(**args) @current_state = args[:current_state] if args.key?(:current_state) @error = args[:error] if args.key?(:error) @error_timestamp = args[:error_timestamp] if args.key?(:error_timestamp) @external_id = args[:external_id] if args.key?(:external_id) end |