Class: Google::Apis::ComputeBeta::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies the topology state

Defined Under Namespace

Classes: Error

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState

Returns a new instance of InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState.



25732
25733
25734
# File 'lib/google/apis/compute_beta/classes.rb', line 25732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#current_stateString

Corresponds to the JSON property currentState

Returns:

  • (String)


25711
25712
25713
# File 'lib/google/apis/compute_beta/classes.rb', line 25711

def current_state
  @current_state
end

#errorGoogle::Apis::ComputeBeta::InstanceGroupManagersGetAvailableAcceleratorTopologiesResponseAcceleratorTopologyState::Error

Reason why the topology state change failed Corresponds to the JSON property error



25716
25717
25718
# File 'lib/google/apis/compute_beta/classes.rb', line 25716

def error
  @error
end

#error_timestampString

Timestamp when the last error happened Corresponds to the JSON property errorTimestamp

Returns:

  • (String)


25721
25722
25723
# File 'lib/google/apis/compute_beta/classes.rb', line 25721

def error_timestamp
  @error_timestamp
end

#external_idString

Identifier of the accelerator topology assigned externally to differentiate who is the owner of the topology. This is set in ConfigureAcceleratorTopologies. If it is provided on activating the sub-slice it will have to be provided on deactivating as well. This identifier is cleared on successful deform of a sub-slice. Corresponds to the JSON property externalId

Returns:

  • (String)


25730
25731
25732
# File 'lib/google/apis/compute_beta/classes.rb', line 25730

def external_id
  @external_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25737
25738
25739
25740
25741
25742
# File 'lib/google/apis/compute_beta/classes.rb', line 25737

def update!(**args)
  @current_state = args[:current_state] if args.key?(:current_state)
  @error = args[:error] if args.key?(:error)
  @error_timestamp = args[:error_timestamp] if args.key?(:error_timestamp)
  @external_id = args[:external_id] if args.key?(:external_id)
end