Class: Google::Apis::ComputeBeta::InstanceGroupManagersListManagedInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse

Returns a new instance of InstanceGroupManagersListManagedInstancesResponse.



27056
27057
27058
# File 'lib/google/apis/compute_beta/classes.rb', line 27056

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeBeta::ManagedInstance>

Output only. [Output Only] The list of instances in the managed instance group. Corresponds to the JSON property managedInstances



27043
27044
27045
# File 'lib/google/apis/compute_beta/classes.rb', line 27043

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27054
27055
27056
# File 'lib/google/apis/compute_beta/classes.rb', line 27054

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27061
27062
27063
27064
# File 'lib/google/apis/compute_beta/classes.rb', line 27061

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end