Class: Google::Apis::ComputeBeta::InstanceGroupManagersListManagedInstancesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersListManagedInstancesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#managed_instances ⇒ Array<Google::Apis::ComputeBeta::ManagedInstance>
Output only.
-
#next_page_token ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse
constructor
A new instance of InstanceGroupManagersListManagedInstancesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersListManagedInstancesResponse
Returns a new instance of InstanceGroupManagersListManagedInstancesResponse.
26496 26497 26498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26496 def initialize(**args) update!(**args) end |
Instance Attribute Details
#managed_instances ⇒ Array<Google::Apis::ComputeBeta::ManagedInstance>
Output only. [Output Only] The list of instances in the managed instance group.
Corresponds to the JSON property managedInstances
26483 26484 26485 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26483 def managed_instances @managed_instances end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26494 26495 26496 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26494 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26501 26502 26503 26504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26501 def update!(**args) @managed_instances = args[:managed_instances] if args.key?(:managed_instances) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |