Class: Google::Apis::ComputeBeta::InstanceGroupManagersListPerInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListPerInstanceConfigsResp

Returns a new instance of InstanceGroupManagersListPerInstanceConfigsResp.



27092
27093
27094
# File 'lib/google/apis/compute_beta/classes.rb', line 27092

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeBeta::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



27074
27075
27076
# File 'lib/google/apis/compute_beta/classes.rb', line 27074

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27085
27086
27087
# File 'lib/google/apis/compute_beta/classes.rb', line 27085

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagersListPerInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27090
27091
27092
# File 'lib/google/apis/compute_beta/classes.rb', line 27090

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27097
27098
27099
27100
27101
# File 'lib/google/apis/compute_beta/classes.rb', line 27097

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end