Class: Google::Apis::ComputeBeta::InstanceGroupManagersListPerInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersListPerInstanceConfigsResp

Returns a new instance of InstanceGroupManagersListPerInstanceConfigsResp.



26532
26533
26534
# File 'lib/google/apis/compute_beta/classes.rb', line 26532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeBeta::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



26514
26515
26516
# File 'lib/google/apis/compute_beta/classes.rb', line 26514

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


26525
26526
26527
# File 'lib/google/apis/compute_beta/classes.rb', line 26525

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupManagersListPerInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



26530
26531
26532
# File 'lib/google/apis/compute_beta/classes.rb', line 26530

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26537
26538
26539
26540
26541
# File 'lib/google/apis/compute_beta/classes.rb', line 26537

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end