Class: Google::Apis::ComputeBeta::InstanceGroupManagersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#instance_group_managers ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagersScopedList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersScopedList
constructor
A new instance of InstanceGroupManagersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersScopedList
Returns a new instance of InstanceGroupManagersScopedList.
26759 26760 26761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_group_managers ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
Output only. The list of managed instance groups that are contained in the
specified
project and zone.
Corresponds to the JSON property instanceGroupManagers
26750 26751 26752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26750 def instance_group_managers @instance_group_managers end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagersScopedList::Warning
Output only. The warning that replaces the list of managed instance groups
when the list
is empty.
Corresponds to the JSON property warning
26757 26758 26759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26757 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26764 26765 26766 26767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26764 def update!(**args) @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers) @warning = args[:warning] if args.key?(:warning) end |