Class: Google::Apis::ComputeBeta::InstanceGroupManagersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#instance_group_managers ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagersScopedList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersScopedList
constructor
A new instance of InstanceGroupManagersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersScopedList
Returns a new instance of InstanceGroupManagersScopedList.
26735 26736 26737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26735 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_group_managers ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
Output only. The list of managed instance groups that are contained in the
specified
project and zone.
Corresponds to the JSON property instanceGroupManagers
26726 26727 26728 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26726 def instance_group_managers @instance_group_managers end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceGroupManagersScopedList::Warning
Output only. The warning that replaces the list of managed instance groups
when the list
is empty.
Corresponds to the JSON property warning
26733 26734 26735 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26733 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26740 26741 26742 26743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26740 def update!(**args) @instance_group_managers = args[:instance_group_managers] if args.key?(:instance_group_managers) @warning = args[:warning] if args.key?(:warning) end |