Class: Google::Apis::ComputeBeta::InstanceGroupManagersSetInstanceTemplateRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest

Returns a new instance of InstanceGroupManagersSetInstanceTemplateRequest.



26850
26851
26852
# File 'lib/google/apis/compute_beta/classes.rb', line 26850

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_templateString

The URL of the instance template that is specified for this managed instance group. The group uses this template to create all new instances in the managed instance group. The templates for existing instances in the group do not change unless you run recreateInstances, runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE. Corresponds to the JSON property instanceTemplate

Returns:

  • (String)


26848
26849
26850
# File 'lib/google/apis/compute_beta/classes.rb', line 26848

def instance_template
  @instance_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26855
26856
26857
# File 'lib/google/apis/compute_beta/classes.rb', line 26855

def update!(**args)
  @instance_template = args[:instance_template] if args.key?(:instance_template)
end