Class: Google::Apis::ComputeBeta::InstanceGroupManagersSetInstanceTemplateRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersSetInstanceTemplateRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instance_template ⇒ String
The URL of the instance template that is specified for this managed instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest
constructor
A new instance of InstanceGroupManagersSetInstanceTemplateRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersSetInstanceTemplateRequest
Returns a new instance of InstanceGroupManagersSetInstanceTemplateRequest.
26271 26272 26273 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_template ⇒ String
The URL of the instance template that is specified for this managed
instance group. The group uses this template to create all new instances
in the managed instance group. The templates for existing instances in the
group do not change unless you run recreateInstances,
runapplyUpdatesToInstances, or set the group'supdatePolicy.type to PROACTIVE.
Corresponds to the JSON property instanceTemplate
26269 26270 26271 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26269 def instance_template @instance_template end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26276 26277 26278 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26276 def update!(**args) @instance_template = args[:instance_template] if args.key?(:instance_template) end |