Class: Google::Apis::ComputeBeta::InstanceGroupManagersSetTargetPoolsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupManagersSetTargetPoolsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the target pools information.
-
#target_pools ⇒ Array<String>
The list of target pool URLs that instances in this managed instance group belong to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupManagersSetTargetPoolsRequest
constructor
A new instance of InstanceGroupManagersSetTargetPoolsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupManagersSetTargetPoolsRequest
Returns a new instance of InstanceGroupManagersSetTargetPoolsRequest.
24765 24766 24767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24765 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the target pools information. Use this optional
property to prevent conflicts when multiple users change the target pools
settings concurrently. Obtain the fingerprint with theinstanceGroupManagers.
get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another
concurrent request.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
24755 24756 24757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24755 def fingerprint @fingerprint end |
#target_pools ⇒ Array<String>
The list of target pool URLs that instances in this managed instance group
belong to. The managed instance group applies these target pools to all
of the instances in the group. Existing instances and new instances in the
group all receive these target pool settings.
Corresponds to the JSON property targetPools
24763 24764 24765 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24763 def target_pools @target_pools end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
24770 24771 24772 24773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 24770 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @target_pools = args[:target_pools] if args.key?(:target_pools) end |