Class: Google::Apis::ComputeBeta::InstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstances

Returns a new instance of InstanceGroupsListInstances.



27623
27624
27625
# File 'lib/google/apis/compute_beta/classes.rb', line 27623

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27588
27589
27590
# File 'lib/google/apis/compute_beta/classes.rb', line 27588

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



27593
27594
27595
# File 'lib/google/apis/compute_beta/classes.rb', line 27593

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupsListInstances for the list of instances in the specified instance group. Corresponds to the JSON property kind

Returns:

  • (String)


27600
27601
27602
# File 'lib/google/apis/compute_beta/classes.rb', line 27600

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27611
27612
27613
# File 'lib/google/apis/compute_beta/classes.rb', line 27611

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27616
27617
27618
# File 'lib/google/apis/compute_beta/classes.rb', line 27616

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27621
27622
27623
# File 'lib/google/apis/compute_beta/classes.rb', line 27621

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27628
27629
27630
27631
27632
27633
27634
27635
# File 'lib/google/apis/compute_beta/classes.rb', line 27628

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end