Class: Google::Apis::ComputeBeta::InstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstances

Returns a new instance of InstanceGroupsListInstances.



27613
27614
27615
# File 'lib/google/apis/compute_beta/classes.rb', line 27613

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27578
27579
27580
# File 'lib/google/apis/compute_beta/classes.rb', line 27578

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



27583
27584
27585
# File 'lib/google/apis/compute_beta/classes.rb', line 27583

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupsListInstances for the list of instances in the specified instance group. Corresponds to the JSON property kind

Returns:

  • (String)


27590
27591
27592
# File 'lib/google/apis/compute_beta/classes.rb', line 27590

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27601
27602
27603
# File 'lib/google/apis/compute_beta/classes.rb', line 27601

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27606
27607
27608
# File 'lib/google/apis/compute_beta/classes.rb', line 27606

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



27611
27612
27613
# File 'lib/google/apis/compute_beta/classes.rb', line 27611

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27618
27619
27620
27621
27622
27623
27624
27625
# File 'lib/google/apis/compute_beta/classes.rb', line 27618

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end