Class: Google::Apis::ComputeBeta::InstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstances

Returns a new instance of InstanceGroupsListInstances.



24934
24935
24936
# File 'lib/google/apis/compute_beta/classes.rb', line 24934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


24899
24900
24901
# File 'lib/google/apis/compute_beta/classes.rb', line 24899

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



24904
24905
24906
# File 'lib/google/apis/compute_beta/classes.rb', line 24904

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceGroupsListInstances for the list of instances in the specified instance group. Corresponds to the JSON property kind

Returns:

  • (String)


24911
24912
24913
# File 'lib/google/apis/compute_beta/classes.rb', line 24911

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


24922
24923
24924
# File 'lib/google/apis/compute_beta/classes.rb', line 24922

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


24927
24928
24929
# File 'lib/google/apis/compute_beta/classes.rb', line 24927

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



24932
24933
24934
# File 'lib/google/apis/compute_beta/classes.rb', line 24932

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



24939
24940
24941
24942
24943
24944
24945
24946
# File 'lib/google/apis/compute_beta/classes.rb', line 24939

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end