Class: Google::Apis::ComputeBeta::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstancesRequest

Returns a new instance of InstanceGroupsListInstancesRequest.



27719
27720
27721
# File 'lib/google/apis/compute_beta/classes.rb', line 27719

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Corresponds to the JSON property instanceState

Returns:

  • (String)


27717
27718
27719
# File 'lib/google/apis/compute_beta/classes.rb', line 27717

def instance_state
  @instance_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27724
27725
27726
# File 'lib/google/apis/compute_beta/classes.rb', line 27724

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
end