Class: Google::Apis::ComputeBeta::InstanceGroupsListInstancesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsListInstancesRequest

Returns a new instance of InstanceGroupsListInstancesRequest.



25760
25761
25762
# File 'lib/google/apis/compute_beta/classes.rb', line 25760

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_stateString

A filter for the state of the instances in the instance group. Valid options are ALL or RUNNING. If you do not specify this parameter the list includes all instances regardless of their state. Corresponds to the JSON property instanceState

Returns:

  • (String)


25758
25759
25760
# File 'lib/google/apis/compute_beta/classes.rb', line 25758

def instance_state
  @instance_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25765
25766
25767
# File 'lib/google/apis/compute_beta/classes.rb', line 25765

def update!(**args)
  @instance_state = args[:instance_state] if args.key?(:instance_state)
end