Class: Google::Apis::ComputeBeta::InstanceGroupsListInstancesRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceGroupsListInstancesRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instance_state ⇒ String
A filter for the state of the instances in the instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
constructor
A new instance of InstanceGroupsListInstancesRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceGroupsListInstancesRequest
Returns a new instance of InstanceGroupsListInstancesRequest.
25030 25031 25032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25030 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instance_state ⇒ String
A filter for the state of the instances in the instance group. Valid
options are ALL or RUNNING. If you do not specify
this parameter the list includes all instances regardless of their state.
Corresponds to the JSON property instanceState
25028 25029 25030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25028 def instance_state @instance_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25035 25036 25037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25035 def update!(**args) @instance_state = args[:instance_state] if args.key?(:instance_state) end |