Class: Google::Apis::ComputeBeta::InstanceGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsScopedList

Returns a new instance of InstanceGroupsScopedList.



27194
27195
27196
# File 'lib/google/apis/compute_beta/classes.rb', line 27194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_groupsArray<Google::Apis::ComputeBeta::InstanceGroup>

Output only. [Output Only] The list ofinstance groups that are contained in this scope. Corresponds to the JSON property instanceGroups



27186
27187
27188
# File 'lib/google/apis/compute_beta/classes.rb', line 27186

def instance_groups
  @instance_groups
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of instance groups when the list is empty. Corresponds to the JSON property warning



27192
27193
27194
# File 'lib/google/apis/compute_beta/classes.rb', line 27192

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27199
27200
27201
27202
# File 'lib/google/apis/compute_beta/classes.rb', line 27199

def update!(**args)
  @instance_groups = args[:instance_groups] if args.key?(:instance_groups)
  @warning = args[:warning] if args.key?(:warning)
end