Class: Google::Apis::ComputeBeta::InstanceGroupsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceGroupsScopedList

Returns a new instance of InstanceGroupsScopedList.



25805
25806
25807
# File 'lib/google/apis/compute_beta/classes.rb', line 25805

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_groupsArray<Google::Apis::ComputeBeta::InstanceGroup>

Output only. [Output Only] The list ofinstance groups that are contained in this scope. Corresponds to the JSON property instanceGroups



25797
25798
25799
# File 'lib/google/apis/compute_beta/classes.rb', line 25797

def instance_groups
  @instance_groups
end

#warningGoogle::Apis::ComputeBeta::InstanceGroupsScopedList::Warning

Output only. [Output Only] An informational warning that replaces the list of instance groups when the list is empty. Corresponds to the JSON property warning



25803
25804
25805
# File 'lib/google/apis/compute_beta/classes.rb', line 25803

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25810
25811
25812
25813
# File 'lib/google/apis/compute_beta/classes.rb', line 25810

def update!(**args)
  @instance_groups = args[:instance_groups] if args.key?(:instance_groups)
  @warning = args[:warning] if args.key?(:warning)
end