Class: Google::Apis::ComputeBeta::InstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceList

Returns a new instance of InstanceList.



27969
27970
27971
# File 'lib/google/apis/compute_beta/classes.rb', line 27969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27936
27937
27938
# File 'lib/google/apis/compute_beta/classes.rb', line 27936

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Instance>

A list of Instance resources. Corresponds to the JSON property items



27941
27942
27943
# File 'lib/google/apis/compute_beta/classes.rb', line 27941

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#instanceList for lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


27947
27948
27949
# File 'lib/google/apis/compute_beta/classes.rb', line 27947

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27957
27958
27959
# File 'lib/google/apis/compute_beta/classes.rb', line 27957

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27962
27963
27964
# File 'lib/google/apis/compute_beta/classes.rb', line 27962

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27967
27968
27969
# File 'lib/google/apis/compute_beta/classes.rb', line 27967

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27974
27975
27976
27977
27978
27979
27980
27981
# File 'lib/google/apis/compute_beta/classes.rb', line 27974

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end