Class: Google::Apis::ComputeBeta::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
27919 27920 27921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27886 27887 27888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27886 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
A list of Instance resources.
Corresponds to the JSON property items
27891 27892 27893 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27891 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
27897 27898 27899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27897 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27907 27908 27909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27907 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27912 27913 27914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27912 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27917 27918 27919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27917 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27924 27925 27926 27927 27928 27929 27930 27931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27924 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |