Class: Google::Apis::ComputeBeta::InstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instances.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceList

Returns a new instance of InstanceList.



27854
27855
27856
# File 'lib/google/apis/compute_beta/classes.rb', line 27854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27821
27822
27823
# File 'lib/google/apis/compute_beta/classes.rb', line 27821

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Instance>

A list of Instance resources. Corresponds to the JSON property items



27826
27827
27828
# File 'lib/google/apis/compute_beta/classes.rb', line 27826

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#instanceList for lists of Instance resources. Corresponds to the JSON property kind

Returns:

  • (String)


27832
27833
27834
# File 'lib/google/apis/compute_beta/classes.rb', line 27832

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27842
27843
27844
# File 'lib/google/apis/compute_beta/classes.rb', line 27842

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27847
27848
27849
# File 'lib/google/apis/compute_beta/classes.rb', line 27847

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27852
27853
27854
# File 'lib/google/apis/compute_beta/classes.rb', line 27852

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27859
27860
27861
27862
27863
27864
27865
27866
# File 'lib/google/apis/compute_beta/classes.rb', line 27859

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end