Class: Google::Apis::ComputeBeta::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
27349 27350 27351 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27349 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27316 27317 27318 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27316 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
A list of Instance resources.
Corresponds to the JSON property items
27321 27322 27323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27321 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
27327 27328 27329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27327 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27337 27338 27339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27337 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27342 27343 27344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27342 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27347 27348 27349 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27347 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27354 27355 27356 27357 27358 27359 27360 27361 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27354 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |