Class: Google::Apis::ComputeBeta::InstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of instances.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
A list of Instance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceList
constructor
A new instance of InstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceList
Returns a new instance of InstanceList.
25230 25231 25232 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25230 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25197 25198 25199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25197 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Instance>
A list of Instance resources.
Corresponds to the JSON property items
25202 25203 25204 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25202 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#instanceList
for lists of Instance resources.
Corresponds to the JSON property kind
25208 25209 25210 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25208 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25218 25219 25220 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25218 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25223 25224 25225 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25223 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25228 25229 25230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25228 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25235 25236 25237 25238 25239 25240 25241 25242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25235 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |