Class: Google::Apis::ComputeBeta::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



28094
28095
28096
# File 'lib/google/apis/compute_beta/classes.rb', line 28094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28061
28062
28063
# File 'lib/google/apis/compute_beta/classes.rb', line 28061

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reference>

A list of Reference resources. Corresponds to the JSON property items



28066
28067
28068
# File 'lib/google/apis/compute_beta/classes.rb', line 28066

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


28072
28073
28074
# File 'lib/google/apis/compute_beta/classes.rb', line 28072

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28082
28083
28084
# File 'lib/google/apis/compute_beta/classes.rb', line 28082

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28087
28088
28089
# File 'lib/google/apis/compute_beta/classes.rb', line 28087

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28092
28093
28094
# File 'lib/google/apis/compute_beta/classes.rb', line 28092

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28099
28100
28101
28102
28103
28104
28105
28106
# File 'lib/google/apis/compute_beta/classes.rb', line 28099

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end