Class: Google::Apis::ComputeBeta::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



28034
28035
28036
# File 'lib/google/apis/compute_beta/classes.rb', line 28034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28001
28002
28003
# File 'lib/google/apis/compute_beta/classes.rb', line 28001

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reference>

A list of Reference resources. Corresponds to the JSON property items



28006
28007
28008
# File 'lib/google/apis/compute_beta/classes.rb', line 28006

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


28012
28013
28014
# File 'lib/google/apis/compute_beta/classes.rb', line 28012

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28022
28023
28024
# File 'lib/google/apis/compute_beta/classes.rb', line 28022

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28027
28028
28029
# File 'lib/google/apis/compute_beta/classes.rb', line 28027

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28032
28033
28034
# File 'lib/google/apis/compute_beta/classes.rb', line 28032

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28039
28040
28041
28042
28043
28044
28045
28046
# File 'lib/google/apis/compute_beta/classes.rb', line 28039

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end