Class: Google::Apis::ComputeBeta::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



27474
27475
27476
# File 'lib/google/apis/compute_beta/classes.rb', line 27474

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27441
27442
27443
# File 'lib/google/apis/compute_beta/classes.rb', line 27441

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reference>

A list of Reference resources. Corresponds to the JSON property items



27446
27447
27448
# File 'lib/google/apis/compute_beta/classes.rb', line 27446

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


27452
27453
27454
# File 'lib/google/apis/compute_beta/classes.rb', line 27452

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27462
27463
27464
# File 'lib/google/apis/compute_beta/classes.rb', line 27462

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27467
27468
27469
# File 'lib/google/apis/compute_beta/classes.rb', line 27467

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27472
27473
27474
# File 'lib/google/apis/compute_beta/classes.rb', line 27472

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27479
27480
27481
27482
27483
27484
27485
27486
# File 'lib/google/apis/compute_beta/classes.rb', line 27479

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end