Class: Google::Apis::ComputeBeta::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
27474 27475 27476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27441 27442 27443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27441 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reference>
A list of Reference resources.
Corresponds to the JSON property items
27446 27447 27448 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27446 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
27452 27453 27454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27452 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27462 27463 27464 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27462 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27467 27468 27469 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27467 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27472 27473 27474 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27472 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27479 27480 27481 27482 27483 27484 27485 27486 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27479 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |