Class: Google::Apis::ComputeBeta::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
26085 26086 26087 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26085 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
26052 26053 26054 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26052 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reference>
A list of Reference resources.
Corresponds to the JSON property items
26057 26058 26059 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26057 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
26063 26064 26065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26063 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26073 26074 26075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26073 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26078 26079 26080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26078 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26083 26084 26085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26083 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26090 26091 26092 26093 26094 26095 26096 26097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26090 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |