Class: Google::Apis::ComputeBeta::InstanceListReferrers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of instance referrers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceListReferrers

Returns a new instance of InstanceListReferrers.



25355
25356
25357
# File 'lib/google/apis/compute_beta/classes.rb', line 25355

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


25322
25323
25324
# File 'lib/google/apis/compute_beta/classes.rb', line 25322

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reference>

A list of Reference resources. Corresponds to the JSON property items



25327
25328
25329
# File 'lib/google/apis/compute_beta/classes.rb', line 25327

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# instanceListReferrers for lists of Instance referrers. Corresponds to the JSON property kind

Returns:

  • (String)


25333
25334
25335
# File 'lib/google/apis/compute_beta/classes.rb', line 25333

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


25343
25344
25345
# File 'lib/google/apis/compute_beta/classes.rb', line 25343

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


25348
25349
25350
# File 'lib/google/apis/compute_beta/classes.rb', line 25348

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceListReferrers::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



25353
25354
25355
# File 'lib/google/apis/compute_beta/classes.rb', line 25353

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25360
25361
25362
25363
25364
25365
25366
25367
# File 'lib/google/apis/compute_beta/classes.rb', line 25360

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end