Class: Google::Apis::ComputeBeta::InstanceListReferrers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceListReferrers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of instance referrers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reference>
A list of Reference resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceListReferrers
constructor
A new instance of InstanceListReferrers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceListReferrers
Returns a new instance of InstanceListReferrers.
25355 25356 25357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25355 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
25322 25323 25324 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25322 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reference>
A list of Reference resources.
Corresponds to the JSON property items
25327 25328 25329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25327 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
instanceListReferrers for lists of Instance referrers.
Corresponds to the JSON property kind
25333 25334 25335 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25333 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
25343 25344 25345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25343 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
25348 25349 25350 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25348 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceListReferrers::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
25353 25354 25355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25353 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25360 25361 25362 25363 25364 25365 25366 25367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25360 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |