Class: Google::Apis::ComputeBeta::InstanceManagedByIgmError
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceManagedByIgmError
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeBeta::InstanceManagedByIgmErrorManagedInstanceError
Output only.
-
#instance_action_details ⇒ Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails
Output only.
-
#timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmError
constructor
A new instance of InstanceManagedByIgmError.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmError
Returns a new instance of InstanceManagedByIgmError.
28141 28142 28143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeBeta::InstanceManagedByIgmErrorManagedInstanceError
Output only. Contents of the error.
Corresponds to the JSON property error
28126 28127 28128 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28126 def error @error end |
#instance_action_details ⇒ Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails
Output only. Details of the instance action that triggered this error.
May be null, if the error was not caused by an action on an instance.
This field is optional.
Corresponds to the JSON property instanceActionDetails
28133 28134 28135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28133 def instance_action_details @instance_action_details end |
#timestamp ⇒ String
Output only. The time that this error occurred. This value is in RFC3339 text
format.
Corresponds to the JSON property timestamp
28139 28140 28141 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28139 def @timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28146 28147 28148 28149 28150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28146 def update!(**args) @error = args[:error] if args.key?(:error) @instance_action_details = args[:instance_action_details] if args.key?(:instance_action_details) @timestamp = args[:timestamp] if args.key?(:timestamp) end |