Class: Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
28179 28180 28181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28179 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. Action that managed instance group was executing on the instance
when the
error occurred. Possible values:
Corresponds to the JSON property action
28162 28163 28164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28162 def action @action end |
#instance ⇒ String
Output only. The URL of the instance. The URL can be set even if the instance
has not
yet been created.
Corresponds to the JSON property instance
28169 28170 28171 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28169 def instance @instance end |
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only. Version this instance was created from, or was being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
28177 28178 28179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28177 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28184 28185 28186 28187 28188 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28184 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |