Class: Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



28146
28147
28148
# File 'lib/google/apis/compute_beta/classes.rb', line 28146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


28129
28130
28131
# File 'lib/google/apis/compute_beta/classes.rb', line 28129

def action
  @action
end

#instanceString

Output only. The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


28136
28137
28138
# File 'lib/google/apis/compute_beta/classes.rb', line 28136

def instance
  @instance
end

#versionGoogle::Apis::ComputeBeta::ManagedInstanceVersion

Output only. Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



28144
28145
28146
# File 'lib/google/apis/compute_beta/classes.rb', line 28144

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28151
28152
28153
28154
28155
# File 'lib/google/apis/compute_beta/classes.rb', line 28151

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end