Class: Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails

Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.



25500
25501
25502
# File 'lib/google/apis/compute_beta/classes.rb', line 25500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actionString

Output only. [Output Only] Action that managed instance group was executing on the instance when the error occurred. Possible values: Corresponds to the JSON property action

Returns:

  • (String)


25483
25484
25485
# File 'lib/google/apis/compute_beta/classes.rb', line 25483

def action
  @action
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can be set even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


25489
25490
25491
# File 'lib/google/apis/compute_beta/classes.rb', line 25489

def instance
  @instance
end

#versionGoogle::Apis::ComputeBeta::ManagedInstanceVersion

Output only. [Output Only] Version this instance was created from, or was being created from, but the creation failed. Corresponds to one of the versions that were set on the Instance Group Manager resource at the time this instance was being created. Corresponds to the JSON property version



25498
25499
25500
# File 'lib/google/apis/compute_beta/classes.rb', line 25498

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



25505
25506
25507
25508
25509
# File 'lib/google/apis/compute_beta/classes.rb', line 25505

def update!(**args)
  @action = args[:action] if args.key?(:action)
  @instance = args[:instance] if args.key?(:instance)
  @version = args[:version] if args.key?(:version)
end