Class: Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceManagedByIgmErrorInstanceActionDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#action ⇒ String
Output only.
-
#instance ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
constructor
A new instance of InstanceManagedByIgmErrorInstanceActionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceManagedByIgmErrorInstanceActionDetails
Returns a new instance of InstanceManagedByIgmErrorInstanceActionDetails.
25500 25501 25502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25500 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ String
Output only. [Output Only] Action that managed instance group was executing on
the instance when the error occurred. Possible values:
Corresponds to the JSON property action
25483 25484 25485 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25483 def action @action end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance.
The URL can be set even if the instance has not yet been created.
Corresponds to the JSON property instance
25489 25490 25491 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25489 def instance @instance end |
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only. [Output Only] Version this instance was created from, or was
being
created from, but the creation failed. Corresponds to one of the versions
that were set on the Instance Group Manager resource at the time this
instance was being created.
Corresponds to the JSON property version
25498 25499 25500 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25498 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25505 25506 25507 25508 25509 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25505 def update!(**args) @action = args[:action] if args.key?(:action) @instance = args[:instance] if args.key?(:instance) @version = args[:version] if args.key?(:version) end |