Class: Google::Apis::ComputeBeta::InstanceParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Additional instance params.
Instance Attribute Summary collapse
-
#request_valid_for_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#resource_manager_tags ⇒ Hash<String,String>
Input only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceParams
constructor
A new instance of InstanceParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceParams
Returns a new instance of InstanceParams.
28221 28222 28223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_valid_for_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property requestValidForDuration
28207 28208 28209 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28207 def request_valid_for_duration @request_valid_for_duration end |
#resource_manager_tags ⇒ Hash<String,String>
Input only. Resource manager tags to be bound to the instance. Tag keys and
values
have the same definition as resource
manager tags. Keys and values can be either in numeric format,
such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in
namespaced format such as org_id|project_id`/`tag_key_short_name and
tag_value_short_name. The field is ignored (both PUT &
PATCH) when empty.
Corresponds to the JSON property resourceManagerTags
28219 28220 28221 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28219 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28226 28227 28228 28229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28226 def update!(**args) @request_valid_for_duration = args[:request_valid_for_duration] if args.key?(:request_valid_for_duration) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |