Class: Google::Apis::ComputeBeta::InstanceParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Additional instance params.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceParams

Returns a new instance of InstanceParams.



27137
27138
27139
# File 'lib/google/apis/compute_beta/classes.rb', line 27137

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_valid_for_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property requestValidForDuration



27123
27124
27125
# File 'lib/google/apis/compute_beta/classes.rb', line 27123

def request_valid_for_duration
  @request_valid_for_duration
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/456` or in namespaced format such asorg_id|project_id/tag_key_short_nameand tag_value_short_name`. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON propertyresourceManagerTags`

Returns:

  • (Hash<String,String>)


27135
27136
27137
# File 'lib/google/apis/compute_beta/classes.rb', line 27135

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27142
27143
27144
27145
# File 'lib/google/apis/compute_beta/classes.rb', line 27142

def update!(**args)
  @request_valid_for_duration = args[:request_valid_for_duration] if args.key?(:request_valid_for_duration)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end