Class: Google::Apis::ComputeBeta::InstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceProperties

Returns a new instance of InstanceProperties.



28468
28469
28470
# File 'lib/google/apis/compute_beta/classes.rb', line 28468

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_machine_featuresGoogle::Apis::ComputeBeta::AdvancedMachineFeatures

Specifies options for controlling advanced machine features. Options that would traditionally be configured in a BIOS belong here. Features that require operating system support may have corresponding entries in the GuestOsFeatures of anImage (e.g., whether or not the OS in theImage supports nested virtualization being enabled or disabled). Corresponds to the JSON property advancedMachineFeatures



28299
28300
28301
# File 'lib/google/apis/compute_beta/classes.rb', line 28299

def advanced_machine_features
  @advanced_machine_features
end

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on these properties to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


28310
28311
28312
# File 'lib/google/apis/compute_beta/classes.rb', line 28310

def can_ip_forward
  @can_ip_forward
end

#confidential_instance_configGoogle::Apis::ComputeBeta::ConfidentialInstanceConfig

A set of Confidential Instance options. Corresponds to the JSON property confidentialInstanceConfig



28316
28317
28318
# File 'lib/google/apis/compute_beta/classes.rb', line 28316

def confidential_instance_config
  @confidential_instance_config
end

#descriptionString

An optional text description for the instances that are created from these properties. Corresponds to the JSON property description

Returns:

  • (String)


28322
28323
28324
# File 'lib/google/apis/compute_beta/classes.rb', line 28322

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::AttachedDisk>

An array of disks that are associated with the instances that are created from these properties. Corresponds to the JSON property disks



28328
28329
28330
# File 'lib/google/apis/compute_beta/classes.rb', line 28328

def disks
  @disks
end

#display_deviceGoogle::Apis::ComputeBeta::DisplayDevice

A set of Display Device options Corresponds to the JSON property displayDevice



28333
28334
28335
# File 'lib/google/apis/compute_beta/classes.rb', line 28333

def display_device
  @display_device
end

#guest_acceleratorsArray<Google::Apis::ComputeBeta::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from these properties. Corresponds to the JSON property guestAccelerators



28339
28340
28341
# File 'lib/google/apis/compute_beta/classes.rb', line 28339

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


28345
28346
28347
# File 'lib/google/apis/compute_beta/classes.rb', line 28345

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from these properties. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


28350
28351
28352
# File 'lib/google/apis/compute_beta/classes.rb', line 28350

def labels
  @labels
end

#local_ssd_encryption_modeString

Specifies which method should be used for encrypting the Local SSDs attached to the VM. Corresponds to the JSON property localSsdEncryptionMode

Returns:

  • (String)


28356
28357
28358
# File 'lib/google/apis/compute_beta/classes.rb', line 28356

def local_ssd_encryption_mode
  @local_ssd_encryption_mode
end

#machine_typeString

The machine type to use for instances that are created from these properties. This field only accepts a machine type name, for example n2-standard-4. If you use the machine type full or partial URL, for example projects/my-l7ilb-project/zones/us-central1-a/machineTypes/n2-standard-4, the request will result in an INTERNAL_ERROR. Corresponds to the JSON property machineType

Returns:

  • (String)


28366
28367
28368
# File 'lib/google/apis/compute_beta/classes.rb', line 28366

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



28371
28372
28373
# File 'lib/google/apis/compute_beta/classes.rb', line 28371

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such asminCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


28381
28382
28383
# File 'lib/google/apis/compute_beta/classes.rb', line 28381

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeBeta::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



28386
28387
28388
# File 'lib/google/apis/compute_beta/classes.rb', line 28386

def network_interfaces
  @network_interfaces
end

#network_performance_configGoogle::Apis::ComputeBeta::NetworkPerformanceConfig

Note that for MachineImage, this is not supported yet. Corresponds to the JSON property networkPerformanceConfig



28391
28392
28393
# File 'lib/google/apis/compute_beta/classes.rb', line 28391

def network_performance_config
  @network_performance_config
end

#partner_metadataHash<String,Google::Apis::ComputeBeta::StructuredEntries>

Partner Metadata assigned to the instance properties. A map from a subdomain (namespace) to entries map. Corresponds to the JSON property partnerMetadata



28397
28398
28399
# File 'lib/google/apis/compute_beta/classes.rb', line 28397

def 
  @partner_metadata
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


28402
28403
28404
# File 'lib/google/apis/compute_beta/classes.rb', line 28402

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#private_ipv6_google_accessString

The private IPv6 google access type for VMs. If not specified, use INHERIT_FROM_SUBNETWORK as default. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


28409
28410
28411
# File 'lib/google/apis/compute_beta/classes.rb', line 28409

def private_ipv6_google_access
  @private_ipv6_google_access
end

#reservation_affinityGoogle::Apis::ComputeBeta::ReservationAffinity

Specifies the reservations that this instance can consume from. Corresponds to the JSON property reservationAffinity



28414
28415
28416
# File 'lib/google/apis/compute_beta/classes.rb', line 28414

def reservation_affinity
  @reservation_affinity
end

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the instance. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


28426
28427
28428
# File 'lib/google/apis/compute_beta/classes.rb', line 28426

def resource_manager_tags
  @resource_manager_tags
end

#resource_policiesArray<String>

Resource policies (names, not URLs) applied to instances created from these properties. Note that for MachineImage, this is not supported yet. Corresponds to the JSON property resourcePolicies

Returns:

  • (Array<String>)


28433
28434
28435
# File 'lib/google/apis/compute_beta/classes.rb', line 28433

def resource_policies
  @resource_policies
end

#schedulingGoogle::Apis::ComputeBeta::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



28438
28439
28440
# File 'lib/google/apis/compute_beta/classes.rb', line 28438

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeBeta::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from these properties. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



28446
28447
28448
# File 'lib/google/apis/compute_beta/classes.rb', line 28446

def service_accounts
  @service_accounts
end

#shielded_instance_configGoogle::Apis::ComputeBeta::ShieldedInstanceConfig

A set of Shielded Instance options. Corresponds to the JSON property shieldedInstanceConfig



28451
28452
28453
# File 'lib/google/apis/compute_beta/classes.rb', line 28451

def shielded_instance_config
  @shielded_instance_config
end

#shielded_vm_configGoogle::Apis::ComputeBeta::ShieldedVmConfig

A set of Shielded VM options. Corresponds to the JSON property shieldedVmConfig



28456
28457
28458
# File 'lib/google/apis/compute_beta/classes.rb', line 28456

def shielded_vm_config
  @shielded_vm_config
end

#tagsGoogle::Apis::ComputeBeta::Tags

A set of instance tags. Corresponds to the JSON property tags



28461
28462
28463
# File 'lib/google/apis/compute_beta/classes.rb', line 28461

def tags
  @tags
end

#workload_identity_configGoogle::Apis::ComputeBeta::WorkloadIdentityConfig

Corresponds to the JSON property workloadIdentityConfig



28466
28467
28468
# File 'lib/google/apis/compute_beta/classes.rb', line 28466

def workload_identity_config
  @workload_identity_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28473
28474
28475
28476
28477
28478
28479
28480
28481
28482
28483
28484
28485
28486
28487
28488
28489
28490
28491
28492
28493
28494
28495
28496
28497
28498
28499
28500
28501
# File 'lib/google/apis/compute_beta/classes.rb', line 28473

def update!(**args)
  @advanced_machine_features = args[:advanced_machine_features] if args.key?(:advanced_machine_features)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @confidential_instance_config = args[:confidential_instance_config] if args.key?(:confidential_instance_config)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @display_device = args[:display_device] if args.key?(:display_device)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @local_ssd_encryption_mode = args[:local_ssd_encryption_mode] if args.key?(:local_ssd_encryption_mode)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @network_performance_config = args[:network_performance_config] if args.key?(:network_performance_config)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @reservation_affinity = args[:reservation_affinity] if args.key?(:reservation_affinity)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @shielded_instance_config = args[:shielded_instance_config] if args.key?(:shielded_instance_config)
  @shielded_vm_config = args[:shielded_vm_config] if args.key?(:shielded_vm_config)
  @tags = args[:tags] if args.key?(:tags)
  @workload_identity_config = args[:workload_identity_config] if args.key?(:workload_identity_config)
end