Class: Google::Apis::ComputeBeta::InstanceSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceSettings

Returns a new instance of InstanceSettings.



26632
26633
26634
# File 'lib/google/apis/compute_beta/classes.rb', line 26632

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the instance settings resource. You must always provide an up-to-date fingerprint hash in order to update or change the resource, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the resource. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


26611
26612
26613
# File 'lib/google/apis/compute_beta/classes.rb', line 26611

def fingerprint
  @fingerprint
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# instance_settings for instance settings. Corresponds to the JSON property kind

Returns:

  • (String)


26617
26618
26619
# File 'lib/google/apis/compute_beta/classes.rb', line 26617

def kind
  @kind
end

#metadataGoogle::Apis::ComputeBeta::InstanceSettingsMetadata

The metadata key/value pairs assigned to all the instances in the corresponding scope. Corresponds to the JSON property metadata



26623
26624
26625
# File 'lib/google/apis/compute_beta/classes.rb', line 26623

def 
  @metadata
end

#zoneString

Output only. [Output Only] URL of the zone where the resource resides You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


26630
26631
26632
# File 'lib/google/apis/compute_beta/classes.rb', line 26630

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26637
26638
26639
26640
26641
26642
# File 'lib/google/apis/compute_beta/classes.rb', line 26637

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @zone = args[:zone] if args.key?(:zone)
end