Class: Google::Apis::ComputeBeta::InstanceSettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Instance Settings resource. You can use instance settings to configure default settings for Compute Engine VM instances. For example, you can use it to configure default machine type of Compute Engine VM instances.
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Specifies a fingerprint for instance settings, which is essentially a hash of the instance settings resource's contents and used for optimistic locking.
-
#kind ⇒ String
Output only.
-
#metadata ⇒ Google::Apis::ComputeBeta::InstanceSettingsMetadata
The metadata key/value pairs assigned to all the instances in the corresponding scope.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceSettings
constructor
A new instance of InstanceSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceSettings
Returns a new instance of InstanceSettings.
25894 25895 25896 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25894 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Specifies a fingerprint for instance settings, which is essentially a hash
of the instance settings resource's contents and used for optimistic
locking. The fingerprint is initially generated by Compute Engine and
changes after every request to modify or update the instance settings
resource. You must always provide an up-to-date fingerprint hash in order
to update or change the resource, otherwise the request will fail with
error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve the resource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
25873 25874 25875 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25873 def fingerprint @fingerprint end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
instance_settings for instance settings.
Corresponds to the JSON property kind
25879 25880 25881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25879 def kind @kind end |
#metadata ⇒ Google::Apis::ComputeBeta::InstanceSettingsMetadata
The metadata key/value pairs assigned to all the instances in the
corresponding scope.
Corresponds to the JSON property metadata
25885 25886 25887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25885 def @metadata end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the resource resides
You must specify this field as part of the HTTP request URL. It is not
settable as a field in the request body.
Corresponds to the JSON property zone
25892 25893 25894 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25892 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
25899 25900 25901 25902 25903 25904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 25899 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @kind = args[:kind] if args.key?(:kind) @metadata = args[:metadata] if args.key?(:metadata) @zone = args[:zone] if args.key?(:zone) end |