Class: Google::Apis::ComputeBeta::InstanceTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Instance Template resource. Google Compute Engine has two Instance Template resources:

  • Global
  • Regional You can reuse a global instance template in different regions whereas you can use a regional instance template in a specified region only. If you want to reduce cross-region dependency or achieve data residency, use a regional instance template. To create VMs, managed instance groups, and reservations, you can use either global or regional instance templates. For more information, readInstance Templates.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplate

Returns a new instance of InstanceTemplate.



28718
28719
28720
# File 'lib/google/apis/compute_beta/classes.rb', line 28718

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] The creation timestamp for this instance template inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


28649
28650
28651
# File 'lib/google/apis/compute_beta/classes.rb', line 28649

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


28655
28656
28657
# File 'lib/google/apis/compute_beta/classes.rb', line 28655

def description
  @description
end

#idFixnum

Output only. [Output Only] A unique identifier for this instance template. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


28662
28663
28664
# File 'lib/google/apis/compute_beta/classes.rb', line 28662

def id
  @id
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceTemplate for instance templates. Corresponds to the JSON property kind

Returns:

  • (String)


28668
28669
28670
# File 'lib/google/apis/compute_beta/classes.rb', line 28668

def kind
  @kind
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


28679
28680
28681
# File 'lib/google/apis/compute_beta/classes.rb', line 28679

def name
  @name
end

#propertiesGoogle::Apis::ComputeBeta::InstanceProperties

The instance properties for this instance template. Corresponds to the JSON property properties



28684
28685
28686
# File 'lib/google/apis/compute_beta/classes.rb', line 28684

def properties
  @properties
end

#regionString

Output only. [Output Only] URL of the region where the instance template resides. Only applicable for regional resources. Corresponds to the JSON property region

Returns:

  • (String)


28691
28692
28693
# File 'lib/google/apis/compute_beta/classes.rb', line 28691

def region
  @region
end

Output only. [Output Only] The URL for this instance template. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


28698
28699
28700
# File 'lib/google/apis/compute_beta/classes.rb', line 28698

def self_link
  @self_link
end

#source_instanceString

The source instance used to create the template. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


28710
28711
28712
# File 'lib/google/apis/compute_beta/classes.rb', line 28710

def source_instance
  @source_instance
end

#source_instance_paramsGoogle::Apis::ComputeBeta::SourceInstanceParams

A specification of the parameters to use when creating the instance template from a source instance. Corresponds to the JSON property sourceInstanceParams



28716
28717
28718
# File 'lib/google/apis/compute_beta/classes.rb', line 28716

def source_instance_params
  @source_instance_params
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28723
28724
28725
28726
28727
28728
28729
28730
28731
28732
28733
28734
# File 'lib/google/apis/compute_beta/classes.rb', line 28723

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @properties = args[:properties] if args.key?(:properties)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @source_instance = args[:source_instance] if args.key?(:source_instance)
  @source_instance_params = args[:source_instance_params] if args.key?(:source_instance_params)
end