Class: Google::Apis::ComputeBeta::InstanceTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstanceTemplatesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateAggregatedList
constructor
A new instance of InstanceTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateAggregatedList
Returns a new instance of InstanceTemplateAggregatedList.
29051 29052 29053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
29019 29020 29021 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29019 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
Corresponds to the JSON property items
29024 29025 29026 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29024 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
29029 29030 29031 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29029 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
29039 29040 29041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29039 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
29044 29045 29046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29044 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
29049 29050 29051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29049 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29056 29057 29058 29059 29060 29061 29062 29063 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29056 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |