Class: Google::Apis::ComputeBeta::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



28836
28837
28838
# File 'lib/google/apis/compute_beta/classes.rb', line 28836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28804
28805
28806
# File 'lib/google/apis/compute_beta/classes.rb', line 28804

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



28809
28810
28811
# File 'lib/google/apis/compute_beta/classes.rb', line 28809

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


28814
28815
28816
# File 'lib/google/apis/compute_beta/classes.rb', line 28814

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28824
28825
28826
# File 'lib/google/apis/compute_beta/classes.rb', line 28824

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28829
28830
28831
# File 'lib/google/apis/compute_beta/classes.rb', line 28829

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28834
28835
28836
# File 'lib/google/apis/compute_beta/classes.rb', line 28834

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28841
28842
28843
28844
28845
28846
28847
28848
# File 'lib/google/apis/compute_beta/classes.rb', line 28841

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end