Class: Google::Apis::ComputeBeta::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



28786
28787
28788
# File 'lib/google/apis/compute_beta/classes.rb', line 28786

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


28754
28755
28756
# File 'lib/google/apis/compute_beta/classes.rb', line 28754

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



28759
28760
28761
# File 'lib/google/apis/compute_beta/classes.rb', line 28759

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


28764
28765
28766
# File 'lib/google/apis/compute_beta/classes.rb', line 28764

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


28774
28775
28776
# File 'lib/google/apis/compute_beta/classes.rb', line 28774

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


28779
28780
28781
# File 'lib/google/apis/compute_beta/classes.rb', line 28779

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



28784
28785
28786
# File 'lib/google/apis/compute_beta/classes.rb', line 28784

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28791
28792
28793
28794
28795
28796
28797
28798
# File 'lib/google/apis/compute_beta/classes.rb', line 28791

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end