Class: Google::Apis::ComputeBeta::InstanceTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstanceTemplatesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateAggregatedList
constructor
A new instance of InstanceTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateAggregatedList
Returns a new instance of InstanceTemplateAggregatedList.
28736 28737 28738 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28736 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
28704 28705 28706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28704 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
Corresponds to the JSON property items
28709 28710 28711 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28709 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
28714 28715 28716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28714 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
28724 28725 28726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28724 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
28729 28730 28731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28729 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
28734 28735 28736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28734 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28741 28742 28743 28744 28745 28746 28747 28748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28741 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |