Class: Google::Apis::ComputeBeta::InstanceTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceTemplatesScopedList.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateAggregatedList

Returns a new instance of InstanceTemplateAggregatedList.



27628
27629
27630
# File 'lib/google/apis/compute_beta/classes.rb', line 27628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27596
27597
27598
# File 'lib/google/apis/compute_beta/classes.rb', line 27596

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>

A list of InstanceTemplatesScopedList resources. Corresponds to the JSON property items



27601
27602
27603
# File 'lib/google/apis/compute_beta/classes.rb', line 27601

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


27606
27607
27608
# File 'lib/google/apis/compute_beta/classes.rb', line 27606

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27616
27617
27618
# File 'lib/google/apis/compute_beta/classes.rb', line 27616

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27621
27622
27623
# File 'lib/google/apis/compute_beta/classes.rb', line 27621

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27626
27627
27628
# File 'lib/google/apis/compute_beta/classes.rb', line 27626

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27633
27634
27635
27636
27637
27638
27639
27640
# File 'lib/google/apis/compute_beta/classes.rb', line 27633

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end