Class: Google::Apis::ComputeBeta::InstanceTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstanceTemplatesScopedList.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateAggregatedList
constructor
A new instance of InstanceTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateAggregatedList
Returns a new instance of InstanceTemplateAggregatedList.
27628 27629 27630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
27596 27597 27598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27596 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::InstanceTemplatesScopedList>
A list of InstanceTemplatesScopedList resources.
Corresponds to the JSON property items
27601 27602 27603 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27601 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
27606 27607 27608 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27606 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
27616 27617 27618 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27616 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
27621 27622 27623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27621 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
27626 27627 27628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27626 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
27633 27634 27635 27636 27637 27638 27639 27640 |
# File 'lib/google/apis/compute_beta/classes.rb', line 27633 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |