Class: Google::Apis::ComputeBeta::InstanceTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of instance templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstanceTemplateList

Returns a new instance of InstanceTemplateList.



27754
27755
27756
# File 'lib/google/apis/compute_beta/classes.rb', line 27754

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


27720
27721
27722
# File 'lib/google/apis/compute_beta/classes.rb', line 27720

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceTemplate>

A list of InstanceTemplate resources. Corresponds to the JSON property items



27725
27726
27727
# File 'lib/google/apis/compute_beta/classes.rb', line 27725

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# instanceTemplatesListResponse for instance template lists. Corresponds to the JSON property kind

Returns:

  • (String)


27732
27733
27734
# File 'lib/google/apis/compute_beta/classes.rb', line 27732

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


27742
27743
27744
# File 'lib/google/apis/compute_beta/classes.rb', line 27742

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27747
27748
27749
# File 'lib/google/apis/compute_beta/classes.rb', line 27747

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstanceTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



27752
27753
27754
# File 'lib/google/apis/compute_beta/classes.rb', line 27752

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27759
27760
27761
27762
27763
27764
27765
27766
# File 'lib/google/apis/compute_beta/classes.rb', line 27759

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end