Class: Google::Apis::ComputeBeta::InstanceTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstanceTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of instance templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceTemplate>
A list of InstanceTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstanceTemplateList
constructor
A new instance of InstanceTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstanceTemplateList
Returns a new instance of InstanceTemplateList.
26206 26207 26208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
26172 26173 26174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26172 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceTemplate>
A list of InstanceTemplate resources.
Corresponds to the JSON property items
26177 26178 26179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26177 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
instanceTemplatesListResponse for instance template
lists.
Corresponds to the JSON property kind
26184 26185 26186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26184 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
26194 26195 26196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26194 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
26199 26200 26201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26199 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstanceTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
26204 26205 26206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26204 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26211 26212 26213 26214 26215 26216 26217 26218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26211 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |