Class: Google::Apis::ComputeBeta::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



28691
28692
28693
# File 'lib/google/apis/compute_beta/classes.rb', line 28691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


28652
28653
28654
# File 'lib/google/apis/compute_beta/classes.rb', line 28652

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


28657
28658
28659
# File 'lib/google/apis/compute_beta/classes.rb', line 28657

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeBeta::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



28663
28664
28665
# File 'lib/google/apis/compute_beta/classes.rb', line 28663

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


28670
28671
28672
# File 'lib/google/apis/compute_beta/classes.rb', line 28670

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeBeta::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



28677
28678
28679
# File 'lib/google/apis/compute_beta/classes.rb', line 28677

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


28682
28683
28684
# File 'lib/google/apis/compute_beta/classes.rb', line 28682

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


28689
28690
28691
# File 'lib/google/apis/compute_beta/classes.rb', line 28689

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28696
28697
28698
28699
28700
28701
28702
28703
28704
# File 'lib/google/apis/compute_beta/classes.rb', line 28696

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end