Class: Google::Apis::ComputeBeta::InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy

Returns a new instance of InstancesGetEffectiveFirewallsResponseEffectiveFirewallPolicy.



26538
26539
26540
# File 'lib/google/apis/compute_beta/classes.rb', line 26538

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Output only. [Output Only] Deprecated, please use short name instead. The display name of the firewall policy. Corresponds to the JSON property displayName

Returns:

  • (String)


26499
26500
26501
# File 'lib/google/apis/compute_beta/classes.rb', line 26499

def display_name
  @display_name
end

#nameString

Output only. [Output Only] The name of the firewall policy. Corresponds to the JSON property name

Returns:

  • (String)


26504
26505
26506
# File 'lib/google/apis/compute_beta/classes.rb', line 26504

def name
  @name
end

#packet_mirroring_rulesArray<Google::Apis::ComputeBeta::FirewallPolicyRule>

Output only. [Output Only] The packet mirroring rules that apply to the instance. Corresponds to the JSON property packetMirroringRules



26510
26511
26512
# File 'lib/google/apis/compute_beta/classes.rb', line 26510

def packet_mirroring_rules
  @packet_mirroring_rules
end

#priorityFixnum

Output only. [Output only] Priority of firewall policy association. Not applicable for type=HIERARCHY. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


26517
26518
26519
# File 'lib/google/apis/compute_beta/classes.rb', line 26517

def priority
  @priority
end

#rulesArray<Google::Apis::ComputeBeta::FirewallPolicyRule>

[Output Only] The rules that apply to the instance. Only rules that target the specific VM instance are returned if target service accounts or target secure tags are specified in the rules. Corresponds to the JSON property rules



26524
26525
26526
# File 'lib/google/apis/compute_beta/classes.rb', line 26524

def rules
  @rules
end

#short_nameString

Output only. [Output Only] The short name of the firewall policy. Corresponds to the JSON property shortName

Returns:

  • (String)


26529
26530
26531
# File 'lib/google/apis/compute_beta/classes.rb', line 26529

def short_name
  @short_name
end

#typeString

Output only. [Output Only] The type of the firewall policy. Can be one of HIERARCHY, NETWORK, NETWORK_REGIONAL, SYSTEM_GLOBAL, SYSTEM_REGIONAL. Corresponds to the JSON property type

Returns:

  • (String)


26536
26537
26538
# File 'lib/google/apis/compute_beta/classes.rb', line 26536

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



26543
26544
26545
26546
26547
26548
26549
26550
26551
# File 'lib/google/apis/compute_beta/classes.rb', line 26543

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @packet_mirroring_rules = args[:packet_mirroring_rules] if args.key?(:packet_mirroring_rules)
  @priority = args[:priority] if args.key?(:priority)
  @rules = args[:rules] if args.key?(:rules)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
end