Class: Google::Apis::ComputeBeta::InstancesResumeRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstancesResumeRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeBeta::CustomerEncryptionKeyProtectedDisk>
Array of disks associated with this instance that are protected with acustomer- supplied encryption key.
-
#instance_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Decrypts data associated with an instance that is protected with acustomer- supplied encryption key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstancesResumeRequest
constructor
A new instance of InstancesResumeRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstancesResumeRequest
Returns a new instance of InstancesResumeRequest.
26674 26675 26676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeBeta::CustomerEncryptionKeyProtectedDisk>
Array of disks associated with this instance that are protected with acustomer-
supplied
encryption key.
In order to resume the instance, the disk url and its corresponding key
must be provided.
If the disk is not protected with a customer-supplied encryption key it
should not be specified.
Corresponds to the JSON property disks
26662 26663 26664 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26662 def disks @disks end |
#instance_encryption_key ⇒ Google::Apis::ComputeBeta::CustomerEncryptionKey
Decrypts data associated with an instance that is protected with acustomer-
supplied
encryption key.
If the instance you are starting is protected with a customer-supplied
encryption key, the correct key must be provided otherwise the
instance resume will not succeed.
Corresponds to the JSON property instanceEncryptionKey
26672 26673 26674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26672 def instance_encryption_key @instance_encryption_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
26679 26680 26681 26682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 26679 def update!(**args) @disks = args[:disks] if args.key?(:disks) @instance_encryption_key = args[:instance_encryption_key] if args.key?(:instance_encryption_key) end |