Class: Google::Apis::ComputeBeta::InstantSnapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a InstantSnapshot resource. You can use instant snapshots to create disk rollback points quickly..

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshot

Returns a new instance of InstantSnapshot.



27893
27894
27895
# File 'lib/google/apis/compute_beta/classes.rb', line 27893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the instant snapshot. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


27722
27723
27724
# File 'lib/google/apis/compute_beta/classes.rb', line 27722

def architecture
  @architecture
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


27728
27729
27730
# File 'lib/google/apis/compute_beta/classes.rb', line 27728

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


27734
27735
27736
# File 'lib/google/apis/compute_beta/classes.rb', line 27734

def description
  @description
end

#disk_size_gbFixnum

Output only. [Output Only] Size of the source disk, specified in GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


27739
27740
27741
# File 'lib/google/apis/compute_beta/classes.rb', line 27739

def disk_size_gb
  @disk_size_gb
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


27746
27747
27748
# File 'lib/google/apis/compute_beta/classes.rb', line 27746

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#instantSnapshot for InstantSnapshot resources. Corresponds to the JSON property kind

Returns:

  • (String)


27752
27753
27754
# File 'lib/google/apis/compute_beta/classes.rb', line 27752

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this InstantSnapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a InstantSnapshot. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


27765
27766
27767
# File 'lib/google/apis/compute_beta/classes.rb', line 27765

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this InstantSnapshot. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


27772
27773
27774
# File 'lib/google/apis/compute_beta/classes.rb', line 27772

def labels
  @labels
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


27783
27784
27785
# File 'lib/google/apis/compute_beta/classes.rb', line 27783

def name
  @name
end

#paramsGoogle::Apis::ComputeBeta::InstantSnapshotParams

Additional instant snapshot params. Corresponds to the JSON property params



27788
27789
27790
# File 'lib/google/apis/compute_beta/classes.rb', line 27788

def params
  @params
end

#regionString

Output only. [Output Only] URL of the region where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


27796
27797
27798
# File 'lib/google/apis/compute_beta/classes.rb', line 27796

def region
  @region
end

#resource_statusGoogle::Apis::ComputeBeta::InstantSnapshotResourceStatus

Output only. [Output Only] Status information for the instant snapshot resource. Corresponds to the JSON property resourceStatus



27802
27803
27804
# File 'lib/google/apis/compute_beta/classes.rb', line 27802

def resource_status
  @resource_status
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


27807
27808
27809
# File 'lib/google/apis/compute_beta/classes.rb', line 27807

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


27813
27814
27815
# File 'lib/google/apis/compute_beta/classes.rb', line 27813

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


27819
27820
27821
# File 'lib/google/apis/compute_beta/classes.rb', line 27819

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


27824
27825
27826
# File 'lib/google/apis/compute_beta/classes.rb', line 27824

def self_link_with_id
  @self_link_with_id
end

#source_diskString

URL of the source disk used to create this instant snapshot. Note that the source disk must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. For example, the following are valid values:

- https://www.googleapis.com/compute/v1/projects/project/zones/zone/disks/ disk

- https://www.googleapis.com/compute/v1/projects/project/regions/region/ disks/disk

- projects/project/zones/zone/disks/disk

- projects/project/regions/region/disks/disk

- zones/zone/disks/disk

- regions/region/disks/disk Corresponds to the JSON property sourceDisk

Returns:

  • (String)


27853
27854
27855
# File 'lib/google/apis/compute_beta/classes.rb', line 27853

def source_disk
  @source_disk
end

#source_disk_idString

Output only. [Output Only] The ID value of the disk used to create this InstantSnapshot. This value may be used to determine whether the InstantSnapshot was taken from the current or a previous instance of a given disk name. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


27861
27862
27863
# File 'lib/google/apis/compute_beta/classes.rb', line 27861

def source_disk_id
  @source_disk_id
end

#source_instant_snapshot_groupString

Output only. [Output Only] URL of the source instant snapshot this instant snapshot is part of. Note that the source instant snapshot group must be in the same zone/region as the instant snapshot to be created. This can be a full or valid partial URL. Corresponds to the JSON property sourceInstantSnapshotGroup

Returns:

  • (String)


27870
27871
27872
# File 'lib/google/apis/compute_beta/classes.rb', line 27870

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

#source_instant_snapshot_group_idString

Output only. [Output Only] The ID value of the source instant snapshot group this InstantSnapshot is part of. This value may be used to determine whether the InstantSnapshot was created as part of an InstantSnapshotGroup creation. Corresponds to the JSON property sourceInstantSnapshotGroupId

Returns:

  • (String)


27878
27879
27880
# File 'lib/google/apis/compute_beta/classes.rb', line 27878

def source_instant_snapshot_group_id
  @source_instant_snapshot_group_id
end

#statusString

Output only. [Output Only] The status of the instantSnapshot. This can beCREATING, DELETING, FAILED, orREADY. Corresponds to the JSON property status

Returns:

  • (String)


27884
27885
27886
# File 'lib/google/apis/compute_beta/classes.rb', line 27884

def status
  @status
end

#zoneString

Output only. [Output Only] URL of the zone where the instant snapshot resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property zone

Returns:

  • (String)


27891
27892
27893
# File 'lib/google/apis/compute_beta/classes.rb', line 27891

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



27898
27899
27900
27901
27902
27903
27904
27905
27906
27907
27908
27909
27910
27911
27912
27913
27914
27915
27916
27917
27918
27919
27920
27921
# File 'lib/google/apis/compute_beta/classes.rb', line 27898

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
  @source_instant_snapshot_group_id = args[:source_instant_snapshot_group_id] if args.key?(:source_instant_snapshot_group_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end