Class: Google::Apis::ComputeBeta::InstantSnapshotGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstantSnapshotGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an InstantSnapshotGroup resource. An instant snapshot group is a set of instant snapshots that represents a point in time state of a consistency group.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#region ⇒ String
Output only.
-
#resource_status ⇒ Google::Apis::ComputeBeta::InstantSnapshotGroupResourceStatus
Corresponds to the JSON property
resourceStatus. -
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_consistency_group ⇒ String
Corresponds to the JSON property
sourceConsistencyGroup. -
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotGroup
constructor
A new instance of InstantSnapshotGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotGroup
Returns a new instance of InstantSnapshotGroup.
28142 28143 28144 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28142 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
28066 28067 28068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28066 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource. Provide this property when
you
create the resource.
Corresponds to the JSON property description
28073 28074 28075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28073 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
28080 28081 28082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28080 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
instantSnapshotGroup for InstantSnapshotGroup
resources.
Corresponds to the JSON property kind
28087 28088 28089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28087 def kind @kind end |
#name ⇒ String
Identifier. Name of the resource; provided by the client when the resource is
created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
28099 28100 28101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28099 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the instant snapshot group
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
28107 28108 28109 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28107 def region @region end |
#resource_status ⇒ Google::Apis::ComputeBeta::InstantSnapshotGroupResourceStatus
Corresponds to the JSON property resourceStatus
28112 28113 28114 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28112 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
28117 28118 28119 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28117 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
28122 28123 28124 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28122 def self_link_with_id @self_link_with_id end |
#source_consistency_group ⇒ String
Corresponds to the JSON property sourceConsistencyGroup
28127 28128 28129 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28127 def source_consistency_group @source_consistency_group end |
#status ⇒ String
Output only. [Output Only]
Corresponds to the JSON property status
28132 28133 28134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28132 def status @status end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the instant snapshot group
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
28140 28141 28142 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28140 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28147 28148 28149 28150 28151 28152 28153 28154 28155 28156 28157 28158 28159 28160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28147 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_consistency_group = args[:source_consistency_group] if args.key?(:source_consistency_group) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |