Class: Google::Apis::ComputeBeta::InstantSnapshotGroupParameters

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotGroupParameters

Returns a new instance of InstantSnapshotGroupParameters.



28180
28181
28182
# File 'lib/google/apis/compute_beta/classes.rb', line 28180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_instant_snapshot_groupString

The source instant snapshot group used to create disks. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


28178
28179
28180
# File 'lib/google/apis/compute_beta/classes.rb', line 28178

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



28185
28186
28187
# File 'lib/google/apis/compute_beta/classes.rb', line 28185

def update!(**args)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
end