Class: Google::Apis::ComputeBeta::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



30297
30298
30299
# File 'lib/google/apis/compute_beta/classes.rb', line 30297

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30265
30266
30267
# File 'lib/google/apis/compute_beta/classes.rb', line 30265

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



30270
30271
30272
# File 'lib/google/apis/compute_beta/classes.rb', line 30270

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


30275
30276
30277
# File 'lib/google/apis/compute_beta/classes.rb', line 30275

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30285
30286
30287
# File 'lib/google/apis/compute_beta/classes.rb', line 30285

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30290
30291
30292
# File 'lib/google/apis/compute_beta/classes.rb', line 30290

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30295
30296
30297
# File 'lib/google/apis/compute_beta/classes.rb', line 30295

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30302
30303
30304
30305
30306
30307
30308
30309
# File 'lib/google/apis/compute_beta/classes.rb', line 30302

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end