Class: Google::Apis::ComputeBeta::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
30197 30198 30199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30165 30166 30167 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30165 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
30170 30171 30172 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30170 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
30175 30176 30177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30175 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30185 30186 30187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30185 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30190 30191 30192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30190 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30195 30196 30197 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30195 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30202 30203 30204 30205 30206 30207 30208 30209 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30202 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |