Class: Google::Apis::ComputeBeta::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
30175 30176 30177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
30143 30144 30145 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30143 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
30148 30149 30150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30148 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
30153 30154 30155 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30153 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
30163 30164 30165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30163 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
30168 30169 30170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30168 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
30173 30174 30175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30173 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30180 30181 30182 30183 30184 30185 30186 30187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30180 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |