Class: Google::Apis::ComputeBeta::InstantSnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InstantSnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstantSnapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshot>
A list of InstantSnapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InstantSnapshotList
constructor
A new instance of InstantSnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InstantSnapshotList
Returns a new instance of InstantSnapshotList.
29694 29695 29696 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
29662 29663 29664 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29662 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshot>
A list of InstantSnapshot resources.
Corresponds to the JSON property items
29667 29668 29669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29667 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
29672 29673 29674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29672 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
29682 29683 29684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29682 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
29687 29688 29689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29687 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InstantSnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
29692 29693 29694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29692 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29699 29700 29701 29702 29703 29704 29705 29706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29699 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |