Class: Google::Apis::ComputeBeta::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



29670
29671
29672
# File 'lib/google/apis/compute_beta/classes.rb', line 29670

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29638
29639
29640
# File 'lib/google/apis/compute_beta/classes.rb', line 29638

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



29643
29644
29645
# File 'lib/google/apis/compute_beta/classes.rb', line 29643

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


29648
29649
29650
# File 'lib/google/apis/compute_beta/classes.rb', line 29648

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29658
29659
29660
# File 'lib/google/apis/compute_beta/classes.rb', line 29658

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29663
29664
29665
# File 'lib/google/apis/compute_beta/classes.rb', line 29663

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29668
29669
29670
# File 'lib/google/apis/compute_beta/classes.rb', line 29668

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29675
29676
29677
29678
29679
29680
29681
29682
# File 'lib/google/apis/compute_beta/classes.rb', line 29675

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end