Class: Google::Apis::ComputeBeta::InstantSnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstantSnapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InstantSnapshotList

Returns a new instance of InstantSnapshotList.



29089
29090
29091
# File 'lib/google/apis/compute_beta/classes.rb', line 29089

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


29057
29058
29059
# File 'lib/google/apis/compute_beta/classes.rb', line 29057

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstantSnapshot>

A list of InstantSnapshot resources. Corresponds to the JSON property items



29062
29063
29064
# File 'lib/google/apis/compute_beta/classes.rb', line 29062

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


29067
29068
29069
# File 'lib/google/apis/compute_beta/classes.rb', line 29067

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


29077
29078
29079
# File 'lib/google/apis/compute_beta/classes.rb', line 29077

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


29082
29083
29084
# File 'lib/google/apis/compute_beta/classes.rb', line 29082

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InstantSnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



29087
29088
29089
# File 'lib/google/apis/compute_beta/classes.rb', line 29087

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29094
29095
29096
29097
29098
29099
29100
29101
# File 'lib/google/apis/compute_beta/classes.rb', line 29094

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end