Class: Google::Apis::ComputeBeta::Interconnect

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Interconnect resource. An Interconnect resource is a dedicated connection between the Google Cloud network and your on-premises network. For more information, read the Dedicated Interconnect Overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Interconnect

Returns a new instance of Interconnect.



30732
30733
30734
# File 'lib/google/apis/compute_beta/classes.rb', line 30732

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aai_enabledBoolean Also known as: aai_enabled?

Enable or disable the application awareness feature on this Cloud Interconnect. Corresponds to the JSON property aaiEnabled

Returns:

  • (Boolean)


30439
30440
30441
# File 'lib/google/apis/compute_beta/classes.rb', line 30439

def aai_enabled
  @aai_enabled
end

#admin_enabledBoolean Also known as: admin_enabled?

Administrative status of the interconnect. When this is set to true, the Interconnect is functional and can carry traffic. When set to false, no packets can be carried over the interconnect and no BGP routes are exchanged over it. By default, the status is set to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


30448
30449
30450
# File 'lib/google/apis/compute_beta/classes.rb', line 30448

def admin_enabled
  @admin_enabled
end

#application_aware_interconnectGoogle::Apis::ComputeBeta::InterconnectApplicationAwareInterconnect

Configuration information for application awareness on this Cloud Interconnect. Corresponds to the JSON property applicationAwareInterconnect



30455
30456
30457
# File 'lib/google/apis/compute_beta/classes.rb', line 30455

def application_aware_interconnect
  @application_aware_interconnect
end

#available_featuresArray<String>

[Output only] List of features available for this Interconnect connection, which can take one of the following values:

  • IF_MACSEC: If present, then the Interconnect connection is provisioned on MACsec capable hardware ports. If not present, then the Interconnect connection is provisioned on non-MACsec capable ports. Any attempt to enable MACsec will fail.
  • IF_CROSS_SITE_NETWORK: If present, then the Interconnect connection is provisioned exclusively for Cross-Site Networking. Any attempt to configure VLAN attachments will fail. If not present, then the Interconnect connection is not provisioned for Cross-Site Networking. Any attempt to use it for Cross-Site Networking will fail. Corresponds to the JSON property availableFeatures

Returns:

  • (Array<String>)


30471
30472
30473
# File 'lib/google/apis/compute_beta/classes.rb', line 30471

def available_features
  @available_features
end

#circuit_infosArray<Google::Apis::ComputeBeta::InterconnectCircuitInfo>

Output only. [Output Only] A list of CircuitInfo objects, that describe the individual circuits in this LAG. Corresponds to the JSON property circuitInfos



30478
30479
30480
# File 'lib/google/apis/compute_beta/classes.rb', line 30478

def circuit_infos
  @circuit_infos
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


30484
30485
30486
# File 'lib/google/apis/compute_beta/classes.rb', line 30484

def creation_timestamp
  @creation_timestamp
end

#customer_nameString

Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect. Corresponds to the JSON property customerName

Returns:

  • (String)


30490
30491
30492
# File 'lib/google/apis/compute_beta/classes.rb', line 30490

def customer_name
  @customer_name
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


30496
30497
30498
# File 'lib/google/apis/compute_beta/classes.rb', line 30496

def description
  @description
end

#effective_locationString

Output only. URL of the InterconnectLocation object that represents where this connection is to be provisioned. By default it will be the same as the location field. Corresponds to the JSON property effectiveLocation

Returns:

  • (String)


30503
30504
30505
# File 'lib/google/apis/compute_beta/classes.rb', line 30503

def effective_location
  @effective_location
end

#expected_outagesArray<Google::Apis::ComputeBeta::InterconnectOutageNotification>

Output only. [Output Only] A list of outages expected for this Interconnect. Corresponds to the JSON property expectedOutages



30508
30509
30510
# File 'lib/google/apis/compute_beta/classes.rb', line 30508

def expected_outages
  @expected_outages
end

#google_ip_addressString

Output only. [Output Only] IP address configured on the Google side of the Interconnect link. This can be used only for ping tests. Corresponds to the JSON property googleIpAddress

Returns:

  • (String)


30515
30516
30517
# File 'lib/google/apis/compute_beta/classes.rb', line 30515

def google_ip_address
  @google_ip_address
end

#google_reference_idString

Output only. [Output Only] Google reference ID to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. Corresponds to the JSON property googleReferenceId

Returns:

  • (String)


30522
30523
30524
# File 'lib/google/apis/compute_beta/classes.rb', line 30522

def google_reference_id
  @google_reference_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30529
30530
30531
# File 'lib/google/apis/compute_beta/classes.rb', line 30529

def id
  @id
end

#interconnect_attachmentsArray<String>

Output only. [Output Only] A list of the URLs of all InterconnectAttachments configured to use this Interconnect. Corresponds to the JSON property interconnectAttachments

Returns:

  • (Array<String>)


30536
30537
30538
# File 'lib/google/apis/compute_beta/classes.rb', line 30536

def interconnect_attachments
  @interconnect_attachments
end

#interconnect_groupsArray<String>

Output only. [Output Only] URLs of InterconnectGroups that include this Interconnect. Order is arbitrary and items are unique. Corresponds to the JSON property interconnectGroups

Returns:

  • (Array<String>)


30543
30544
30545
# File 'lib/google/apis/compute_beta/classes.rb', line 30543

def interconnect_groups
  @interconnect_groups
end

#interconnect_typeString

Type of interconnect, which can take one of the following values:

  • PARTNER: A partner-managed interconnection shared between customers though a partner.
  • DEDICATED: A dedicated physical interconnection with the customer. Note that a value IT_PRIVATE has been deprecated in favor of DEDICATED. Corresponds to the JSON property interconnectType

Returns:

  • (String)


30554
30555
30556
# File 'lib/google/apis/compute_beta/classes.rb', line 30554

def interconnect_type
  @interconnect_type
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#interconnect for interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


30560
30561
30562
# File 'lib/google/apis/compute_beta/classes.rb', line 30560

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this Interconnect, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an Interconnect. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


30573
30574
30575
# File 'lib/google/apis/compute_beta/classes.rb', line 30573

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


30580
30581
30582
# File 'lib/google/apis/compute_beta/classes.rb', line 30580

def labels
  @labels
end

Type of link requested, which can take one of the following values:

  • LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics
  • LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
  • LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4 optics. Note that this field indicates the speed of each of the links in the bundle, not the speed of the entire bundle. Corresponds to the JSON property linkType

Returns:

  • (String)


30591
30592
30593
# File 'lib/google/apis/compute_beta/classes.rb', line 30591

def link_type
  @link_type
end

#locationString

URL of the InterconnectLocation object that represents where this connection is to be provisioned. Corresponds to the JSON property location

Returns:

  • (String)


30597
30598
30599
# File 'lib/google/apis/compute_beta/classes.rb', line 30597

def location
  @location
end

#macsecGoogle::Apis::ComputeBeta::InterconnectMacsec

Configuration information for enabling Media Access Control security (MACsec) on this Cloud Interconnect connection between Google and your on-premises router. Corresponds to the JSON property macsec



30604
30605
30606
# File 'lib/google/apis/compute_beta/classes.rb', line 30604

def macsec
  @macsec
end

#macsec_enabledBoolean Also known as: macsec_enabled?

Enable or disable MACsec on this Interconnect connection. MACsec enablement fails if the MACsec object is not specified. Corresponds to the JSON property macsecEnabled

Returns:

  • (Boolean)


30610
30611
30612
# File 'lib/google/apis/compute_beta/classes.rb', line 30610

def macsec_enabled
  @macsec_enabled
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


30622
30623
30624
# File 'lib/google/apis/compute_beta/classes.rb', line 30622

def name
  @name
end

#noc_contact_emailString

Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect. If specified, this will be used for notifications in addition to all other forms described, such as Cloud Monitoring logs alerting and Cloud Notifications. This field is required for users who sign up for Cloud Interconnect using workforce identity federation. Corresponds to the JSON property nocContactEmail

Returns:

  • (String)


30632
30633
30634
# File 'lib/google/apis/compute_beta/classes.rb', line 30632

def noc_contact_email
  @noc_contact_email
end

#operational_statusString

Output only. [Output Only] The current status of this Interconnect's functionality, which can take one of the following values:

  • OS_ACTIVE: A valid Interconnect, which is turned up and is ready to use. Attachments may be provisioned on this Interconnect.
  • OS_UNPROVISIONED: An Interconnect that has not completed turnup. No attachments may be provisioned on this Interconnect.
  • OS_UNDER_MAINTENANCE: An Interconnect that is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


30647
30648
30649
# File 'lib/google/apis/compute_beta/classes.rb', line 30647

def operational_status
  @operational_status
end

#paramsGoogle::Apis::ComputeBeta::InterconnectParams

Additional interconnect parameters. Corresponds to the JSON property params



30652
30653
30654
# File 'lib/google/apis/compute_beta/classes.rb', line 30652

def params
  @params
end

#peer_ip_addressString

Output only. [Output Only] IP address configured on the customer side of the Interconnect link. The customer should configure this IP address during turnup when prompted by Google NOC. This can be used only for ping tests. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


30659
30660
30661
# File 'lib/google/apis/compute_beta/classes.rb', line 30659

def peer_ip_address
  @peer_ip_address
end

Output only. [Output Only] Number of links actually provisioned in this interconnect. Corresponds to the JSON property provisionedLinkCount

Returns:

  • (Fixnum)


30665
30666
30667
# File 'lib/google/apis/compute_beta/classes.rb', line 30665

def provisioned_link_count
  @provisioned_link_count
end

#remote_locationString

Indicates that this is a Cross-Cloud Interconnect. This field specifies the location outside of Google's network that the interconnect is connected to. Corresponds to the JSON property remoteLocation

Returns:

  • (String)


30671
30672
30673
# File 'lib/google/apis/compute_beta/classes.rb', line 30671

def remote_location
  @remote_location
end

#requested_featuresArray<String>

Optional. This parameter can be provided only with Interconnect INSERT. It isn't valid for Interconnect PATCH. List of features requested for this Interconnect connection, which can take one of the following values:

  • IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
  • IF_CROSS_SITE_NETWORK: If specified, then the connection is created exclusively for Cross-Site Networking. The connection can not be used for Cross-Site Networking unless this feature is specified. Corresponds to the JSON property requestedFeatures

Returns:

  • (Array<String>)


30685
30686
30687
# File 'lib/google/apis/compute_beta/classes.rb', line 30685

def requested_features
  @requested_features
end

Target number of physical links in the link bundle, as requested by the customer. Corresponds to the JSON property requestedLinkCount

Returns:

  • (Fixnum)


30691
30692
30693
# File 'lib/google/apis/compute_beta/classes.rb', line 30691

def requested_link_count
  @requested_link_count
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


30696
30697
30698
# File 'lib/google/apis/compute_beta/classes.rb', line 30696

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30702
30703
30704
# File 'lib/google/apis/compute_beta/classes.rb', line 30702

def self_link
  @self_link
end

#stateString

Output only. [Output Only] The current state of Interconnect functionality, which can take one of the following values:

  • ACTIVE: The Interconnect is valid, turned up and ready to use. Attachments may be provisioned on this Interconnect.
  • UNPROVISIONED: The Interconnect has not completed turnup. No attachments may be provisioned on this Interconnect.
  • UNDER_MAINTENANCE: The Interconnect is undergoing internal maintenance. No attachments may be provisioned or updated on this Interconnect. Corresponds to the JSON property state

Returns:

  • (String)


30717
30718
30719
# File 'lib/google/apis/compute_beta/classes.rb', line 30717

def state
  @state
end

#subzoneString

To be deprecated. Corresponds to the JSON property subzone

Returns:

  • (String)


30722
30723
30724
# File 'lib/google/apis/compute_beta/classes.rb', line 30722

def subzone
  @subzone
end

#wire_groupsArray<String>

Output only. [Output Only] A list of the URLs of all CrossSiteNetwork WireGroups configured to use this Interconnect. The Interconnect cannot be deleted if this list is non-empty. Corresponds to the JSON property wireGroups

Returns:

  • (Array<String>)


30730
30731
30732
# File 'lib/google/apis/compute_beta/classes.rb', line 30730

def wire_groups
  @wire_groups
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30737
30738
30739
30740
30741
30742
30743
30744
30745
30746
30747
30748
30749
30750
30751
30752
30753
30754
30755
30756
30757
30758
30759
30760
30761
30762
30763
30764
30765
30766
30767
30768
30769
30770
30771
30772
30773
30774
30775
# File 'lib/google/apis/compute_beta/classes.rb', line 30737

def update!(**args)
  @aai_enabled = args[:aai_enabled] if args.key?(:aai_enabled)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @application_aware_interconnect = args[:application_aware_interconnect] if args.key?(:application_aware_interconnect)
  @available_features = args[:available_features] if args.key?(:available_features)
  @circuit_infos = args[:circuit_infos] if args.key?(:circuit_infos)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @customer_name = args[:customer_name] if args.key?(:customer_name)
  @description = args[:description] if args.key?(:description)
  @effective_location = args[:effective_location] if args.key?(:effective_location)
  @expected_outages = args[:expected_outages] if args.key?(:expected_outages)
  @google_ip_address = args[:google_ip_address] if args.key?(:google_ip_address)
  @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id)
  @id = args[:id] if args.key?(:id)
  @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments)
  @interconnect_groups = args[:interconnect_groups] if args.key?(:interconnect_groups)
  @interconnect_type = args[:interconnect_type] if args.key?(:interconnect_type)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @link_type = args[:link_type] if args.key?(:link_type)
  @location = args[:location] if args.key?(:location)
  @macsec = args[:macsec] if args.key?(:macsec)
  @macsec_enabled = args[:macsec_enabled] if args.key?(:macsec_enabled)
  @name = args[:name] if args.key?(:name)
  @noc_contact_email = args[:noc_contact_email] if args.key?(:noc_contact_email)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @params = args[:params] if args.key?(:params)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @provisioned_link_count = args[:provisioned_link_count] if args.key?(:provisioned_link_count)
  @remote_location = args[:remote_location] if args.key?(:remote_location)
  @requested_features = args[:requested_features] if args.key?(:requested_features)
  @requested_link_count = args[:requested_link_count] if args.key?(:requested_link_count)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @state = args[:state] if args.key?(:state)
  @subzone = args[:subzone] if args.key?(:subzone)
  @wire_groups = args[:wire_groups] if args.key?(:wire_groups)
end