Class: Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnect

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration information for application awareness on this Cloud Interconnect.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect

Returns a new instance of InterconnectApplicationAwareInterconnect.



30868
30869
30870
# File 'lib/google/apis/compute_beta/classes.rb', line 30868

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bandwidth_percentage_policyGoogle::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy

Corresponds to the JSON property bandwidthPercentagePolicy



30848
30849
30850
# File 'lib/google/apis/compute_beta/classes.rb', line 30848

def bandwidth_percentage_policy
  @bandwidth_percentage_policy
end

#profile_descriptionString

Description for the application awareness profile on this Cloud Interconnect. Corresponds to the JSON property profileDescription

Returns:

  • (String)


30854
30855
30856
# File 'lib/google/apis/compute_beta/classes.rb', line 30854

def profile_description
  @profile_description
end

#shape_average_percentagesArray<Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectBandwidthPercentage>

Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy. Corresponds to the JSON property shapeAveragePercentages



30861
30862
30863
# File 'lib/google/apis/compute_beta/classes.rb', line 30861

def shape_average_percentages
  @shape_average_percentages
end

#strict_priority_policyGoogle::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectStrictPriorityPolicy

Specify configuration for StrictPriorityPolicy. Corresponds to the JSON property strictPriorityPolicy



30866
30867
30868
# File 'lib/google/apis/compute_beta/classes.rb', line 30866

def strict_priority_policy
  @strict_priority_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30873
30874
30875
30876
30877
30878
# File 'lib/google/apis/compute_beta/classes.rb', line 30873

def update!(**args)
  @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy)
  @profile_description = args[:profile_description] if args.key?(:profile_description)
  @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages)
  @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy)
end