Class: Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnect
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnect
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration information for application awareness on this Cloud Interconnect.
Instance Attribute Summary collapse
-
#bandwidth_percentage_policy ⇒ Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
Corresponds to the JSON property
bandwidthPercentagePolicy. -
#profile_description ⇒ String
Description for the application awareness profile on this Cloud Interconnect.
-
#shape_average_percentages ⇒ Array<Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectBandwidthPercentage>
Optional field to specify a list of shape average percentages to be applied in conjunction with StrictPriorityPolicy or BandwidthPercentagePolicy.
-
#strict_priority_policy ⇒ Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectStrictPriorityPolicy
Specify configuration for StrictPriorityPolicy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect
constructor
A new instance of InterconnectApplicationAwareInterconnect.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectApplicationAwareInterconnect
Returns a new instance of InterconnectApplicationAwareInterconnect.
29712 29713 29714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29712 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bandwidth_percentage_policy ⇒ Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectBandwidthPercentagePolicy
Corresponds to the JSON property bandwidthPercentagePolicy
29692 29693 29694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29692 def bandwidth_percentage_policy @bandwidth_percentage_policy end |
#profile_description ⇒ String
Description for the application awareness profile on this Cloud
Interconnect.
Corresponds to the JSON property profileDescription
29698 29699 29700 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29698 def profile_description @profile_description end |
#shape_average_percentages ⇒ Array<Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectBandwidthPercentage>
Optional field to specify a list of shape average percentages to be
applied in conjunction with StrictPriorityPolicy or
BandwidthPercentagePolicy.
Corresponds to the JSON property shapeAveragePercentages
29705 29706 29707 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29705 def shape_average_percentages @shape_average_percentages end |
#strict_priority_policy ⇒ Google::Apis::ComputeBeta::InterconnectApplicationAwareInterconnectStrictPriorityPolicy
Specify configuration for StrictPriorityPolicy.
Corresponds to the JSON property strictPriorityPolicy
29710 29711 29712 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29710 def strict_priority_policy @strict_priority_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29717 29718 29719 29720 29721 29722 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29717 def update!(**args) @bandwidth_percentage_policy = args[:bandwidth_percentage_policy] if args.key?(:bandwidth_percentage_policy) @profile_description = args[:profile_description] if args.key?(:profile_description) @shape_average_percentages = args[:shape_average_percentages] if args.key?(:shape_average_percentages) @strict_priority_policy = args[:strict_priority_policy] if args.key?(:strict_priority_policy) end |