Class: Google::Apis::ComputeBeta::InterconnectAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachment

Returns a new instance of InterconnectAttachment.



31447
31448
31449
# File 'lib/google/apis/compute_beta/classes.rb', line 31447

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


31013
31014
31015
# File 'lib/google/apis/compute_beta/classes.rb', line 31013

def admin_enabled
  @admin_enabled
end

#attachment_groupString

Output only. [Output Only] URL of the AttachmentGroup that includes this Attachment. Corresponds to the JSON property attachmentGroup

Returns:

  • (String)


31020
31021
31022
# File 'lib/google/apis/compute_beta/classes.rb', line 31020

def attachment_group
  @attachment_group
end

#bandwidthString

Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:

  • BPS_50M: 50 Mbit/s
  • BPS_100M: 100 Mbit/s
  • BPS_200M: 200 Mbit/s
  • BPS_300M: 300 Mbit/s
  • BPS_400M: 400 Mbit/s
  • BPS_500M: 500 Mbit/s
  • BPS_1G: 1 Gbit/s
  • BPS_2G: 2 Gbit/s
  • BPS_5G: 5 Gbit/s
  • BPS_10G: 10 Gbit/s
  • BPS_20G: 20 Gbit/s
  • BPS_50G: 50 Gbit/s
  • BPS_100G: 100 Gbit/s
  • BPS_400G: 400 Gbit/s Corresponds to the JSON property bandwidth

Returns:

  • (String)


31045
31046
31047
# File 'lib/google/apis/compute_beta/classes.rb', line 31045

def bandwidth
  @bandwidth
end

#candidate_cloud_router_ip_addressString

Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
  • Max prefix length is 31. Corresponds to the JSON property candidateCloudRouterIpAddress

Returns:

  • (String)


31058
31059
31060
# File 'lib/google/apis/compute_beta/classes.rb', line 31058

def candidate_cloud_router_ip_address
  @candidate_cloud_router_ip_address
end

#candidate_cloud_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
  • Max prefix length is 126. Corresponds to the JSON property candidateCloudRouterIpv6Address

Returns:

  • (String)


31071
31072
31073
# File 'lib/google/apis/compute_beta/classes.rb', line 31071

def candidate_cloud_router_ipv6_address
  @candidate_cloud_router_ipv6_address
end

#candidate_customer_router_ip_addressString

Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpAddress

Returns:

  • (String)


31077
31078
31079
# File 'lib/google/apis/compute_beta/classes.rb', line 31077

def candidate_customer_router_ip_address
  @candidate_customer_router_ip_address
end

#candidate_customer_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpv6Address

Returns:

  • (String)


31083
31084
31085
# File 'lib/google/apis/compute_beta/classes.rb', line 31083

def candidate_customer_router_ipv6_address
  @candidate_customer_router_ipv6_address
end

#candidate_ipv6_subnetsArray<String>

This field is not available. Corresponds to the JSON property candidateIpv6Subnets

Returns:

  • (Array<String>)


31088
31089
31090
# File 'lib/google/apis/compute_beta/classes.rb', line 31088

def candidate_ipv6_subnets
  @candidate_ipv6_subnets
end

#candidate_subnetsArray<String>

Input only. Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space. Corresponds to the JSON property candidateSubnets

Returns:

  • (Array<String>)


31100
31101
31102
# File 'lib/google/apis/compute_beta/classes.rb', line 31100

def candidate_subnets
  @candidate_subnets
end

#cloud_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpAddress

Returns:

  • (String)


31107
31108
31109
# File 'lib/google/apis/compute_beta/classes.rb', line 31107

def cloud_router_ip_address
  @cloud_router_ip_address
end

#cloud_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpv6Address

Returns:

  • (String)


31114
31115
31116
# File 'lib/google/apis/compute_beta/classes.rb', line 31114

def cloud_router_ipv6_address
  @cloud_router_ipv6_address
end

#cloud_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property cloudRouterIpv6InterfaceId

Returns:

  • (String)


31119
31120
31121
# File 'lib/google/apis/compute_beta/classes.rb', line 31119

def cloud_router_ipv6_interface_id
  @cloud_router_ipv6_interface_id
end

#configuration_constraintsGoogle::Apis::ComputeBeta::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Constraints for this attachment, if any. The attachment does not work if these constraints are not met. Corresponds to the JSON property configurationConstraints



31126
31127
31128
# File 'lib/google/apis/compute_beta/classes.rb', line 31126

def configuration_constraints
  @configuration_constraints
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


31132
31133
31134
# File 'lib/google/apis/compute_beta/classes.rb', line 31132

def creation_timestamp
  @creation_timestamp
end

#customer_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpAddress

Returns:

  • (String)


31139
31140
31141
# File 'lib/google/apis/compute_beta/classes.rb', line 31139

def customer_router_ip_address
  @customer_router_ip_address
end

#customer_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpv6Address

Returns:

  • (String)


31146
31147
31148
# File 'lib/google/apis/compute_beta/classes.rb', line 31146

def customer_router_ipv6_address
  @customer_router_ipv6_address
end

#customer_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property customerRouterIpv6InterfaceId

Returns:

  • (String)


31151
31152
31153
# File 'lib/google/apis/compute_beta/classes.rb', line 31151

def customer_router_ipv6_interface_id
  @customer_router_ipv6_interface_id
end

#dataplane_versionFixnum

Output only. [Output Only] Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1. Corresponds to the JSON property dataplaneVersion

Returns:

  • (Fixnum)


31159
31160
31161
# File 'lib/google/apis/compute_beta/classes.rb', line 31159

def dataplane_version
  @dataplane_version
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


31164
31165
31166
# File 'lib/google/apis/compute_beta/classes.rb', line 31164

def description
  @description
end

#edge_availability_domainString

Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:

  • AVAILABILITY_DOMAIN_ANY
  • AVAILABILITY_DOMAIN_1
  • AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY. Corresponds to the JSON property edgeAvailabilityDomain

Returns:

  • (String)


31180
31181
31182
# File 'lib/google/apis/compute_beta/classes.rb', line 31180

def edge_availability_domain
  @edge_availability_domain
end

#encryptionString

Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:

  • NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment.
  • IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use HA VPN over Cloud Interconnect, the VLAN attachment must be created with this option. Corresponds to the JSON property encryption

Returns:

  • (String)


31198
31199
31200
# File 'lib/google/apis/compute_beta/classes.rb', line 31198

def encryption
  @encryption
end

#google_reference_idString

Output only. [Output Only] Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. [Deprecated] This field is not used. Corresponds to the JSON property googleReferenceId

Returns:

  • (String)


31206
31207
31208
# File 'lib/google/apis/compute_beta/classes.rb', line 31206

def google_reference_id
  @google_reference_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31213
31214
31215
# File 'lib/google/apis/compute_beta/classes.rb', line 31213

def id
  @id
end

#interconnectString

URL of the underlying Interconnect object that this attachment's traffic will traverse through. Corresponds to the JSON property interconnect

Returns:

  • (String)


31219
31220
31221
# File 'lib/google/apis/compute_beta/classes.rb', line 31219

def interconnect
  @interconnect
end

#ipsec_internal_addressesArray<String>

A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool. Corresponds to the JSON property ipsecInternalAddresses

Returns:

  • (Array<String>)


31237
31238
31239
# File 'lib/google/apis/compute_beta/classes.rb', line 31237

def ipsec_internal_addresses
  @ipsec_internal_addresses
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectAttachment for interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


31243
31244
31245
# File 'lib/google/apis/compute_beta/classes.rb', line 31243

def kind
  @kind
end

#l2_forwardingGoogle::Apis::ComputeBeta::InterconnectAttachmentL2Forwarding

L2 Interconnect Attachment related configuration. Corresponds to the JSON property l2Forwarding



31248
31249
31250
# File 'lib/google/apis/compute_beta/classes.rb', line 31248

def l2_forwarding
  @l2_forwarding
end

#label_fingerprintString

A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InterconnectAttachment. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


31261
31262
31263
# File 'lib/google/apis/compute_beta/classes.rb', line 31261

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


31268
31269
31270
# File 'lib/google/apis/compute_beta/classes.rb', line 31268

def labels
  @labels
end

#mtuFixnum

Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Valid values are 1440, 1460, 1500, and 8896. If not specified, the value will default to 1440. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


31276
31277
31278
# File 'lib/google/apis/compute_beta/classes.rb', line 31276

def mtu
  @mtu
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


31287
31288
31289
# File 'lib/google/apis/compute_beta/classes.rb', line 31287

def name
  @name
end

#operational_statusString

Output only. [Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values:

  • OS_ACTIVE: The attachment has been turned up and is ready to use.
  • OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


31299
31300
31301
# File 'lib/google/apis/compute_beta/classes.rb', line 31299

def operational_status
  @operational_status
end

#pairing_keyString

[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain" Corresponds to the JSON property pairingKey

Returns:

  • (String)


31308
31309
31310
# File 'lib/google/apis/compute_beta/classes.rb', line 31308

def pairing_key
  @pairing_key
end

#paramsGoogle::Apis::ComputeBeta::InterconnectAttachmentParams

Additional interconnect attachment parameters. Corresponds to the JSON property params



31313
31314
31315
# File 'lib/google/apis/compute_beta/classes.rb', line 31313

def params
  @params
end

#partner_asnFixnum

Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED. Corresponds to the JSON property partnerAsn

Returns:

  • (Fixnum)


31321
31322
31323
# File 'lib/google/apis/compute_beta/classes.rb', line 31321

def partner_asn
  @partner_asn
end

#partner_metadataGoogle::Apis::ComputeBeta::InterconnectAttachmentPartnerMetadata

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments. Corresponds to the JSON property partnerMetadata



31328
31329
31330
# File 'lib/google/apis/compute_beta/classes.rb', line 31328

def 
  @partner_metadata
end

#private_interconnect_infoGoogle::Apis::ComputeBeta::InterconnectAttachmentPrivateInfo

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED. Corresponds to the JSON property privateInterconnectInfo



31334
31335
31336
# File 'lib/google/apis/compute_beta/classes.rb', line 31334

def private_interconnect_info
  @private_interconnect_info
end

#regionString

Output only. [Output Only] URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


31343
31344
31345
# File 'lib/google/apis/compute_beta/classes.rb', line 31343

def region
  @region
end

#remote_serviceString

Output only. [Output Only] If the attachment is on a Cross-Cloud Interconnect connection, this field contains the interconnect's remote location service provider. Example values: "Amazon Web Services" "Microsoft Azure". The field is set only for attachments on Cross-Cloud Interconnect connections. Its value is copied from the InterconnectRemoteLocation remoteService field. Corresponds to the JSON property remoteService

Returns:

  • (String)


31354
31355
31356
# File 'lib/google/apis/compute_beta/classes.rb', line 31354

def remote_service
  @remote_service
end

#routerString

URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured. Corresponds to the JSON property router

Returns:

  • (String)


31362
31363
31364
# File 'lib/google/apis/compute_beta/classes.rb', line 31362

def router
  @router
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


31367
31368
31369
# File 'lib/google/apis/compute_beta/classes.rb', line 31367

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31373
31374
31375
# File 'lib/google/apis/compute_beta/classes.rb', line 31373

def self_link
  @self_link
end

#stack_typeString

The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations. Corresponds to the JSON property stackType

Returns:

  • (String)


31382
31383
31384
# File 'lib/google/apis/compute_beta/classes.rb', line 31382

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values:

  • ACTIVE: The attachment has been turned up and is ready to use.
  • UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
  • PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
  • PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
  • PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
  • DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted. Corresponds to the JSON property state

Returns:

  • (String)


31408
31409
31410
# File 'lib/google/apis/compute_beta/classes.rb', line 31408

def state
  @state
end

#subnet_lengthFixnum

Input only. Length of the IPv4 subnet mask. Allowed values:

  • 29 (default)
  • 30 The default value is 29, except for Cross-Cloud Interconnect connections that use an InterconnectRemoteLocation with a constraints.subnetLengthRange.min equal to 30. For example, connections that use an Azure remote location fall into this category. In these cases, the default value is 30, and requesting 29 returns an error. Where both 29 and 30 are allowed, 29 is preferred, because it gives Google Cloud Support more debugging visibility. Corresponds to the JSON property subnetLength

Returns:

  • (Fixnum)


31426
31427
31428
# File 'lib/google/apis/compute_beta/classes.rb', line 31426

def subnet_length
  @subnet_length
end

#typeString

The type of interconnect attachment this is, which can take one of the following values:

  • DEDICATED: an attachment to a Dedicated Interconnect.
  • PARTNER: an attachment to a Partner Interconnect, created by the customer.
  • PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
  • L2_DEDICATED: a L2 attachment to a Dedicated Interconnect. Corresponds to the JSON property type

Returns:

  • (String)


31439
31440
31441
# File 'lib/google/apis/compute_beta/classes.rb', line 31439

def type
  @type
end

#vlan_tag8021qFixnum

The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time. Corresponds to the JSON property vlanTag8021q

Returns:

  • (Fixnum)


31445
31446
31447
# File 'lib/google/apis/compute_beta/classes.rb', line 31445

def vlan_tag8021q
  @vlan_tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31452
31453
31454
31455
31456
31457
31458
31459
31460
31461
31462
31463
31464
31465
31466
31467
31468
31469
31470
31471
31472
31473
31474
31475
31476
31477
31478
31479
31480
31481
31482
31483
31484
31485
31486
31487
31488
31489
31490
31491
31492
31493
31494
31495
31496
31497
31498
31499
31500
# File 'lib/google/apis/compute_beta/classes.rb', line 31452

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @attachment_group = args[:attachment_group] if args.key?(:attachment_group)
  @bandwidth = args[:bandwidth] if args.key?(:bandwidth)
  @candidate_cloud_router_ip_address = args[:candidate_cloud_router_ip_address] if args.key?(:candidate_cloud_router_ip_address)
  @candidate_cloud_router_ipv6_address = args[:candidate_cloud_router_ipv6_address] if args.key?(:candidate_cloud_router_ipv6_address)
  @candidate_customer_router_ip_address = args[:candidate_customer_router_ip_address] if args.key?(:candidate_customer_router_ip_address)
  @candidate_customer_router_ipv6_address = args[:candidate_customer_router_ipv6_address] if args.key?(:candidate_customer_router_ipv6_address)
  @candidate_ipv6_subnets = args[:candidate_ipv6_subnets] if args.key?(:candidate_ipv6_subnets)
  @candidate_subnets = args[:candidate_subnets] if args.key?(:candidate_subnets)
  @cloud_router_ip_address = args[:cloud_router_ip_address] if args.key?(:cloud_router_ip_address)
  @cloud_router_ipv6_address = args[:cloud_router_ipv6_address] if args.key?(:cloud_router_ipv6_address)
  @cloud_router_ipv6_interface_id = args[:cloud_router_ipv6_interface_id] if args.key?(:cloud_router_ipv6_interface_id)
  @configuration_constraints = args[:configuration_constraints] if args.key?(:configuration_constraints)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @customer_router_ip_address = args[:customer_router_ip_address] if args.key?(:customer_router_ip_address)
  @customer_router_ipv6_address = args[:customer_router_ipv6_address] if args.key?(:customer_router_ipv6_address)
  @customer_router_ipv6_interface_id = args[:customer_router_ipv6_interface_id] if args.key?(:customer_router_ipv6_interface_id)
  @dataplane_version = args[:dataplane_version] if args.key?(:dataplane_version)
  @description = args[:description] if args.key?(:description)
  @edge_availability_domain = args[:edge_availability_domain] if args.key?(:edge_availability_domain)
  @encryption = args[:encryption] if args.key?(:encryption)
  @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id)
  @id = args[:id] if args.key?(:id)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @ipsec_internal_addresses = args[:ipsec_internal_addresses] if args.key?(:ipsec_internal_addresses)
  @kind = args[:kind] if args.key?(:kind)
  @l2_forwarding = args[:l2_forwarding] if args.key?(:l2_forwarding)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @mtu = args[:mtu] if args.key?(:mtu)
  @name = args[:name] if args.key?(:name)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @pairing_key = args[:pairing_key] if args.key?(:pairing_key)
  @params = args[:params] if args.key?(:params)
  @partner_asn = args[:partner_asn] if args.key?(:partner_asn)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @private_interconnect_info = args[:private_interconnect_info] if args.key?(:private_interconnect_info)
  @region = args[:region] if args.key?(:region)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @router = args[:router] if args.key?(:router)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @subnet_length = args[:subnet_length] if args.key?(:subnet_length)
  @type = args[:type] if args.key?(:type)
  @vlan_tag8021q = args[:vlan_tag8021q] if args.key?(:vlan_tag8021q)
end