Class: Google::Apis::ComputeBeta::InterconnectAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) resource. You can use Interconnect attachments (VLANS) to connect your Virtual Private Cloud networks to your on-premises networks through an Interconnect. For more information, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachment

Returns a new instance of InterconnectAttachment.



31347
31348
31349
# File 'lib/google/apis/compute_beta/classes.rb', line 31347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Determines whether this Attachment will carry packets. Not present for PARTNER_PROVIDER. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


30913
30914
30915
# File 'lib/google/apis/compute_beta/classes.rb', line 30913

def admin_enabled
  @admin_enabled
end

#attachment_groupString

Output only. [Output Only] URL of the AttachmentGroup that includes this Attachment. Corresponds to the JSON property attachmentGroup

Returns:

  • (String)


30920
30921
30922
# File 'lib/google/apis/compute_beta/classes.rb', line 30920

def attachment_group
  @attachment_group
end

#bandwidthString

Provisioned bandwidth capacity for the interconnect attachment. For attachments of type DEDICATED, the user can set the bandwidth. For attachments of type PARTNER, the Google Partner that is operating the interconnect must set the bandwidth. Output only for PARTNER type, mutable for PARTNER_PROVIDER and DEDICATED, and can take one of the following values:

  • BPS_50M: 50 Mbit/s
  • BPS_100M: 100 Mbit/s
  • BPS_200M: 200 Mbit/s
  • BPS_300M: 300 Mbit/s
  • BPS_400M: 400 Mbit/s
  • BPS_500M: 500 Mbit/s
  • BPS_1G: 1 Gbit/s
  • BPS_2G: 2 Gbit/s
  • BPS_5G: 5 Gbit/s
  • BPS_10G: 10 Gbit/s
  • BPS_20G: 20 Gbit/s
  • BPS_50G: 50 Gbit/s
  • BPS_100G: 100 Gbit/s
  • BPS_400G: 400 Gbit/s Corresponds to the JSON property bandwidth

Returns:

  • (String)


30945
30946
30947
# File 'lib/google/apis/compute_beta/classes.rb', line 30945

def bandwidth
  @bandwidth
end

#candidate_cloud_router_ip_addressString

Single IPv4 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ip_address and candidate_customer_router_ip_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ip_address and candidate_customer_router_ip_address must be the same.
  • Max prefix length is 31. Corresponds to the JSON property candidateCloudRouterIpAddress

Returns:

  • (String)


30958
30959
30960
# File 'lib/google/apis/compute_beta/classes.rb', line 30958

def candidate_cloud_router_ip_address
  @candidate_cloud_router_ip_address
end

#candidate_cloud_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the cloud router interface for this interconnect attachment.

  • Both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address fields must be set or both must be unset.
  • Prefix length of both candidate_cloud_router_ipv6_address and candidate_customer_router_ipv6_address must be the same.
  • Max prefix length is 126. Corresponds to the JSON property candidateCloudRouterIpv6Address

Returns:

  • (String)


30971
30972
30973
# File 'lib/google/apis/compute_beta/classes.rb', line 30971

def candidate_cloud_router_ipv6_address
  @candidate_cloud_router_ipv6_address
end

#candidate_customer_router_ip_addressString

Single IPv4 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpAddress

Returns:

  • (String)


30977
30978
30979
# File 'lib/google/apis/compute_beta/classes.rb', line 30977

def candidate_customer_router_ip_address
  @candidate_customer_router_ip_address
end

#candidate_customer_router_ipv6_addressString

Single IPv6 address + prefix length to be configured on the customer router interface for this interconnect attachment. Corresponds to the JSON property candidateCustomerRouterIpv6Address

Returns:

  • (String)


30983
30984
30985
# File 'lib/google/apis/compute_beta/classes.rb', line 30983

def candidate_customer_router_ipv6_address
  @candidate_customer_router_ipv6_address
end

#candidate_ipv6_subnetsArray<String>

This field is not available. Corresponds to the JSON property candidateIpv6Subnets

Returns:

  • (Array<String>)


30988
30989
30990
# File 'lib/google/apis/compute_beta/classes.rb', line 30988

def candidate_ipv6_subnets
  @candidate_ipv6_subnets
end

#candidate_subnetsArray<String>

Input only. Up to 16 candidate prefixes that can be used to restrict the allocation of cloudRouterIpAddress and customerRouterIpAddress for this attachment. All prefixes must be within link-local address space (169.254.0.0/16) and must be /29 or shorter (/28, /27, etc). Google will attempt to select an unused /29 from the supplied candidate prefix(es). The request will fail if all possible /29s are in use on Google's edge. If not supplied, Google will randomly select an unused /29 from all of link-local space. Corresponds to the JSON property candidateSubnets

Returns:

  • (Array<String>)


31000
31001
31002
# File 'lib/google/apis/compute_beta/classes.rb', line 31000

def candidate_subnets
  @candidate_subnets
end

#cloud_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpAddress

Returns:

  • (String)


31007
31008
31009
# File 'lib/google/apis/compute_beta/classes.rb', line 31007

def cloud_router_ip_address
  @cloud_router_ip_address
end

#cloud_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on Cloud Router Interface for this interconnect attachment. Corresponds to the JSON property cloudRouterIpv6Address

Returns:

  • (String)


31014
31015
31016
# File 'lib/google/apis/compute_beta/classes.rb', line 31014

def cloud_router_ipv6_address
  @cloud_router_ipv6_address
end

#cloud_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property cloudRouterIpv6InterfaceId

Returns:

  • (String)


31019
31020
31021
# File 'lib/google/apis/compute_beta/classes.rb', line 31019

def cloud_router_ipv6_interface_id
  @cloud_router_ipv6_interface_id
end

#configuration_constraintsGoogle::Apis::ComputeBeta::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Constraints for this attachment, if any. The attachment does not work if these constraints are not met. Corresponds to the JSON property configurationConstraints



31026
31027
31028
# File 'lib/google/apis/compute_beta/classes.rb', line 31026

def configuration_constraints
  @configuration_constraints
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


31032
31033
31034
# File 'lib/google/apis/compute_beta/classes.rb', line 31032

def creation_timestamp
  @creation_timestamp
end

#customer_router_ip_addressString

Output only. [Output Only] IPv4 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpAddress

Returns:

  • (String)


31039
31040
31041
# File 'lib/google/apis/compute_beta/classes.rb', line 31039

def customer_router_ip_address
  @customer_router_ip_address
end

#customer_router_ipv6_addressString

Output only. [Output Only] IPv6 address + prefix length to be configured on the customer router subinterface for this interconnect attachment. Corresponds to the JSON property customerRouterIpv6Address

Returns:

  • (String)


31046
31047
31048
# File 'lib/google/apis/compute_beta/classes.rb', line 31046

def customer_router_ipv6_address
  @customer_router_ipv6_address
end

#customer_router_ipv6_interface_idString

This field is not available. Corresponds to the JSON property customerRouterIpv6InterfaceId

Returns:

  • (String)


31051
31052
31053
# File 'lib/google/apis/compute_beta/classes.rb', line 31051

def customer_router_ipv6_interface_id
  @customer_router_ipv6_interface_id
end

#dataplane_versionFixnum

Output only. [Output Only] Dataplane version for this InterconnectAttachment. This field is only present for Dataplane version 2 and higher. Absence of this field in the API output indicates that the Dataplane is version 1. Corresponds to the JSON property dataplaneVersion

Returns:

  • (Fixnum)


31059
31060
31061
# File 'lib/google/apis/compute_beta/classes.rb', line 31059

def dataplane_version
  @dataplane_version
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


31064
31065
31066
# File 'lib/google/apis/compute_beta/classes.rb', line 31064

def description
  @description
end

#edge_availability_domainString

Input only. Desired availability domain for the attachment. Only available for type PARTNER, at creation time, and can take one of the following values:

  • AVAILABILITY_DOMAIN_ANY
  • AVAILABILITY_DOMAIN_1
  • AVAILABILITY_DOMAIN_2 For improved reliability, customers should configure a pair of attachments, one per availability domain. The selected availability domain will be provided to the Partner via the pairing key, so that the provisioned circuit will lie in the specified domain. If not specified, the value will default to AVAILABILITY_DOMAIN_ANY. Corresponds to the JSON property edgeAvailabilityDomain

Returns:

  • (String)


31080
31081
31082
# File 'lib/google/apis/compute_beta/classes.rb', line 31080

def edge_availability_domain
  @edge_availability_domain
end

#encryptionString

Indicates the user-supplied encryption option of this VLAN attachment (interconnectAttachment). Can only be specified at attachment creation for PARTNER or DEDICATED attachments. Possible values are:

  • NONE - This is the default value, which means that the VLAN attachment carries unencrypted traffic. VMs are able to send traffic to, or receive traffic from, such a VLAN attachment.
  • IPSEC - The VLAN attachment carries only encrypted traffic that is encrypted by an IPsec device, such as an HA VPN gateway or third-party IPsec VPN. VMs cannot directly send traffic to, or receive traffic from, such a VLAN attachment. To use HA VPN over Cloud Interconnect, the VLAN attachment must be created with this option. Corresponds to the JSON property encryption

Returns:

  • (String)


31098
31099
31100
# File 'lib/google/apis/compute_beta/classes.rb', line 31098

def encryption
  @encryption
end

#google_reference_idString

Output only. [Output Only] Google reference ID, to be used when raising support tickets with Google or otherwise to debug backend connectivity issues. [Deprecated] This field is not used. Corresponds to the JSON property googleReferenceId

Returns:

  • (String)


31106
31107
31108
# File 'lib/google/apis/compute_beta/classes.rb', line 31106

def google_reference_id
  @google_reference_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


31113
31114
31115
# File 'lib/google/apis/compute_beta/classes.rb', line 31113

def id
  @id
end

#interconnectString

URL of the underlying Interconnect object that this attachment's traffic will traverse through. Corresponds to the JSON property interconnect

Returns:

  • (String)


31119
31120
31121
# File 'lib/google/apis/compute_beta/classes.rb', line 31119

def interconnect
  @interconnect
end

#ipsec_internal_addressesArray<String>

A list of URLs of addresses that have been reserved for the VLAN attachment. Used only for the VLAN attachment that has the encryption option as IPSEC. The addresses must be regional internal IP address ranges. When creating an HA VPN gateway over the VLAN attachment, if the attachment is configured to use a regional internal IP address, then the VPN gateway's IP address is allocated from the IP address range specified here. For example, if the HA VPN gateway's interface 0 is paired to this VLAN attachment, then a regional internal IP address for the VPN gateway interface 0 will be allocated from the IP address specified for this VLAN attachment. If this field is not specified when creating the VLAN attachment, then later on when creating an HA VPN gateway on this VLAN attachment, the HA VPN gateway's IP address is allocated from the regional external IP address pool. Corresponds to the JSON property ipsecInternalAddresses

Returns:

  • (Array<String>)


31137
31138
31139
# File 'lib/google/apis/compute_beta/classes.rb', line 31137

def ipsec_internal_addresses
  @ipsec_internal_addresses
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectAttachment for interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


31143
31144
31145
# File 'lib/google/apis/compute_beta/classes.rb', line 31143

def kind
  @kind
end

#l2_forwardingGoogle::Apis::ComputeBeta::InterconnectAttachmentL2Forwarding

L2 Interconnect Attachment related configuration. Corresponds to the JSON property l2Forwarding



31148
31149
31150
# File 'lib/google/apis/compute_beta/classes.rb', line 31148

def l2_forwarding
  @l2_forwarding
end

#label_fingerprintString

A fingerprint for the labels being applied to this InterconnectAttachment, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve an InterconnectAttachment. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


31161
31162
31163
# File 'lib/google/apis/compute_beta/classes.rb', line 31161

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


31168
31169
31170
# File 'lib/google/apis/compute_beta/classes.rb', line 31168

def labels
  @labels
end

#mtuFixnum

Maximum Transmission Unit (MTU), in bytes, of packets passing through this interconnect attachment. Valid values are 1440, 1460, 1500, and 8896. If not specified, the value will default to 1440. Corresponds to the JSON property mtu

Returns:

  • (Fixnum)


31176
31177
31178
# File 'lib/google/apis/compute_beta/classes.rb', line 31176

def mtu
  @mtu
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


31187
31188
31189
# File 'lib/google/apis/compute_beta/classes.rb', line 31187

def name
  @name
end

#operational_statusString

Output only. [Output Only] The current status of whether or not this interconnect attachment is functional, which can take one of the following values:

  • OS_ACTIVE: The attachment has been turned up and is ready to use.
  • OS_UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


31199
31200
31201
# File 'lib/google/apis/compute_beta/classes.rb', line 31199

def operational_status
  @operational_status
end

#pairing_keyString

[Output only for type PARTNER. Input only for PARTNER_PROVIDER. Not present for DEDICATED]. The opaque identifier of a PARTNER attachment used to initiate provisioning with a selected partner. Of the form "XXXXX/region/domain" Corresponds to the JSON property pairingKey

Returns:

  • (String)


31208
31209
31210
# File 'lib/google/apis/compute_beta/classes.rb', line 31208

def pairing_key
  @pairing_key
end

#paramsGoogle::Apis::ComputeBeta::InterconnectAttachmentParams

Additional interconnect attachment parameters. Corresponds to the JSON property params



31213
31214
31215
# File 'lib/google/apis/compute_beta/classes.rb', line 31213

def params
  @params
end

#partner_asnFixnum

Optional BGP ASN for the router supplied by a Layer 3 Partner if they configured BGP on behalf of the customer. Output only for PARTNER type, input only for PARTNER_PROVIDER, not available for DEDICATED. Corresponds to the JSON property partnerAsn

Returns:

  • (Fixnum)


31221
31222
31223
# File 'lib/google/apis/compute_beta/classes.rb', line 31221

def partner_asn
  @partner_asn
end

#partner_metadataGoogle::Apis::ComputeBeta::InterconnectAttachmentPartnerMetadata

Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments. Corresponds to the JSON property partnerMetadata



31228
31229
31230
# File 'lib/google/apis/compute_beta/classes.rb', line 31228

def 
  @partner_metadata
end

#private_interconnect_infoGoogle::Apis::ComputeBeta::InterconnectAttachmentPrivateInfo

Information for an interconnect attachment when this belongs to an interconnect of type DEDICATED. Corresponds to the JSON property privateInterconnectInfo



31234
31235
31236
# File 'lib/google/apis/compute_beta/classes.rb', line 31234

def private_interconnect_info
  @private_interconnect_info
end

#regionString

Output only. [Output Only] URL of the region where the regional interconnect attachment resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


31243
31244
31245
# File 'lib/google/apis/compute_beta/classes.rb', line 31243

def region
  @region
end

#remote_serviceString

Output only. [Output Only] If the attachment is on a Cross-Cloud Interconnect connection, this field contains the interconnect's remote location service provider. Example values: "Amazon Web Services" "Microsoft Azure". The field is set only for attachments on Cross-Cloud Interconnect connections. Its value is copied from the InterconnectRemoteLocation remoteService field. Corresponds to the JSON property remoteService

Returns:

  • (String)


31254
31255
31256
# File 'lib/google/apis/compute_beta/classes.rb', line 31254

def remote_service
  @remote_service
end

#routerString

URL of the Cloud Router to be used for dynamic routing. This router must be in the same region as this InterconnectAttachment. The InterconnectAttachment will automatically connect the Interconnect to the network & region within which the Cloud Router is configured. Corresponds to the JSON property router

Returns:

  • (String)


31262
31263
31264
# File 'lib/google/apis/compute_beta/classes.rb', line 31262

def router
  @router
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


31267
31268
31269
# File 'lib/google/apis/compute_beta/classes.rb', line 31267

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31273
31274
31275
# File 'lib/google/apis/compute_beta/classes.rb', line 31273

def self_link
  @self_link
end

#stack_typeString

The stack type for this interconnect attachment to identify whether the IPv6 feature is enabled or not. If not specified, IPV4_ONLY will be used. This field can be both set at interconnect attachments creation and update interconnect attachment operations. Corresponds to the JSON property stackType

Returns:

  • (String)


31282
31283
31284
# File 'lib/google/apis/compute_beta/classes.rb', line 31282

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] The current state of this attachment's functionality. Enum values ACTIVE and UNPROVISIONED are shared by DEDICATED/PRIVATE, PARTNER, and PARTNER_PROVIDER interconnect attachments, while enum values PENDING_PARTNER, PARTNER_REQUEST_RECEIVED, and PENDING_CUSTOMER are used for only PARTNER and PARTNER_PROVIDER interconnect attachments. This state can take one of the following values:

  • ACTIVE: The attachment has been turned up and is ready to use.
  • UNPROVISIONED: The attachment is not ready to use yet, because turnup is not complete.
  • PENDING_PARTNER: A newly-created PARTNER attachment that has not yet been configured on the Partner side.
  • PARTNER_REQUEST_RECEIVED: A PARTNER attachment is in the process of provisioning after a PARTNER_PROVIDER attachment was created that references it.
  • PENDING_CUSTOMER: A PARTNER or PARTNER_PROVIDER attachment that is waiting for a customer to activate it.
  • DEFUNCT: The attachment was deleted externally and is no longer functional. This could be because the associated Interconnect was removed, or because the other side of a Partner attachment was deleted. Corresponds to the JSON property state

Returns:

  • (String)


31308
31309
31310
# File 'lib/google/apis/compute_beta/classes.rb', line 31308

def state
  @state
end

#subnet_lengthFixnum

Input only. Length of the IPv4 subnet mask. Allowed values:

  • 29 (default)
  • 30 The default value is 29, except for Cross-Cloud Interconnect connections that use an InterconnectRemoteLocation with a constraints.subnetLengthRange.min equal to 30. For example, connections that use an Azure remote location fall into this category. In these cases, the default value is 30, and requesting 29 returns an error. Where both 29 and 30 are allowed, 29 is preferred, because it gives Google Cloud Support more debugging visibility. Corresponds to the JSON property subnetLength

Returns:

  • (Fixnum)


31326
31327
31328
# File 'lib/google/apis/compute_beta/classes.rb', line 31326

def subnet_length
  @subnet_length
end

#typeString

The type of interconnect attachment this is, which can take one of the following values:

  • DEDICATED: an attachment to a Dedicated Interconnect.
  • PARTNER: an attachment to a Partner Interconnect, created by the customer.
  • PARTNER_PROVIDER: an attachment to a Partner Interconnect, created by the partner.
  • L2_DEDICATED: a L2 attachment to a Dedicated Interconnect. Corresponds to the JSON property type

Returns:

  • (String)


31339
31340
31341
# File 'lib/google/apis/compute_beta/classes.rb', line 31339

def type
  @type
end

#vlan_tag8021qFixnum

The IEEE 802.1Q VLAN tag for this attachment, in the range 2-4093. Only specified at creation time. Corresponds to the JSON property vlanTag8021q

Returns:

  • (Fixnum)


31345
31346
31347
# File 'lib/google/apis/compute_beta/classes.rb', line 31345

def vlan_tag8021q
  @vlan_tag8021q
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31352
31353
31354
31355
31356
31357
31358
31359
31360
31361
31362
31363
31364
31365
31366
31367
31368
31369
31370
31371
31372
31373
31374
31375
31376
31377
31378
31379
31380
31381
31382
31383
31384
31385
31386
31387
31388
31389
31390
31391
31392
31393
31394
31395
31396
31397
31398
31399
31400
# File 'lib/google/apis/compute_beta/classes.rb', line 31352

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @attachment_group = args[:attachment_group] if args.key?(:attachment_group)
  @bandwidth = args[:bandwidth] if args.key?(:bandwidth)
  @candidate_cloud_router_ip_address = args[:candidate_cloud_router_ip_address] if args.key?(:candidate_cloud_router_ip_address)
  @candidate_cloud_router_ipv6_address = args[:candidate_cloud_router_ipv6_address] if args.key?(:candidate_cloud_router_ipv6_address)
  @candidate_customer_router_ip_address = args[:candidate_customer_router_ip_address] if args.key?(:candidate_customer_router_ip_address)
  @candidate_customer_router_ipv6_address = args[:candidate_customer_router_ipv6_address] if args.key?(:candidate_customer_router_ipv6_address)
  @candidate_ipv6_subnets = args[:candidate_ipv6_subnets] if args.key?(:candidate_ipv6_subnets)
  @candidate_subnets = args[:candidate_subnets] if args.key?(:candidate_subnets)
  @cloud_router_ip_address = args[:cloud_router_ip_address] if args.key?(:cloud_router_ip_address)
  @cloud_router_ipv6_address = args[:cloud_router_ipv6_address] if args.key?(:cloud_router_ipv6_address)
  @cloud_router_ipv6_interface_id = args[:cloud_router_ipv6_interface_id] if args.key?(:cloud_router_ipv6_interface_id)
  @configuration_constraints = args[:configuration_constraints] if args.key?(:configuration_constraints)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @customer_router_ip_address = args[:customer_router_ip_address] if args.key?(:customer_router_ip_address)
  @customer_router_ipv6_address = args[:customer_router_ipv6_address] if args.key?(:customer_router_ipv6_address)
  @customer_router_ipv6_interface_id = args[:customer_router_ipv6_interface_id] if args.key?(:customer_router_ipv6_interface_id)
  @dataplane_version = args[:dataplane_version] if args.key?(:dataplane_version)
  @description = args[:description] if args.key?(:description)
  @edge_availability_domain = args[:edge_availability_domain] if args.key?(:edge_availability_domain)
  @encryption = args[:encryption] if args.key?(:encryption)
  @google_reference_id = args[:google_reference_id] if args.key?(:google_reference_id)
  @id = args[:id] if args.key?(:id)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @ipsec_internal_addresses = args[:ipsec_internal_addresses] if args.key?(:ipsec_internal_addresses)
  @kind = args[:kind] if args.key?(:kind)
  @l2_forwarding = args[:l2_forwarding] if args.key?(:l2_forwarding)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @mtu = args[:mtu] if args.key?(:mtu)
  @name = args[:name] if args.key?(:name)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @pairing_key = args[:pairing_key] if args.key?(:pairing_key)
  @params = args[:params] if args.key?(:params)
  @partner_asn = args[:partner_asn] if args.key?(:partner_asn)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
  @private_interconnect_info = args[:private_interconnect_info] if args.key?(:private_interconnect_info)
  @region = args[:region] if args.key?(:region)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @router = args[:router] if args.key?(:router)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @subnet_length = args[:subnet_length] if args.key?(:subnet_length)
  @type = args[:type] if args.key?(:type)
  @vlan_tag8021q = args[:vlan_tag8021q] if args.key?(:vlan_tag8021q)
end