Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An interconnect attachment group resource allows customers to create, analyze, and expand highly available deployments.
Instance Attribute Summary collapse
-
#attachments ⇒ Hash<String,Google::Apis::ComputeBeta::InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup.
-
#configured ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ Fixnum
Output only.
-
#intent ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#interconnect_group ⇒ String
The URL of an InterconnectGroup that groups these Attachments' Interconnects.
-
#kind ⇒ String
Output only.
-
#logical_structure ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructure
[Output Only] An analysis of the logical layout of Attachments in this group.
-
#name ⇒ String
Name of the resource.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroup
constructor
A new instance of InterconnectAttachmentGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroup
Returns a new instance of InterconnectAttachmentGroup.
31729 31730 31731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31729 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Hash<String,Google::Apis::ComputeBeta::InterconnectAttachmentGroupAttachment>
Attachments in the AttachmentGroup. Keys are arbitrary user-specified
strings. Users are encouraged, but not required, to use their preferred
format for resource links as keys.
Note that there are add-members and remove-members methods in gcloud.
The size of this map is limited by an "Attachments per group" quota.
Corresponds to the JSON property attachments
31651 31652 31653 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31651 def @attachments end |
#configured ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
31658 31659 31660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31658 def configured @configured end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
31664 31665 31666 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31664 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
31670 31671 31672 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31670 def description @description end |
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
If provided when patching a configuration in update mode, the provided
token must match the current token or the update is rejected. This provides
a reliable means of doing read-modify-write (optimistic locking) as
described byAIP 154.
Corresponds to the JSON property etag
31679 31680 31681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31679 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
31686 31687 31688 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31686 def id @id end |
#intent ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
31692 31693 31694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31692 def intent @intent end |
#interconnect_group ⇒ String
The URL of an InterconnectGroup that groups these Attachments'
Interconnects. Customers do not need to set this unless directed by
Google Support.
Corresponds to the JSON property interconnectGroup
31699 31700 31701 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31699 def interconnect_group @interconnect_group end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always
compute#interconnectAttachmentGroup.
Corresponds to the JSON property kind
31705 31706 31707 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31705 def kind @kind end |
#logical_structure ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructure
[Output Only] An analysis of the logical layout of Attachments in this
group. Every Attachment in the group is shown once in this structure.
Corresponds to the JSON property logicalStructure
31711 31712 31713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31711 def logical_structure @logical_structure end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
31722 31723 31724 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31722 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
31727 31728 31729 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31727 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31734 31735 31736 31737 31738 31739 31740 31741 31742 31743 31744 31745 31746 31747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31734 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @configured = args[:configured] if args.key?(:configured) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @intent = args[:intent] if args.key?(:intent) @interconnect_group = args[:interconnect_group] if args.key?(:interconnect_group) @kind = args[:kind] if args.key?(:kind) @logical_structure = args[:logical_structure] if args.key?(:logical_structure) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) end |