Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySla

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.



30650
30651
30652
# File 'lib/google/apis/compute_beta/classes.rb', line 30650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_slaString

Corresponds to the JSON property effectiveSla

Returns:

  • (String)


30643
30644
30645
# File 'lib/google/apis/compute_beta/classes.rb', line 30643

def effective_sla
  @effective_sla
end

#intended_sla_blockersArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>

Corresponds to the JSON property intendedSlaBlockers



30648
30649
30650
# File 'lib/google/apis/compute_beta/classes.rb', line 30648

def intended_sla_blockers
  @intended_sla_blockers
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30655
30656
30657
30658
# File 'lib/google/apis/compute_beta/classes.rb', line 30655

def update!(**args)
  @effective_sla = args[:effective_sla] if args.key?(:effective_sla)
  @intended_sla_blockers = args[:intended_sla_blockers] if args.key?(:intended_sla_blockers)
end