Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySla
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySla
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] Which SLA this group is configured to support, and why this group does or does not meet that SLA's requirements.
Instance Attribute Summary collapse
-
#effective_sla ⇒ String
Corresponds to the JSON property
effectiveSla. -
#intended_sla_blockers ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>
Corresponds to the JSON property
intendedSlaBlockers.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla
constructor
A new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySla
Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySla.
29840 29841 29842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29840 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_sla ⇒ String
Corresponds to the JSON property effectiveSla
29833 29834 29835 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29833 def effective_sla @effective_sla end |
#intended_sla_blockers ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers>
Corresponds to the JSON property intendedSlaBlockers
29838 29839 29840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29838 def intended_sla_blockers @intended_sla_blockers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29845 29846 29847 29848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29845 def update!(**args) @effective_sla = args[:effective_sla] if args.key?(:effective_sla) @intended_sla_blockers = args[:intended_sla_blockers] if args.key?(:intended_sla_blockers) end |