Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Reasons why configuration.availabilitySLA.sla differs from intent.availabilitySLA. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers

Returns a new instance of InterconnectAttachmentGroupConfiguredAvailabilitySlaIntendedSlaBlockers.



29905
29906
29907
# File 'lib/google/apis/compute_beta/classes.rb', line 29905

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of any particular Attachments to explain this blocker in more detail. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


29861
29862
29863
# File 'lib/google/apis/compute_beta/classes.rb', line 29861

def attachments
  @attachments
end

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


29866
29867
29868
# File 'lib/google/apis/compute_beta/classes.rb', line 29866

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


29873
29874
29875
# File 'lib/google/apis/compute_beta/classes.rb', line 29873

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


29880
29881
29882
# File 'lib/google/apis/compute_beta/classes.rb', line 29880

def explanation
  @explanation
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". This will be set for some blockers (like NO_ATTACHMENTS_IN_METRO_AND_ZONE) but does not apply to others. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


29888
29889
29890
# File 'lib/google/apis/compute_beta/classes.rb', line 29888

def metros
  @metros
end

#regionsArray<String>

Output only. [Output Only] Regions used to explain this blocker in more detail. These are region names formatted like "us-central1". This will be set for some blockers (like INCOMPATIBLE_REGIONS) but does not apply to others. Corresponds to the JSON property regions

Returns:

  • (Array<String>)


29896
29897
29898
# File 'lib/google/apis/compute_beta/classes.rb', line 29896

def regions
  @regions
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Format is "zone1" and/or "zone2". This will be set for some blockers (like MISSING_ZONE) but does not apply to others. Corresponds to the JSON property zones

Returns:

  • (Array<String>)


29903
29904
29905
# File 'lib/google/apis/compute_beta/classes.rb', line 29903

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29910
29911
29912
29913
29914
29915
29916
29917
29918
# File 'lib/google/apis/compute_beta/classes.rb', line 29910

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @metros = args[:metros] if args.key?(:metros)
  @regions = args[:regions] if args.key?(:regions)
  @zones = args[:zones] if args.key?(:zones)
end