Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



31917
31918
31919
# File 'lib/google/apis/compute_beta/classes.rb', line 31917

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



31915
31916
31917
# File 'lib/google/apis/compute_beta/classes.rb', line 31915

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31922
31923
31924
# File 'lib/google/apis/compute_beta/classes.rb', line 31922

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end