Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure

Returns a new instance of InterconnectAttachmentGroupLogicalStructure.



31855
31856
31857
# File 'lib/google/apis/compute_beta/classes.rb', line 31855

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#regionsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegion>

Corresponds to the JSON property regions



31853
31854
31855
# File 'lib/google/apis/compute_beta/classes.rb', line 31853

def regions
  @regions
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31860
31861
31862
# File 'lib/google/apis/compute_beta/classes.rb', line 31860

def update!(**args)
  @regions = args[:regions] if args.key?(:regions)
end