Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] An analysis of the logical layout of Attachments in this group. Every Attachment in the group is shown once in this structure.
Instance Attribute Summary collapse
-
#regions ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegion>
Corresponds to the JSON property
regions.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure
constructor
A new instance of InterconnectAttachmentGroupLogicalStructure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructure
Returns a new instance of InterconnectAttachmentGroupLogicalStructure.
28978 28979 28980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#regions ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegion>
Corresponds to the JSON property regions
28976 28977 28978 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28976 def regions @regions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
28983 28984 28985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 28983 def update!(**args) @regions = args[:regions] if args.key?(:regions) end |