Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetro

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The metros of Attachments in this group in this region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.



31906
31907
31908
# File 'lib/google/apis/compute_beta/classes.rb', line 31906

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilitiesArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>

Corresponds to the JSON property facilities



31897
31898
31899
# File 'lib/google/apis/compute_beta/classes.rb', line 31897

def facilities
  @facilities
end

#metroString

Output only. [Output Only] The name of the metro, as a three-letter lowercase string like "iad". This is the first component of the location of an Interconnect. Corresponds to the JSON property metro

Returns:

  • (String)


31904
31905
31906
# File 'lib/google/apis/compute_beta/classes.rb', line 31904

def metro
  @metro
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31911
31912
31913
31914
# File 'lib/google/apis/compute_beta/classes.rb', line 31911

def update!(**args)
  @facilities = args[:facilities] if args.key?(:facilities)
  @metro = args[:metro] if args.key?(:metro)
end