Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetro
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The metros of Attachments in this group in this region.
Instance Attribute Summary collapse
-
#facilities ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property
facilities. -
#metro ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetro
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetro.
31393 31394 31395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facilities ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacility>
Corresponds to the JSON property facilities
31384 31385 31386 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31384 def facilities @facilities end |
#metro ⇒ String
Output only. [Output Only] The name of the metro, as a three-letter lowercase
string like "iad". This is the first component of the location of an
Interconnect.
Corresponds to the JSON property metro
31391 31392 31393 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31391 def metro @metro end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31398 31399 31400 31401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31398 def update!(**args) @facilities = args[:facilities] if args.key?(:facilities) @metro = args[:metro] if args.key?(:metro) end |