Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
32298 32299 32300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32298 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of Attachments in the given zone, to the given
region, on Interconnects in the given facility and metro. Every
Attachment in the AG has such an entry.
Corresponds to the JSON property attachments
32291 32292 32293 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32291 def @attachments end |
#zone ⇒ String
Output only. [Output Only] The name of a zone, either "zone1" or "zone2".
Corresponds to the JSON property zone
32296 32297 32298 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32296 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32303 32304 32305 32306 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32303 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @zone = args[:zone] if args.key?(:zone) end |