Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone

Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.



31961
31962
31963
# File 'lib/google/apis/compute_beta/classes.rb', line 31961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachmentsArray<String>

Output only. [Output Only] URLs of Attachments in the given zone, to the given region, on Interconnects in the given facility and metro. Every Attachment in the AG has such an entry. Corresponds to the JSON property attachments

Returns:

  • (Array<String>)


31954
31955
31956
# File 'lib/google/apis/compute_beta/classes.rb', line 31954

def attachments
  @attachments
end

#zoneString

Output only. [Output Only] The name of a zone, either "zone1" or "zone2". Corresponds to the JSON property zone

Returns:

  • (String)


31959
31960
31961
# File 'lib/google/apis/compute_beta/classes.rb', line 31959

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31966
31967
31968
31969
# File 'lib/google/apis/compute_beta/classes.rb', line 31966

def update!(**args)
  @attachments = args[:attachments] if args.key?(:attachments)
  @zone = args[:zone] if args.key?(:zone)
end