Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The zones that Attachments in this group are present in, in the given facilities. This is inherited from their Interconnects.
Instance Attribute Summary collapse
-
#attachments ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
constructor
A new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone
Returns a new instance of InterconnectAttachmentGroupLogicalStructureRegionMetroFacilityZone.
30867 30868 30869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachments ⇒ Array<String>
Output only. [Output Only] URLs of Attachments in the given zone, to the given
region, on Interconnects in the given facility and metro. Every
Attachment in the AG has such an entry.
Corresponds to the JSON property attachments
30860 30861 30862 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30860 def @attachments end |
#zone ⇒ String
Output only. [Output Only] The name of a zone, either "zone1" or "zone2".
Corresponds to the JSON property zone
30865 30866 30867 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30865 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30872 30873 30874 30875 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30872 def update!(**args) @attachments = args[:attachments] if args.key?(:attachments) @zone = args[:zone] if args.key?(:zone) end |