Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



32170
32171
32172
# File 'lib/google/apis/compute_beta/classes.rb', line 32170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


32126
32127
32128
# File 'lib/google/apis/compute_beta/classes.rb', line 32126

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32131
32132
32133
# File 'lib/google/apis/compute_beta/classes.rb', line 32131

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



32136
32137
32138
# File 'lib/google/apis/compute_beta/classes.rb', line 32136

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


32141
32142
32143
# File 'lib/google/apis/compute_beta/classes.rb', line 32141

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32151
32152
32153
# File 'lib/google/apis/compute_beta/classes.rb', line 32151

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32156
32157
32158
# File 'lib/google/apis/compute_beta/classes.rb', line 32156

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


32163
32164
32165
# File 'lib/google/apis/compute_beta/classes.rb', line 32163

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32168
32169
32170
# File 'lib/google/apis/compute_beta/classes.rb', line 32168

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32175
32176
32177
32178
32179
32180
32181
32182
32183
32184
# File 'lib/google/apis/compute_beta/classes.rb', line 32175

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end