Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



32070
32071
32072
# File 'lib/google/apis/compute_beta/classes.rb', line 32070

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


32026
32027
32028
# File 'lib/google/apis/compute_beta/classes.rb', line 32026

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32031
32032
32033
# File 'lib/google/apis/compute_beta/classes.rb', line 32031

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



32036
32037
32038
# File 'lib/google/apis/compute_beta/classes.rb', line 32036

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


32041
32042
32043
# File 'lib/google/apis/compute_beta/classes.rb', line 32041

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32051
32052
32053
# File 'lib/google/apis/compute_beta/classes.rb', line 32051

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32056
32057
32058
# File 'lib/google/apis/compute_beta/classes.rb', line 32056

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


32063
32064
32065
# File 'lib/google/apis/compute_beta/classes.rb', line 32063

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32068
32069
32070
# File 'lib/google/apis/compute_beta/classes.rb', line 32068

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32075
32076
32077
32078
32079
32080
32081
32082
32083
32084
# File 'lib/google/apis/compute_beta/classes.rb', line 32075

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end