Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



32048
32049
32050
# File 'lib/google/apis/compute_beta/classes.rb', line 32048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


32004
32005
32006
# File 'lib/google/apis/compute_beta/classes.rb', line 32004

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32009
32010
32011
# File 'lib/google/apis/compute_beta/classes.rb', line 32009

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



32014
32015
32016
# File 'lib/google/apis/compute_beta/classes.rb', line 32014

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


32019
32020
32021
# File 'lib/google/apis/compute_beta/classes.rb', line 32019

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32029
32030
32031
# File 'lib/google/apis/compute_beta/classes.rb', line 32029

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32034
32035
32036
# File 'lib/google/apis/compute_beta/classes.rb', line 32034

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


32041
32042
32043
# File 'lib/google/apis/compute_beta/classes.rb', line 32041

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32046
32047
32048
# File 'lib/google/apis/compute_beta/classes.rb', line 32046

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32053
32054
32055
32056
32057
32058
32059
32060
32061
32062
# File 'lib/google/apis/compute_beta/classes.rb', line 32053

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end