Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



31535
31536
31537
# File 'lib/google/apis/compute_beta/classes.rb', line 31535

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


31491
31492
31493
# File 'lib/google/apis/compute_beta/classes.rb', line 31491

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31496
31497
31498
# File 'lib/google/apis/compute_beta/classes.rb', line 31496

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



31501
31502
31503
# File 'lib/google/apis/compute_beta/classes.rb', line 31501

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


31506
31507
31508
# File 'lib/google/apis/compute_beta/classes.rb', line 31506

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31516
31517
31518
# File 'lib/google/apis/compute_beta/classes.rb', line 31516

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31521
31522
31523
# File 'lib/google/apis/compute_beta/classes.rb', line 31521

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


31528
31529
31530
# File 'lib/google/apis/compute_beta/classes.rb', line 31528

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31533
31534
31535
# File 'lib/google/apis/compute_beta/classes.rb', line 31533

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31540
31541
31542
31543
31544
31545
31546
31547
31548
31549
# File 'lib/google/apis/compute_beta/classes.rb', line 31540

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end