Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



30954
30955
30956
# File 'lib/google/apis/compute_beta/classes.rb', line 30954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


30910
30911
30912
# File 'lib/google/apis/compute_beta/classes.rb', line 30910

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30915
30916
30917
# File 'lib/google/apis/compute_beta/classes.rb', line 30915

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



30920
30921
30922
# File 'lib/google/apis/compute_beta/classes.rb', line 30920

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


30925
30926
30927
# File 'lib/google/apis/compute_beta/classes.rb', line 30925

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30935
30936
30937
# File 'lib/google/apis/compute_beta/classes.rb', line 30935

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30940
30941
30942
# File 'lib/google/apis/compute_beta/classes.rb', line 30940

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


30947
30948
30949
# File 'lib/google/apis/compute_beta/classes.rb', line 30947

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30952
30953
30954
# File 'lib/google/apis/compute_beta/classes.rb', line 30952

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30959
30960
30961
30962
30963
30964
30965
30966
30967
30968
# File 'lib/google/apis/compute_beta/classes.rb', line 30959

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end