Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsListResponse

Returns a new instance of InterconnectAttachmentGroupsListResponse.



30144
30145
30146
# File 'lib/google/apis/compute_beta/classes.rb', line 30144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


30100
30101
30102
# File 'lib/google/apis/compute_beta/classes.rb', line 30100

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30105
30106
30107
# File 'lib/google/apis/compute_beta/classes.rb', line 30105

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroup>

A list of InterconnectAttachmentGroup resources. Corresponds to the JSON property items



30110
30111
30112
# File 'lib/google/apis/compute_beta/classes.rb', line 30110

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


30115
30116
30117
# File 'lib/google/apis/compute_beta/classes.rb', line 30115

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30125
30126
30127
# File 'lib/google/apis/compute_beta/classes.rb', line 30125

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30130
30131
30132
# File 'lib/google/apis/compute_beta/classes.rb', line 30130

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


30137
30138
30139
# File 'lib/google/apis/compute_beta/classes.rb', line 30137

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30142
30143
30144
# File 'lib/google/apis/compute_beta/classes.rb', line 30142

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30149
30150
30151
30152
30153
30154
30155
30156
30157
30158
# File 'lib/google/apis/compute_beta/classes.rb', line 30149

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end