Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#attachment_statuses ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property
attachmentStatuses. -
#configured ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
-
#group_status ⇒ String
Output only.
-
#intent ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup.
-
#operational ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.
32241 32242 32243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32241 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_statuses ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>
Corresponds to the JSON property attachmentStatuses
32214 32215 32216 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32214 def @attachment_statuses end |
#configured ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property configured
32221 32222 32223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32221 def configured @configured end |
#group_status ⇒ String
Output only. Summarizes the status of the group.
Corresponds to the JSON property groupStatus
32226 32227 32228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32226 def group_status @group_status end |
#intent ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupIntent
The user's intent for this AttachmentGroup. This is the only required field
besides the name that must be specified on group creation.
Corresponds to the JSON property intent
32232 32233 32234 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32232 def intent @intent end |
#operational ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured
[Output Only] The redundancy this group is configured to support. The way a
user queries what SLA their Attachment gets is by looking at this field of
the Attachment's AttachmentGroup.
Corresponds to the JSON property operational
32239 32240 32241 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32239 def operational @operational end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32246 32247 32248 32249 32250 32251 32252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32246 def update!(**args) @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses) @configured = args[:configured] if args.key?(:configured) @group_status = args[:group_status] if args.key?(:group_status) @intent = args[:intent] if args.key?(:intent) @operational = args[:operational] if args.key?(:operational) end |