Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



32231
32232
32233
# File 'lib/google/apis/compute_beta/classes.rb', line 32231

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



32204
32205
32206
# File 'lib/google/apis/compute_beta/classes.rb', line 32204

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



32211
32212
32213
# File 'lib/google/apis/compute_beta/classes.rb', line 32211

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


32216
32217
32218
# File 'lib/google/apis/compute_beta/classes.rb', line 32216

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



32222
32223
32224
# File 'lib/google/apis/compute_beta/classes.rb', line 32222

def intent
  @intent
end

#operationalGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



32229
32230
32231
# File 'lib/google/apis/compute_beta/classes.rb', line 32229

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32236
32237
32238
32239
32240
32241
32242
# File 'lib/google/apis/compute_beta/classes.rb', line 32236

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end