Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



31075
31076
31077
# File 'lib/google/apis/compute_beta/classes.rb', line 31075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



31048
31049
31050
# File 'lib/google/apis/compute_beta/classes.rb', line 31048

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



31055
31056
31057
# File 'lib/google/apis/compute_beta/classes.rb', line 31055

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


31060
31061
31062
# File 'lib/google/apis/compute_beta/classes.rb', line 31060

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



31066
31067
31068
# File 'lib/google/apis/compute_beta/classes.rb', line 31066

def intent
  @intent
end

#operationalGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



31073
31074
31075
# File 'lib/google/apis/compute_beta/classes.rb', line 31073

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31080
31081
31082
31083
31084
31085
31086
# File 'lib/google/apis/compute_beta/classes.rb', line 31080

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end