Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatus

Returns a new instance of InterconnectAttachmentGroupsOperationalStatus.



29292
29293
29294
# File 'lib/google/apis/compute_beta/classes.rb', line 29292

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_statusesArray<Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus>

Corresponds to the JSON property attachmentStatuses



29265
29266
29267
# File 'lib/google/apis/compute_beta/classes.rb', line 29265

def attachment_statuses
  @attachment_statuses
end

#configuredGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property configured



29272
29273
29274
# File 'lib/google/apis/compute_beta/classes.rb', line 29272

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


29277
29278
29279
# File 'lib/google/apis/compute_beta/classes.rb', line 29277

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupIntent

The user's intent for this AttachmentGroup. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



29283
29284
29285
# File 'lib/google/apis/compute_beta/classes.rb', line 29283

def intent
  @intent
end

#operationalGoogle::Apis::ComputeBeta::InterconnectAttachmentGroupConfigured

[Output Only] The redundancy this group is configured to support. The way a user queries what SLA their Attachment gets is by looking at this field of the Attachment's AttachmentGroup. Corresponds to the JSON property operational



29290
29291
29292
# File 'lib/google/apis/compute_beta/classes.rb', line 29290

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



29297
29298
29299
29300
29301
29302
29303
# File 'lib/google/apis/compute_beta/classes.rb', line 29297

def update!(**args)
  @attachment_statuses = args[:attachment_statuses] if args.key?(:attachment_statuses)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @operational = args[:operational] if args.key?(:operational)
end