Class: Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The status of one Attachment in the group. List order is arbitrary.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Output only.
-
#attachment ⇒ String
Output only.
-
#is_active ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
constructor
A new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentGroupsOperationalStatusAttachmentStatus
Returns a new instance of InterconnectAttachmentGroupsOperationalStatusAttachmentStatus.
29337 29338 29339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29337 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Output only. Whether this Attachment is enabled. This becomes false when the
customer
drains their Attachment.
Corresponds to the JSON property adminEnabled
29315 29316 29317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29315 def admin_enabled @admin_enabled end |
#attachment ⇒ String
Output only. The URL of the Attachment being described.
Corresponds to the JSON property attachment
29321 29322 29323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29321 def @attachment end |
#is_active ⇒ String
Output only. Whether this Attachment is participating in the redundant
configuration.
This will be ACTIVE if and only if the status below is CONNECTION_UP.
Any INACTIVE Attachments are excluded from the analysis that generates
operational.availabilitySLA.
Corresponds to the JSON property isActive
29330 29331 29332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29330 def is_active @is_active end |
#status ⇒ String
Output only. Whether this Attachment is active, and if so, whether BGP is up.
Corresponds to the JSON property status
29335 29336 29337 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29335 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29342 29343 29344 29345 29346 29347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29342 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @attachment = args[:attachment] if args.key?(:attachment) @is_active = args[:is_active] if args.key?(:is_active) @status = args[:status] if args.key?(:status) end |