Class: Google::Apis::ComputeBeta::InterconnectAttachmentL2Forwarding
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentL2Forwarding
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
L2 Interconnect Attachment related configuration.
Instance Attribute Summary collapse
-
#appliance_mappings ⇒ Hash<String,Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingApplianceMapping>
Optional.
-
#default_appliance_ip_address ⇒ String
Optional.
-
#geneve_header ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingGeneveHeader
GeneveHeader related configurations.
-
#network ⇒ String
Required.
-
#tunnel_endpoint_ip_address ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentL2Forwarding
constructor
A new instance of InterconnectAttachmentL2Forwarding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentL2Forwarding
Returns a new instance of InterconnectAttachmentL2Forwarding.
31756 31757 31758 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31756 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appliance_mappings ⇒ Hash<String,Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingApplianceMapping>
Optional. A map of VLAN tags to appliances and optional inner mapping
rules. If VLANs are not explicitly mapped to any appliance, the
defaultApplianceIpAddress is used.
Each VLAN tag can be a single number or a range of numbers in the range
of 1 to 4094, e.g., "1" or "4001-4094". Non-empty and non-overlapping
VLAN tag ranges are enforced, and violating operations will be rejected.
The VLAN tags in the Ethernet header must use an ethertype value of
0x88A8 or 0x8100.
Corresponds to the JSON property applianceMappings
31728 31729 31730 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31728 def appliance_mappings @appliance_mappings end |
#default_appliance_ip_address ⇒ String
Optional. A single IPv4 or IPv6 address used as the default destination
IP when there is no VLAN mapping result found.
Unset field (null-value) indicates the unmatched packet should be
dropped.
Corresponds to the JSON property defaultApplianceIpAddress
31736 31737 31738 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31736 def default_appliance_ip_address @default_appliance_ip_address end |
#geneve_header ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingGeneveHeader
GeneveHeader related configurations.
Corresponds to the JSON property geneveHeader
31741 31742 31743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31741 def geneve_header @geneve_header end |
#network ⇒ String
Required. Resource URL of the network to which this attachment belongs.
Corresponds to the JSON property network
31746 31747 31748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31746 def network @network end |
#tunnel_endpoint_ip_address ⇒ String
Required. A single IPv4 or IPv6 address. This address will be used as the
source IP address for packets sent to the appliances, and must be used as
the destination IP address for packets that should be sent out through
this attachment.
Corresponds to the JSON property tunnelEndpointIpAddress
31754 31755 31756 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31754 def tunnel_endpoint_ip_address @tunnel_endpoint_ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31761 31762 31763 31764 31765 31766 31767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31761 def update!(**args) @appliance_mappings = args[:appliance_mappings] if args.key?(:appliance_mappings) @default_appliance_ip_address = args[:default_appliance_ip_address] if args.key?(:default_appliance_ip_address) @geneve_header = args[:geneve_header] if args.key?(:geneve_header) @network = args[:network] if args.key?(:network) @tunnel_endpoint_ip_address = args[:tunnel_endpoint_ip_address] if args.key?(:tunnel_endpoint_ip_address) end |