Class: Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingApplianceMapping

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Two-level VLAN-to-Appliance mapping rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentL2ForwardingApplianceMapping

Returns a new instance of InterconnectAttachmentL2ForwardingApplianceMapping.



31216
31217
31218
# File 'lib/google/apis/compute_beta/classes.rb', line 31216

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_ip_addressString

Optional. A single IPv4 or IPv6 address used as the destination IP address for ingress packets that match on a VLAN tag, but do not match a more specific inner VLAN tag. Unset field (null-value) indicates both VLAN tags are required to be mapped. Otherwise, defaultApplianceIpAddress is used. Corresponds to the JSON property applianceIpAddress

Returns:

  • (String)


31200
31201
31202
# File 'lib/google/apis/compute_beta/classes.rb', line 31200

def appliance_ip_address
  @appliance_ip_address
end

#inner_vlan_to_appliance_mappingsArray<Google::Apis::ComputeBeta::InterconnectAttachmentL2ForwardingApplianceMappingInnerVlanToApplianceMapping>

Optional. Used to match against the inner VLAN when the packet contains two VLAN tags. A list of mapping rules from inner VLAN tags to IP addresses. If the inner VLAN is not explicitly mapped to an IP address range, the applianceIpAddress is used. Corresponds to the JSON property innerVlanToApplianceMappings



31209
31210
31211
# File 'lib/google/apis/compute_beta/classes.rb', line 31209

def inner_vlan_to_appliance_mappings
  @inner_vlan_to_appliance_mappings
end

#nameString

Optional. The name of this appliance mapping rule. Corresponds to the JSON property name

Returns:

  • (String)


31214
31215
31216
# File 'lib/google/apis/compute_beta/classes.rb', line 31214

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31221
31222
31223
31224
31225
# File 'lib/google/apis/compute_beta/classes.rb', line 31221

def update!(**args)
  @appliance_ip_address = args[:appliance_ip_address] if args.key?(:appliance_ip_address)
  @inner_vlan_to_appliance_mappings = args[:inner_vlan_to_appliance_mappings] if args.key?(:inner_vlan_to_appliance_mappings)
  @name = args[:name] if args.key?(:name)
end