Class: Google::Apis::ComputeBeta::InterconnectAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of interconnect attachments.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachment>
A list of InterconnectAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentList
constructor
A new instance of InterconnectAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentList
Returns a new instance of InterconnectAttachmentList.
32478 32479 32480 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
32444 32445 32446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32444 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachment>
A list of InterconnectAttachment resources.
Corresponds to the JSON property items
32449 32450 32451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32449 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectAttachmentList for lists of interconnect
attachments.
Corresponds to the JSON property kind
32456 32457 32458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32456 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
32466 32467 32468 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32466 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
32471 32472 32473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32471 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
32476 32477 32478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32476 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32483 32484 32485 32486 32487 32488 32489 32490 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32483 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |