Class: Google::Apis::ComputeBeta::InterconnectAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of interconnect attachments.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachment>
A list of InterconnectAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentList
constructor
A new instance of InterconnectAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentList
Returns a new instance of InterconnectAttachmentList.
31936 31937 31938 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31936 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
31902 31903 31904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31902 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectAttachment>
A list of InterconnectAttachment resources.
Corresponds to the JSON property items
31907 31908 31909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31907 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectAttachmentList for lists of interconnect
attachments.
Corresponds to the JSON property kind
31914 31915 31916 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31914 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
31924 31925 31926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31924 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
31929 31930 31931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31929 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
31934 31935 31936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31934 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31941 31942 31943 31944 31945 31946 31947 31948 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31941 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |