Class: Google::Apis::ComputeBeta::InterconnectAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect attachments.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentList

Returns a new instance of InterconnectAttachmentList.



31903
31904
31905
# File 'lib/google/apis/compute_beta/classes.rb', line 31903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31869
31870
31871
# File 'lib/google/apis/compute_beta/classes.rb', line 31869

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectAttachment>

A list of InterconnectAttachment resources. Corresponds to the JSON property items



31874
31875
31876
# File 'lib/google/apis/compute_beta/classes.rb', line 31874

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectAttachmentList for lists of interconnect attachments. Corresponds to the JSON property kind

Returns:

  • (String)


31881
31882
31883
# File 'lib/google/apis/compute_beta/classes.rb', line 31881

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31891
31892
31893
# File 'lib/google/apis/compute_beta/classes.rb', line 31891

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31896
31897
31898
# File 'lib/google/apis/compute_beta/classes.rb', line 31896

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31901
31902
31903
# File 'lib/google/apis/compute_beta/classes.rb', line 31901

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31908
31909
31910
31911
31912
31913
31914
31915
# File 'lib/google/apis/compute_beta/classes.rb', line 31908

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end