Class: Google::Apis::ComputeBeta::InterconnectAttachmentPartnerMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectAttachmentPartnerMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Informational metadata about Partner attachments from Partners to display to customers. These fields are propagated from PARTNER_PROVIDER attachments to their corresponding PARTNER attachments.
Instance Attribute Summary collapse
-
#interconnect_name ⇒ String
Plain text name of the Interconnect this attachment is connected to, as displayed in the Partner's portal.
-
#partner_name ⇒ String
Plain text name of the Partner providing this attachment.
-
#portal_url ⇒ String
URL of the Partner's portal for this Attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectAttachmentPartnerMetadata
constructor
A new instance of InterconnectAttachmentPartnerMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectAttachmentPartnerMetadata
Returns a new instance of InterconnectAttachmentPartnerMetadata.
32581 32582 32583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32581 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interconnect_name ⇒ String
Plain text name of the Interconnect this attachment is connected to, as
displayed in the Partner's portal. For instance "Chicago 1".
This value may be validated to match approved Partner values.
Corresponds to the JSON property interconnectName
32566 32567 32568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32566 def interconnect_name @interconnect_name end |
#partner_name ⇒ String
Plain text name of the Partner providing this attachment.
This value may be validated to match approved Partner values.
Corresponds to the JSON property partnerName
32572 32573 32574 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32572 def partner_name @partner_name end |
#portal_url ⇒ String
URL of the Partner's portal for this Attachment. Partners may customise
this to be a deep link to the specific resource on the Partner portal.
This value may be validated to match approved Partner values.
Corresponds to the JSON property portalUrl
32579 32580 32581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32579 def portal_url @portal_url end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32586 32587 32588 32589 32590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32586 def update!(**args) @interconnect_name = args[:interconnect_name] if args.key?(:interconnect_name) @partner_name = args[:partner_name] if args.key?(:partner_name) @portal_url = args[:portal_url] if args.key?(:portal_url) end |