Class: Google::Apis::ComputeBeta::InterconnectAttachmentsScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectAttachmentsScopedList

Returns a new instance of InterconnectAttachmentsScopedList.



32127
32128
32129
# File 'lib/google/apis/compute_beta/classes.rb', line 32127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#interconnect_attachmentsArray<Google::Apis::ComputeBeta::InterconnectAttachment>

A list of interconnect attachments contained in this scope. Corresponds to the JSON property interconnectAttachments



32119
32120
32121
# File 'lib/google/apis/compute_beta/classes.rb', line 32119

def interconnect_attachments
  @interconnect_attachments
end

#warningGoogle::Apis::ComputeBeta::InterconnectAttachmentsScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



32125
32126
32127
# File 'lib/google/apis/compute_beta/classes.rb', line 32125

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32132
32133
32134
32135
# File 'lib/google/apis/compute_beta/classes.rb', line 32132

def update!(**args)
  @interconnect_attachments = args[:interconnect_attachments] if args.key?(:interconnect_attachments)
  @warning = args[:warning] if args.key?(:warning)
end