Class: Google::Apis::ComputeBeta::InterconnectCircuitInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectCircuitInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.
Instance Attribute Summary collapse
-
#customer_demarc_id ⇒ String
Customer-side demarc ID for this circuit.
-
#google_circuit_id ⇒ String
Google-assigned unique ID for this circuit.
-
#google_demarc_id ⇒ String
Google-side demarc ID for this circuit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectCircuitInfo
constructor
A new instance of InterconnectCircuitInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectCircuitInfo
Returns a new instance of InterconnectCircuitInfo.
32732 32733 32734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32732 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_demarc_id ⇒ String
Customer-side demarc ID for this circuit.
Corresponds to the JSON property customerDemarcId
32719 32720 32721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32719 def customer_demarc_id @customer_demarc_id end |
#google_circuit_id ⇒ String
Google-assigned unique ID for this circuit. Assigned at circuit turn-up.
Corresponds to the JSON property googleCircuitId
32724 32725 32726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32724 def google_circuit_id @google_circuit_id end |
#google_demarc_id ⇒ String
Google-side demarc ID for this circuit. Assigned at circuit turn-up and
provided by Google to the customer in the LOA.
Corresponds to the JSON property googleDemarcId
32730 32731 32732 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32730 def google_demarc_id @google_demarc_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32737 32738 32739 32740 32741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32737 def update!(**args) @customer_demarc_id = args[:customer_demarc_id] if args.key?(:customer_demarc_id) @google_circuit_id = args[:google_circuit_id] if args.key?(:google_circuit_id) @google_demarc_id = args[:google_demarc_id] if args.key?(:google_demarc_id) end |