Class: Google::Apis::ComputeBeta::InterconnectCircuitInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Describes a single physical circuit between the Customer and Google. CircuitInfo objects are created by Google, so all fields are output only.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectCircuitInfo

Returns a new instance of InterconnectCircuitInfo.



30806
30807
30808
# File 'lib/google/apis/compute_beta/classes.rb', line 30806

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#customer_demarc_idString

Customer-side demarc ID for this circuit. Corresponds to the JSON property customerDemarcId

Returns:

  • (String)


30793
30794
30795
# File 'lib/google/apis/compute_beta/classes.rb', line 30793

def customer_demarc_id
  @customer_demarc_id
end

#google_circuit_idString

Google-assigned unique ID for this circuit. Assigned at circuit turn-up. Corresponds to the JSON property googleCircuitId

Returns:

  • (String)


30798
30799
30800
# File 'lib/google/apis/compute_beta/classes.rb', line 30798

def google_circuit_id
  @google_circuit_id
end

#google_demarc_idString

Google-side demarc ID for this circuit. Assigned at circuit turn-up and provided by Google to the customer in the LOA. Corresponds to the JSON property googleDemarcId

Returns:

  • (String)


30804
30805
30806
# File 'lib/google/apis/compute_beta/classes.rb', line 30804

def google_demarc_id
  @google_demarc_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30811
30812
30813
30814
30815
# File 'lib/google/apis/compute_beta/classes.rb', line 30811

def update!(**args)
  @customer_demarc_id = args[:customer_demarc_id] if args.key?(:customer_demarc_id)
  @google_circuit_id = args[:google_circuit_id] if args.key?(:google_circuit_id)
  @google_demarc_id = args[:google_demarc_id] if args.key?(:google_demarc_id)
end