Class: Google::Apis::ComputeBeta::InterconnectDiagnostics
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectDiagnostics
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection.
Instance Attribute Summary collapse
-
#arp_caches ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects, describing individual neighbors currently seen by the Google router in the ARP cache for the Interconnect.
-
#bundle_aggregation_type ⇒ String
The aggregation type of the bundle interface.
-
#bundle_operational_status ⇒ String
The operational status of the bundle interface.
-
#links ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus>
A list of InterconnectDiagnostics.LinkStatus objects, describing the status for each link on the Interconnect.
-
#mac_address ⇒ String
The MAC address of the Interconnect's bundle interface.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnostics
constructor
A new instance of InterconnectDiagnostics.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnostics
Returns a new instance of InterconnectDiagnostics.
32829 32830 32831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32829 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arp_caches ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects,
describing individual neighbors currently seen by the Google router in
the ARP cache for the Interconnect.
This will be empty when the Interconnect is not bundled.
Corresponds to the JSON property arpCaches
32806 32807 32808 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32806 def arp_caches @arp_caches end |
#bundle_aggregation_type ⇒ String
The aggregation type of the bundle interface.
Corresponds to the JSON property bundleAggregationType
32811 32812 32813 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32811 def bundle_aggregation_type @bundle_aggregation_type end |
#bundle_operational_status ⇒ String
The operational status of the bundle interface.
Corresponds to the JSON property bundleOperationalStatus
32816 32817 32818 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32816 def bundle_operational_status @bundle_operational_status end |
#links ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus>
A list of InterconnectDiagnostics.LinkStatus objects,
describing the status for each link on the Interconnect.
Corresponds to the JSON property links
32822 32823 32824 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32822 def links @links end |
#mac_address ⇒ String
The MAC address of the Interconnect's bundle interface.
Corresponds to the JSON property macAddress
32827 32828 32829 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32827 def mac_address @mac_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32834 32835 32836 32837 32838 32839 32840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32834 def update!(**args) @arp_caches = args[:arp_caches] if args.key?(:arp_caches) @bundle_aggregation_type = args[:bundle_aggregation_type] if args.key?(:bundle_aggregation_type) @bundle_operational_status = args[:bundle_operational_status] if args.key?(:bundle_operational_status) @links = args[:links] if args.key?(:links) @mac_address = args[:mac_address] if args.key?(:mac_address) end |