Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus

Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.



31725
31726
31727
# File 'lib/google/apis/compute_beta/classes.rb', line 31725

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#google_system_idString

System ID of the port on Google's side of the LACP exchange. Corresponds to the JSON property googleSystemId

Returns:

  • (String)


31709
31710
31711
# File 'lib/google/apis/compute_beta/classes.rb', line 31709

def google_system_id
  @google_system_id
end

#neighbor_system_idString

System ID of the port on the neighbor's side of the LACP exchange. Corresponds to the JSON property neighborSystemId

Returns:

  • (String)


31714
31715
31716
# File 'lib/google/apis/compute_beta/classes.rb', line 31714

def neighbor_system_id
  @neighbor_system_id
end

#stateString

The state of a LACP link, which can take one of the following values:

  • ACTIVE: The link is configured and active within the bundle.
  • DETACHED: The link is not configured within the bundle. This means that the rest of the object should be empty. Corresponds to the JSON property state

Returns:

  • (String)


31723
31724
31725
# File 'lib/google/apis/compute_beta/classes.rb', line 31723

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31730
31731
31732
31733
31734
# File 'lib/google/apis/compute_beta/classes.rb', line 31730

def update!(**args)
  @google_system_id = args[:google_system_id] if args.key?(:google_system_id)
  @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id)
  @state = args[:state] if args.key?(:state)
end