Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#google_system_id ⇒ String
System ID of the port on Google's side of the LACP exchange.
-
#neighbor_system_id ⇒ String
System ID of the port on the neighbor's side of the LACP exchange.
-
#state ⇒ String
The state of a LACP link, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus
constructor
A new instance of InterconnectDiagnosticsLinkLacpStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnosticsLinkLacpStatus
Returns a new instance of InterconnectDiagnosticsLinkLacpStatus.
29942 29943 29944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29942 def initialize(**args) update!(**args) end |
Instance Attribute Details
#google_system_id ⇒ String
System ID of the port on Google's side of the LACP exchange.
Corresponds to the JSON property googleSystemId
29926 29927 29928 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29926 def google_system_id @google_system_id end |
#neighbor_system_id ⇒ String
System ID of the port on the neighbor's side of the LACP exchange.
Corresponds to the JSON property neighborSystemId
29931 29932 29933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29931 def neighbor_system_id @neighbor_system_id end |
#state ⇒ String
The state of a LACP link, which can take one of the following values:
- ACTIVE: The link is configured and active within the bundle.
- DETACHED: The link is not configured within the bundle. This means
that the rest of the object should be empty.
Corresponds to the JSON property
state
29940 29941 29942 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29940 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
29947 29948 29949 29950 29951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 29947 def update!(**args) @google_system_id = args[:google_system_id] if args.key?(:google_system_id) @neighbor_system_id = args[:neighbor_system_id] if args.key?(:neighbor_system_id) @state = args[:state] if args.key?(:state) end |