Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



32992
32993
32994
# File 'lib/google/apis/compute_beta/classes.rb', line 32992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



32953
32954
32955
# File 'lib/google/apis/compute_beta/classes.rb', line 32953

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


32958
32959
32960
# File 'lib/google/apis/compute_beta/classes.rb', line 32958

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


32963
32964
32965
# File 'lib/google/apis/compute_beta/classes.rb', line 32963

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



32968
32969
32970
# File 'lib/google/apis/compute_beta/classes.rb', line 32968

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



32973
32974
32975
# File 'lib/google/apis/compute_beta/classes.rb', line 32973

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


32978
32979
32980
# File 'lib/google/apis/compute_beta/classes.rb', line 32978

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



32984
32985
32986
# File 'lib/google/apis/compute_beta/classes.rb', line 32984

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



32990
32991
32992
# File 'lib/google/apis/compute_beta/classes.rb', line 32990

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32997
32998
32999
33000
33001
33002
33003
33004
33005
33006
# File 'lib/google/apis/compute_beta/classes.rb', line 32997

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end