Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#arp_caches ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link.
-
#circuit_id ⇒ String
The unique ID for this link assigned during turn up by Google.
-
#google_demarc ⇒ String
The Demarc address assigned by Google and provided in the LoA.
-
#lacp_status ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus
Corresponds to the JSON property
lacpStatus. -
#macsec ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus
Describes the status of MACsec encryption on the link.
-
#operational_status ⇒ String
The operational status of the link.
-
#receiving_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
-
#transmitting_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus
constructor
A new instance of InterconnectDiagnosticsLinkStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus
Returns a new instance of InterconnectDiagnosticsLinkStatus.
32440 32441 32442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arp_caches ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects,
describing the ARP neighbor entries seen on this link.
This will be empty if the link is bundled
Corresponds to the JSON property arpCaches
32401 32402 32403 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32401 def arp_caches @arp_caches end |
#circuit_id ⇒ String
The unique ID for this link assigned during turn up by Google.
Corresponds to the JSON property circuitId
32406 32407 32408 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32406 def circuit_id @circuit_id end |
#google_demarc ⇒ String
The Demarc address assigned by Google and provided in the LoA.
Corresponds to the JSON property googleDemarc
32411 32412 32413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32411 def google_demarc @google_demarc end |
#lacp_status ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus
Corresponds to the JSON property lacpStatus
32416 32417 32418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32416 def lacp_status @lacp_status end |
#macsec ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus
Describes the status of MACsec encryption on the link.
Corresponds to the JSON property macsec
32421 32422 32423 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32421 def macsec @macsec end |
#operational_status ⇒ String
The operational status of the link.
Corresponds to the JSON property operationalStatus
32426 32427 32428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32426 def operational_status @operational_status end |
#receiving_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object,
describing the current value and status of the received light level.
Corresponds to the JSON property receivingOpticalPower
32432 32433 32434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32432 def receiving_optical_power @receiving_optical_power end |
#transmitting_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object,
describing the current value and status of the transmitted light level.
Corresponds to the JSON property transmittingOpticalPower
32438 32439 32440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32438 def transmitting_optical_power @transmitting_optical_power end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32445 32446 32447 32448 32449 32450 32451 32452 32453 32454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32445 def update!(**args) @arp_caches = args[:arp_caches] if args.key?(:arp_caches) @circuit_id = args[:circuit_id] if args.key?(:circuit_id) @google_demarc = args[:google_demarc] if args.key?(:google_demarc) @lacp_status = args[:lacp_status] if args.key?(:lacp_status) @macsec = args[:macsec] if args.key?(:macsec) @operational_status = args[:operational_status] if args.key?(:operational_status) @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power) @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power) end |