Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



32407
32408
32409
# File 'lib/google/apis/compute_beta/classes.rb', line 32407

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



32368
32369
32370
# File 'lib/google/apis/compute_beta/classes.rb', line 32368

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


32373
32374
32375
# File 'lib/google/apis/compute_beta/classes.rb', line 32373

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


32378
32379
32380
# File 'lib/google/apis/compute_beta/classes.rb', line 32378

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



32383
32384
32385
# File 'lib/google/apis/compute_beta/classes.rb', line 32383

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



32388
32389
32390
# File 'lib/google/apis/compute_beta/classes.rb', line 32388

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


32393
32394
32395
# File 'lib/google/apis/compute_beta/classes.rb', line 32393

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



32399
32400
32401
# File 'lib/google/apis/compute_beta/classes.rb', line 32399

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



32405
32406
32407
# File 'lib/google/apis/compute_beta/classes.rb', line 32405

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32412
32413
32414
32415
32416
32417
32418
32419
32420
32421
# File 'lib/google/apis/compute_beta/classes.rb', line 32412

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end