Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus

Returns a new instance of InterconnectDiagnosticsLinkStatus.



31826
31827
31828
# File 'lib/google/apis/compute_beta/classes.rb', line 31826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arp_cachesArray<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>

A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link. This will be empty if the link is bundled Corresponds to the JSON property arpCaches



31787
31788
31789
# File 'lib/google/apis/compute_beta/classes.rb', line 31787

def arp_caches
  @arp_caches
end

#circuit_idString

The unique ID for this link assigned during turn up by Google. Corresponds to the JSON property circuitId

Returns:

  • (String)


31792
31793
31794
# File 'lib/google/apis/compute_beta/classes.rb', line 31792

def circuit_id
  @circuit_id
end

#google_demarcString

The Demarc address assigned by Google and provided in the LoA. Corresponds to the JSON property googleDemarc

Returns:

  • (String)


31797
31798
31799
# File 'lib/google/apis/compute_beta/classes.rb', line 31797

def google_demarc
  @google_demarc
end

#lacp_statusGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus

Corresponds to the JSON property lacpStatus



31802
31803
31804
# File 'lib/google/apis/compute_beta/classes.rb', line 31802

def lacp_status
  @lacp_status
end

#macsecGoogle::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus

Describes the status of MACsec encryption on the link. Corresponds to the JSON property macsec



31807
31808
31809
# File 'lib/google/apis/compute_beta/classes.rb', line 31807

def macsec
  @macsec
end

#operational_statusString

The operational status of the link. Corresponds to the JSON property operationalStatus

Returns:

  • (String)


31812
31813
31814
# File 'lib/google/apis/compute_beta/classes.rb', line 31812

def operational_status
  @operational_status
end

#receiving_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level. Corresponds to the JSON property receivingOpticalPower



31818
31819
31820
# File 'lib/google/apis/compute_beta/classes.rb', line 31818

def receiving_optical_power
  @receiving_optical_power
end

#transmitting_optical_powerGoogle::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower

An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level. Corresponds to the JSON property transmittingOpticalPower



31824
31825
31826
# File 'lib/google/apis/compute_beta/classes.rb', line 31824

def transmitting_optical_power
  @transmitting_optical_power
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31831
31832
31833
31834
31835
31836
31837
31838
31839
31840
# File 'lib/google/apis/compute_beta/classes.rb', line 31831

def update!(**args)
  @arp_caches = args[:arp_caches] if args.key?(:arp_caches)
  @circuit_id = args[:circuit_id] if args.key?(:circuit_id)
  @google_demarc = args[:google_demarc] if args.key?(:google_demarc)
  @lacp_status = args[:lacp_status] if args.key?(:lacp_status)
  @macsec = args[:macsec] if args.key?(:macsec)
  @operational_status = args[:operational_status] if args.key?(:operational_status)
  @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power)
  @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power)
end