Class: Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#arp_caches ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects, describing the ARP neighbor entries seen on this link.
-
#circuit_id ⇒ String
The unique ID for this link assigned during turn up by Google.
-
#google_demarc ⇒ String
The Demarc address assigned by Google and provided in the LoA.
-
#lacp_status ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus
Corresponds to the JSON property
lacpStatus. -
#macsec ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus
Describes the status of MACsec encryption on the link.
-
#operational_status ⇒ String
The operational status of the link.
-
#receiving_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the received light level.
-
#transmitting_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object, describing the current value and status of the transmitted light level.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus
constructor
A new instance of InterconnectDiagnosticsLinkStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectDiagnosticsLinkStatus
Returns a new instance of InterconnectDiagnosticsLinkStatus.
31016 31017 31018 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#arp_caches ⇒ Array<Google::Apis::ComputeBeta::InterconnectDiagnosticsArpEntry>
A list of InterconnectDiagnostics.ARPEntry objects,
describing the ARP neighbor entries seen on this link.
This will be empty if the link is bundled
Corresponds to the JSON property arpCaches
30977 30978 30979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30977 def arp_caches @arp_caches end |
#circuit_id ⇒ String
The unique ID for this link assigned during turn up by Google.
Corresponds to the JSON property circuitId
30982 30983 30984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30982 def circuit_id @circuit_id end |
#google_demarc ⇒ String
The Demarc address assigned by Google and provided in the LoA.
Corresponds to the JSON property googleDemarc
30987 30988 30989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30987 def google_demarc @google_demarc end |
#lacp_status ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkLacpStatus
Corresponds to the JSON property lacpStatus
30992 30993 30994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30992 def lacp_status @lacp_status end |
#macsec ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsMacsecStatus
Describes the status of MACsec encryption on the link.
Corresponds to the JSON property macsec
30997 30998 30999 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30997 def macsec @macsec end |
#operational_status ⇒ String
The operational status of the link.
Corresponds to the JSON property operationalStatus
31002 31003 31004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31002 def operational_status @operational_status end |
#receiving_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object,
describing the current value and status of the received light level.
Corresponds to the JSON property receivingOpticalPower
31008 31009 31010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31008 def receiving_optical_power @receiving_optical_power end |
#transmitting_optical_power ⇒ Google::Apis::ComputeBeta::InterconnectDiagnosticsLinkOpticalPower
An InterconnectDiagnostics.LinkOpticalPower object,
describing the current value and status of the transmitted light level.
Corresponds to the JSON property transmittingOpticalPower
31014 31015 31016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31014 def transmitting_optical_power @transmitting_optical_power end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
31021 31022 31023 31024 31025 31026 31027 31028 31029 31030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 31021 def update!(**args) @arp_caches = args[:arp_caches] if args.key?(:arp_caches) @circuit_id = args[:circuit_id] if args.key?(:circuit_id) @google_demarc = args[:google_demarc] if args.key?(:google_demarc) @lacp_status = args[:lacp_status] if args.key?(:lacp_status) @macsec = args[:macsec] if args.key?(:macsec) @operational_status = args[:operational_status] if args.key?(:operational_status) @receiving_optical_power = args[:receiving_optical_power] if args.key?(:receiving_optical_power) @transmitting_optical_power = args[:transmitting_optical_power] if args.key?(:transmitting_optical_power) end |