Class: Google::Apis::ComputeBeta::InterconnectGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

An interconnect group resource allows customers to create, analyze, and expand their redundant connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroup

Returns a new instance of InterconnectGroup.



33170
33171
33172
# File 'lib/google/apis/compute_beta/classes.rb', line 33170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



33097
33098
33099
# File 'lib/google/apis/compute_beta/classes.rb', line 33097

def configured
  @configured
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


33103
33104
33105
# File 'lib/google/apis/compute_beta/classes.rb', line 33103

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


33109
33110
33111
# File 'lib/google/apis/compute_beta/classes.rb', line 33109

def description
  @description
end

#etagString

Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described by AIP 154. Corresponds to the JSON property etag

Returns:

  • (String)


33118
33119
33120
# File 'lib/google/apis/compute_beta/classes.rb', line 33118

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33125
33126
33127
# File 'lib/google/apis/compute_beta/classes.rb', line 33125

def id
  @id
end

#intentGoogle::Apis::ComputeBeta::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



33131
33132
33133
# File 'lib/google/apis/compute_beta/classes.rb', line 33131

def intent
  @intent
end

#interconnectsHash<String,Google::Apis::ComputeBeta::InterconnectGroupInterconnect>

Interconnects in the InterconnectGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Interconnects per group" quota. Corresponds to the JSON property interconnects



33140
33141
33142
# File 'lib/google/apis/compute_beta/classes.rb', line 33140

def interconnects
  @interconnects
end

#kindString

Output only. [Output Only] Type of the resource. Always compute# InterconnectGroup Corresponds to the JSON property kind

Returns:

  • (String)


33146
33147
33148
# File 'lib/google/apis/compute_beta/classes.rb', line 33146

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


33157
33158
33159
# File 'lib/google/apis/compute_beta/classes.rb', line 33157

def name
  @name
end

#physical_structureGoogle::Apis::ComputeBeta::InterconnectGroupPhysicalStructure

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure. Corresponds to the JSON property physicalStructure



33163
33164
33165
# File 'lib/google/apis/compute_beta/classes.rb', line 33163

def physical_structure
  @physical_structure
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33168
33169
33170
# File 'lib/google/apis/compute_beta/classes.rb', line 33168

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33175
33176
33177
33178
33179
33180
33181
33182
33183
33184
33185
33186
33187
# File 'lib/google/apis/compute_beta/classes.rb', line 33175

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @intent = args[:intent] if args.key?(:intent)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_structure = args[:physical_structure] if args.key?(:physical_structure)
  @self_link = args[:self_link] if args.key?(:self_link)
end