Class: Google::Apis::ComputeBeta::InterconnectGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An interconnect group resource allows customers to create, analyze, and expand their redundant connections.
Instance Attribute Summary collapse
-
#configured ⇒ Google::Apis::ComputeBeta::InterconnectGroupConfigured
[Output Only] The status of the group as configured.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
-
#id ⇒ Fixnum
Output only.
-
#intent ⇒ Google::Apis::ComputeBeta::InterconnectGroupIntent
The user's intent for this group.
-
#interconnects ⇒ Hash<String,Google::Apis::ComputeBeta::InterconnectGroupInterconnect>
Interconnects in the InterconnectGroup.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#physical_structure ⇒ Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructure
[Output Only] An analysis of the physical layout of Interconnects in this group.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroup
constructor
A new instance of InterconnectGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroup
Returns a new instance of InterconnectGroup.
33110 33111 33112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33110 def initialize(**args) update!(**args) end |
Instance Attribute Details
#configured ⇒ Google::Apis::ComputeBeta::InterconnectGroupConfigured
[Output Only] The status of the group as configured. This has the same
structure as the operational field reported by the OperationalStatus
method, but does not take into account the operational status of each
resource.
Corresponds to the JSON property configured
33037 33038 33039 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33037 def configured @configured end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
33043 33044 33045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33043 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
33049 33050 33051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33049 def description @description end |
#etag ⇒ String
Opaque system-generated token that uniquely identifies the configuration.
If provided when patching a configuration in update mode, the provided
token must match the current token or the update is rejected. This provides
a reliable means of doing read-modify-write (optimistic locking) as
described by AIP 154.
Corresponds to the JSON property etag
33058 33059 33060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33058 def etag @etag end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
33065 33066 33067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33065 def id @id end |
#intent ⇒ Google::Apis::ComputeBeta::InterconnectGroupIntent
The user's intent for this group. This is the only required field besides
the name that must be specified on group creation.
Corresponds to the JSON property intent
33071 33072 33073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33071 def intent @intent end |
#interconnects ⇒ Hash<String,Google::Apis::ComputeBeta::InterconnectGroupInterconnect>
Interconnects in the InterconnectGroup. Keys are arbitrary user-specified
strings. Users are encouraged, but not required, to use their preferred
format for resource links as keys.
Note that there are add-members and remove-members methods in gcloud.
The size of this map is limited by an "Interconnects per group" quota.
Corresponds to the JSON property interconnects
33080 33081 33082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33080 def interconnects @interconnects end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#
InterconnectGroup
Corresponds to the JSON property kind
33086 33087 33088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33086 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
33097 33098 33099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33097 def name @name end |
#physical_structure ⇒ Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructure
[Output Only] An analysis of the physical layout of Interconnects in this
group. Every Interconnect in the group is shown once in this structure.
Corresponds to the JSON property physicalStructure
33103 33104 33105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33103 def physical_structure @physical_structure end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
33108 33109 33110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33108 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33115 33116 33117 33118 33119 33120 33121 33122 33123 33124 33125 33126 33127 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33115 def update!(**args) @configured = args[:configured] if args.key?(:configured) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @intent = args[:intent] if args.key?(:intent) @interconnects = args[:interconnects] if args.key?(:interconnects) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_structure = args[:physical_structure] if args.key?(:physical_structure) @self_link = args[:self_link] if args.key?(:self_link) end |