Class: Google::Apis::ComputeBeta::InterconnectGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

An interconnect group resource allows customers to create, analyze, and expand their redundant connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroup

Returns a new instance of InterconnectGroup.



30171
30172
30173
# File 'lib/google/apis/compute_beta/classes.rb', line 30171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



30098
30099
30100
# File 'lib/google/apis/compute_beta/classes.rb', line 30098

def configured
  @configured
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


30104
30105
30106
# File 'lib/google/apis/compute_beta/classes.rb', line 30104

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


30110
30111
30112
# File 'lib/google/apis/compute_beta/classes.rb', line 30110

def description
  @description
end

#etagString

Opaque system-generated token that uniquely identifies the configuration. If provided when patching a configuration in update mode, the provided token must match the current token or the update is rejected. This provides a reliable means of doing read-modify-write (optimistic locking) as described by AIP 154. Corresponds to the JSON property etag

Returns:

  • (String)


30119
30120
30121
# File 'lib/google/apis/compute_beta/classes.rb', line 30119

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


30126
30127
30128
# File 'lib/google/apis/compute_beta/classes.rb', line 30126

def id
  @id
end

#intentGoogle::Apis::ComputeBeta::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



30132
30133
30134
# File 'lib/google/apis/compute_beta/classes.rb', line 30132

def intent
  @intent
end

#interconnectsHash<String,Google::Apis::ComputeBeta::InterconnectGroupInterconnect>

Interconnects in the InterconnectGroup. Keys are arbitrary user-specified strings. Users are encouraged, but not required, to use their preferred format for resource links as keys. Note that there are add-members and remove-members methods in gcloud. The size of this map is limited by an "Interconnects per group" quota. Corresponds to the JSON property interconnects



30141
30142
30143
# File 'lib/google/apis/compute_beta/classes.rb', line 30141

def interconnects
  @interconnects
end

#kindString

Output only. [Output Only] Type of the resource. Always compute# InterconnectGroup Corresponds to the JSON property kind

Returns:

  • (String)


30147
30148
30149
# File 'lib/google/apis/compute_beta/classes.rb', line 30147

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


30158
30159
30160
# File 'lib/google/apis/compute_beta/classes.rb', line 30158

def name
  @name
end

#physical_structureGoogle::Apis::ComputeBeta::InterconnectGroupPhysicalStructure

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure. Corresponds to the JSON property physicalStructure



30164
30165
30166
# File 'lib/google/apis/compute_beta/classes.rb', line 30164

def physical_structure
  @physical_structure
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30169
30170
30171
# File 'lib/google/apis/compute_beta/classes.rb', line 30169

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30176
30177
30178
30179
30180
30181
30182
30183
30184
30185
30186
30187
30188
# File 'lib/google/apis/compute_beta/classes.rb', line 30176

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @intent = args[:intent] if args.key?(:intent)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_structure = args[:physical_structure] if args.key?(:physical_structure)
  @self_link = args[:self_link] if args.key?(:self_link)
end