Class: Google::Apis::ComputeBeta::InterconnectGroupConfigured

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfigured

Returns a new instance of InterconnectGroupConfigured.



31988
31989
31990
# File 'lib/google/apis/compute_beta/classes.rb', line 31988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#topology_capabilityGoogle::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapability

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability. Corresponds to the JSON property topologyCapability



31986
31987
31988
# File 'lib/google/apis/compute_beta/classes.rb', line 31986

def topology_capability
  @topology_capability
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31993
31994
31995
# File 'lib/google/apis/compute_beta/classes.rb', line 31993

def update!(**args)
  @topology_capability = args[:topology_capability] if args.key?(:topology_capability)
end