Class: Google::Apis::ComputeBeta::InterconnectGroupConfigured
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupConfigured
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource.
Instance Attribute Summary collapse
-
#topology_capability ⇒ Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapability
[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfigured
constructor
A new instance of InterconnectGroupConfigured.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfigured
Returns a new instance of InterconnectGroupConfigured.
30205 30206 30207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#topology_capability ⇒ Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapability
[Output Only] How reliable this topology is configured to be, and why
this group does or does not meet the requirements for the intended
capability.
Corresponds to the JSON property topologyCapability
30203 30204 30205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30203 def topology_capability @topology_capability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30210 30211 30212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30210 def update!(**args) @topology_capability = args[:topology_capability] if args.key?(:topology_capability) end |