Class: Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapability

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] How reliable this topology is configured to be, and why this group does or does not meet the requirements for the intended capability.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapability

Returns a new instance of InterconnectGroupConfiguredTopologyCapability.



32014
32015
32016
# File 'lib/google/apis/compute_beta/classes.rb', line 32014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#intended_capability_blockersArray<Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers>

Corresponds to the JSON property intendedCapabilityBlockers



32007
32008
32009
# File 'lib/google/apis/compute_beta/classes.rb', line 32007

def intended_capability_blockers
  @intended_capability_blockers
end

#supported_slaString

Corresponds to the JSON property supportedSla

Returns:

  • (String)


32012
32013
32014
# File 'lib/google/apis/compute_beta/classes.rb', line 32012

def supported_sla
  @supported_sla
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32019
32020
32021
32022
# File 'lib/google/apis/compute_beta/classes.rb', line 32019

def update!(**args)
  @intended_capability_blockers = args[:intended_capability_blockers] if args.key?(:intended_capability_blockers)
  @supported_sla = args[:supported_sla] if args.key?(:supported_sla)
end