Class: Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.
Instance Attribute Summary collapse
-
#blocker_type ⇒ String
Corresponds to the JSON property
blockerType. -
#documentation_link ⇒ String
Output only.
-
#explanation ⇒ String
Output only.
-
#facilities ⇒ Array<String>
Output only.
-
#interconnects ⇒ Array<String>
Output only.
-
#metros ⇒ Array<String>
Output only.
-
#zones ⇒ Array<String>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
constructor
A new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers
Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.
33234 33235 33236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#blocker_type ⇒ String
Corresponds to the JSON property blockerType
33190 33191 33192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33190 def blocker_type @blocker_type end |
#documentation_link ⇒ String
Output only. [Output Only] The url of Google Cloud public documentation
explaining
this requirement. This is set for every type of requirement.
Corresponds to the JSON property documentationLink
33197 33198 33199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33197 def documentation_link @documentation_link end |
#explanation ⇒ String
Output only. [Output Only] A human-readable explanation of this requirement
and
why it's not met. This is set for every type of requirement.
Corresponds to the JSON property explanation
33204 33205 33206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33204 def explanation @explanation end |
#facilities ⇒ Array<String>
Output only. [Output Only] Facilities used to explain this blocker in more
detail.
Like physicalStructure.metros.facilities.facility, this is a numeric
string like "5467".
Corresponds to the JSON property facilities
33212 33213 33214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33212 def facilities @facilities end |
#interconnects ⇒ Array<String>
Output only. [Output Only] Interconnects used to explain this blocker in more
detail.
Corresponds to the JSON property interconnects
33218 33219 33220 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33218 def interconnects @interconnects end |
#metros ⇒ Array<String>
Output only. [Output Only] Metros used to explain this blocker in more detail.
These are three-letter lowercase strings like "iad". A blocker like
INCOMPATIBLE_METROS will specify the problematic metros in this
field.
Corresponds to the JSON property metros
33226 33227 33228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33226 def metros @metros end |
#zones ⇒ Array<String>
Output only. [Output Only] Zones used to explain this blocker in more detail.
Zone names are "zone1" and/or "zone2".
Corresponds to the JSON property zones
33232 33233 33234 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33232 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33239 33240 33241 33242 33243 33244 33245 33246 33247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33239 def update!(**args) @blocker_type = args[:blocker_type] if args.key?(:blocker_type) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @explanation = args[:explanation] if args.key?(:explanation) @facilities = args[:facilities] if args.key?(:facilities) @interconnects = args[:interconnects] if args.key?(:interconnects) @metros = args[:metros] if args.key?(:metros) @zones = args[:zones] if args.key?(:zones) end |