Class: Google::Apis::ComputeBeta::InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Reasons why configuration.topologyCapability.sla differs from intent.topologyCapability. This list is empty if and only if those are the same.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers

Returns a new instance of InterconnectGroupConfiguredTopologyCapabilityIntendedCapabilityBlockers.



33172
33173
33174
# File 'lib/google/apis/compute_beta/classes.rb', line 33172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blocker_typeString

Corresponds to the JSON property blockerType

Returns:

  • (String)


33128
33129
33130
# File 'lib/google/apis/compute_beta/classes.rb', line 33128

def blocker_type
  @blocker_type
end

Output only. [Output Only] The url of Google Cloud public documentation explaining this requirement. This is set for every type of requirement. Corresponds to the JSON property documentationLink

Returns:

  • (String)


33135
33136
33137
# File 'lib/google/apis/compute_beta/classes.rb', line 33135

def documentation_link
  @documentation_link
end

#explanationString

Output only. [Output Only] A human-readable explanation of this requirement and why it's not met. This is set for every type of requirement. Corresponds to the JSON property explanation

Returns:

  • (String)


33142
33143
33144
# File 'lib/google/apis/compute_beta/classes.rb', line 33142

def explanation
  @explanation
end

#facilitiesArray<String>

Output only. [Output Only] Facilities used to explain this blocker in more detail. Like physicalStructure.metros.facilities.facility, this is a numeric string like "5467". Corresponds to the JSON property facilities

Returns:

  • (Array<String>)


33150
33151
33152
# File 'lib/google/apis/compute_beta/classes.rb', line 33150

def facilities
  @facilities
end

#interconnectsArray<String>

Output only. [Output Only] Interconnects used to explain this blocker in more detail. Corresponds to the JSON property interconnects

Returns:

  • (Array<String>)


33156
33157
33158
# File 'lib/google/apis/compute_beta/classes.rb', line 33156

def interconnects
  @interconnects
end

#metrosArray<String>

Output only. [Output Only] Metros used to explain this blocker in more detail. These are three-letter lowercase strings like "iad". A blocker like INCOMPATIBLE_METROS will specify the problematic metros in this field. Corresponds to the JSON property metros

Returns:

  • (Array<String>)


33164
33165
33166
# File 'lib/google/apis/compute_beta/classes.rb', line 33164

def metros
  @metros
end

#zonesArray<String>

Output only. [Output Only] Zones used to explain this blocker in more detail. Zone names are "zone1" and/or "zone2". Corresponds to the JSON property zones

Returns:

  • (Array<String>)


33170
33171
33172
# File 'lib/google/apis/compute_beta/classes.rb', line 33170

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33177
33178
33179
33180
33181
33182
33183
33184
33185
# File 'lib/google/apis/compute_beta/classes.rb', line 33177

def update!(**args)
  @blocker_type = args[:blocker_type] if args.key?(:blocker_type)
  @documentation_link = args[:documentation_link] if args.key?(:documentation_link)
  @explanation = args[:explanation] if args.key?(:explanation)
  @facilities = args[:facilities] if args.key?(:facilities)
  @interconnects = args[:interconnects] if args.key?(:interconnects)
  @metros = args[:metros] if args.key?(:metros)
  @zones = args[:zones] if args.key?(:zones)
end