Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructure

Returns a new instance of InterconnectGroupPhysicalStructure.



33300
33301
33302
# File 'lib/google/apis/compute_beta/classes.rb', line 33300

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metrosArray<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetros>

Corresponds to the JSON property metros



33298
33299
33300
# File 'lib/google/apis/compute_beta/classes.rb', line 33298

def metros
  @metros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33305
33306
33307
# File 'lib/google/apis/compute_beta/classes.rb', line 33305

def update!(**args)
  @metros = args[:metros] if args.key?(:metros)
end