Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructure

Returns a new instance of InterconnectGroupPhysicalStructure.



33238
33239
33240
# File 'lib/google/apis/compute_beta/classes.rb', line 33238

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metrosArray<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetros>

Corresponds to the JSON property metros



33236
33237
33238
# File 'lib/google/apis/compute_beta/classes.rb', line 33236

def metros
  @metros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33243
33244
33245
# File 'lib/google/apis/compute_beta/classes.rb', line 33243

def update!(**args)
  @metros = args[:metros] if args.key?(:metros)
end