Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] An analysis of the physical layout of Interconnects in this group. Every Interconnect in the group is shown once in this structure.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructure

Returns a new instance of InterconnectGroupPhysicalStructure.



32144
32145
32146
# File 'lib/google/apis/compute_beta/classes.rb', line 32144

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#metrosArray<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetros>

Corresponds to the JSON property metros



32142
32143
32144
# File 'lib/google/apis/compute_beta/classes.rb', line 32142

def metros
  @metros
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32149
32150
32151
# File 'lib/google/apis/compute_beta/classes.rb', line 32149

def update!(**args)
  @metros = args[:metros] if args.key?(:metros)
end