Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.



32780
32781
32782
# File 'lib/google/apis/compute_beta/classes.rb', line 32780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilityString

Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility. Corresponds to the JSON property facility

Returns:

  • (String)


32773
32774
32775
# File 'lib/google/apis/compute_beta/classes.rb', line 32773

def facility
  @facility
end

#zonesArray<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>

Corresponds to the JSON property zones



32778
32779
32780
# File 'lib/google/apis/compute_beta/classes.rb', line 32778

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32785
32786
32787
32788
# File 'lib/google/apis/compute_beta/classes.rb', line 32785

def update!(**args)
  @facility = args[:facility] if args.key?(:facility)
  @zones = args[:zones] if args.key?(:zones)
end