Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilities

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The facilities Interconnects in this metro are present in.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities

Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.



31389
31390
31391
# File 'lib/google/apis/compute_beta/classes.rb', line 31389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#facilityString

Output only. [Output Only] The ID of this facility, as a numeric string like "5467". This is the third component of the location of Interconnects in this facility. Corresponds to the JSON property facility

Returns:

  • (String)


31382
31383
31384
# File 'lib/google/apis/compute_beta/classes.rb', line 31382

def facility
  @facility
end

#zonesArray<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>

Corresponds to the JSON property zones



31387
31388
31389
# File 'lib/google/apis/compute_beta/classes.rb', line 31387

def zones
  @zones
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31394
31395
31396
31397
# File 'lib/google/apis/compute_beta/classes.rb', line 31394

def update!(**args)
  @facility = args[:facility] if args.key?(:facility)
  @zones = args[:zones] if args.key?(:zones)
end