Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilities
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilities
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The facilities Interconnects in this metro are present in.
Instance Attribute Summary collapse
-
#facility ⇒ String
Output only.
-
#zones ⇒ Array<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
Corresponds to the JSON property
zones.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities
constructor
A new instance of InterconnectGroupPhysicalStructureMetrosFacilities.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilities
Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilities.
30416 30417 30418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30416 def initialize(**args) update!(**args) end |
Instance Attribute Details
#facility ⇒ String
Output only. [Output Only] The ID of this facility, as a numeric string like
"5467". This is the third component of the location of Interconnects
in this facility.
Corresponds to the JSON property facility
30409 30410 30411 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30409 def facility @facility end |
#zones ⇒ Array<Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones>
Corresponds to the JSON property zones
30414 30415 30416 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30414 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
30421 30422 30423 30424 |
# File 'lib/google/apis/compute_beta/classes.rb', line 30421 def update!(**args) @facility = args[:facility] if args.key?(:facility) @zones = args[:zones] if args.key?(:zones) end |