Class: Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupPhysicalStructureMetrosFacilitiesZones
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The zones that Interconnects in this facility are present in.
Instance Attribute Summary collapse
-
#interconnects ⇒ Array<String>
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones
constructor
A new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupPhysicalStructureMetrosFacilitiesZones
Returns a new instance of InterconnectGroupPhysicalStructureMetrosFacilitiesZones.
32843 32844 32845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32843 def initialize(**args) update!(**args) end |
Instance Attribute Details
#interconnects ⇒ Array<String>
Output only. [Output Only] URLs of Interconnects in this redundancy group in
the
given metro, facility, and zone.
Corresponds to the JSON property interconnects
32834 32835 32836 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32834 def interconnects @interconnects end |
#zone ⇒ String
Output only. [Output Only] The name of the zone, either "zone1" or "zone2".
This is the second component of the location of Interconnects in
this facility.
Corresponds to the JSON property zone
32841 32842 32843 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32841 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32848 32849 32850 32851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32848 def update!(**args) @interconnects = args[:interconnects] if args.key?(:interconnects) @zone = args[:zone] if args.key?(:zone) end |