Class: Google::Apis::ComputeBeta::InterconnectGroupsCreateMembersInterconnectInput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupsCreateMembersInterconnectInput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Administrative status of the interconnect.
-
#customer_name ⇒ String
Customer name, to put in the Letter of Authorization as the party authorized to request a crossconnect.
-
#description ⇒ String
An optional description of this resource.
-
#facility ⇒ String
A zone-free location to use for all Interconnects created in this call, like "iad-1234".
-
#interconnect_type ⇒ String
Type of interconnect, which can take one of the following values:.
-
#link_type ⇒ String
Type of link requested, which can take one of the following values:.
-
#name ⇒ String
Name of the Interconnects to be created.
-
#noc_contact_email ⇒ String
Email address to contact the customer NOC for operations and maintenance notifications regarding this Interconnect.
-
#remote_location ⇒ String
Indicates that this is a Cross-Cloud Interconnect.
-
#requested_features ⇒ Array<String>
Optional.
-
#requested_link_count ⇒ Fixnum
Target number of physical links in the link bundle, as requested by the customer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsCreateMembersInterconnectInput
constructor
A new instance of InterconnectGroupsCreateMembersInterconnectInput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsCreateMembersInterconnectInput
Returns a new instance of InterconnectGroupsCreateMembersInterconnectInput.
32990 32991 32992 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32990 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Administrative status of the interconnect. When this is set to true, the
Interconnect is functional and can carry traffic.
When set to false, no packets can be carried over the interconnect and
no BGP routes are exchanged over it. By default, the status is set to
true.
Corresponds to the JSON property adminEnabled
32897 32898 32899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32897 def admin_enabled @admin_enabled end |
#customer_name ⇒ String
Customer name, to put in the Letter of Authorization as the party
authorized to request a crossconnect.
Corresponds to the JSON property customerName
32904 32905 32906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32904 def customer_name @customer_name end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
32910 32911 32912 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32910 def description @description end |
#facility ⇒ String
A zone-free location to use for all Interconnects created in this call,
like "iad-1234".
Corresponds to the JSON property facility
32916 32917 32918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32916 def facility @facility end |
#interconnect_type ⇒ String
Type of interconnect, which can take one of the following values:
- PARTNER: A partner-managed interconnection shared between customers though a partner.
- DEDICATED: A dedicated physical
interconnection with the customer.
Note that a value IT_PRIVATE
has been deprecated in favor of DEDICATED.
Corresponds to the JSON property
interconnectType
32928 32929 32930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32928 def interconnect_type @interconnect_type end |
#link_type ⇒ String
Type of link requested, which can take one of the following values:
- LINK_TYPE_ETHERNET_10G_LR: A 10G Ethernet with LR optics
- LINK_TYPE_ETHERNET_100G_LR: A 100G Ethernet with LR optics.
- LINK_TYPE_ETHERNET_400G_LR4: A 400G Ethernet with LR4
optics.
Note that this field indicates the speed of each of the
links in the bundle, not the speed of the entire bundle.
Corresponds to the JSON property
linkType
32940 32941 32942 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32940 def link_type @link_type end |
#name ⇒ String
Name of the Interconnects to be created. This must be specified on the
template and/or on each individual interconnect. The name, if not empty,
must be 1-63 characters long, and comply with RFC1035.
Specifically, any nonempty name must be 1-63 characters long and match
the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
32952 32953 32954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32952 def name @name end |
#noc_contact_email ⇒ String
Email address to contact the customer NOC for operations and maintenance
notifications regarding this Interconnect. If specified, this will be
used for notifications in addition to all other forms described, such as
Cloud Monitoring logs alerting and Cloud Notifications. This field is
required for users who sign up for Cloud Interconnect using
workforce identity federation.
Corresponds to the JSON property nocContactEmail
32962 32963 32964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32962 def noc_contact_email @noc_contact_email end |
#remote_location ⇒ String
Indicates that this is a Cross-Cloud Interconnect. This field specifies
the location outside of Google's network that the interconnect is
connected to.
Corresponds to the JSON property remoteLocation
32969 32970 32971 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32969 def remote_location @remote_location end |
#requested_features ⇒ Array<String>
Optional. List of features requested for this Interconnect connection, which can take one of the following values:
- IF_MACSEC: If specified, then the connection is created on MACsec capable hardware ports. If not specified, non-MACsec capable ports will also be considered.
- IF_CROSS_SITE_NETWORK: If specified, then the connection is created
exclusively for Cross-Site Networking. The connection can not be used for
Cross-Site Networking unless this feature is specified.
Corresponds to the JSON property
requestedFeatures
32982 32983 32984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32982 def requested_features @requested_features end |
#requested_link_count ⇒ Fixnum
Target number of physical links in the link bundle, as requested by the
customer.
Corresponds to the JSON property requestedLinkCount
32988 32989 32990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32988 def requested_link_count @requested_link_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32995 32996 32997 32998 32999 33000 33001 33002 33003 33004 33005 33006 33007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32995 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @customer_name = args[:customer_name] if args.key?(:customer_name) @description = args[:description] if args.key?(:description) @facility = args[:facility] if args.key?(:facility) @interconnect_type = args[:interconnect_type] if args.key?(:interconnect_type) @link_type = args[:link_type] if args.key?(:link_type) @name = args[:name] if args.key?(:name) @noc_contact_email = args[:noc_contact_email] if args.key?(:noc_contact_email) @remote_location = args[:remote_location] if args.key?(:remote_location) @requested_features = args[:requested_features] if args.key?(:requested_features) @requested_link_count = args[:requested_link_count] if args.key?(:requested_link_count) end |