Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



33706
33707
33708
# File 'lib/google/apis/compute_beta/classes.rb', line 33706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33663
33664
33665
# File 'lib/google/apis/compute_beta/classes.rb', line 33663

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33668
33669
33670
# File 'lib/google/apis/compute_beta/classes.rb', line 33668

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



33673
33674
33675
# File 'lib/google/apis/compute_beta/classes.rb', line 33673

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


33678
33679
33680
# File 'lib/google/apis/compute_beta/classes.rb', line 33678

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33688
33689
33690
# File 'lib/google/apis/compute_beta/classes.rb', line 33688

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33693
33694
33695
# File 'lib/google/apis/compute_beta/classes.rb', line 33693

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33699
33700
33701
# File 'lib/google/apis/compute_beta/classes.rb', line 33699

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33704
33705
33706
# File 'lib/google/apis/compute_beta/classes.rb', line 33704

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33711
33712
33713
33714
33715
33716
33717
33718
33719
33720
# File 'lib/google/apis/compute_beta/classes.rb', line 33711

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end