Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



33646
33647
33648
# File 'lib/google/apis/compute_beta/classes.rb', line 33646

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33603
33604
33605
# File 'lib/google/apis/compute_beta/classes.rb', line 33603

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33608
33609
33610
# File 'lib/google/apis/compute_beta/classes.rb', line 33608

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



33613
33614
33615
# File 'lib/google/apis/compute_beta/classes.rb', line 33613

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


33618
33619
33620
# File 'lib/google/apis/compute_beta/classes.rb', line 33618

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33628
33629
33630
# File 'lib/google/apis/compute_beta/classes.rb', line 33628

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33633
33634
33635
# File 'lib/google/apis/compute_beta/classes.rb', line 33633

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33639
33640
33641
# File 'lib/google/apis/compute_beta/classes.rb', line 33639

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33644
33645
33646
# File 'lib/google/apis/compute_beta/classes.rb', line 33644

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33651
33652
33653
33654
33655
33656
33657
33658
33659
33660
# File 'lib/google/apis/compute_beta/classes.rb', line 33651

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end