Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



33606
33607
33608
# File 'lib/google/apis/compute_beta/classes.rb', line 33606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33563
33564
33565
# File 'lib/google/apis/compute_beta/classes.rb', line 33563

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33568
33569
33570
# File 'lib/google/apis/compute_beta/classes.rb', line 33568

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



33573
33574
33575
# File 'lib/google/apis/compute_beta/classes.rb', line 33573

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


33578
33579
33580
# File 'lib/google/apis/compute_beta/classes.rb', line 33578

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33588
33589
33590
# File 'lib/google/apis/compute_beta/classes.rb', line 33588

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33593
33594
33595
# File 'lib/google/apis/compute_beta/classes.rb', line 33593

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33599
33600
33601
# File 'lib/google/apis/compute_beta/classes.rb', line 33599

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33604
33605
33606
# File 'lib/google/apis/compute_beta/classes.rb', line 33604

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33611
33612
33613
33614
33615
33616
33617
33618
33619
33620
# File 'lib/google/apis/compute_beta/classes.rb', line 33611

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end