Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
33584 33585 33586 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33584 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
33541 33542 33543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33541 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33546 33547 33548 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33546 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
33551 33552 33553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33551 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
33556 33557 33558 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33556 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33566 33567 33568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33566 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33571 33572 33573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33571 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
33577 33578 33579 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33577 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33582 33583 33584 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33582 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33589 33590 33591 33592 33593 33594 33595 33596 33597 33598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33589 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |