Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



33104
33105
33106
# File 'lib/google/apis/compute_beta/classes.rb', line 33104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33061
33062
33063
# File 'lib/google/apis/compute_beta/classes.rb', line 33061

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33066
33067
33068
# File 'lib/google/apis/compute_beta/classes.rb', line 33066

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



33071
33072
33073
# File 'lib/google/apis/compute_beta/classes.rb', line 33071

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


33076
33077
33078
# File 'lib/google/apis/compute_beta/classes.rb', line 33076

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33086
33087
33088
# File 'lib/google/apis/compute_beta/classes.rb', line 33086

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33091
33092
33093
# File 'lib/google/apis/compute_beta/classes.rb', line 33091

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33097
33098
33099
# File 'lib/google/apis/compute_beta/classes.rb', line 33097

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33102
33103
33104
# File 'lib/google/apis/compute_beta/classes.rb', line 33102

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33109
33110
33111
33112
33113
33114
33115
33116
33117
33118
# File 'lib/google/apis/compute_beta/classes.rb', line 33109

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end