Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectGroupsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectGroup>
A list of InterconnectGroup resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectGroupsListResponse
constructor
A new instance of InterconnectGroupsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectGroupsListResponse
Returns a new instance of InterconnectGroupsListResponse.
33104 33105 33106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33104 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
33061 33062 33063 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33061 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33066 33067 33068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33066 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectGroup>
A list of InterconnectGroup resources.
Corresponds to the JSON property items
33071 33072 33073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33071 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
33076 33077 33078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33076 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33086 33087 33088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33086 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33091 33092 33093 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33091 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
33097 33098 33099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33097 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33102 33103 33104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33102 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33109 33110 33111 33112 33113 33114 33115 33116 33117 33118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33109 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |