Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



33071
33072
33073
# File 'lib/google/apis/compute_beta/classes.rb', line 33071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33028
33029
33030
# File 'lib/google/apis/compute_beta/classes.rb', line 33028

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33033
33034
33035
# File 'lib/google/apis/compute_beta/classes.rb', line 33033

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



33038
33039
33040
# File 'lib/google/apis/compute_beta/classes.rb', line 33038

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


33043
33044
33045
# File 'lib/google/apis/compute_beta/classes.rb', line 33043

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33053
33054
33055
# File 'lib/google/apis/compute_beta/classes.rb', line 33053

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33058
33059
33060
# File 'lib/google/apis/compute_beta/classes.rb', line 33058

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33064
33065
33066
# File 'lib/google/apis/compute_beta/classes.rb', line 33064

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33069
33070
33071
# File 'lib/google/apis/compute_beta/classes.rb', line 33069

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33076
33077
33078
33079
33080
33081
33082
33083
33084
33085
# File 'lib/google/apis/compute_beta/classes.rb', line 33076

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end