Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



32490
32491
32492
# File 'lib/google/apis/compute_beta/classes.rb', line 32490

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


32447
32448
32449
# File 'lib/google/apis/compute_beta/classes.rb', line 32447

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32452
32453
32454
# File 'lib/google/apis/compute_beta/classes.rb', line 32452

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



32457
32458
32459
# File 'lib/google/apis/compute_beta/classes.rb', line 32457

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


32462
32463
32464
# File 'lib/google/apis/compute_beta/classes.rb', line 32462

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32472
32473
32474
# File 'lib/google/apis/compute_beta/classes.rb', line 32472

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32477
32478
32479
# File 'lib/google/apis/compute_beta/classes.rb', line 32477

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


32483
32484
32485
# File 'lib/google/apis/compute_beta/classes.rb', line 32483

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32488
32489
32490
# File 'lib/google/apis/compute_beta/classes.rb', line 32488

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32495
32496
32497
32498
32499
32500
32501
32502
32503
32504
# File 'lib/google/apis/compute_beta/classes.rb', line 32495

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end