Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



31680
31681
31682
# File 'lib/google/apis/compute_beta/classes.rb', line 31680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


31637
31638
31639
# File 'lib/google/apis/compute_beta/classes.rb', line 31637

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31642
31643
31644
# File 'lib/google/apis/compute_beta/classes.rb', line 31642

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



31647
31648
31649
# File 'lib/google/apis/compute_beta/classes.rb', line 31647

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


31652
31653
31654
# File 'lib/google/apis/compute_beta/classes.rb', line 31652

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31662
31663
31664
# File 'lib/google/apis/compute_beta/classes.rb', line 31662

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31667
31668
31669
# File 'lib/google/apis/compute_beta/classes.rb', line 31667

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


31673
31674
31675
# File 'lib/google/apis/compute_beta/classes.rb', line 31673

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31678
31679
31680
# File 'lib/google/apis/compute_beta/classes.rb', line 31678

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31685
31686
31687
31688
31689
31690
31691
31692
31693
31694
# File 'lib/google/apis/compute_beta/classes.rb', line 31685

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end