Class: Google::Apis::ComputeBeta::InterconnectGroupsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsListResponse

Returns a new instance of InterconnectGroupsListResponse.



30707
30708
30709
# File 'lib/google/apis/compute_beta/classes.rb', line 30707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


30664
30665
30666
# File 'lib/google/apis/compute_beta/classes.rb', line 30664

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


30669
30670
30671
# File 'lib/google/apis/compute_beta/classes.rb', line 30669

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectGroup>

A list of InterconnectGroup resources. Corresponds to the JSON property items



30674
30675
30676
# File 'lib/google/apis/compute_beta/classes.rb', line 30674

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


30679
30680
30681
# File 'lib/google/apis/compute_beta/classes.rb', line 30679

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


30689
30690
30691
# File 'lib/google/apis/compute_beta/classes.rb', line 30689

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


30694
30695
30696
# File 'lib/google/apis/compute_beta/classes.rb', line 30694

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


30700
30701
30702
# File 'lib/google/apis/compute_beta/classes.rb', line 30700

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::InterconnectGroupsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



30705
30706
30707
# File 'lib/google/apis/compute_beta/classes.rb', line 30705

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30712
30713
30714
30715
30716
30717
30718
30719
30720
30721
# File 'lib/google/apis/compute_beta/classes.rb', line 30712

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end