Class: Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



33769
33770
33771
# File 'lib/google/apis/compute_beta/classes.rb', line 33769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



33743
33744
33745
# File 'lib/google/apis/compute_beta/classes.rb', line 33743

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


33748
33749
33750
# File 'lib/google/apis/compute_beta/classes.rb', line 33748

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



33754
33755
33756
# File 'lib/google/apis/compute_beta/classes.rb', line 33754

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



33759
33760
33761
# File 'lib/google/apis/compute_beta/classes.rb', line 33759

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



33767
33768
33769
# File 'lib/google/apis/compute_beta/classes.rb', line 33767

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33774
33775
33776
33777
33778
33779
33780
# File 'lib/google/apis/compute_beta/classes.rb', line 33774

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end