Class: Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



33707
33708
33709
# File 'lib/google/apis/compute_beta/classes.rb', line 33707

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



33681
33682
33683
# File 'lib/google/apis/compute_beta/classes.rb', line 33681

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


33686
33687
33688
# File 'lib/google/apis/compute_beta/classes.rb', line 33686

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



33692
33693
33694
# File 'lib/google/apis/compute_beta/classes.rb', line 33692

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



33697
33698
33699
# File 'lib/google/apis/compute_beta/classes.rb', line 33697

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



33705
33706
33707
# File 'lib/google/apis/compute_beta/classes.rb', line 33705

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33712
33713
33714
33715
33716
33717
33718
# File 'lib/google/apis/compute_beta/classes.rb', line 33712

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end