Class: Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



33227
33228
33229
# File 'lib/google/apis/compute_beta/classes.rb', line 33227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



33201
33202
33203
# File 'lib/google/apis/compute_beta/classes.rb', line 33201

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


33206
33207
33208
# File 'lib/google/apis/compute_beta/classes.rb', line 33206

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



33212
33213
33214
# File 'lib/google/apis/compute_beta/classes.rb', line 33212

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



33217
33218
33219
# File 'lib/google/apis/compute_beta/classes.rb', line 33217

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



33225
33226
33227
# File 'lib/google/apis/compute_beta/classes.rb', line 33225

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33232
33233
33234
33235
33236
33237
33238
# File 'lib/google/apis/compute_beta/classes.rb', line 33232

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end