Class: Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Request to get the status of the interconnect group with extra detail.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatus

Returns a new instance of InterconnectGroupsOperationalStatus.



33194
33195
33196
# File 'lib/google/apis/compute_beta/classes.rb', line 33194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configuredGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property configured



33168
33169
33170
# File 'lib/google/apis/compute_beta/classes.rb', line 33168

def configured
  @configured
end

#group_statusString

Output only. Summarizes the status of the group. Corresponds to the JSON property groupStatus

Returns:

  • (String)


33173
33174
33175
# File 'lib/google/apis/compute_beta/classes.rb', line 33173

def group_status
  @group_status
end

#intentGoogle::Apis::ComputeBeta::InterconnectGroupIntent

The user's intent for this group. This is the only required field besides the name that must be specified on group creation. Corresponds to the JSON property intent



33179
33180
33181
# File 'lib/google/apis/compute_beta/classes.rb', line 33179

def intent
  @intent
end

#interconnect_statusesArray<Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatusInterconnectStatus>

Corresponds to the JSON property interconnectStatuses



33184
33185
33186
# File 'lib/google/apis/compute_beta/classes.rb', line 33184

def interconnect_statuses
  @interconnect_statuses
end

#operationalGoogle::Apis::ComputeBeta::InterconnectGroupConfigured

[Output Only] The status of the group as configured. This has the same structure as the operational field reported by the OperationalStatus method, but does not take into account the operational status of each resource. Corresponds to the JSON property operational



33192
33193
33194
# File 'lib/google/apis/compute_beta/classes.rb', line 33192

def operational
  @operational
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33199
33200
33201
33202
33203
33204
33205
# File 'lib/google/apis/compute_beta/classes.rb', line 33199

def update!(**args)
  @configured = args[:configured] if args.key?(:configured)
  @group_status = args[:group_status] if args.key?(:group_status)
  @intent = args[:intent] if args.key?(:intent)
  @interconnect_statuses = args[:interconnect_statuses] if args.key?(:interconnect_statuses)
  @operational = args[:operational] if args.key?(:operational)
end