Class: Google::Apis::ComputeBeta::InterconnectGroupsOperationalStatusInterconnectStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The status of one Interconnect in the group. The order is arbitrary.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectGroupsOperationalStatusInterconnectStatus

Returns a new instance of InterconnectGroupsOperationalStatusInterconnectStatus.



30872
30873
30874
# File 'lib/google/apis/compute_beta/classes.rb', line 30872

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. Whether the Interconnect is enabled. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


30851
30852
30853
# File 'lib/google/apis/compute_beta/classes.rb', line 30851

def admin_enabled
  @admin_enabled
end

#diagnosticsGoogle::Apis::ComputeBeta::InterconnectDiagnostics

Diagnostics information about the Interconnect connection, which contains detailed and current technical information about Google's side of the connection. Corresponds to the JSON property diagnostics



30859
30860
30861
# File 'lib/google/apis/compute_beta/classes.rb', line 30859

def diagnostics
  @diagnostics
end

#interconnectString

Output only. The URL of the Interconnect being described. Corresponds to the JSON property interconnect

Returns:

  • (String)


30864
30865
30866
# File 'lib/google/apis/compute_beta/classes.rb', line 30864

def interconnect
  @interconnect
end

#is_activeString

Output only. Whether this interconnect is participating in the redundant configuration. Corresponds to the JSON property isActive

Returns:

  • (String)


30870
30871
30872
# File 'lib/google/apis/compute_beta/classes.rb', line 30870

def is_active
  @is_active
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



30877
30878
30879
30880
30881
30882
# File 'lib/google/apis/compute_beta/classes.rb', line 30877

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @diagnostics = args[:diagnostics] if args.key?(:diagnostics)
  @interconnect = args[:interconnect] if args.key?(:interconnect)
  @is_active = args[:is_active] if args.key?(:is_active)
end