Class: Google::Apis::ComputeBeta::InterconnectList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of interconnects.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Interconnect>
A list of Interconnect resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectList
constructor
A new instance of InterconnectList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectList
Returns a new instance of InterconnectList.
33322 33323 33324 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33322 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33289 33290 33291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33289 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Interconnect>
A list of Interconnect resources.
Corresponds to the JSON property items
33294 33295 33296 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33294 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#interconnectList
for lists of interconnects.
Corresponds to the JSON property kind
33300 33301 33302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33300 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33310 33311 33312 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33310 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33315 33316 33317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33315 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33320 33321 33322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33320 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33327 33328 33329 33330 33331 33332 33333 33334 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33327 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |