Class: Google::Apis::ComputeBeta::InterconnectList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of interconnects.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Interconnect>
A list of Interconnect resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectList
constructor
A new instance of InterconnectList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectList
Returns a new instance of InterconnectList.
33289 33290 33291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
33256 33257 33258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33256 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Interconnect>
A list of Interconnect resources.
Corresponds to the JSON property items
33261 33262 33263 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33261 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#interconnectList
for lists of interconnects.
Corresponds to the JSON property kind
33267 33268 33269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33267 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
33277 33278 33279 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33277 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
33282 33283 33284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33282 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
33287 33288 33289 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33287 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33294 33295 33296 33297 33298 33299 33300 33301 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33294 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |