Class: Google::Apis::ComputeBeta::InterconnectList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnects.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectList

Returns a new instance of InterconnectList.



32708
32709
32710
# File 'lib/google/apis/compute_beta/classes.rb', line 32708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32675
32676
32677
# File 'lib/google/apis/compute_beta/classes.rb', line 32675

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Interconnect>

A list of Interconnect resources. Corresponds to the JSON property items



32680
32681
32682
# File 'lib/google/apis/compute_beta/classes.rb', line 32680

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#interconnectList for lists of interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


32686
32687
32688
# File 'lib/google/apis/compute_beta/classes.rb', line 32686

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32696
32697
32698
# File 'lib/google/apis/compute_beta/classes.rb', line 32696

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32701
32702
32703
# File 'lib/google/apis/compute_beta/classes.rb', line 32701

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32706
32707
32708
# File 'lib/google/apis/compute_beta/classes.rb', line 32706

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32713
32714
32715
32716
32717
32718
32719
32720
# File 'lib/google/apis/compute_beta/classes.rb', line 32713

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end