Class: Google::Apis::ComputeBeta::InterconnectList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnects.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectList

Returns a new instance of InterconnectList.



31898
31899
31900
# File 'lib/google/apis/compute_beta/classes.rb', line 31898

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31865
31866
31867
# File 'lib/google/apis/compute_beta/classes.rb', line 31865

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Interconnect>

A list of Interconnect resources. Corresponds to the JSON property items



31870
31871
31872
# File 'lib/google/apis/compute_beta/classes.rb', line 31870

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#interconnectList for lists of interconnects. Corresponds to the JSON property kind

Returns:

  • (String)


31876
31877
31878
# File 'lib/google/apis/compute_beta/classes.rb', line 31876

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31886
31887
31888
# File 'lib/google/apis/compute_beta/classes.rb', line 31886

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31891
31892
31893
# File 'lib/google/apis/compute_beta/classes.rb', line 31891

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31896
31897
31898
# File 'lib/google/apis/compute_beta/classes.rb', line 31896

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31903
31904
31905
31906
31907
31908
31909
31910
# File 'lib/google/apis/compute_beta/classes.rb', line 31903

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end