Class: Google::Apis::ComputeBeta::InterconnectLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Interconnect Attachment (VLAN) Location resource. You can use this resource to find location details about an Interconnect attachment (VLAN). For more information about interconnect attachments, read Creating VLAN Attachments.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocation

Returns a new instance of InterconnectLocation.



33528
33529
33530
# File 'lib/google/apis/compute_beta/classes.rb', line 33528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character. Corresponds to the JSON property address

Returns:

  • (String)


33386
33387
33388
# File 'lib/google/apis/compute_beta/classes.rb', line 33386

def address
  @address
end

#availability_zoneString

[Output Only] Availability zone for this InterconnectLocation. Within a metropolitan area (metro), maintenance will not be simultaneously scheduled in more than one availability zone. Example: "zone1" or "zone2". Corresponds to the JSON property availabilityZone

Returns:

  • (String)


33393
33394
33395
# File 'lib/google/apis/compute_beta/classes.rb', line 33393

def availability_zone
  @availability_zone
end

#available_featuresArray<String>

[Output only] List of features available at this InterconnectLocation, which can take one of the following values:

  • IF_MACSEC
  • IF_CROSS_SITE_NETWORK Corresponds to the JSON property availableFeatures

Returns:

  • (Array<String>)


33402
33403
33404
# File 'lib/google/apis/compute_beta/classes.rb', line 33402

def available_features
  @available_features
end

[Output only] List of link types available at this InterconnectLocation, which can take one of the following values:

  • LINK_TYPE_ETHERNET_10G_LR
  • LINK_TYPE_ETHERNET_100G_LR
  • LINK_TYPE_ETHERNET_400G_LR4 Corresponds to the JSON property availableLinkTypes

Returns:

  • (Array<String>)


33412
33413
33414
# File 'lib/google/apis/compute_beta/classes.rb', line 33412

def available_link_types
  @available_link_types
end

#cityString

[Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands". Corresponds to the JSON property city

Returns:

  • (String)


33419
33420
33421
# File 'lib/google/apis/compute_beta/classes.rb', line 33419

def city
  @city
end

#continentString

[Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA Corresponds to the JSON property continent

Returns:

  • (String)


33431
33432
33433
# File 'lib/google/apis/compute_beta/classes.rb', line 33431

def continent
  @continent
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


33437
33438
33439
# File 'lib/google/apis/compute_beta/classes.rb', line 33437

def creation_timestamp
  @creation_timestamp
end

#cross_site_interconnect_infosArray<Google::Apis::ComputeBeta::InterconnectLocationCrossSiteInterconnectInfo>

[Output Only] A list of InterconnectLocation.CrossSiteInterconnectInfo objects, that describe where Cross-Site Interconnect wires may connect to from this location and associated connection parameters. Cross-Site Interconnect isn't allowed to locations which are not listed. Corresponds to the JSON property crossSiteInterconnectInfos



33445
33446
33447
# File 'lib/google/apis/compute_beta/classes.rb', line 33445

def cross_site_interconnect_infos
  @cross_site_interconnect_infos
end

#descriptionString

Output only. [Output Only] An optional description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


33450
33451
33452
# File 'lib/google/apis/compute_beta/classes.rb', line 33450

def description
  @description
end

#facility_providerString

Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX). Corresponds to the JSON property facilityProvider

Returns:

  • (String)


33456
33457
33458
# File 'lib/google/apis/compute_beta/classes.rb', line 33456

def facility_provider
  @facility_provider
end

#facility_provider_facility_idString

Output only. [Output Only] A provider-assigned Identifier for this facility (e. g., Ashburn-DC1). Corresponds to the JSON property facilityProviderFacilityId

Returns:

  • (String)


33463
33464
33465
# File 'lib/google/apis/compute_beta/classes.rb', line 33463

def facility_provider_facility_id
  @facility_provider_facility_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33470
33471
33472
# File 'lib/google/apis/compute_beta/classes.rb', line 33470

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectLocation for interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


33476
33477
33478
# File 'lib/google/apis/compute_beta/classes.rb', line 33476

def kind
  @kind
end

#nameString

Output only. [Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


33481
33482
33483
# File 'lib/google/apis/compute_beta/classes.rb', line 33481

def name
  @name
end

#peeringdb_facility_idString

Output only. [Output Only] The peeringdb identifier for this facility ( corresponding with a netfac type in peeringdb). Corresponds to the JSON property peeringdbFacilityId

Returns:

  • (String)


33488
33489
33490
# File 'lib/google/apis/compute_beta/classes.rb', line 33488

def peeringdb_facility_id
  @peeringdb_facility_id
end

#region_infosArray<Google::Apis::ComputeBeta::InterconnectLocationRegionInfo>

Output only. [Output Only] A list of InterconnectLocation.RegionInfo objects, that describe parameters pertaining to the relation between this InterconnectLocation and various Google Cloud regions. Corresponds to the JSON property regionInfos



33496
33497
33498
# File 'lib/google/apis/compute_beta/classes.rb', line 33496

def region_infos
  @region_infos
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33501
33502
33503
# File 'lib/google/apis/compute_beta/classes.rb', line 33501

def self_link
  @self_link
end

#single_region_production_critical_peer_locationsArray<String>

Output only. [Output Only] URLs of the other locations that can pair up with this location to support Single-Region 99.99% SLA. E.g. iad-zone1-1 and iad-zone2-5467 are Single-Region 99.99% peer locations of each other. Corresponds to the JSON property singleRegionProductionCriticalPeerLocations

Returns:

  • (Array<String>)


33509
33510
33511
# File 'lib/google/apis/compute_beta/classes.rb', line 33509

def single_region_production_critical_peer_locations
  @single_region_production_critical_peer_locations
end

#statusString

[Output Only] The status of this InterconnectLocation, which can take one of the following values:

  • CLOSED: The InterconnectLocation is closed and is unavailable for provisioning new Interconnects.
  • AVAILABLE: The InterconnectLocation is available for provisioning new Interconnects. Corresponds to the JSON property status

Returns:

  • (String)


33520
33521
33522
# File 'lib/google/apis/compute_beta/classes.rb', line 33520

def status
  @status
end

#supports_pzsBoolean Also known as: supports_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property supportsPzs

Returns:

  • (Boolean)


33525
33526
33527
# File 'lib/google/apis/compute_beta/classes.rb', line 33525

def supports_pzs
  @supports_pzs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33533
33534
33535
33536
33537
33538
33539
33540
33541
33542
33543
33544
33545
33546
33547
33548
33549
33550
33551
33552
33553
33554
# File 'lib/google/apis/compute_beta/classes.rb', line 33533

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @availability_zone = args[:availability_zone] if args.key?(:availability_zone)
  @available_features = args[:available_features] if args.key?(:available_features)
  @available_link_types = args[:available_link_types] if args.key?(:available_link_types)
  @city = args[:city] if args.key?(:city)
  @continent = args[:continent] if args.key?(:continent)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @cross_site_interconnect_infos = args[:cross_site_interconnect_infos] if args.key?(:cross_site_interconnect_infos)
  @description = args[:description] if args.key?(:description)
  @facility_provider = args[:facility_provider] if args.key?(:facility_provider)
  @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id)
  @region_infos = args[:region_infos] if args.key?(:region_infos)
  @self_link = args[:self_link] if args.key?(:self_link)
  @single_region_production_critical_peer_locations = args[:single_region_production_critical_peer_locations] if args.key?(:single_region_production_critical_peer_locations)
  @status = args[:status] if args.key?(:status)
  @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs)
end