Class: Google::Apis::ComputeBeta::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



34256
34257
34258
# File 'lib/google/apis/compute_beta/classes.rb', line 34256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34222
34223
34224
# File 'lib/google/apis/compute_beta/classes.rb', line 34222

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



34227
34228
34229
# File 'lib/google/apis/compute_beta/classes.rb', line 34227

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


34234
34235
34236
# File 'lib/google/apis/compute_beta/classes.rb', line 34234

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34244
34245
34246
# File 'lib/google/apis/compute_beta/classes.rb', line 34244

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34249
34250
34251
# File 'lib/google/apis/compute_beta/classes.rb', line 34249

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34254
34255
34256
# File 'lib/google/apis/compute_beta/classes.rb', line 34254

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34261
34262
34263
34264
34265
34266
34267
34268
# File 'lib/google/apis/compute_beta/classes.rb', line 34261

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end