Class: Google::Apis::ComputeBeta::InterconnectLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of interconnect locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectLocation>
A list of InterconnectLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectLocationList
constructor
A new instance of InterconnectLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectLocationList
Returns a new instance of InterconnectLocationList.
34206 34207 34208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34206 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
34172 34173 34174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34172 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectLocation>
A list of InterconnectLocation resources.
Corresponds to the JSON property items
34177 34178 34179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34177 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectLocationList for lists of interconnect
locations.
Corresponds to the JSON property kind
34184 34185 34186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34184 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
34194 34195 34196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34194 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
34199 34200 34201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34199 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
34204 34205 34206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34204 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34211 34212 34213 34214 34215 34216 34217 34218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34211 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |