Class: Google::Apis::ComputeBeta::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



34196
34197
34198
# File 'lib/google/apis/compute_beta/classes.rb', line 34196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34162
34163
34164
# File 'lib/google/apis/compute_beta/classes.rb', line 34162

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



34167
34168
34169
# File 'lib/google/apis/compute_beta/classes.rb', line 34167

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


34174
34175
34176
# File 'lib/google/apis/compute_beta/classes.rb', line 34174

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34184
34185
34186
# File 'lib/google/apis/compute_beta/classes.rb', line 34184

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34189
34190
34191
# File 'lib/google/apis/compute_beta/classes.rb', line 34189

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34194
34195
34196
# File 'lib/google/apis/compute_beta/classes.rb', line 34194

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34201
34202
34203
34204
34205
34206
34207
34208
# File 'lib/google/apis/compute_beta/classes.rb', line 34201

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end