Class: Google::Apis::ComputeBeta::InterconnectLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectLocationList

Returns a new instance of InterconnectLocationList.



33621
33622
33623
# File 'lib/google/apis/compute_beta/classes.rb', line 33621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33587
33588
33589
# File 'lib/google/apis/compute_beta/classes.rb', line 33587

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectLocation>

A list of InterconnectLocation resources. Corresponds to the JSON property items



33592
33593
33594
# File 'lib/google/apis/compute_beta/classes.rb', line 33592

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectLocationList for lists of interconnect locations. Corresponds to the JSON property kind

Returns:

  • (String)


33599
33600
33601
# File 'lib/google/apis/compute_beta/classes.rb', line 33599

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33609
33610
33611
# File 'lib/google/apis/compute_beta/classes.rb', line 33609

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33614
33615
33616
# File 'lib/google/apis/compute_beta/classes.rb', line 33614

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33619
33620
33621
# File 'lib/google/apis/compute_beta/classes.rb', line 33619

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33626
33627
33628
33629
33630
33631
33632
33633
# File 'lib/google/apis/compute_beta/classes.rb', line 33626

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end