Class: Google::Apis::ComputeBeta::InterconnectMacsecConfigPreSharedKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectMacsecConfigPreSharedKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Describes a pre-shared key used to setup MACsec in static connectivity association key (CAK) mode.
Instance Attribute Summary collapse
-
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
-
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
-
#name ⇒ String
User provided name for this pre-shared key.
-
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
constructor
A new instance of InterconnectMacsecConfigPreSharedKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectMacsecConfigPreSharedKey
Returns a new instance of InterconnectMacsecConfigPreSharedKey.
32445 32446 32447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32445 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cak ⇒ String
An auto-generated Connectivity Association Key (CAK) for this key.
Corresponds to the JSON property cak
32428 32429 32430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32428 def cak @cak end |
#ckn ⇒ String
An auto-generated Connectivity Association Key Name (CKN) for this key.
Corresponds to the JSON property ckn
32433 32434 32435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32433 def ckn @ckn end |
#name ⇒ String
User provided name for this pre-shared key.
Corresponds to the JSON property name
32438 32439 32440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32438 def name @name end |
#start_time ⇒ String
User provided timestamp on or after which this key is valid.
Corresponds to the JSON property startTime
32443 32444 32445 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32443 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32450 32451 32452 32453 32454 32455 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32450 def update!(**args) @cak = args[:cak] if args.key?(:cak) @ckn = args[:ckn] if args.key?(:ckn) @name = args[:name] if args.key?(:name) @start_time = args[:start_time] if args.key?(:start_time) end |