Class: Google::Apis::ComputeBeta::InterconnectOutageNotification
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectOutageNotification
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Description of a planned outage on this Interconnect.
Instance Attribute Summary collapse
-
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit IDs that will be affected.
-
#description ⇒ String
A description about the purpose of the outage.
-
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix epoch).
-
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:.
-
#name ⇒ String
Unique identifier for this outage notification.
-
#source ⇒ String
The party that generated this notification, which can take the following value:.
-
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix epoch).
-
#state ⇒ String
State of this notification, which can take one of the following values:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectOutageNotification
constructor
A new instance of InterconnectOutageNotification.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectOutageNotification
Returns a new instance of InterconnectOutageNotification.
32565 32566 32567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#affected_circuits ⇒ Array<String>
If issue_type is IT_PARTIAL_OUTAGE, a list of the Google-side circuit
IDs that will be affected.
Corresponds to the JSON property affectedCircuits
32504 32505 32506 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32504 def affected_circuits @affected_circuits end |
#description ⇒ String
A description about the purpose of the outage.
Corresponds to the JSON property description
32509 32510 32511 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32509 def description @description end |
#end_time ⇒ Fixnum
Scheduled end time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property endTime
32515 32516 32517 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32515 def end_time @end_time end |
#issue_type ⇒ String
Form this outage is expected to take, which can take one of the following values:
- OUTAGE: The Interconnect may be completely out of service for some or all of the specified window.
- PARTIAL_OUTAGE: Some circuits comprising the Interconnect as a whole
should remain up, but with reduced bandwidth.
Note that the versions of this enum prefixed with "IT_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
issueType
32528 32529 32530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32528 def issue_type @issue_type end |
#name ⇒ String
Unique identifier for this outage notification.
Corresponds to the JSON property name
32533 32534 32535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32533 def name @name end |
#source ⇒ String
The party that generated this notification, which can take the following value:
- GOOGLE: this notification as generated by Google.
Note that the value of NSRC_GOOGLE has been deprecated in favor of
GOOGLE.
Corresponds to the JSON property
source
32543 32544 32545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32543 def source @source end |
#start_time ⇒ Fixnum
Scheduled start time for the outage (milliseconds since Unix
epoch).
Corresponds to the JSON property startTime
32549 32550 32551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32549 def start_time @start_time end |
#state ⇒ String
State of this notification, which can take one of the following values:
- ACTIVE: This outage notification is active. The event could be in the past, present, or future. See start_time and end_time for scheduling.
- CANCELLED: The outage associated with this notification was cancelled before the outage was due to start.
- COMPLETED: The outage associated with this notification is complete.
Note that the versions of this enum prefixed with "NS_" have been
deprecated in favor of the unprefixed values.
Corresponds to the JSON property
state
32563 32564 32565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32563 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
32570 32571 32572 32573 32574 32575 32576 32577 32578 32579 |
# File 'lib/google/apis/compute_beta/classes.rb', line 32570 def update!(**args) @affected_circuits = args[:affected_circuits] if args.key?(:affected_circuits) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @issue_type = args[:issue_type] if args.key?(:issue_type) @name = args[:name] if args.key?(:name) @source = args[:source] if args.key?(:source) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |