Class: Google::Apis::ComputeBeta::InterconnectRemoteLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectRemoteLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).
Instance Attribute Summary collapse
-
#address ⇒ String
Output only.
-
#attachment_configuration_constraints ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentConfigurationConstraints
Output only.
-
#city ⇒ String
Output only.
-
#constraints ⇒ Google::Apis::ComputeBeta::InterconnectRemoteLocationConstraints
Output only.
-
#continent ⇒ String
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#facility_provider ⇒ String
Output only.
-
#facility_provider_facility_id ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#lacp ⇒ String
Output only.
-
#max_lag_size100_gbps ⇒ Fixnum
Output only.
-
#max_lag_size10_gbps ⇒ Fixnum
Output only.
-
#max_lag_size400_gbps ⇒ Fixnum
Output only.
-
#name ⇒ String
Output only.
-
#peeringdb_facility_id ⇒ String
Output only.
-
#permitted_connections ⇒ Array<Google::Apis::ComputeBeta::InterconnectRemoteLocationPermittedConnections>
Output only.
-
#remote_service ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocation
constructor
A new instance of InterconnectRemoteLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocation
Returns a new instance of InterconnectRemoteLocation.
34749 34750 34751 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address ⇒ String
Output only. [Output Only] The postal address of the Point of Presence, each
line in
the address is separated by a newline character.
Corresponds to the JSON property address
34601 34602 34603 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34601 def address @address end |
#attachment_configuration_constraints ⇒ Google::Apis::ComputeBeta::InterconnectAttachmentConfigurationConstraints
Output only. [Output Only] Subset of fields from InterconnectAttachment's
|configurationConstraints| field that apply to all attachments for this
remote location.
Corresponds to the JSON property attachmentConfigurationConstraints
34608 34609 34610 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34608 def @attachment_configuration_constraints end |
#city ⇒ String
Output only. [Output Only] Metropolitan area designator that indicates which
city an
interconnect is located.
For example: "Chicago, IL", "Amsterdam, Netherlands".
Corresponds to the JSON property city
34616 34617 34618 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34616 def city @city end |
#constraints ⇒ Google::Apis::ComputeBeta::InterconnectRemoteLocationConstraints
Output only. [Output Only] Constraints on the parameters for creating Cross-
Cloud
Interconnect and associated InterconnectAttachments.
Corresponds to the JSON property constraints
34623 34624 34625 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34623 def constraints @constraints end |
#continent ⇒ String
Output only. [Output Only] Continent for this location, which can take one of the following values:
- AFRICA
- ASIA_PAC
- EUROPE
- NORTH_AMERICA
- SOUTH_AMERICA
Corresponds to the JSON property
continent
34636 34637 34638 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34636 def continent @continent end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
34642 34643 34644 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34642 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] An optional description of the resource.
Corresponds to the JSON property description
34647 34648 34649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34647 def description @description end |
#facility_provider ⇒ String
Output only. [Output Only] The name of the provider for this facility (e.g.,
EQUINIX).
Corresponds to the JSON property facilityProvider
34653 34654 34655 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34653 def facility_provider @facility_provider end |
#facility_provider_facility_id ⇒ String
Output only. [Output Only] A provider-assigned Identifier for this facility (e.
g.,
Ashburn-DC1).
Corresponds to the JSON property facilityProviderFacilityId
34660 34661 34662 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34660 def facility_provider_facility_id @facility_provider_facility_id end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
34667 34668 34669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34667 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
interconnectRemoteLocation for interconnect remote
locations.
Corresponds to the JSON property kind
34674 34675 34676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34674 def kind @kind end |
#lacp ⇒ String
Output only. [Output Only] Link Aggregation Control Protocol (LACP)
constraints, which
can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED
Corresponds to the JSON property lacp
34681 34682 34683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34681 def lacp @lacp end |
#max_lag_size100_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 100 Gbps ports supported in a link aggregation group
(LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed
max_lag_size_100_gbps.
Corresponds to the JSON property maxLagSize100Gbps
34689 34690 34691 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34689 def max_lag_size100_gbps @max_lag_size100_gbps end |
#max_lag_size10_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 10 Gbps ports supported in a link aggregation group
(LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed
max_lag_size_10_gbps.
Corresponds to the JSON property maxLagSize10Gbps
34697 34698 34699 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34697 def max_lag_size10_gbps @max_lag_size10_gbps end |
#max_lag_size400_gbps ⇒ Fixnum
Output only. [Output Only]
The maximum number of 400 Gbps ports supported in a link aggregation group
(LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed
max_lag_size_400_gbps.
Corresponds to the JSON property maxLagSize400Gbps
34705 34706 34707 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34705 def max_lag_size400_gbps @max_lag_size400_gbps end |
#name ⇒ String
Output only. [Output Only] Name of the resource.
Corresponds to the JSON property name
34710 34711 34712 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34710 def name @name end |
#peeringdb_facility_id ⇒ String
Output only. [Output Only] The peeringdb identifier for this facility (
corresponding
with a netfac type in peeringdb).
Corresponds to the JSON property peeringdbFacilityId
34717 34718 34719 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34717 def peeringdb_facility_id @peeringdb_facility_id end |
#permitted_connections ⇒ Array<Google::Apis::ComputeBeta::InterconnectRemoteLocationPermittedConnections>
Output only. [Output Only] Permitted connections.
Corresponds to the JSON property permittedConnections
34722 34723 34724 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34722 def permitted_connections @permitted_connections end |
#remote_service ⇒ String
Output only. [Output Only] Indicates the service provider present at the
remote
location. Example values: "Amazon Web Services", "Microsoft Azure".
Corresponds to the JSON property remoteService
34729 34730 34731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34729 def remote_service @remote_service end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
34734 34735 34736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34734 def self_link @self_link end |
#status ⇒ String
Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:
- CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
- AVAILABLE: The
InterconnectRemoteLocation is available for provisioning new
Cross-Cloud Interconnects.
Corresponds to the JSON property
status
34747 34748 34749 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34747 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34754 34755 34756 34757 34758 34759 34760 34761 34762 34763 34764 34765 34766 34767 34768 34769 34770 34771 34772 34773 34774 34775 34776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34754 def update!(**args) @address = args[:address] if args.key?(:address) @attachment_configuration_constraints = args[:attachment_configuration_constraints] if args.key?(:attachment_configuration_constraints) @city = args[:city] if args.key?(:city) @constraints = args[:constraints] if args.key?(:constraints) @continent = args[:continent] if args.key?(:continent) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @facility_provider = args[:facility_provider] if args.key?(:facility_provider) @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @lacp = args[:lacp] if args.key?(:lacp) @max_lag_size100_gbps = args[:max_lag_size100_gbps] if args.key?(:max_lag_size100_gbps) @max_lag_size10_gbps = args[:max_lag_size10_gbps] if args.key?(:max_lag_size10_gbps) @max_lag_size400_gbps = args[:max_lag_size400_gbps] if args.key?(:max_lag_size400_gbps) @name = args[:name] if args.key?(:name) @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id) @permitted_connections = args[:permitted_connections] if args.key?(:permitted_connections) @remote_service = args[:remote_service] if args.key?(:remote_service) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) end |