Class: Google::Apis::ComputeBeta::InterconnectRemoteLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Cross-Cloud Interconnect Remote Location resource. You can use this resource to find remote location details about an Interconnect attachment (VLAN).

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocation

Returns a new instance of InterconnectRemoteLocation.



34164
34165
34166
# File 'lib/google/apis/compute_beta/classes.rb', line 34164

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#addressString

Output only. [Output Only] The postal address of the Point of Presence, each line in the address is separated by a newline character. Corresponds to the JSON property address

Returns:

  • (String)


34016
34017
34018
# File 'lib/google/apis/compute_beta/classes.rb', line 34016

def address
  @address
end

#attachment_configuration_constraintsGoogle::Apis::ComputeBeta::InterconnectAttachmentConfigurationConstraints

Output only. [Output Only] Subset of fields from InterconnectAttachment's |configurationConstraints| field that apply to all attachments for this remote location. Corresponds to the JSON property attachmentConfigurationConstraints



34023
34024
34025
# File 'lib/google/apis/compute_beta/classes.rb', line 34023

def attachment_configuration_constraints
  @attachment_configuration_constraints
end

#cityString

Output only. [Output Only] Metropolitan area designator that indicates which city an interconnect is located. For example: "Chicago, IL", "Amsterdam, Netherlands". Corresponds to the JSON property city

Returns:

  • (String)


34031
34032
34033
# File 'lib/google/apis/compute_beta/classes.rb', line 34031

def city
  @city
end

#constraintsGoogle::Apis::ComputeBeta::InterconnectRemoteLocationConstraints

Output only. [Output Only] Constraints on the parameters for creating Cross- Cloud Interconnect and associated InterconnectAttachments. Corresponds to the JSON property constraints



34038
34039
34040
# File 'lib/google/apis/compute_beta/classes.rb', line 34038

def constraints
  @constraints
end

#continentString

Output only. [Output Only] Continent for this location, which can take one of the following values:

  • AFRICA
  • ASIA_PAC
  • EUROPE
  • NORTH_AMERICA
  • SOUTH_AMERICA Corresponds to the JSON property continent

Returns:

  • (String)


34051
34052
34053
# File 'lib/google/apis/compute_beta/classes.rb', line 34051

def continent
  @continent
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


34057
34058
34059
# File 'lib/google/apis/compute_beta/classes.rb', line 34057

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Output only. [Output Only] An optional description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


34062
34063
34064
# File 'lib/google/apis/compute_beta/classes.rb', line 34062

def description
  @description
end

#facility_providerString

Output only. [Output Only] The name of the provider for this facility (e.g., EQUINIX). Corresponds to the JSON property facilityProvider

Returns:

  • (String)


34068
34069
34070
# File 'lib/google/apis/compute_beta/classes.rb', line 34068

def facility_provider
  @facility_provider
end

#facility_provider_facility_idString

Output only. [Output Only] A provider-assigned Identifier for this facility (e. g., Ashburn-DC1). Corresponds to the JSON property facilityProviderFacilityId

Returns:

  • (String)


34075
34076
34077
# File 'lib/google/apis/compute_beta/classes.rb', line 34075

def facility_provider_facility_id
  @facility_provider_facility_id
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34082
34083
34084
# File 'lib/google/apis/compute_beta/classes.rb', line 34082

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# interconnectRemoteLocation for interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


34089
34090
34091
# File 'lib/google/apis/compute_beta/classes.rb', line 34089

def kind
  @kind
end

#lacpString

Output only. [Output Only] Link Aggregation Control Protocol (LACP) constraints, which can take one of the following values: LACP_SUPPORTED, LACP_UNSUPPORTED Corresponds to the JSON property lacp

Returns:

  • (String)


34096
34097
34098
# File 'lib/google/apis/compute_beta/classes.rb', line 34096

def lacp
  @lacp
end

#max_lag_size100_gbpsFixnum

Output only. [Output Only] The maximum number of 100 Gbps ports supported in a link aggregation group (LAG). When linkType is 100 Gbps, requestedLinkCount cannot exceed max_lag_size_100_gbps. Corresponds to the JSON property maxLagSize100Gbps

Returns:

  • (Fixnum)


34104
34105
34106
# File 'lib/google/apis/compute_beta/classes.rb', line 34104

def max_lag_size100_gbps
  @max_lag_size100_gbps
end

#max_lag_size10_gbpsFixnum

Output only. [Output Only] The maximum number of 10 Gbps ports supported in a link aggregation group (LAG). When linkType is 10 Gbps, requestedLinkCount cannot exceed max_lag_size_10_gbps. Corresponds to the JSON property maxLagSize10Gbps

Returns:

  • (Fixnum)


34112
34113
34114
# File 'lib/google/apis/compute_beta/classes.rb', line 34112

def max_lag_size10_gbps
  @max_lag_size10_gbps
end

#max_lag_size400_gbpsFixnum

Output only. [Output Only] The maximum number of 400 Gbps ports supported in a link aggregation group (LAG). When linkType is 400 Gbps, requestedLinkCount cannot exceed max_lag_size_400_gbps. Corresponds to the JSON property maxLagSize400Gbps

Returns:

  • (Fixnum)


34120
34121
34122
# File 'lib/google/apis/compute_beta/classes.rb', line 34120

def max_lag_size400_gbps
  @max_lag_size400_gbps
end

#nameString

Output only. [Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


34125
34126
34127
# File 'lib/google/apis/compute_beta/classes.rb', line 34125

def name
  @name
end

#peeringdb_facility_idString

Output only. [Output Only] The peeringdb identifier for this facility ( corresponding with a netfac type in peeringdb). Corresponds to the JSON property peeringdbFacilityId

Returns:

  • (String)


34132
34133
34134
# File 'lib/google/apis/compute_beta/classes.rb', line 34132

def peeringdb_facility_id
  @peeringdb_facility_id
end

#permitted_connectionsArray<Google::Apis::ComputeBeta::InterconnectRemoteLocationPermittedConnections>

Output only. [Output Only] Permitted connections. Corresponds to the JSON property permittedConnections



34137
34138
34139
# File 'lib/google/apis/compute_beta/classes.rb', line 34137

def permitted_connections
  @permitted_connections
end

#remote_serviceString

Output only. [Output Only] Indicates the service provider present at the remote location. Example values: "Amazon Web Services", "Microsoft Azure". Corresponds to the JSON property remoteService

Returns:

  • (String)


34144
34145
34146
# File 'lib/google/apis/compute_beta/classes.rb', line 34144

def remote_service
  @remote_service
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34149
34150
34151
# File 'lib/google/apis/compute_beta/classes.rb', line 34149

def self_link
  @self_link
end

#statusString

Output only. [Output Only] The status of this InterconnectRemoteLocation, which can take one of the following values:

  • CLOSED: The InterconnectRemoteLocation is closed and is unavailable for provisioning new Cross-Cloud Interconnects.
  • AVAILABLE: The InterconnectRemoteLocation is available for provisioning new Cross-Cloud Interconnects. Corresponds to the JSON property status

Returns:

  • (String)


34162
34163
34164
# File 'lib/google/apis/compute_beta/classes.rb', line 34162

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34169
34170
34171
34172
34173
34174
34175
34176
34177
34178
34179
34180
34181
34182
34183
34184
34185
34186
34187
34188
34189
34190
34191
# File 'lib/google/apis/compute_beta/classes.rb', line 34169

def update!(**args)
  @address = args[:address] if args.key?(:address)
  @attachment_configuration_constraints = args[:attachment_configuration_constraints] if args.key?(:attachment_configuration_constraints)
  @city = args[:city] if args.key?(:city)
  @constraints = args[:constraints] if args.key?(:constraints)
  @continent = args[:continent] if args.key?(:continent)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @facility_provider = args[:facility_provider] if args.key?(:facility_provider)
  @facility_provider_facility_id = args[:facility_provider_facility_id] if args.key?(:facility_provider_facility_id)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @lacp = args[:lacp] if args.key?(:lacp)
  @max_lag_size100_gbps = args[:max_lag_size100_gbps] if args.key?(:max_lag_size100_gbps)
  @max_lag_size10_gbps = args[:max_lag_size10_gbps] if args.key?(:max_lag_size10_gbps)
  @max_lag_size400_gbps = args[:max_lag_size400_gbps] if args.key?(:max_lag_size400_gbps)
  @name = args[:name] if args.key?(:name)
  @peeringdb_facility_id = args[:peeringdb_facility_id] if args.key?(:peeringdb_facility_id)
  @permitted_connections = args[:permitted_connections] if args.key?(:permitted_connections)
  @remote_service = args[:remote_service] if args.key?(:remote_service)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
end