Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::InterconnectRemoteLocationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response to the list request, and contains a list of interconnect remote locations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ InterconnectRemoteLocationList
constructor
A new instance of InterconnectRemoteLocationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ InterconnectRemoteLocationList
Returns a new instance of InterconnectRemoteLocationList.
35164 35165 35166 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35130 35131 35132 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35130 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InterconnectRemoteLocation>
A list of InterconnectRemoteLocation resources.
Corresponds to the JSON property items
35135 35136 35137 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35135 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
interconnectRemoteLocationList for lists of
interconnect remote locations.
Corresponds to the JSON property kind
35142 35143 35144 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35142 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token lets you get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35152 35153 35154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35152 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35157 35158 35159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35157 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35162 35163 35164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35162 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35169 35170 35171 35172 35173 35174 35175 35176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35169 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |