Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



34949
34950
34951
# File 'lib/google/apis/compute_beta/classes.rb', line 34949

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34915
34916
34917
# File 'lib/google/apis/compute_beta/classes.rb', line 34915

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



34920
34921
34922
# File 'lib/google/apis/compute_beta/classes.rb', line 34920

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


34927
34928
34929
# File 'lib/google/apis/compute_beta/classes.rb', line 34927

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34937
34938
34939
# File 'lib/google/apis/compute_beta/classes.rb', line 34937

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34942
34943
34944
# File 'lib/google/apis/compute_beta/classes.rb', line 34942

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34947
34948
34949
# File 'lib/google/apis/compute_beta/classes.rb', line 34947

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34954
34955
34956
34957
34958
34959
34960
34961
# File 'lib/google/apis/compute_beta/classes.rb', line 34954

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end