Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



34889
34890
34891
# File 'lib/google/apis/compute_beta/classes.rb', line 34889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34855
34856
34857
# File 'lib/google/apis/compute_beta/classes.rb', line 34855

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



34860
34861
34862
# File 'lib/google/apis/compute_beta/classes.rb', line 34860

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


34867
34868
34869
# File 'lib/google/apis/compute_beta/classes.rb', line 34867

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34877
34878
34879
# File 'lib/google/apis/compute_beta/classes.rb', line 34877

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34882
34883
34884
# File 'lib/google/apis/compute_beta/classes.rb', line 34882

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34887
34888
34889
# File 'lib/google/apis/compute_beta/classes.rb', line 34887

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34894
34895
34896
34897
34898
34899
34900
34901
# File 'lib/google/apis/compute_beta/classes.rb', line 34894

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end