Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



34314
34315
34316
# File 'lib/google/apis/compute_beta/classes.rb', line 34314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34280
34281
34282
# File 'lib/google/apis/compute_beta/classes.rb', line 34280

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



34285
34286
34287
# File 'lib/google/apis/compute_beta/classes.rb', line 34285

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


34292
34293
34294
# File 'lib/google/apis/compute_beta/classes.rb', line 34292

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34302
34303
34304
# File 'lib/google/apis/compute_beta/classes.rb', line 34302

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34307
34308
34309
# File 'lib/google/apis/compute_beta/classes.rb', line 34307

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34312
34313
34314
# File 'lib/google/apis/compute_beta/classes.rb', line 34312

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34319
34320
34321
34322
34323
34324
34325
34326
# File 'lib/google/apis/compute_beta/classes.rb', line 34319

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end