Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



32923
32924
32925
# File 'lib/google/apis/compute_beta/classes.rb', line 32923

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


32889
32890
32891
# File 'lib/google/apis/compute_beta/classes.rb', line 32889

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



32894
32895
32896
# File 'lib/google/apis/compute_beta/classes.rb', line 32894

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


32901
32902
32903
# File 'lib/google/apis/compute_beta/classes.rb', line 32901

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


32911
32912
32913
# File 'lib/google/apis/compute_beta/classes.rb', line 32911

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32916
32917
32918
# File 'lib/google/apis/compute_beta/classes.rb', line 32916

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



32921
32922
32923
# File 'lib/google/apis/compute_beta/classes.rb', line 32921

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32928
32929
32930
32931
32932
32933
32934
32935
# File 'lib/google/apis/compute_beta/classes.rb', line 32928

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end