Class: Google::Apis::ComputeBeta::InterconnectRemoteLocationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response to the list request, and contains a list of interconnect remote locations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InterconnectRemoteLocationList

Returns a new instance of InterconnectRemoteLocationList.



31950
31951
31952
# File 'lib/google/apis/compute_beta/classes.rb', line 31950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


31916
31917
31918
# File 'lib/google/apis/compute_beta/classes.rb', line 31916

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InterconnectRemoteLocation>

A list of InterconnectRemoteLocation resources. Corresponds to the JSON property items



31921
31922
31923
# File 'lib/google/apis/compute_beta/classes.rb', line 31921

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# interconnectRemoteLocationList for lists of interconnect remote locations. Corresponds to the JSON property kind

Returns:

  • (String)


31928
31929
31930
# File 'lib/google/apis/compute_beta/classes.rb', line 31928

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token lets you get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


31938
31939
31940
# File 'lib/google/apis/compute_beta/classes.rb', line 31938

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


31943
31944
31945
# File 'lib/google/apis/compute_beta/classes.rb', line 31943

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::InterconnectRemoteLocationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



31948
31949
31950
# File 'lib/google/apis/compute_beta/classes.rb', line 31948

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



31955
31956
31957
31958
31959
31960
31961
31962
# File 'lib/google/apis/compute_beta/classes.rb', line 31955

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end