Class: Google::Apis::ComputeBeta::Interval
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Interval
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a time interval, encoded as a Timestamp start (inclusive) and a Timestamp end (exclusive). The start must be less than or equal to the end. When the start equals the end, the interval is empty (matches no time). When both start and end are unspecified, the interval matches any time.
Instance Attribute Summary collapse
-
#end_time ⇒ String
Optional.
-
#start_time ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Interval
constructor
A new instance of Interval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Interval
Returns a new instance of Interval.
35075 35076 35077 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_time ⇒ String
Optional. Exclusive end of the interval.
If specified, a Timestamp matching this interval will have to be before the
end.
Corresponds to the JSON property endTime
35066 35067 35068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35066 def end_time @end_time end |
#start_time ⇒ String
Optional. Inclusive start of the interval.
If specified, a Timestamp matching this interval will have to be the same
or after the start.
Corresponds to the JSON property startTime
35073 35074 35075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35073 def start_time @start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35080 35081 35082 35083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35080 def update!(**args) @end_time = args[:end_time] if args.key?(:end_time) @start_time = args[:start_time] if args.key?(:start_time) end |