Class: Google::Apis::ComputeBeta::LicenseCode
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::LicenseCode
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license.
-
#appendable_to_disk ⇒ Boolean
(also: #appendable_to_disk?)
If true, this license can be appended to an existing disk's set of licenses.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
-
#kind ⇒ String
Output only.
-
#license_alias ⇒ Array<Google::Apis::ComputeBeta::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#minimum_retention ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#multi_tenant_only ⇒ Boolean
(also: #multi_tenant_only?)
If true, this license can only be used on VMs on multi tenant nodes.
-
#name ⇒ String
Output only.
-
#os_license ⇒ Boolean
(also: #os_license?)
If true, indicates this is an OS license.
-
#removable_from_disk ⇒ Boolean
(also: #removable_from_disk?)
If true, this license can be removed from a disk's set of licenses, with no replacement license needed.
-
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that satisfy the coattachment requirement of this license.
-
#self_link ⇒ String
Output only.
-
#sole_tenant_only ⇒ Boolean
(also: #sole_tenant_only?)
If true, this license can only be used on VMs on sole tenant nodes.
-
#state ⇒ String
Output only.
-
#transferable ⇒ Boolean
(also: #transferable?)
Output only.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicenseCode
constructor
A new instance of LicenseCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicenseCode
Returns a new instance of LicenseCode.
35345 35346 35347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35345 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_replacement_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that can replace this license. Note:
such replacements are allowed even if removable_from_disk is false.
Corresponds to the JSON property allowedReplacementLicenses
35227 35228 35229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35227 def allowed_replacement_licenses @allowed_replacement_licenses end |
#appendable_to_disk ⇒ Boolean Also known as: appendable_to_disk?
If true, this license can be appended to an existing disk's set of
licenses.
Corresponds to the JSON property appendableToDisk
35233 35234 35235 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35233 def appendable_to_disk @appendable_to_disk end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
35240 35241 35242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35240 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] Description of this License Code.
Corresponds to the JSON property description
35245 35246 35247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35245 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
35252 35253 35254 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35252 def id @id end |
#incompatible_licenses ⇒ Array<String>
Specifies licenseCodes of licenses that are incompatible with this license.
If a license is incompatible with this license, it cannot be attached to
the same disk or image.
Corresponds to the JSON property incompatibleLicenses
35259 35260 35261 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35259 def incompatible_licenses @incompatible_licenses end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#licenseCode for
licenses.
Corresponds to the JSON property kind
35265 35266 35267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35265 def kind @kind end |
#license_alias ⇒ Array<Google::Apis::ComputeBeta::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same
License Code.
Corresponds to the JSON property licenseAlias
35271 35272 35273 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35271 def license_alias @license_alias end |
#minimum_retention ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property minimumRetention
35279 35280 35281 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35279 def minimum_retention @minimum_retention end |
#multi_tenant_only ⇒ Boolean Also known as: multi_tenant_only?
If true, this license can only be used on VMs on multi tenant nodes.
Corresponds to the JSON property multiTenantOnly
35284 35285 35286 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35284 def multi_tenant_only @multi_tenant_only end |
#name ⇒ String
Output only. [Output Only] Name of the resource. The name is 1-20 characters
long and
must be a valid 64 bit integer.
Corresponds to the JSON property name
35292 35293 35294 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35292 def name @name end |
#os_license ⇒ Boolean Also known as: os_license?
If true, indicates this is an OS license. Only one OS license can be
attached to a disk or image at a time.
Corresponds to the JSON property osLicense
35298 35299 35300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35298 def os_license @os_license end |
#removable_from_disk ⇒ Boolean Also known as: removable_from_disk?
If true, this license can be removed from a disk's set of licenses, with no
replacement license needed.
Corresponds to the JSON property removableFromDisk
35305 35306 35307 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35305 def removable_from_disk @removable_from_disk end |
#required_coattached_licenses ⇒ Array<String>
Specifies the set of permissible coattached licenseCodes of licenses that
satisfy the coattachment requirement of this license. At least one license
from the set must be attached to the same disk or image as this license.
Corresponds to the JSON property requiredCoattachedLicenses
35313 35314 35315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35313 def required_coattached_licenses @required_coattached_licenses end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
35318 35319 35320 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35318 def self_link @self_link end |
#sole_tenant_only ⇒ Boolean Also known as: sole_tenant_only?
If true, this license can only be used on VMs on sole tenant nodes.
Corresponds to the JSON property soleTenantOnly
35323 35324 35325 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35323 def sole_tenant_only @sole_tenant_only end |
#state ⇒ String
Output only. [Output Only] Current state of this License Code.
Corresponds to the JSON property state
35329 35330 35331 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35329 def state @state end |
#transferable ⇒ Boolean Also known as: transferable?
Output only. [Output Only] If true, the license will remain attached when
creating
images or snapshots from disks. Otherwise, the license is not transferred.
Corresponds to the JSON property transferable
35336 35337 35338 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35336 def transferable @transferable end |
#update_timestamp ⇒ String
Output only. [Output Only] Last update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
35343 35344 35345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35343 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35350 35351 35352 35353 35354 35355 35356 35357 35358 35359 35360 35361 35362 35363 35364 35365 35366 35367 35368 35369 35370 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35350 def update!(**args) @allowed_replacement_licenses = args[:allowed_replacement_licenses] if args.key?(:allowed_replacement_licenses) @appendable_to_disk = args[:appendable_to_disk] if args.key?(:appendable_to_disk) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @incompatible_licenses = args[:incompatible_licenses] if args.key?(:incompatible_licenses) @kind = args[:kind] if args.key?(:kind) @license_alias = args[:license_alias] if args.key?(:license_alias) @minimum_retention = args[:minimum_retention] if args.key?(:minimum_retention) @multi_tenant_only = args[:multi_tenant_only] if args.key?(:multi_tenant_only) @name = args[:name] if args.key?(:name) @os_license = args[:os_license] if args.key?(:os_license) @removable_from_disk = args[:removable_from_disk] if args.key?(:removable_from_disk) @required_coattached_licenses = args[:required_coattached_licenses] if args.key?(:required_coattached_licenses) @self_link = args[:self_link] if args.key?(:self_link) @sole_tenant_only = args[:sole_tenant_only] if args.key?(:sole_tenant_only) @state = args[:state] if args.key?(:state) @transferable = args[:transferable] if args.key?(:transferable) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |