Class: Google::Apis::ComputeBeta::LicenseCode
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::LicenseCode
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#license_alias ⇒ Array<Google::Apis::ComputeBeta::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same License Code.
-
#name ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#transferable ⇒ Boolean
(also: #transferable?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicenseCode
constructor
A new instance of LicenseCode.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicenseCode
Returns a new instance of LicenseCode.
34129 34130 34131 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
34078 34079 34080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34078 def @creation_timestamp end |
#description ⇒ String
Output only. [Output Only] Description of this License Code.
Corresponds to the JSON property description
34083 34084 34085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34083 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
34090 34091 34092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34090 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#licenseCode for
licenses.
Corresponds to the JSON property kind
34096 34097 34098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34096 def kind @kind end |
#license_alias ⇒ Array<Google::Apis::ComputeBeta::LicenseCodeLicenseAlias>
[Output Only] URL and description aliases of Licenses with the same
License Code.
Corresponds to the JSON property licenseAlias
34102 34103 34104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34102 def license_alias @license_alias end |
#name ⇒ String
Output only. [Output Only] Name of the resource. The name is 1-20 characters
long and
must be a valid 64 bit integer.
Corresponds to the JSON property name
34109 34110 34111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34109 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
34114 34115 34116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34114 def self_link @self_link end |
#state ⇒ String
Output only. [Output Only] Current state of this License Code.
Corresponds to the JSON property state
34119 34120 34121 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34119 def state @state end |
#transferable ⇒ Boolean Also known as: transferable?
Output only. [Output Only] If true, the license will remain attached when
creating
images or snapshots from disks. Otherwise, the license is not transferred.
Corresponds to the JSON property transferable
34126 34127 34128 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34126 def transferable @transferable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34134 34135 34136 34137 34138 34139 34140 34141 34142 34143 34144 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34134 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @license_alias = args[:license_alias] if args.key?(:license_alias) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @state = args[:state] if args.key?(:state) @transferable = args[:transferable] if args.key?(:transferable) end |