Class: Google::Apis::ComputeBeta::LicenseCode

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a License Code resource. A License Code is a unique identifier used to represent alicense resource. Caution This resource is intended for use only by third-party partners who are creatingCloud Marketplace images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicenseCode

Returns a new instance of LicenseCode.



32346
32347
32348
# File 'lib/google/apis/compute_beta/classes.rb', line 32346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


32295
32296
32297
# File 'lib/google/apis/compute_beta/classes.rb', line 32295

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Output only. [Output Only] Description of this License Code. Corresponds to the JSON property description

Returns:

  • (String)


32300
32301
32302
# File 'lib/google/apis/compute_beta/classes.rb', line 32300

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32307
32308
32309
# File 'lib/google/apis/compute_beta/classes.rb', line 32307

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Always compute#licenseCode for licenses. Corresponds to the JSON property kind

Returns:

  • (String)


32313
32314
32315
# File 'lib/google/apis/compute_beta/classes.rb', line 32313

def kind
  @kind
end

#license_aliasArray<Google::Apis::ComputeBeta::LicenseCodeLicenseAlias>

[Output Only] URL and description aliases of Licenses with the same License Code. Corresponds to the JSON property licenseAlias



32319
32320
32321
# File 'lib/google/apis/compute_beta/classes.rb', line 32319

def license_alias
  @license_alias
end

#nameString

Output only. [Output Only] Name of the resource. The name is 1-20 characters long and must be a valid 64 bit integer. Corresponds to the JSON property name

Returns:

  • (String)


32326
32327
32328
# File 'lib/google/apis/compute_beta/classes.rb', line 32326

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


32331
32332
32333
# File 'lib/google/apis/compute_beta/classes.rb', line 32331

def self_link
  @self_link
end

#stateString

Output only. [Output Only] Current state of this License Code. Corresponds to the JSON property state

Returns:

  • (String)


32336
32337
32338
# File 'lib/google/apis/compute_beta/classes.rb', line 32336

def state
  @state
end

#transferableBoolean Also known as: transferable?

Output only. [Output Only] If true, the license will remain attached when creating images or snapshots from disks. Otherwise, the license is not transferred. Corresponds to the JSON property transferable

Returns:

  • (Boolean)


32343
32344
32345
# File 'lib/google/apis/compute_beta/classes.rb', line 32343

def transferable
  @transferable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32351
32352
32353
32354
32355
32356
32357
32358
32359
32360
32361
# File 'lib/google/apis/compute_beta/classes.rb', line 32351

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @license_alias = args[:license_alias] if args.key?(:license_alias)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @state = args[:state] if args.key?(:state)
  @transferable = args[:transferable] if args.key?(:transferable)
end