Class: Google::Apis::ComputeBeta::LicensesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::LicensesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::License>
A list of License resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::LicensesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicensesListResponse
constructor
A new instance of LicensesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicensesListResponse
Returns a new instance of LicensesListResponse.
35831 35832 35833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35804 35805 35806 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35804 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::License>
A list of License resources.
Corresponds to the JSON property items
35809 35810 35811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35809 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35819 35820 35821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35819 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35824 35825 35826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35824 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::LicensesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35829 35830 35831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35829 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35836 35837 35838 35839 35840 35841 35842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35836 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |