Class: Google::Apis::ComputeBeta::LicensesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LicensesListResponse

Returns a new instance of LicensesListResponse.



35566
35567
35568
# File 'lib/google/apis/compute_beta/classes.rb', line 35566

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35539
35540
35541
# File 'lib/google/apis/compute_beta/classes.rb', line 35539

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::License>

A list of License resources. Corresponds to the JSON property items



35544
35545
35546
# File 'lib/google/apis/compute_beta/classes.rb', line 35544

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35554
35555
35556
# File 'lib/google/apis/compute_beta/classes.rb', line 35554

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35559
35560
35561
# File 'lib/google/apis/compute_beta/classes.rb', line 35559

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::LicensesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35564
35565
35566
# File 'lib/google/apis/compute_beta/classes.rb', line 35564

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35571
35572
35573
35574
35575
35576
35577
# File 'lib/google/apis/compute_beta/classes.rb', line 35571

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end