Class: Google::Apis::ComputeBeta::LicensesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::LicensesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::License>
A list of License resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::LicensesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LicensesListResponse
constructor
A new instance of LicensesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LicensesListResponse
Returns a new instance of LicensesListResponse.
35014 35015 35016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
34987 34988 34989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34987 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::License>
A list of License resources.
Corresponds to the JSON property items
34992 34993 34994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34992 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35002 35003 35004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35002 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35007 35008 35009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35007 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::LicensesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35012 35013 35014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35012 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35019 35020 35021 35022 35023 35024 35025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35019 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |