Class: Google::Apis::ComputeBeta::ListInstantSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ListInstantSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of InstantSnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInstantSnapshotGroups
constructor
A new instance of ListInstantSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInstantSnapshotGroups
Returns a new instance of ListInstantSnapshotGroups.
35700 35701 35702 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35700 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
35657 35658 35659 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35657 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35662 35663 35664 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35662 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstantSnapshotGroup>
A list of InstantSnapshotGroup resources.
Corresponds to the JSON property items
35667 35668 35669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35667 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
35672 35673 35674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35672 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35682 35683 35684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35682 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35687 35688 35689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35687 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
35693 35694 35695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35693 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ListInstantSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35698 35699 35700 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35698 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35705 35706 35707 35708 35709 35710 35711 35712 35713 35714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35705 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |