Class: Google::Apis::ComputeBeta::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



35690
35691
35692
# File 'lib/google/apis/compute_beta/classes.rb', line 35690

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35647
35648
35649
# File 'lib/google/apis/compute_beta/classes.rb', line 35647

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35652
35653
35654
# File 'lib/google/apis/compute_beta/classes.rb', line 35652

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



35657
35658
35659
# File 'lib/google/apis/compute_beta/classes.rb', line 35657

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


35662
35663
35664
# File 'lib/google/apis/compute_beta/classes.rb', line 35662

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35672
35673
35674
# File 'lib/google/apis/compute_beta/classes.rb', line 35672

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35677
35678
35679
# File 'lib/google/apis/compute_beta/classes.rb', line 35677

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35683
35684
35685
# File 'lib/google/apis/compute_beta/classes.rb', line 35683

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35688
35689
35690
# File 'lib/google/apis/compute_beta/classes.rb', line 35688

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35695
35696
35697
35698
35699
35700
35701
35702
35703
35704
# File 'lib/google/apis/compute_beta/classes.rb', line 35695

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end