Class: Google::Apis::ComputeBeta::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



35115
35116
35117
# File 'lib/google/apis/compute_beta/classes.rb', line 35115

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35072
35073
35074
# File 'lib/google/apis/compute_beta/classes.rb', line 35072

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35077
35078
35079
# File 'lib/google/apis/compute_beta/classes.rb', line 35077

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



35082
35083
35084
# File 'lib/google/apis/compute_beta/classes.rb', line 35082

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


35087
35088
35089
# File 'lib/google/apis/compute_beta/classes.rb', line 35087

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35097
35098
35099
# File 'lib/google/apis/compute_beta/classes.rb', line 35097

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35102
35103
35104
# File 'lib/google/apis/compute_beta/classes.rb', line 35102

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35108
35109
35110
# File 'lib/google/apis/compute_beta/classes.rb', line 35108

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35113
35114
35115
# File 'lib/google/apis/compute_beta/classes.rb', line 35113

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35120
35121
35122
35123
35124
35125
35126
35127
35128
35129
# File 'lib/google/apis/compute_beta/classes.rb', line 35120

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end