Class: Google::Apis::ComputeBeta::ListInstantSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstantSnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListInstantSnapshotGroups

Returns a new instance of ListInstantSnapshotGroups.



33614
33615
33616
# File 'lib/google/apis/compute_beta/classes.rb', line 33614

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


33571
33572
33573
# File 'lib/google/apis/compute_beta/classes.rb', line 33571

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


33576
33577
33578
# File 'lib/google/apis/compute_beta/classes.rb', line 33576

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstantSnapshotGroup>

A list of InstantSnapshotGroup resources. Corresponds to the JSON property items



33581
33582
33583
# File 'lib/google/apis/compute_beta/classes.rb', line 33581

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


33586
33587
33588
# File 'lib/google/apis/compute_beta/classes.rb', line 33586

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


33596
33597
33598
# File 'lib/google/apis/compute_beta/classes.rb', line 33596

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


33601
33602
33603
# File 'lib/google/apis/compute_beta/classes.rb', line 33601

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


33607
33608
33609
# File 'lib/google/apis/compute_beta/classes.rb', line 33607

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ListInstantSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



33612
33613
33614
# File 'lib/google/apis/compute_beta/classes.rb', line 33612

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33619
33620
33621
33622
33623
33624
33625
33626
33627
33628
# File 'lib/google/apis/compute_beta/classes.rb', line 33619

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end