Class: Google::Apis::ComputeBeta::ListSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ListSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of SnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SnapshotGroup>
A list of SnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ListSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSnapshotGroups
constructor
A new instance of ListSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSnapshotGroups
Returns a new instance of ListSnapshotGroups.
36102 36103 36104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36102 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
36059 36060 36061 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36059 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36064 36065 36066 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36064 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SnapshotGroup>
A list of SnapshotGroup resources.
Corresponds to the JSON property items
36069 36070 36071 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36069 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
36074 36075 36076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36074 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36084 36085 36086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36084 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36089 36090 36091 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36089 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
36095 36096 36097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36095 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ListSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36100 36101 36102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36100 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36107 36108 36109 36110 36111 36112 36113 36114 36115 36116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36107 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |