Class: Google::Apis::ComputeBeta::ListSnapshotGroups
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ListSnapshotGroups
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of SnapshotGroup resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SnapshotGroup>
A list of SnapshotGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ListSnapshotGroups::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListSnapshotGroups
constructor
A new instance of ListSnapshotGroups.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListSnapshotGroups
Returns a new instance of ListSnapshotGroups.
35887 35888 35889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
35844 35845 35846 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35844 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35849 35850 35851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35849 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SnapshotGroup>
A list of SnapshotGroup resources.
Corresponds to the JSON property items
35854 35855 35856 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35854 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
35859 35860 35861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35859 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35869 35870 35871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35869 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35874 35875 35876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35874 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
35880 35881 35882 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35880 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ListSnapshotGroups::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35885 35886 35887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35885 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35892 35893 35894 35895 35896 35897 35898 35899 35900 35901 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35892 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |