Class: Google::Apis::ComputeBeta::ListSnapshotGroups

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of SnapshotGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSnapshotGroups

Returns a new instance of ListSnapshotGroups.



35827
35828
35829
# File 'lib/google/apis/compute_beta/classes.rb', line 35827

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35784
35785
35786
# File 'lib/google/apis/compute_beta/classes.rb', line 35784

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35789
35790
35791
# File 'lib/google/apis/compute_beta/classes.rb', line 35789

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SnapshotGroup>

A list of SnapshotGroup resources. Corresponds to the JSON property items



35794
35795
35796
# File 'lib/google/apis/compute_beta/classes.rb', line 35794

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


35799
35800
35801
# File 'lib/google/apis/compute_beta/classes.rb', line 35799

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35809
35810
35811
# File 'lib/google/apis/compute_beta/classes.rb', line 35809

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35814
35815
35816
# File 'lib/google/apis/compute_beta/classes.rb', line 35814

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35820
35821
35822
# File 'lib/google/apis/compute_beta/classes.rb', line 35820

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ListSnapshotGroups::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35825
35826
35827
# File 'lib/google/apis/compute_beta/classes.rb', line 35825

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35832
35833
35834
35835
35836
35837
35838
35839
35840
35841
# File 'lib/google/apis/compute_beta/classes.rb', line 35832

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end