Class: Google::Apis::ComputeBeta::MachineImage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a machine image resource. A machine image is a Compute Engine resource that stores all the configuration, metadata, permissions, and data from one or more disks required to create a Virtual machine (VM) instance. For more information, seeMachine images.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImage

Returns a new instance of MachineImage.



32884
32885
32886
# File 'lib/google/apis/compute_beta/classes.rb', line 32884

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] The creation timestamp for this machine image inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


32739
32740
32741
# File 'lib/google/apis/compute_beta/classes.rb', line 32739

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


32745
32746
32747
# File 'lib/google/apis/compute_beta/classes.rb', line 32745

def description
  @description
end

#guest_flushBoolean Also known as: guest_flush?

[Input Only] Whether to attempt an application consistent machine image by informing the OS to prepare for the snapshot process. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


32751
32752
32753
# File 'lib/google/apis/compute_beta/classes.rb', line 32751

def guest_flush
  @guest_flush
end

#idFixnum

Output only. [Output Only] A unique identifier for this machine image. The server defines this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


32759
32760
32761
# File 'lib/google/apis/compute_beta/classes.rb', line 32759

def id
  @id
end

#instance_propertiesGoogle::Apis::ComputeBeta::InstanceProperties

[Output Only] Properties of source instance Corresponds to the JSON property instanceProperties



32764
32765
32766
# File 'lib/google/apis/compute_beta/classes.rb', line 32764

def instance_properties
  @instance_properties
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImage for machine image. Corresponds to the JSON property kind

Returns:

  • (String)


32770
32771
32772
# File 'lib/google/apis/compute_beta/classes.rb', line 32770

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this machine image, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the machine image. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


32782
32783
32784
# File 'lib/google/apis/compute_beta/classes.rb', line 32782

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this machine image. These can be later modified by the setLabels method. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


32788
32789
32790
# File 'lib/google/apis/compute_beta/classes.rb', line 32788

def labels
  @labels
end

#machine_image_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Encrypts the machine image using acustomer-supplied encryption key. After you encrypt a machine image using a customer-supplied key, you must provide the same key if you use the machine image later. For example, you must provide the encryption key when you create an instance from the encrypted machine image in a future request. Customer-supplied encryption keys do not protect access to metadata of the machine image. If you do not provide an encryption key when creating the machine image, then the machine image will be encrypted using an automatically generated key and you do not need to provide a key to use the machine image later. Corresponds to the JSON property machineImageEncryptionKey



32803
32804
32805
# File 'lib/google/apis/compute_beta/classes.rb', line 32803

def machine_image_encryption_key
  @machine_image_encryption_key
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


32814
32815
32816
# File 'lib/google/apis/compute_beta/classes.rb', line 32814

def name
  @name
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


32819
32820
32821
# File 'lib/google/apis/compute_beta/classes.rb', line 32819

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


32825
32826
32827
# File 'lib/google/apis/compute_beta/classes.rb', line 32825

def satisfies_pzs
  @satisfies_pzs
end

#saved_disksArray<Google::Apis::ComputeBeta::SavedDisk>

Output only. An array of Machine Image specific properties for disks attached to the source instance Corresponds to the JSON property savedDisks



32833
32834
32835
# File 'lib/google/apis/compute_beta/classes.rb', line 32833

def saved_disks
  @saved_disks
end

Output only. [Output Only] The URL for this machine image. The server defines this URL. Corresponds to the JSON property selfLink

Returns:

  • (String)


32839
32840
32841
# File 'lib/google/apis/compute_beta/classes.rb', line 32839

def self_link
  @self_link
end

#source_disk_encryption_keysArray<Google::Apis::ComputeBeta::SourceDiskEncryptionKey>

[Input Only] Thecustomer-supplied encryption key of the disks attached to the source instance. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKeys



32846
32847
32848
# File 'lib/google/apis/compute_beta/classes.rb', line 32846

def source_disk_encryption_keys
  @source_disk_encryption_keys
end

#source_instanceString

The source instance used to create the machine image. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


32858
32859
32860
# File 'lib/google/apis/compute_beta/classes.rb', line 32858

def source_instance
  @source_instance
end

#source_instance_propertiesGoogle::Apis::ComputeBeta::SourceInstanceProperties

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field. Corresponds to the JSON property sourceInstanceProperties



32864
32865
32866
# File 'lib/google/apis/compute_beta/classes.rb', line 32864

def source_instance_properties
  @source_instance_properties
end

#statusString

Output only. [Output Only] The status of the machine image. One of the following values:INVALID, CREATING, READY,DELETING, and UPLOADING. Corresponds to the JSON property status

Returns:

  • (String)


32870
32871
32872
# File 'lib/google/apis/compute_beta/classes.rb', line 32870

def status
  @status
end

#storage_locationsArray<String>

The regional or multi-regional Cloud Storage bucket location where themachine image is stored. Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


32877
32878
32879
# File 'lib/google/apis/compute_beta/classes.rb', line 32877

def storage_locations
  @storage_locations
end

#total_storage_bytesFixnum

Output only. [Output Only] Total size of the storage used by the machine image. Corresponds to the JSON property totalStorageBytes

Returns:

  • (Fixnum)


32882
32883
32884
# File 'lib/google/apis/compute_beta/classes.rb', line 32882

def total_storage_bytes
  @total_storage_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



32889
32890
32891
32892
32893
32894
32895
32896
32897
32898
32899
32900
32901
32902
32903
32904
32905
32906
32907
32908
32909
32910
# File 'lib/google/apis/compute_beta/classes.rb', line 32889

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @id = args[:id] if args.key?(:id)
  @instance_properties = args[:instance_properties] if args.key?(:instance_properties)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @machine_image_encryption_key = args[:machine_image_encryption_key] if args.key?(:machine_image_encryption_key)
  @name = args[:name] if args.key?(:name)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @saved_disks = args[:saved_disks] if args.key?(:saved_disks)
  @self_link = args[:self_link] if args.key?(:self_link)
  @source_disk_encryption_keys = args[:source_disk_encryption_keys] if args.key?(:source_disk_encryption_keys)
  @source_instance = args[:source_instance] if args.key?(:source_instance)
  @source_instance_properties = args[:source_instance_properties] if args.key?(:source_instance_properties)
  @status = args[:status] if args.key?(:status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
  @total_storage_bytes = args[:total_storage_bytes] if args.key?(:total_storage_bytes)
end