Class: Google::Apis::ComputeBeta::MachineImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MachineImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of machine images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MachineImage>
A list of MachineImage resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MachineImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageList
constructor
A new instance of MachineImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageList
Returns a new instance of MachineImageList.
36329 36330 36331 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36329 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36296 36297 36298 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36296 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MachineImage>
A list of MachineImage resources.
Corresponds to the JSON property items
36301 36302 36303 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36301 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImagesListResponse for machine image lists.
Corresponds to the JSON property kind
36307 36308 36309 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36307 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36317 36318 36319 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36317 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36322 36323 36324 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36322 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MachineImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36327 36328 36329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36327 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36334 36335 36336 36337 36338 36339 36340 36341 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36334 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |