Class: Google::Apis::ComputeBeta::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



36319
36320
36321
# File 'lib/google/apis/compute_beta/classes.rb', line 36319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36286
36287
36288
# File 'lib/google/apis/compute_beta/classes.rb', line 36286

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



36291
36292
36293
# File 'lib/google/apis/compute_beta/classes.rb', line 36291

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


36297
36298
36299
# File 'lib/google/apis/compute_beta/classes.rb', line 36297

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36307
36308
36309
# File 'lib/google/apis/compute_beta/classes.rb', line 36307

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36312
36313
36314
# File 'lib/google/apis/compute_beta/classes.rb', line 36312

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36317
36318
36319
# File 'lib/google/apis/compute_beta/classes.rb', line 36317

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36324
36325
36326
36327
36328
36329
36330
36331
# File 'lib/google/apis/compute_beta/classes.rb', line 36324

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end