Class: Google::Apis::ComputeBeta::MachineImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MachineImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of machine images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MachineImage>
A list of MachineImage resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MachineImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageList
constructor
A new instance of MachineImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageList
Returns a new instance of MachineImageList.
36279 36280 36281 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36246 36247 36248 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36246 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MachineImage>
A list of MachineImage resources.
Corresponds to the JSON property items
36251 36252 36253 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36251 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImagesListResponse for machine image lists.
Corresponds to the JSON property kind
36257 36258 36259 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36257 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36267 36268 36269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36267 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36272 36273 36274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36272 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MachineImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36277 36278 36279 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36277 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36284 36285 36286 36287 36288 36289 36290 36291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36284 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |