Class: Google::Apis::ComputeBeta::MachineImageList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MachineImageList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of machine images.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MachineImage>
A list of MachineImage resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MachineImageList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineImageList
constructor
A new instance of MachineImageList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineImageList
Returns a new instance of MachineImageList.
35053 35054 35055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35053 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
35020 35021 35022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35020 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MachineImage>
A list of MachineImage resources.
Corresponds to the JSON property items
35025 35026 35027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35025 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
machineImagesListResponse for machine image lists.
Corresponds to the JSON property kind
35031 35032 35033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35031 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
35041 35042 35043 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35041 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
35046 35047 35048 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35046 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MachineImageList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
35051 35052 35053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35051 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
35058 35059 35060 35061 35062 35063 35064 35065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 35058 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |