Class: Google::Apis::ComputeBeta::MachineImageList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of machine images.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageList

Returns a new instance of MachineImageList.



34243
34244
34245
# File 'lib/google/apis/compute_beta/classes.rb', line 34243

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


34210
34211
34212
# File 'lib/google/apis/compute_beta/classes.rb', line 34210

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MachineImage>

A list of MachineImage resources. Corresponds to the JSON property items



34215
34216
34217
# File 'lib/google/apis/compute_beta/classes.rb', line 34215

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# machineImagesListResponse for machine image lists. Corresponds to the JSON property kind

Returns:

  • (String)


34221
34222
34223
# File 'lib/google/apis/compute_beta/classes.rb', line 34221

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


34231
34232
34233
# File 'lib/google/apis/compute_beta/classes.rb', line 34231

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34236
34237
34238
# File 'lib/google/apis/compute_beta/classes.rb', line 34236

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MachineImageList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



34241
34242
34243
# File 'lib/google/apis/compute_beta/classes.rb', line 34241

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34248
34249
34250
34251
34252
34253
34254
34255
# File 'lib/google/apis/compute_beta/classes.rb', line 34248

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end