Class: Google::Apis::ComputeBeta::MachineImageParams

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Machine Image parameters

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineImageParams

Returns a new instance of MachineImageParams.



34344
34345
34346
# File 'lib/google/apis/compute_beta/classes.rb', line 34344

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#resource_manager_tagsHash<String,String>

Input only. Resource manager tags to be bound to the machine image. Tag keys and values have the same definition as resource manager tags. Keys and values can be either in numeric format, such as tagKeys/tag_key_idand `tagValues/`tag_value_id or in namespaced format such as org_id|project_id`/`tag_key_short_name and tag_value_short_name. The field is ignored (both PUT & PATCH) when empty. Corresponds to the JSON property resourceManagerTags

Returns:

  • (Hash<String,String>)


34342
34343
34344
# File 'lib/google/apis/compute_beta/classes.rb', line 34342

def resource_manager_tags
  @resource_manager_tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34349
34350
34351
# File 'lib/google/apis/compute_beta/classes.rb', line 34349

def update!(**args)
  @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags)
end