Class: Google::Apis::ComputeBeta::MachineType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MachineType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Machine Type resource. You can use specific machine types for your VM instances based on performance and pricing requirements. For more information, readMachine Types.
Defined Under Namespace
Classes: Accelerator
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ComputeBeta::MachineType::Accelerator>
[Output Only] A list of accelerator configurations assigned to this machine type.
-
#architecture ⇒ String
[Output Only] The architecture of the machine type.
-
#bundled_local_ssds ⇒ Google::Apis::ComputeBeta::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the instance.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#is_shared_cpu ⇒ Boolean
(also: #is_shared_cpu?)
[Output Only] Whether this machine type has a shared CPU.
-
#kind ⇒ String
Output only.
-
#maximum_persistent_disks ⇒ Fixnum
[Output Only] Maximum persistent disks allowed.
-
#maximum_persistent_disks_size_gb ⇒ Fixnum
[Output Only] Maximum total persistent disks size (GB) allowed.
-
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the instance, defined in MB.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ String
[Output Only] The name of the zone where the machine type resides, such as us-central1-a.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineType
constructor
A new instance of MachineType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineType
Returns a new instance of MachineType.
33134 33135 33136 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ComputeBeta::MachineType::Accelerator>
[Output Only] A list of accelerator configurations assigned to this
machine type.
Corresponds to the JSON property accelerators
33048 33049 33050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33048 def accelerators @accelerators end |
#architecture ⇒ String
[Output Only] The architecture of the machine type.
Corresponds to the JSON property architecture
33053 33054 33055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33053 def architecture @architecture end |
#bundled_local_ssds ⇒ Google::Apis::ComputeBeta::BundledLocalSsds
[Output Only] The configuration of bundled local SSD for the machine type.
Corresponds to the JSON property bundledLocalSsds
33058 33059 33060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33058 def bundled_local_ssds @bundled_local_ssds end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
33064 33065 33066 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33064 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
33069 33070 33071 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33069 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional textual description of the resource.
Corresponds to the JSON property description
33074 33075 33076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33074 def description @description end |
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the
instance.
Corresponds to the JSON property guestCpus
33080 33081 33082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33080 def guest_cpus @guest_cpus end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
33086 33087 33088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33086 def id @id end |
#is_shared_cpu ⇒ Boolean Also known as:
[Output Only] Whether this machine type has a shared CPU. SeeShared-core
machine
types for more information.
Corresponds to the JSON property isSharedCpu
33093 33094 33095 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33093 def is_shared_cpu @is_shared_cpu end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#machineType
for machine types.
Corresponds to the JSON property kind
33100 33101 33102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33100 def kind @kind end |
#maximum_persistent_disks ⇒ Fixnum
[Output Only] Maximum persistent disks allowed.
Corresponds to the JSON property maximumPersistentDisks
33105 33106 33107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33105 def maximum_persistent_disks @maximum_persistent_disks end |
#maximum_persistent_disks_size_gb ⇒ Fixnum
[Output Only] Maximum total persistent disks size (GB) allowed.
Corresponds to the JSON property maximumPersistentDisksSizeGb
33110 33111 33112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33110 def maximum_persistent_disks_size_gb @maximum_persistent_disks_size_gb end |
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the instance,
defined in MB.
Corresponds to the JSON property memoryMb
33116 33117 33118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33116 def memory_mb @memory_mb end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
33121 33122 33123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33121 def name @name end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
33126 33127 33128 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33126 def self_link @self_link end |
#zone ⇒ String
[Output Only] The name of the zone where the machine type resides,
such as us-central1-a.
Corresponds to the JSON property zone
33132 33133 33134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33132 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33139 33140 33141 33142 33143 33144 33145 33146 33147 33148 33149 33150 33151 33152 33153 33154 33155 33156 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33139 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @architecture = args[:architecture] if args.key?(:architecture) @bundled_local_ssds = args[:bundled_local_ssds] if args.key?(:bundled_local_ssds) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus) @id = args[:id] if args.key?(:id) @is_shared_cpu = args[:is_shared_cpu] if args.key?(:is_shared_cpu) @kind = args[:kind] if args.key?(:kind) @maximum_persistent_disks = args[:maximum_persistent_disks] if args.key?(:maximum_persistent_disks) @maximum_persistent_disks_size_gb = args[:maximum_persistent_disks_size_gb] if args.key?(:maximum_persistent_disks_size_gb) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |