Class: Google::Apis::ComputeBeta::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A Managed Instance resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeBeta::ManagedInstanceAllInstancesConfig
Output only.
-
#current_action ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#instance ⇒ String
Output only.
-
#instance_health ⇒ Array<Google::Apis::ComputeBeta::ManagedInstanceInstanceHealth>
Output only.
-
#instance_status ⇒ String
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeBeta::ManagedInstanceLastAttempt
Output only.
-
#name ⇒ String
Output only.
-
#preserved_state_from_config ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
-
#preserved_state_from_policy ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
-
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
Output only.
-
#scheduling ⇒ Google::Apis::ComputeBeta::ManagedInstanceScheduling
Output only.
-
#shutdown_details ⇒ Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
Output only.
-
#target_status ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
37129 37130 37131 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37129 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeBeta::ManagedInstanceAllInstancesConfig
Output only. [Output Only] Current all-instances configuration revision
applied to this
instance.
Corresponds to the JSON property allInstancesConfig
37013 37014 37015 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37013 def all_instances_config @all_instances_config end |
#current_action ⇒ String
Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- VERIFYING The managed instance group has created the
instance and it is in the process of being verified.
Corresponds to the JSON property
currentAction
37045 37046 37047 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37045 def current_action @current_action end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource. This field
is empty
when instance does not exist.
Corresponds to the JSON property id
37052 37053 37054 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37052 def id @id end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance. The URL can exist even if
the
instance has not yet been created.
Corresponds to the JSON property instance
37059 37060 37061 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37059 def instance @instance end |
#instance_health ⇒ Array<Google::Apis::ComputeBeta::ManagedInstanceInstanceHealth>
Output only. [Output Only] Health state of the instance per health-check.
Corresponds to the JSON property instanceHealth
37064 37065 37066 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37064 def instance_health @instance_health end |
#instance_status ⇒ String
Output only. [Output Only] The status of the instance. This field is empty
when
the instance does not exist.
Corresponds to the JSON property instanceStatus
37071 37072 37073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37071 def instance_status @instance_status end |
#last_attempt ⇒ Google::Apis::ComputeBeta::ManagedInstanceLastAttempt
Output only. [Output Only] Information about the last attempt to create or
delete
the instance.
Corresponds to the JSON property lastAttempt
37078 37079 37080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37078 def last_attempt @last_attempt end |
#name ⇒ String
Output only. [Output Only] The name of the instance. The name always exists
even if the
instance has not yet been created.
Corresponds to the JSON property name
37085 37086 37087 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37085 def name @name end |
#preserved_state_from_config ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromConfig
37090 37091 37092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37090 def preserved_state_from_config @preserved_state_from_config end |
#preserved_state_from_policy ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromPolicy
37095 37096 37097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37095 def preserved_state_from_policy @preserved_state_from_policy end |
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
Output only. [Output Only] Instance properties selected for this instance
resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property propertiesFromFlexibilityPolicy
37102 37103 37104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37102 def properties_from_flexibility_policy @properties_from_flexibility_policy end |
#scheduling ⇒ Google::Apis::ComputeBeta::ManagedInstanceScheduling
Output only. Information about the termination timestamp of the instance, if
applicable.
Corresponds to the JSON property scheduling
37108 37109 37110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37108 def scheduling @scheduling end |
#shutdown_details ⇒ Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
Output only. Specifies the graceful shutdown details if the instance is in
PENDING_STOP state or there is a programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
37114 37115 37116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37114 def shutdown_details @shutdown_details end |
#target_status ⇒ String
Output only. [Output Only] The eventual status of the instance. The instance
group
manager will not be identified as stable till each managed instance reaches
its targetStatus.
Corresponds to the JSON property targetStatus
37122 37123 37124 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37122 def target_status @target_status end |
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only. [Output Only] Intended version of this instance.
Corresponds to the JSON property version
37127 37128 37129 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37127 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37134 37135 37136 37137 37138 37139 37140 37141 37142 37143 37144 37145 37146 37147 37148 37149 37150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37134 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @current_action = args[:current_action] if args.key?(:current_action) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_health = args[:instance_health] if args.key?(:instance_health) @instance_status = args[:instance_status] if args.key?(:instance_status) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @name = args[:name] if args.key?(:name) @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config) @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy) @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy) @scheduling = args[:scheduling] if args.key?(:scheduling) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @target_status = args[:target_status] if args.key?(:target_status) @version = args[:version] if args.key?(:version) end |