Class: Google::Apis::ComputeBeta::ManagedInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A Managed Instance resource.
Instance Attribute Summary collapse
-
#all_instances_config ⇒ Google::Apis::ComputeBeta::ManagedInstanceAllInstancesConfig
Output only.
-
#current_action ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#instance ⇒ String
Output only.
-
#instance_health ⇒ Array<Google::Apis::ComputeBeta::ManagedInstanceInstanceHealth>
Output only.
-
#instance_status ⇒ String
Output only.
-
#last_attempt ⇒ Google::Apis::ComputeBeta::ManagedInstanceLastAttempt
Output only.
-
#name ⇒ String
Output only.
-
#preserved_state_from_config ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
-
#preserved_state_from_policy ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
-
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
Output only.
-
#scheduling ⇒ Google::Apis::ComputeBeta::ManagedInstanceScheduling
Output only.
-
#shutdown_details ⇒ Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
Output only.
-
#target_status ⇒ String
Output only.
-
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstance
constructor
A new instance of ManagedInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstance
Returns a new instance of ManagedInstance.
36482 36483 36484 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36482 def initialize(**args) update!(**args) end |
Instance Attribute Details
#all_instances_config ⇒ Google::Apis::ComputeBeta::ManagedInstanceAllInstancesConfig
Output only. [Output Only] Current all-instances configuration revision
applied to this
instance.
Corresponds to the JSON property allInstancesConfig
36364 36365 36366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36364 def all_instances_config @all_instances_config end |
#current_action ⇒ String
Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:
- NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
- CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
- CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
- RECREATING The managed instance group is recreating this instance.
- DELETING The managed instance group is permanently deleting this instance.
- ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
- RESTARTING The managed instance group is restarting the instance.
- REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
- VERIFYING The managed instance group has created the
instance and it is in the process of being verified.
Corresponds to the JSON property
currentAction
36396 36397 36398 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36396 def current_action @current_action end |
#id ⇒ Fixnum
Output only. [Output only] The unique identifier for this resource. This field
is empty
when instance does not exist.
Corresponds to the JSON property id
36403 36404 36405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36403 def id @id end |
#instance ⇒ String
Output only. [Output Only] The URL of the instance. The URL can exist even if
the
instance has not yet been created.
Corresponds to the JSON property instance
36410 36411 36412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36410 def instance @instance end |
#instance_health ⇒ Array<Google::Apis::ComputeBeta::ManagedInstanceInstanceHealth>
Output only. [Output Only] Health state of the instance per health-check.
Corresponds to the JSON property instanceHealth
36415 36416 36417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36415 def instance_health @instance_health end |
#instance_status ⇒ String
Output only. [Output Only] The status of the instance. This field is empty
when
the instance does not exist.
Corresponds to the JSON property instanceStatus
36422 36423 36424 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36422 def instance_status @instance_status end |
#last_attempt ⇒ Google::Apis::ComputeBeta::ManagedInstanceLastAttempt
Output only. [Output Only] Information about the last attempt to create or
delete
the instance.
Corresponds to the JSON property lastAttempt
36429 36430 36431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36429 def last_attempt @last_attempt end |
#name ⇒ String
Output only. [Output Only] The name of the instance. The name always exists
even if the
instance has not yet been created.
Corresponds to the JSON property name
36436 36437 36438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36436 def name @name end |
#preserved_state_from_config ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromConfig
36441 36442 36443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36441 def preserved_state_from_config @preserved_state_from_config end |
#preserved_state_from_policy ⇒ Google::Apis::ComputeBeta::PreservedState
Preserved state for a given instance.
Corresponds to the JSON property preservedStateFromPolicy
36446 36447 36448 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36446 def preserved_state_from_policy @preserved_state_from_policy end |
#properties_from_flexibility_policy ⇒ Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
Output only. [Output Only] Instance properties selected for this instance
resulting from
InstanceFlexibilityPolicy.
Corresponds to the JSON property propertiesFromFlexibilityPolicy
36453 36454 36455 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36453 def properties_from_flexibility_policy @properties_from_flexibility_policy end |
#scheduling ⇒ Google::Apis::ComputeBeta::ManagedInstanceScheduling
Output only. [Output Only] Information about the termination timestamp of the
instance,
if applicable.
Corresponds to the JSON property scheduling
36460 36461 36462 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36460 def scheduling @scheduling end |
#shutdown_details ⇒ Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
Output only. [Output Only] Specifies the graceful shutdown details if the
instance is in
PENDING_STOP state or there is a programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
36467 36468 36469 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36467 def shutdown_details @shutdown_details end |
#target_status ⇒ String
Output only. [Output Only] The eventual status of the instance. The instance
group
manager will not be identified as stable till each managed instance reaches
its targetStatus.
Corresponds to the JSON property targetStatus
36475 36476 36477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36475 def target_status @target_status end |
#version ⇒ Google::Apis::ComputeBeta::ManagedInstanceVersion
Output only. [Output Only] Intended version of this instance.
Corresponds to the JSON property version
36480 36481 36482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36480 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36487 36488 36489 36490 36491 36492 36493 36494 36495 36496 36497 36498 36499 36500 36501 36502 36503 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36487 def update!(**args) @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config) @current_action = args[:current_action] if args.key?(:current_action) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @instance_health = args[:instance_health] if args.key?(:instance_health) @instance_status = args[:instance_status] if args.key?(:instance_status) @last_attempt = args[:last_attempt] if args.key?(:last_attempt) @name = args[:name] if args.key?(:name) @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config) @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy) @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy) @scheduling = args[:scheduling] if args.key?(:scheduling) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @target_status = args[:target_status] if args.key?(:target_status) @version = args[:version] if args.key?(:version) end |