Class: Google::Apis::ComputeBeta::ManagedInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A Managed Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstance

Returns a new instance of ManagedInstance.



35784
35785
35786
# File 'lib/google/apis/compute_beta/classes.rb', line 35784

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::ManagedInstanceAllInstancesConfig

Output only. [Output Only] Current all-instances configuration revision applied to this instance. Corresponds to the JSON property allInstancesConfig



35673
35674
35675
# File 'lib/google/apis/compute_beta/classes.rb', line 35673

def all_instances_config
  @all_instances_config
end

#current_actionString

Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:

  • NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
  • CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
  • CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
  • RECREATING The managed instance group is recreating this instance.
  • DELETING The managed instance group is permanently deleting this instance.
  • ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
  • RESTARTING The managed instance group is restarting the instance.
  • REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
  • VERIFYING The managed instance group has created the instance and it is in the process of being verified. Corresponds to the JSON property currentAction

Returns:

  • (String)


35705
35706
35707
# File 'lib/google/apis/compute_beta/classes.rb', line 35705

def current_action
  @current_action
end

#idFixnum

Output only. [Output only] The unique identifier for this resource. This field is empty when instance does not exist. Corresponds to the JSON property id

Returns:

  • (Fixnum)


35712
35713
35714
# File 'lib/google/apis/compute_beta/classes.rb', line 35712

def id
  @id
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


35719
35720
35721
# File 'lib/google/apis/compute_beta/classes.rb', line 35719

def instance
  @instance
end

#instance_healthArray<Google::Apis::ComputeBeta::ManagedInstanceInstanceHealth>

Output only. [Output Only] Health state of the instance per health-check. Corresponds to the JSON property instanceHealth



35724
35725
35726
# File 'lib/google/apis/compute_beta/classes.rb', line 35724

def instance_health
  @instance_health
end

#instance_statusString

Output only. [Output Only] The status of the instance. This field is empty when the instance does not exist. Corresponds to the JSON property instanceStatus

Returns:

  • (String)


35731
35732
35733
# File 'lib/google/apis/compute_beta/classes.rb', line 35731

def instance_status
  @instance_status
end

#last_attemptGoogle::Apis::ComputeBeta::ManagedInstanceLastAttempt

Output only. [Output Only] Information about the last attempt to create or delete the instance. Corresponds to the JSON property lastAttempt



35738
35739
35740
# File 'lib/google/apis/compute_beta/classes.rb', line 35738

def last_attempt
  @last_attempt
end

#nameString

Output only. [Output Only] The name of the instance. The name always exists even if the instance has not yet been created. Corresponds to the JSON property name

Returns:

  • (String)


35745
35746
35747
# File 'lib/google/apis/compute_beta/classes.rb', line 35745

def name
  @name
end

#preserved_state_from_configGoogle::Apis::ComputeBeta::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromConfig



35750
35751
35752
# File 'lib/google/apis/compute_beta/classes.rb', line 35750

def preserved_state_from_config
  @preserved_state_from_config
end

#preserved_state_from_policyGoogle::Apis::ComputeBeta::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromPolicy



35755
35756
35757
# File 'lib/google/apis/compute_beta/classes.rb', line 35755

def preserved_state_from_policy
  @preserved_state_from_policy
end

#properties_from_flexibility_policyGoogle::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy

Output only. [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property propertiesFromFlexibilityPolicy



35762
35763
35764
# File 'lib/google/apis/compute_beta/classes.rb', line 35762

def properties_from_flexibility_policy
  @properties_from_flexibility_policy
end

#schedulingGoogle::Apis::ComputeBeta::ManagedInstanceScheduling

Output only. [Output Only] Information about the termination timestamp of the instance, if applicable. Corresponds to the JSON property scheduling



35769
35770
35771
# File 'lib/google/apis/compute_beta/classes.rb', line 35769

def scheduling
  @scheduling
end

#target_statusString

Output only. [Output Only] The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Corresponds to the JSON property targetStatus

Returns:

  • (String)


35777
35778
35779
# File 'lib/google/apis/compute_beta/classes.rb', line 35777

def target_status
  @target_status
end

#versionGoogle::Apis::ComputeBeta::ManagedInstanceVersion

Output only. [Output Only] Intended version of this instance. Corresponds to the JSON property version



35782
35783
35784
# File 'lib/google/apis/compute_beta/classes.rb', line 35782

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35789
35790
35791
35792
35793
35794
35795
35796
35797
35798
35799
35800
35801
35802
35803
35804
# File 'lib/google/apis/compute_beta/classes.rb', line 35789

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @current_action = args[:current_action] if args.key?(:current_action)
  @id = args[:id] if args.key?(:id)
  @instance = args[:instance] if args.key?(:instance)
  @instance_health = args[:instance_health] if args.key?(:instance_health)
  @instance_status = args[:instance_status] if args.key?(:instance_status)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @name = args[:name] if args.key?(:name)
  @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config)
  @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy)
  @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @target_status = args[:target_status] if args.key?(:target_status)
  @version = args[:version] if args.key?(:version)
end