Class: Google::Apis::ComputeBeta::ManagedInstance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A Managed Instance resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstance

Returns a new instance of ManagedInstance.



33658
33659
33660
# File 'lib/google/apis/compute_beta/classes.rb', line 33658

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instances_configGoogle::Apis::ComputeBeta::ManagedInstanceAllInstancesConfig

Output only. [Output Only] Current all-instances configuration revision applied to this instance. Corresponds to the JSON property allInstancesConfig



33547
33548
33549
# File 'lib/google/apis/compute_beta/classes.rb', line 33547

def all_instances_config
  @all_instances_config
end

#current_actionString

Output only. [Output Only] The current action that the managed instance group has scheduled for the instance. Possible values:

  • NONE The instance is running, and the managed instance group does not have any scheduled actions for this instance.
  • CREATING The managed instance group is creating this instance. If the group fails to create this instance, it will try again until it is successful.
  • CREATING_WITHOUT_RETRIES The managed instance group is attempting to create this instance only once. If the group fails to create this instance, it does not try again and the group'stargetSize value is decreased instead.
  • RECREATING The managed instance group is recreating this instance.
  • DELETING The managed instance group is permanently deleting this instance.
  • ABANDONING The managed instance group is abandoning this instance. The instance will be removed from the instance group and from any target pools that are associated with this group.
  • RESTARTING The managed instance group is restarting the instance.
  • REFRESHING The managed instance group is applying configuration changes to the instance without stopping it. For example, the group can update the target pool list for an instance without stopping that instance.
  • VERIFYING The managed instance group has created the instance and it is in the process of being verified. Corresponds to the JSON property currentAction

Returns:

  • (String)


33579
33580
33581
# File 'lib/google/apis/compute_beta/classes.rb', line 33579

def current_action
  @current_action
end

#idFixnum

Output only. [Output only] The unique identifier for this resource. This field is empty when instance does not exist. Corresponds to the JSON property id

Returns:

  • (Fixnum)


33586
33587
33588
# File 'lib/google/apis/compute_beta/classes.rb', line 33586

def id
  @id
end

#instanceString

Output only. [Output Only] The URL of the instance. The URL can exist even if the instance has not yet been created. Corresponds to the JSON property instance

Returns:

  • (String)


33593
33594
33595
# File 'lib/google/apis/compute_beta/classes.rb', line 33593

def instance
  @instance
end

#instance_healthArray<Google::Apis::ComputeBeta::ManagedInstanceInstanceHealth>

Output only. [Output Only] Health state of the instance per health-check. Corresponds to the JSON property instanceHealth



33598
33599
33600
# File 'lib/google/apis/compute_beta/classes.rb', line 33598

def instance_health
  @instance_health
end

#instance_statusString

Output only. [Output Only] The status of the instance. This field is empty when the instance does not exist. Corresponds to the JSON property instanceStatus

Returns:

  • (String)


33605
33606
33607
# File 'lib/google/apis/compute_beta/classes.rb', line 33605

def instance_status
  @instance_status
end

#last_attemptGoogle::Apis::ComputeBeta::ManagedInstanceLastAttempt

Output only. [Output Only] Information about the last attempt to create or delete the instance. Corresponds to the JSON property lastAttempt



33612
33613
33614
# File 'lib/google/apis/compute_beta/classes.rb', line 33612

def last_attempt
  @last_attempt
end

#nameString

Output only. [Output Only] The name of the instance. The name always exists even if the instance has not yet been created. Corresponds to the JSON property name

Returns:

  • (String)


33619
33620
33621
# File 'lib/google/apis/compute_beta/classes.rb', line 33619

def name
  @name
end

#preserved_state_from_configGoogle::Apis::ComputeBeta::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromConfig



33624
33625
33626
# File 'lib/google/apis/compute_beta/classes.rb', line 33624

def preserved_state_from_config
  @preserved_state_from_config
end

#preserved_state_from_policyGoogle::Apis::ComputeBeta::PreservedState

Preserved state for a given instance. Corresponds to the JSON property preservedStateFromPolicy



33629
33630
33631
# File 'lib/google/apis/compute_beta/classes.rb', line 33629

def preserved_state_from_policy
  @preserved_state_from_policy
end

#properties_from_flexibility_policyGoogle::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy

Output only. [Output Only] Instance properties selected for this instance resulting from InstanceFlexibilityPolicy. Corresponds to the JSON property propertiesFromFlexibilityPolicy



33636
33637
33638
# File 'lib/google/apis/compute_beta/classes.rb', line 33636

def properties_from_flexibility_policy
  @properties_from_flexibility_policy
end

#schedulingGoogle::Apis::ComputeBeta::ManagedInstanceScheduling

Output only. [Output Only] Information about the termination timestamp of the instance, if applicable. Corresponds to the JSON property scheduling



33643
33644
33645
# File 'lib/google/apis/compute_beta/classes.rb', line 33643

def scheduling
  @scheduling
end

#target_statusString

Output only. [Output Only] The eventual status of the instance. The instance group manager will not be identified as stable till each managed instance reaches its targetStatus. Corresponds to the JSON property targetStatus

Returns:

  • (String)


33651
33652
33653
# File 'lib/google/apis/compute_beta/classes.rb', line 33651

def target_status
  @target_status
end

#versionGoogle::Apis::ComputeBeta::ManagedInstanceVersion

Output only. [Output Only] Intended version of this instance. Corresponds to the JSON property version



33656
33657
33658
# File 'lib/google/apis/compute_beta/classes.rb', line 33656

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



33663
33664
33665
33666
33667
33668
33669
33670
33671
33672
33673
33674
33675
33676
33677
33678
# File 'lib/google/apis/compute_beta/classes.rb', line 33663

def update!(**args)
  @all_instances_config = args[:all_instances_config] if args.key?(:all_instances_config)
  @current_action = args[:current_action] if args.key?(:current_action)
  @id = args[:id] if args.key?(:id)
  @instance = args[:instance] if args.key?(:instance)
  @instance_health = args[:instance_health] if args.key?(:instance_health)
  @instance_status = args[:instance_status] if args.key?(:instance_status)
  @last_attempt = args[:last_attempt] if args.key?(:last_attempt)
  @name = args[:name] if args.key?(:name)
  @preserved_state_from_config = args[:preserved_state_from_config] if args.key?(:preserved_state_from_config)
  @preserved_state_from_policy = args[:preserved_state_from_policy] if args.key?(:preserved_state_from_policy)
  @properties_from_flexibility_policy = args[:properties_from_flexibility_policy] if args.key?(:properties_from_flexibility_policy)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @target_status = args[:target_status] if args.key?(:target_status)
  @version = args[:version] if args.key?(:version)
end