Class: Google::Apis::ComputeBeta::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ErrorDetail

Returns a new instance of ErrorDetail.



35172
35173
35174
# File 'lib/google/apis/compute_beta/classes.rb', line 35172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#error_infoGoogle::Apis::ComputeBeta::ErrorInfo

Describes the cause of the error with structured details. Example of an error when contacting the "pubsub.googleapis.com" API when it is not enabled: "reason": "API_DISABLED" "domain": "googleapis.com" "metadata": "resource": "projects/123", "service": "pubsub.googleapis.com" This response indicates that the pubsub.googleapis.com API is not enabled. Example of an error that is returned when attempting to create a Spanner instance in a region that is out of stock: "reason": "STOCKOUT" "domain": "spanner.googleapis.com", "metadata": "availableRegions": "us-central1,us-east2" Corresponds to the JSON property errorInfo



35151
35152
35153
# File 'lib/google/apis/compute_beta/classes.rb', line 35151

def error_info
  @error_info
end

#helpGoogle::Apis::ComputeBeta::Help

Provides links to documentation or for performing an out of band action. For example, if a quota check failed with an error indicating the calling project hasn't enabled the accessed service, this can contain a URL pointing directly to the right place in the developer console to flip the bit. Corresponds to the JSON property help



35159
35160
35161
# File 'lib/google/apis/compute_beta/classes.rb', line 35159

def help
  @help
end

#localized_messageGoogle::Apis::ComputeBeta::LocalizedMessage

Provides a localized error message that is safe to return to the user which can be attached to an RPC error. Corresponds to the JSON property localizedMessage



35165
35166
35167
# File 'lib/google/apis/compute_beta/classes.rb', line 35165

def localized_message
  @localized_message
end

#quota_infoGoogle::Apis::ComputeBeta::QuotaExceededInfo

Additional details for quota exceeded error for resource quota. Corresponds to the JSON property quotaInfo



35170
35171
35172
# File 'lib/google/apis/compute_beta/classes.rb', line 35170

def quota_info
  @quota_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35177
35178
35179
35180
35181
35182
# File 'lib/google/apis/compute_beta/classes.rb', line 35177

def update!(**args)
  @error_info = args[:error_info] if args.key?(:error_info)
  @help = args[:help] if args.key?(:help)
  @localized_message = args[:localized_message] if args.key?(:localized_message)
  @quota_info = args[:quota_info] if args.key?(:quota_info)
end