Class: Google::Apis::ComputeBeta::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstanceLastAttempt::Errors::Error::ErrorDetail
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#error_info ⇒ Google::Apis::ComputeBeta::ErrorInfo
Describes the cause of the error with structured details.
-
#help ⇒ Google::Apis::ComputeBeta::Help
Provides links to documentation or for performing an out of band action.
-
#localized_message ⇒ Google::Apis::ComputeBeta::LocalizedMessage
Provides a localized error message that is safe to return to the user which can be attached to an RPC error.
-
#quota_info ⇒ Google::Apis::ComputeBeta::QuotaExceededInfo
Additional details for quota exceeded error for resource quota.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorDetail
constructor
A new instance of ErrorDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorDetail
Returns a new instance of ErrorDetail.
33856 33857 33858 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33856 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error_info ⇒ Google::Apis::ComputeBeta::ErrorInfo
Describes the cause of the error with structured details.
Example of an error when contacting the "pubsub.googleapis.com" API when it
is not enabled:
"reason": "API_DISABLED"
"domain": "googleapis.com"
"metadata":
"resource": "projects/123",
"service": "pubsub.googleapis.com"
This response indicates that the pubsub.googleapis.com API is not enabled.
Example of an error that is returned when attempting to create a Spanner
instance in a region that is out of stock:
"reason": "STOCKOUT"
"domain": "spanner.googleapis.com",
"metadata":
"availableRegions": "us-central1,us-east2"
Corresponds to the JSON property errorInfo
33835 33836 33837 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33835 def error_info @error_info end |
#help ⇒ Google::Apis::ComputeBeta::Help
Provides links to documentation or for performing an out of band action.
For example, if a quota check failed with an error indicating the calling
project hasn't enabled the accessed service, this can contain a URL pointing
directly to the right place in the developer console to flip the bit.
Corresponds to the JSON property help
33843 33844 33845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33843 def help @help end |
#localized_message ⇒ Google::Apis::ComputeBeta::LocalizedMessage
Provides a localized error message that is safe to return to the user
which can be attached to an RPC error.
Corresponds to the JSON property localizedMessage
33849 33850 33851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33849 def @localized_message end |
#quota_info ⇒ Google::Apis::ComputeBeta::QuotaExceededInfo
Additional details for quota exceeded error for resource quota.
Corresponds to the JSON property quotaInfo
33854 33855 33856 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33854 def quota_info @quota_info end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33861 33862 33863 33864 33865 33866 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33861 def update!(**args) @error_info = args[:error_info] if args.key?(:error_info) @help = args[:help] if args.key?(:help) @localized_message = args[:localized_message] if args.key?(:localized_message) @quota_info = args[:quota_info] if args.key?(:quota_info) end |