Class: Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstancePropertiesFromFlexibilityPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
List of disks to be attached to the instance.
-
#machine_type ⇒ String
Output only.
-
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
-
#provisioning_model ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstancePropertiesFromFlexibilityPolicy
constructor
A new instance of ManagedInstancePropertiesFromFlexibilityPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstancePropertiesFromFlexibilityPolicy
Returns a new instance of ManagedInstancePropertiesFromFlexibilityPolicy.
33897 33898 33899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Array<Google::Apis::ComputeBeta::AttachedDisk>
List of disks to be attached to the instance.
Corresponds to the JSON property disks
33879 33880 33881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33879 def disks @disks end |
#machine_type ⇒ String
Output only. The machine type to be used for this instance.
Corresponds to the JSON property machineType
33884 33885 33886 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33884 def machine_type @machine_type end |
#min_cpu_platform ⇒ String
Name of the minimum CPU platform to be used by this instance.
e.g. 'Intel Ice Lake'.
Corresponds to the JSON property minCpuPlatform
33890 33891 33892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33890 def min_cpu_platform @min_cpu_platform end |
#provisioning_model ⇒ String
Output only. The provisioning model to be used for this instance.
Corresponds to the JSON property provisioningModel
33895 33896 33897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33895 def provisioning_model @provisioning_model end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
33902 33903 33904 33905 33906 33907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 33902 def update!(**args) @disks = args[:disks] if args.key?(:disks) @machine_type = args[:machine_type] if args.key?(:machine_type) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @provisioning_model = args[:provisioning_model] if args.key?(:provisioning_model) end |