Class: Google::Apis::ComputeBeta::ManagedInstanceScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstanceScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#graceful_shutdown_timestamp ⇒ String
Output only.
-
#termination_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceScheduling
constructor
A new instance of ManagedInstanceScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceScheduling
Returns a new instance of ManagedInstanceScheduling.
37353 37354 37355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#graceful_shutdown_timestamp ⇒ String
Output only. The timestamp at which the underlying instance will be
triggered for graceful shutdown if it is configured. This is in RFC3339 text
format.
Corresponds to the JSON property gracefulShutdownTimestamp
37343 37344 37345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37343 def @graceful_shutdown_timestamp end |
#termination_timestamp ⇒ String
Output only. The timestamp at which the managed instance will be terminated.
This is
in RFC3339 text
format.
Corresponds to the JSON property terminationTimestamp
37351 37352 37353 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37351 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37358 37359 37360 37361 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37358 def update!(**args) @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |