Class: Google::Apis::ComputeBeta::ManagedInstanceScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstanceScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#graceful_shutdown_timestamp ⇒ String
Output only.
-
#termination_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceScheduling
constructor
A new instance of ManagedInstanceScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceScheduling
Returns a new instance of ManagedInstanceScheduling.
37341 37342 37343 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37341 def initialize(**args) update!(**args) end |
Instance Attribute Details
#graceful_shutdown_timestamp ⇒ String
Output only. The timestamp at which the underlying instance will be
triggered for graceful shutdown if it is configured. This is in RFC3339 text
format.
Corresponds to the JSON property gracefulShutdownTimestamp
37331 37332 37333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37331 def @graceful_shutdown_timestamp end |
#termination_timestamp ⇒ String
Output only. The timestamp at which the managed instance will be terminated.
This is
in RFC3339 text
format.
Corresponds to the JSON property terminationTimestamp
37339 37340 37341 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37339 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37346 37347 37348 37349 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37346 def update!(**args) @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |