Class: Google::Apis::ComputeBeta::ManagedInstanceScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceScheduling

Returns a new instance of ManagedInstanceScheduling.



36800
36801
36802
# File 'lib/google/apis/compute_beta/classes.rb', line 36800

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#graceful_shutdown_timestampString

Output only. [Output Only] The timestamp at which the underlying instance will be triggered for graceful shutdown if it is configured. This is in RFC3339 text format. Corresponds to the JSON property gracefulShutdownTimestamp

Returns:

  • (String)


36792
36793
36794
# File 'lib/google/apis/compute_beta/classes.rb', line 36792

def graceful_shutdown_timestamp
  @graceful_shutdown_timestamp
end

#termination_timestampString

Output only. [Output Only] The timestamp at which the managed instance will be terminated. This is in RFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


36798
36799
36800
# File 'lib/google/apis/compute_beta/classes.rb', line 36798

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36805
36806
36807
36808
# File 'lib/google/apis/compute_beta/classes.rb', line 36805

def update!(**args)
  @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end