Class: Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ManagedInstanceShutdownDetails

Returns a new instance of ManagedInstanceShutdownDetails.



37372
37373
37374
# File 'lib/google/apis/compute_beta/classes.rb', line 37372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



37362
37363
37364
# File 'lib/google/apis/compute_beta/classes.rb', line 37362

def max_duration
  @max_duration
end

#request_timestampString

Output only. Past timestamp indicating the beginning of PENDING_STOP state of instance in RFC3339 text format. Corresponds to the JSON property requestTimestamp

Returns:

  • (String)


37370
37371
37372
# File 'lib/google/apis/compute_beta/classes.rb', line 37370

def request_timestamp
  @request_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37377
37378
37379
37380
# File 'lib/google/apis/compute_beta/classes.rb', line 37377

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp)
end