Class: Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
constructor
A new instance of ManagedInstanceShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
Returns a new instance of ManagedInstanceShutdownDetails.
37310 37311 37312 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37310 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
37301 37302 37303 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37301 def max_duration @max_duration end |
#request_timestamp ⇒ String
Output only. [Output Only] Past timestamp indicating the beginning of
PENDING_STOP
state of instance in RFC3339 text format.
Corresponds to the JSON property requestTimestamp
37308 37309 37310 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37308 def @request_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37315 37316 37317 37318 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37315 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) end |