Class: Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
constructor
A new instance of ManagedInstanceShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
Returns a new instance of ManagedInstanceShutdownDetails.
36830 36831 36832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36830 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
36821 36822 36823 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36821 def max_duration @max_duration end |
#request_timestamp ⇒ String
Output only. [Output Only] Past timestamp indicating the beginning of
PENDING_STOP
state of instance in RFC3339 text format.
Corresponds to the JSON property requestTimestamp
36828 36829 36830 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36828 def @request_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36835 36836 36837 36838 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36835 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) end |