Class: Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ManagedInstanceShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
constructor
A new instance of ManagedInstanceShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ManagedInstanceShutdownDetails
Returns a new instance of ManagedInstanceShutdownDetails.
36783 36784 36785 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
36774 36775 36776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36774 def max_duration @max_duration end |
#request_timestamp ⇒ String
Output only. [Output Only] Past timestamp indicating the beginning of
PENDING_STOP
state of instance in RFC3339 text format.
Corresponds to the JSON property requestTimestamp
36781 36782 36783 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36781 def @request_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36788 36789 36790 36791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36788 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) end |