Class: Google::Apis::ComputeBeta::Metadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Metadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A metadata key/value entry.
Defined Under Namespace
Classes: Item
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Metadata::Item>
Array of key/value pairs.
-
#kind ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Metadata
constructor
A new instance of Metadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Metadata
Returns a new instance of Metadata.
37451 37452 37453 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Specifies a fingerprint for this request, which is essentially a hash of
the metadata's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update metadata. You must always provide an
up-to-date fingerprint hash in order to update or change metadata,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve the resource.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
37437 37438 37439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37437 def fingerprint @fingerprint end |
#items ⇒ Array<Google::Apis::ComputeBeta::Metadata::Item>
Array of key/value pairs. The total size of all keys and values must be
less than 512 KB.
Corresponds to the JSON property items
37443 37444 37445 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37443 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#metadata
for metadata.
Corresponds to the JSON property kind
37449 37450 37451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37449 def kind @kind end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37456 37457 37458 37459 37460 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37456 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) end |