Class: Google::Apis::ComputeBeta::MetadataFilterLabelMatch
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MetadataFilterLabelMatch
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
MetadataFilter label name value pairs that are expected to match corresponding labels presented as metadata to the load balancer.
Instance Attribute Summary collapse
-
#name ⇒ String
Name of metadata label.
-
#value ⇒ String
The value of the label must match the specified value.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MetadataFilterLabelMatch
constructor
A new instance of MetadataFilterLabelMatch.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MetadataFilterLabelMatch
Returns a new instance of MetadataFilterLabelMatch.
37551 37552 37553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37551 def initialize(**args) update!(**args) end |
Instance Attribute Details
#name ⇒ String
Name of metadata label.
The name can have a maximum length of 1024 characters and must be at
least 1 character long.
Corresponds to the JSON property name
37543 37544 37545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37543 def name @name end |
#value ⇒ String
The value of the label must match the specified value.
value can have a maximum length of 1024 characters.
Corresponds to the JSON property value
37549 37550 37551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37549 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37556 37557 37558 37559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37556 def update!(**args) @name = args[:name] if args.key?(:name) @value = args[:value] if args.key?(:value) end |