Class: Google::Apis::ComputeBeta::MultiMig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Multi-MIG represents a group of managed instance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMig

Returns a new instance of MultiMig.



36298
36299
36300
# File 'lib/google/apis/compute_beta/classes.rb', line 36298

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output only] The creation timestamp of this multi-MIG in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


36243
36244
36245
# File 'lib/google/apis/compute_beta/classes.rb', line 36243

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


36248
36249
36250
# File 'lib/google/apis/compute_beta/classes.rb', line 36248

def description
  @description
end

#idFixnum

Output only. [Output only] The unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


36255
36256
36257
# File 'lib/google/apis/compute_beta/classes.rb', line 36255

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#multiMig for multi-MIGs. Corresponds to the JSON property kind

Returns:

  • (String)


36261
36262
36263
# File 'lib/google/apis/compute_beta/classes.rb', line 36261

def kind
  @kind
end

#nameString

The name of the multi-MIG. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


36272
36273
36274
# File 'lib/google/apis/compute_beta/classes.rb', line 36272

def name
  @name
end

#regionString

Output only. [Output only] The URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. You cannot set the region as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


36280
36281
36282
# File 'lib/google/apis/compute_beta/classes.rb', line 36280

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeBeta::MultiMigResourcePolicies

Resource policies message for a multi-MIG. Specifies the workload policy configuration of the multi-MIG. Corresponds to the JSON property resourcePolicies



36286
36287
36288
# File 'lib/google/apis/compute_beta/classes.rb', line 36286

def resource_policies
  @resource_policies
end

Output only. [Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36291
36292
36293
# File 'lib/google/apis/compute_beta/classes.rb', line 36291

def self_link
  @self_link
end

#statusGoogle::Apis::ComputeBeta::MultiMigStatus

Corresponds to the JSON property status



36296
36297
36298
# File 'lib/google/apis/compute_beta/classes.rb', line 36296

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36303
36304
36305
36306
36307
36308
36309
36310
36311
36312
36313
# File 'lib/google/apis/compute_beta/classes.rb', line 36303

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
end