Class: Google::Apis::ComputeBeta::MultiMig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Multi-MIG represents a group of managed instance groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMig

Returns a new instance of MultiMig.



34172
34173
34174
# File 'lib/google/apis/compute_beta/classes.rb', line 34172

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output only] The creation timestamp of this multi-MIG in RFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


34117
34118
34119
# File 'lib/google/apis/compute_beta/classes.rb', line 34117

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Corresponds to the JSON property description

Returns:

  • (String)


34122
34123
34124
# File 'lib/google/apis/compute_beta/classes.rb', line 34122

def description
  @description
end

#idFixnum

Output only. [Output only] The unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


34129
34130
34131
# File 'lib/google/apis/compute_beta/classes.rb', line 34129

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#multiMig for multi-MIGs. Corresponds to the JSON property kind

Returns:

  • (String)


34135
34136
34137
# File 'lib/google/apis/compute_beta/classes.rb', line 34135

def kind
  @kind
end

#nameString

The name of the multi-MIG. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


34146
34147
34148
# File 'lib/google/apis/compute_beta/classes.rb', line 34146

def name
  @name
end

#regionString

Output only. [Output only] The URL of the region where the resource resides. You must specify this field as part of the HTTP request URL. You cannot set the region as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


34154
34155
34156
# File 'lib/google/apis/compute_beta/classes.rb', line 34154

def region
  @region
end

#resource_policiesGoogle::Apis::ComputeBeta::MultiMigResourcePolicies

Resource policies message for a multi-MIG. Specifies the workload policy configuration of the multi-MIG. Corresponds to the JSON property resourcePolicies



34160
34161
34162
# File 'lib/google/apis/compute_beta/classes.rb', line 34160

def resource_policies
  @resource_policies
end

Output only. [Output only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


34165
34166
34167
# File 'lib/google/apis/compute_beta/classes.rb', line 34165

def self_link
  @self_link
end

#statusGoogle::Apis::ComputeBeta::MultiMigStatus

Corresponds to the JSON property status



34170
34171
34172
# File 'lib/google/apis/compute_beta/classes.rb', line 34170

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34177
34178
34179
34180
34181
34182
34183
34184
34185
34186
34187
# File 'lib/google/apis/compute_beta/classes.rb', line 34177

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
end