Class: Google::Apis::ComputeBeta::MultiMigMemberList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MultiMigMemberList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMigMember>
A list of multi-MIG member resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MultiMigMemberList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigMemberList
constructor
A new instance of MultiMigMemberList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigMemberList
Returns a new instance of MultiMigMemberList.
37718 37719 37720 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37718 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37685 37686 37687 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37685 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMigMember>
A list of multi-MIG member resources.
Corresponds to the JSON property items
37690 37691 37692 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37690 def items @items end |
#kind ⇒ String
Output only. Type of the resource. Alwayscompute#multiMigMember for a list of
multi-MIG members.
Corresponds to the JSON property kind
37696 37697 37698 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37696 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37706 37707 37708 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37706 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37711 37712 37713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37711 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MultiMigMemberList::Warning
Informational warning message.
Corresponds to the JSON property warning
37716 37717 37718 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37716 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37723 37724 37725 37726 37727 37728 37729 37730 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37723 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |