Class: Google::Apis::ComputeBeta::MultiMigMemberList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigMemberList

Returns a new instance of MultiMigMemberList.



35606
35607
35608
# File 'lib/google/apis/compute_beta/classes.rb', line 35606

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35573
35574
35575
# File 'lib/google/apis/compute_beta/classes.rb', line 35573

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MultiMigMember>

A list of multi-MIG member resources. Corresponds to the JSON property items



35578
35579
35580
# File 'lib/google/apis/compute_beta/classes.rb', line 35578

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute#multiMigMember for a list of multi-MIG members. Corresponds to the JSON property kind

Returns:

  • (String)


35584
35585
35586
# File 'lib/google/apis/compute_beta/classes.rb', line 35584

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35594
35595
35596
# File 'lib/google/apis/compute_beta/classes.rb', line 35594

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35599
35600
35601
# File 'lib/google/apis/compute_beta/classes.rb', line 35599

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MultiMigMemberList::Warning

Informational warning message. Corresponds to the JSON property warning



35604
35605
35606
# File 'lib/google/apis/compute_beta/classes.rb', line 35604

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35611
35612
35613
35614
35615
35616
35617
35618
# File 'lib/google/apis/compute_beta/classes.rb', line 35611

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end