Class: Google::Apis::ComputeBeta::MultiMigStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigStatusAcceleratorTopology

Returns a new instance of MultiMigStatusAcceleratorTopology.



35787
35788
35789
# File 'lib/google/apis/compute_beta/classes.rb', line 35787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. [Output Only] Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


35774
35775
35776
# File 'lib/google/apis/compute_beta/classes.rb', line 35774

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_stateString

Output only. [Output Only] The state of the accelerator topology. Corresponds to the JSON property acceleratorTopologyState

Returns:

  • (String)


35779
35780
35781
# File 'lib/google/apis/compute_beta/classes.rb', line 35779

def accelerator_topology_state
  @accelerator_topology_state
end

#accelerator_topology_state_last_checkGoogle::Apis::ComputeBeta::MultiMigStatusAcceleratorTopologyAcceleratorTopologyStateLastCheck

Output only. [Output Only] The result of the latest accelerator topology state check. Corresponds to the JSON property acceleratorTopologyStateLastCheck



35785
35786
35787
# File 'lib/google/apis/compute_beta/classes.rb', line 35785

def accelerator_topology_state_last_check
  @accelerator_topology_state_last_check
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35792
35793
35794
35795
35796
# File 'lib/google/apis/compute_beta/classes.rb', line 35792

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_state = args[:accelerator_topology_state] if args.key?(:accelerator_topology_state)
  @accelerator_topology_state_last_check = args[:accelerator_topology_state_last_check] if args.key?(:accelerator_topology_state_last_check)
end