Class: Google::Apis::ComputeBeta::MultiMigStatusAcceleratorTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigStatusAcceleratorTopology

Returns a new instance of MultiMigStatusAcceleratorTopology.



34471
34472
34473
# File 'lib/google/apis/compute_beta/classes.rb', line 34471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Output only. [Output Only] Topology in the format of: "16x16", "4x4x4", etc. The value is the same as configured in the WorkloadPolicy. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


34458
34459
34460
# File 'lib/google/apis/compute_beta/classes.rb', line 34458

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_stateString

Output only. [Output Only] The state of the accelerator topology. Corresponds to the JSON property acceleratorTopologyState

Returns:

  • (String)


34463
34464
34465
# File 'lib/google/apis/compute_beta/classes.rb', line 34463

def accelerator_topology_state
  @accelerator_topology_state
end

#accelerator_topology_state_last_checkGoogle::Apis::ComputeBeta::MultiMigStatusAcceleratorTopologyAcceleratorTopologyStateLastCheck

Output only. [Output Only] The result of the latest accelerator topology state check. Corresponds to the JSON property acceleratorTopologyStateLastCheck



34469
34470
34471
# File 'lib/google/apis/compute_beta/classes.rb', line 34469

def accelerator_topology_state_last_check
  @accelerator_topology_state_last_check
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



34476
34477
34478
34479
34480
# File 'lib/google/apis/compute_beta/classes.rb', line 34476

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_state = args[:accelerator_topology_state] if args.key?(:accelerator_topology_state)
  @accelerator_topology_state_last_check = args[:accelerator_topology_state_last_check] if args.key?(:accelerator_topology_state_last_check)
end