Class: Google::Apis::ComputeBeta::MultiMigsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MultiMigsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMig>
A list of multi-MIGs in the specified project and region.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MultiMigsList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigsList
constructor
A new instance of MultiMigsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigsList
Returns a new instance of MultiMigsList.
38174 38175 38176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38143 38144 38145 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38143 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMig>
A list of multi-MIGs in the specified project and region.
Corresponds to the JSON property items
38148 38149 38150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38148 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
38153 38154 38155 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38153 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38162 38163 38164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38162 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38167 38168 38169 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38167 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MultiMigsList::Warning
Informational warning message.
Corresponds to the JSON property warning
38172 38173 38174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38172 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38179 38180 38181 38182 38183 38184 38185 38186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38179 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |