Class: Google::Apis::ComputeBeta::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



38160
38161
38162
# File 'lib/google/apis/compute_beta/classes.rb', line 38160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38129
38130
38131
# File 'lib/google/apis/compute_beta/classes.rb', line 38129

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



38134
38135
38136
# File 'lib/google/apis/compute_beta/classes.rb', line 38134

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


38139
38140
38141
# File 'lib/google/apis/compute_beta/classes.rb', line 38139

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38148
38149
38150
# File 'lib/google/apis/compute_beta/classes.rb', line 38148

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38153
38154
38155
# File 'lib/google/apis/compute_beta/classes.rb', line 38153

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



38158
38159
38160
# File 'lib/google/apis/compute_beta/classes.rb', line 38158

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38165
38166
38167
38168
38169
38170
38171
38172
# File 'lib/google/apis/compute_beta/classes.rb', line 38165

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end