Class: Google::Apis::ComputeBeta::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



38120
38121
38122
# File 'lib/google/apis/compute_beta/classes.rb', line 38120

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38089
38090
38091
# File 'lib/google/apis/compute_beta/classes.rb', line 38089

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



38094
38095
38096
# File 'lib/google/apis/compute_beta/classes.rb', line 38094

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


38099
38100
38101
# File 'lib/google/apis/compute_beta/classes.rb', line 38099

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38108
38109
38110
# File 'lib/google/apis/compute_beta/classes.rb', line 38108

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38113
38114
38115
# File 'lib/google/apis/compute_beta/classes.rb', line 38113

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



38118
38119
38120
# File 'lib/google/apis/compute_beta/classes.rb', line 38118

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38125
38126
38127
38128
38129
38130
38131
38132
# File 'lib/google/apis/compute_beta/classes.rb', line 38125

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end