Class: Google::Apis::ComputeBeta::MultiMigsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MultiMigsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMig>
A list of multi-MIGs in the specified project and region.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MultiMigsList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigsList
constructor
A new instance of MultiMigsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigsList
Returns a new instance of MultiMigsList.
37618 37619 37620 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37618 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37587 37588 37589 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37587 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMig>
A list of multi-MIGs in the specified project and region.
Corresponds to the JSON property items
37592 37593 37594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37592 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
37597 37598 37599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37597 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37606 37607 37608 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37606 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37611 37612 37613 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37611 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MultiMigsList::Warning
Informational warning message.
Corresponds to the JSON property warning
37616 37617 37618 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37616 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37623 37624 37625 37626 37627 37628 37629 37630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37623 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |