Class: Google::Apis::ComputeBeta::MultiMigsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MultiMigsList

Returns a new instance of MultiMigsList.



36796
36797
36798
# File 'lib/google/apis/compute_beta/classes.rb', line 36796

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36765
36766
36767
# File 'lib/google/apis/compute_beta/classes.rb', line 36765

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::MultiMig>

A list of multi-MIGs in the specified project and region. Corresponds to the JSON property items



36770
36771
36772
# File 'lib/google/apis/compute_beta/classes.rb', line 36770

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


36775
36776
36777
# File 'lib/google/apis/compute_beta/classes.rb', line 36775

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36784
36785
36786
# File 'lib/google/apis/compute_beta/classes.rb', line 36784

def next_page_token
  @next_page_token
end

Output only. [Output only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36789
36790
36791
# File 'lib/google/apis/compute_beta/classes.rb', line 36789

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::MultiMigsList::Warning

Informational warning message. Corresponds to the JSON property warning



36794
36795
36796
# File 'lib/google/apis/compute_beta/classes.rb', line 36794

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36801
36802
36803
36804
36805
36806
36807
36808
# File 'lib/google/apis/compute_beta/classes.rb', line 36801

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end