Class: Google::Apis::ComputeBeta::MultiMigsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::MultiMigsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMig>
A list of multi-MIGs in the specified project and region.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::MultiMigsList::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MultiMigsList
constructor
A new instance of MultiMigsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MultiMigsList
Returns a new instance of MultiMigsList.
34670 34671 34672 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
34639 34640 34641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34639 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::MultiMig>
A list of multi-MIGs in the specified project and region.
Corresponds to the JSON property items
34644 34645 34646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34644 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
34649 34650 34651 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34649 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results formaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
34658 34659 34660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34658 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
34663 34664 34665 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34663 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::MultiMigsList::Warning
Informational warning message.
Corresponds to the JSON property warning
34668 34669 34670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34668 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
34675 34676 34677 34678 34679 34680 34681 34682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 34675 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |