Class: Google::Apis::ComputeBeta::NamedSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NamedSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of named set.
-
#elements ⇒ Array<Google::Apis::ComputeBeta::Expr>
CEL expressions that are comparable to constructs of this set's type (see Policy Language).
-
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking.
-
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all named sets owned by the Router.
-
#type ⇒ String
This named set's type Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NamedSet
constructor
A new instance of NamedSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NamedSet
Returns a new instance of NamedSet.
38772 38773 38774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38772 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of named set.
Corresponds to the JSON property description
38740 38741 38742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38740 def description @description end |
#elements ⇒ Array<Google::Apis::ComputeBeta::Expr>
CEL expressions that are comparable to constructs of this set's type
(see Policy Language).
Corresponds to the JSON property elements
38746 38747 38748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38746 def elements @elements end |
#fingerprint ⇒ String
A fingerprint for the Named Set being applied to this Router, which is
essentially a hash of the Named Set used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update the Named Set. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getNamedSet() request
to retrieve a Named Set.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
38759 38760 38761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38759 def fingerprint @fingerprint end |
#name ⇒ String
This set's name, which must be a resource ID segment and unique within all
named sets owned by the Router. Name should conform to RFC1035.
Corresponds to the JSON property name
38765 38766 38767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38765 def name @name end |
#type ⇒ String
This named set's type
Corresponds to the JSON property type
38770 38771 38772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38770 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38777 38778 38779 38780 38781 38782 38783 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38777 def update!(**args) @description = args[:description] if args.key?(:description) @elements = args[:elements] if args.key?(:elements) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @type = args[:type] if args.key?(:type) end |