Class: Google::Apis::ComputeBeta::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



38270
38271
38272
# File 'lib/google/apis/compute_beta/classes.rb', line 38270

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


38238
38239
38240
# File 'lib/google/apis/compute_beta/classes.rb', line 38238

def description
  @description
end

#elementsArray<Google::Apis::ComputeBeta::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



38244
38245
38246
# File 'lib/google/apis/compute_beta/classes.rb', line 38244

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


38257
38258
38259
# File 'lib/google/apis/compute_beta/classes.rb', line 38257

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


38263
38264
38265
# File 'lib/google/apis/compute_beta/classes.rb', line 38263

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


38268
38269
38270
# File 'lib/google/apis/compute_beta/classes.rb', line 38268

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38275
38276
38277
38278
38279
38280
38281
# File 'lib/google/apis/compute_beta/classes.rb', line 38275

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end