Class: Google::Apis::ComputeBeta::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



38248
38249
38250
# File 'lib/google/apis/compute_beta/classes.rb', line 38248

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


38216
38217
38218
# File 'lib/google/apis/compute_beta/classes.rb', line 38216

def description
  @description
end

#elementsArray<Google::Apis::ComputeBeta::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



38222
38223
38224
# File 'lib/google/apis/compute_beta/classes.rb', line 38222

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


38235
38236
38237
# File 'lib/google/apis/compute_beta/classes.rb', line 38235

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


38241
38242
38243
# File 'lib/google/apis/compute_beta/classes.rb', line 38241

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


38246
38247
38248
# File 'lib/google/apis/compute_beta/classes.rb', line 38246

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38253
38254
38255
38256
38257
38258
38259
# File 'lib/google/apis/compute_beta/classes.rb', line 38253

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end