Class: Google::Apis::ComputeBeta::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



37768
37769
37770
# File 'lib/google/apis/compute_beta/classes.rb', line 37768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


37736
37737
37738
# File 'lib/google/apis/compute_beta/classes.rb', line 37736

def description
  @description
end

#elementsArray<Google::Apis::ComputeBeta::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



37742
37743
37744
# File 'lib/google/apis/compute_beta/classes.rb', line 37742

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


37755
37756
37757
# File 'lib/google/apis/compute_beta/classes.rb', line 37755

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


37761
37762
37763
# File 'lib/google/apis/compute_beta/classes.rb', line 37761

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


37766
37767
37768
# File 'lib/google/apis/compute_beta/classes.rb', line 37766

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37773
37774
37775
37776
37777
37778
37779
# File 'lib/google/apis/compute_beta/classes.rb', line 37773

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end