Class: Google::Apis::ComputeBeta::NamedSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NamedSet

Returns a new instance of NamedSet.



37721
37722
37723
# File 'lib/google/apis/compute_beta/classes.rb', line 37721

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of named set. Corresponds to the JSON property description

Returns:

  • (String)


37689
37690
37691
# File 'lib/google/apis/compute_beta/classes.rb', line 37689

def description
  @description
end

#elementsArray<Google::Apis::ComputeBeta::Expr>

CEL expressions that are comparable to constructs of this set's type (see Policy Language). Corresponds to the JSON property elements



37695
37696
37697
# File 'lib/google/apis/compute_beta/classes.rb', line 37695

def elements
  @elements
end

#fingerprintString

A fingerprint for the Named Set being applied to this Router, which is essentially a hash of the Named Set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update the Named Set. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getNamedSet() request to retrieve a Named Set. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


37708
37709
37710
# File 'lib/google/apis/compute_beta/classes.rb', line 37708

def fingerprint
  @fingerprint
end

#nameString

This set's name, which must be a resource ID segment and unique within all named sets owned by the Router. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


37714
37715
37716
# File 'lib/google/apis/compute_beta/classes.rb', line 37714

def name
  @name
end

#typeString

This named set's type Corresponds to the JSON property type

Returns:

  • (String)


37719
37720
37721
# File 'lib/google/apis/compute_beta/classes.rb', line 37719

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37726
37727
37728
37729
37730
37731
37732
# File 'lib/google/apis/compute_beta/classes.rb', line 37726

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @elements = args[:elements] if args.key?(:elements)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @type = args[:type] if args.key?(:type)
end