Class: Google::Apis::ComputeBeta::NetworkAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

NetworkAttachments A network attachment resource ...

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachment

Returns a new instance of NetworkAttachment.



38759
38760
38761
# File 'lib/google/apis/compute_beta/classes.rb', line 38759

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_endpointsArray<Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint>

Output only. [Output Only] An array of connections for all the producers connected to this network attachment. Corresponds to the JSON property connectionEndpoints



38660
38661
38662
# File 'lib/google/apis/compute_beta/classes.rb', line 38660

def connection_endpoints
  @connection_endpoints
end

#connection_preferenceString

Corresponds to the JSON property connectionPreference

Returns:

  • (String)


38665
38666
38667
# File 'lib/google/apis/compute_beta/classes.rb', line 38665

def connection_preference
  @connection_preference
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


38671
38672
38673
# File 'lib/google/apis/compute_beta/classes.rb', line 38671

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


38677
38678
38679
# File 'lib/google/apis/compute_beta/classes.rb', line 38677

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. An up-to-date fingerprint must be provided in order to patch. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


38685
38686
38687
# File 'lib/google/apis/compute_beta/classes.rb', line 38685

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


38692
38693
38694
# File 'lib/google/apis/compute_beta/classes.rb', line 38692

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


38697
38698
38699
# File 'lib/google/apis/compute_beta/classes.rb', line 38697

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


38708
38709
38710
# File 'lib/google/apis/compute_beta/classes.rb', line 38708

def name
  @name
end

#networkString

Output only. [Output Only] The URL of the network which the Network Attachment belongs to. Practically it is inferred by fetching the network of the first subnetwork associated. Because it is required that all the subnetworks must be from the same network, it is assured that the Network Attachment belongs to the same network as all the subnetworks. Corresponds to the JSON property network

Returns:

  • (String)


38717
38718
38719
# File 'lib/google/apis/compute_beta/classes.rb', line 38717

def network
  @network
end

#producer_accept_listsArray<String>

Projects or service class ids that are allowed to connect to this network attachment. The project can be specified using its id or number. Service class id can be specified as "serviceclasses/service_class_id". Corresponds to the JSON property producerAcceptLists

Returns:

  • (Array<String>)


38724
38725
38726
# File 'lib/google/apis/compute_beta/classes.rb', line 38724

def producer_accept_lists
  @producer_accept_lists
end

#producer_reject_listsArray<String>

Projects or service class ids that are not allowed to connect to this network attachment. The project can be specified using its id or number. Service class id can be specified as "serviceclasses/service_class_id". Corresponds to the JSON property producerRejectLists

Returns:

  • (Array<String>)


38731
38732
38733
# File 'lib/google/apis/compute_beta/classes.rb', line 38731

def producer_reject_lists
  @producer_reject_lists
end

#regionString

Output only. [Output Only] URL of the region where the network attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


38740
38741
38742
# File 'lib/google/apis/compute_beta/classes.rb', line 38740

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38745
38746
38747
# File 'lib/google/apis/compute_beta/classes.rb', line 38745

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


38750
38751
38752
# File 'lib/google/apis/compute_beta/classes.rb', line 38750

def self_link_with_id
  @self_link_with_id
end

#subnetworksArray<String>

An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment. Corresponds to the JSON property subnetworks

Returns:

  • (Array<String>)


38757
38758
38759
# File 'lib/google/apis/compute_beta/classes.rb', line 38757

def subnetworks
  @subnetworks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38764
38765
38766
38767
38768
38769
38770
38771
38772
38773
38774
38775
38776
38777
38778
38779
38780
# File 'lib/google/apis/compute_beta/classes.rb', line 38764

def update!(**args)
  @connection_endpoints = args[:connection_endpoints] if args.key?(:connection_endpoints)
  @connection_preference = args[:connection_preference] if args.key?(:connection_preference)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @producer_accept_lists = args[:producer_accept_lists] if args.key?(:producer_accept_lists)
  @producer_reject_lists = args[:producer_reject_lists] if args.key?(:producer_reject_lists)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
end