Class: Google::Apis::ComputeBeta::NetworkAttachment
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkAttachment
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
NetworkAttachments A network attachment resource ...
Instance Attribute Summary collapse
-
#connection_endpoints ⇒ Array<Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint>
Output only.
-
#connection_preference ⇒ String
Corresponds to the JSON property
connectionPreference. -
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
Output only.
-
#producer_accept_lists ⇒ Array<String>
Projects or service class ids that are allowed to connect to this network attachment.
-
#producer_reject_lists ⇒ Array<String>
Projects or service class ids that are not allowed to connect to this network attachment.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#subnetworks ⇒ Array<String>
An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachment
constructor
A new instance of NetworkAttachment.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachment
Returns a new instance of NetworkAttachment.
38695 38696 38697 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38695 def initialize(**args) update!(**args) end |
Instance Attribute Details
#connection_endpoints ⇒ Array<Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint>
Output only. [Output Only] An array of connections for all the producers
connected
to this network attachment.
Corresponds to the JSON property connectionEndpoints
38596 38597 38598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38596 def connection_endpoints @connection_endpoints end |
#connection_preference ⇒ String
Corresponds to the JSON property connectionPreference
38601 38602 38603 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38601 def connection_preference @connection_preference end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
38607 38608 38609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38607 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
38613 38614 38615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38613 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored
in this object. This field is used in optimistic locking. An up-to-date
fingerprint must be provided in order to patch.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
38621 38622 38623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38621 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
38628 38629 38630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38628 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource.
Corresponds to the JSON property kind
38633 38634 38635 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38633 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
38644 38645 38646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38644 def name @name end |
#network ⇒ String
Output only. [Output Only] The URL of the network which the Network Attachment
belongs to. Practically it is inferred by fetching the network of the first
subnetwork associated. Because it is required that all the subnetworks must
be from the same network, it is assured that the Network Attachment belongs
to the same network as all the subnetworks.
Corresponds to the JSON property network
38653 38654 38655 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38653 def network @network end |
#producer_accept_lists ⇒ Array<String>
Projects or service class ids that are allowed to connect to this network
attachment. The project can be specified using its id or number. Service
class id can be specified as "serviceclasses/service_class_id".
Corresponds to the JSON property producerAcceptLists
38660 38661 38662 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38660 def producer_accept_lists @producer_accept_lists end |
#producer_reject_lists ⇒ Array<String>
Projects or service class ids that are not allowed to connect to this
network attachment. The project can be specified using its id or number.
Service class id can be specified as "serviceclasses/service_class_id".
Corresponds to the JSON property producerRejectLists
38667 38668 38669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38667 def producer_reject_lists @producer_reject_lists end |
#region ⇒ String
Output only. [Output Only] URL of the region where the network attachment
resides.
This field applies only to the region resource. You must specify this
field as part of the HTTP request URL. It is not settable as a field in
the request body.
Corresponds to the JSON property region
38676 38677 38678 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38676 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
38681 38682 38683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38681 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
38686 38687 38688 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38686 def self_link_with_id @self_link_with_id end |
#subnetworks ⇒ Array<String>
An array of URLs where each entry is the URL of a subnet
provided by the service consumer to use for
endpoints in the producers that connect to this network attachment.
Corresponds to the JSON property subnetworks
38693 38694 38695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38693 def subnetworks @subnetworks end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38700 38701 38702 38703 38704 38705 38706 38707 38708 38709 38710 38711 38712 38713 38714 38715 38716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38700 def update!(**args) @connection_endpoints = args[:connection_endpoints] if args.key?(:connection_endpoints) @connection_preference = args[:connection_preference] if args.key?(:connection_preference) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @producer_accept_lists = args[:producer_accept_lists] if args.key?(:producer_accept_lists) @producer_reject_lists = args[:producer_reject_lists] if args.key?(:producer_reject_lists) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) end |