Class: Google::Apis::ComputeBeta::NetworkAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

NetworkAttachments A network attachment resource ...

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachment

Returns a new instance of NetworkAttachment.



38151
38152
38153
# File 'lib/google/apis/compute_beta/classes.rb', line 38151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_endpointsArray<Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint>

Output only. [Output Only] An array of connections for all the producers connected to this network attachment. Corresponds to the JSON property connectionEndpoints



38054
38055
38056
# File 'lib/google/apis/compute_beta/classes.rb', line 38054

def connection_endpoints
  @connection_endpoints
end

#connection_preferenceString

Corresponds to the JSON property connectionPreference

Returns:

  • (String)


38059
38060
38061
# File 'lib/google/apis/compute_beta/classes.rb', line 38059

def connection_preference
  @connection_preference
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


38065
38066
38067
# File 'lib/google/apis/compute_beta/classes.rb', line 38065

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


38071
38072
38073
# File 'lib/google/apis/compute_beta/classes.rb', line 38071

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. An up-to-date fingerprint must be provided in order to patch. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


38079
38080
38081
# File 'lib/google/apis/compute_beta/classes.rb', line 38079

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


38086
38087
38088
# File 'lib/google/apis/compute_beta/classes.rb', line 38086

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Corresponds to the JSON property kind

Returns:

  • (String)


38091
38092
38093
# File 'lib/google/apis/compute_beta/classes.rb', line 38091

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


38102
38103
38104
# File 'lib/google/apis/compute_beta/classes.rb', line 38102

def name
  @name
end

#networkString

Output only. [Output Only] The URL of the network which the Network Attachment belongs to. Practically it is inferred by fetching the network of the first subnetwork associated. Because it is required that all the subnetworks must be from the same network, it is assured that the Network Attachment belongs to the same network as all the subnetworks. Corresponds to the JSON property network

Returns:

  • (String)


38111
38112
38113
# File 'lib/google/apis/compute_beta/classes.rb', line 38111

def network
  @network
end

#producer_accept_listsArray<String>

Projects that are allowed to connect to this network attachment. The project can be specified using its id or number. Corresponds to the JSON property producerAcceptLists

Returns:

  • (Array<String>)


38117
38118
38119
# File 'lib/google/apis/compute_beta/classes.rb', line 38117

def producer_accept_lists
  @producer_accept_lists
end

#producer_reject_listsArray<String>

Projects that are not allowed to connect to this network attachment. The project can be specified using its id or number. Corresponds to the JSON property producerRejectLists

Returns:

  • (Array<String>)


38123
38124
38125
# File 'lib/google/apis/compute_beta/classes.rb', line 38123

def producer_reject_lists
  @producer_reject_lists
end

#regionString

Output only. [Output Only] URL of the region where the network attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


38132
38133
38134
# File 'lib/google/apis/compute_beta/classes.rb', line 38132

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38137
38138
38139
# File 'lib/google/apis/compute_beta/classes.rb', line 38137

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


38142
38143
38144
# File 'lib/google/apis/compute_beta/classes.rb', line 38142

def self_link_with_id
  @self_link_with_id
end

#subnetworksArray<String>

An array of URLs where each entry is the URL of a subnet provided by the service consumer to use for endpoints in the producers that connect to this network attachment. Corresponds to the JSON property subnetworks

Returns:

  • (Array<String>)


38149
38150
38151
# File 'lib/google/apis/compute_beta/classes.rb', line 38149

def subnetworks
  @subnetworks
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38156
38157
38158
38159
38160
38161
38162
38163
38164
38165
38166
38167
38168
38169
38170
38171
38172
# File 'lib/google/apis/compute_beta/classes.rb', line 38156

def update!(**args)
  @connection_endpoints = args[:connection_endpoints] if args.key?(:connection_endpoints)
  @connection_preference = args[:connection_preference] if args.key?(:connection_preference)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @producer_accept_lists = args[:producer_accept_lists] if args.key?(:producer_accept_lists)
  @producer_reject_lists = args[:producer_reject_lists] if args.key?(:producer_reject_lists)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
end