Class: Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] A connection connected to this network attachment.
Instance Attribute Summary collapse
-
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
-
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
-
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
-
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
-
#service_class_id ⇒ String
The service class id of the producer service to which the IP was assigned.
-
#status ⇒ String
The status of a connected endpoint to this network attachment.
-
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer instance network interface.
-
#subnetwork_cidr_range ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
constructor
A new instance of NetworkAttachmentConnectedEndpoint.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint
Returns a new instance of NetworkAttachmentConnectedEndpoint.
38350 38351 38352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38350 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_address ⇒ String
The IPv4 address assigned to the producer instance network interface.
This value will be a range in case of Serverless.
Corresponds to the JSON property ipAddress
38307 38308 38309 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38307 def ip_address @ip_address end |
#ipv6_address ⇒ String
The IPv6 address assigned to the producer instance network interface.
This is only assigned when the stack types of both the instance network
interface and the consumer subnet are IPv4_IPv6.
Corresponds to the JSON property ipv6Address
38314 38315 38316 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38314 def ipv6_address @ipv6_address end |
#project_id_or_num ⇒ String
The project id or number of the interface to which the IP was assigned.
Corresponds to the JSON property projectIdOrNum
38319 38320 38321 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38319 def project_id_or_num @project_id_or_num end |
#secondary_ip_cidr_ranges ⇒ Array<String>
Alias IP ranges from the same subnetwork.
Corresponds to the JSON property secondaryIpCidrRanges
38324 38325 38326 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38324 def secondary_ip_cidr_ranges @secondary_ip_cidr_ranges end |
#service_class_id ⇒ String
The service class id of the producer service to which the IP was
assigned.
Corresponds to the JSON property serviceClassId
38330 38331 38332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38330 def service_class_id @service_class_id end |
#status ⇒ String
The status of a connected endpoint to this network attachment.
Corresponds to the JSON property status
38335 38336 38337 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38335 def status @status end |
#subnetwork ⇒ String
The subnetwork used to assign the IP to the producer
instance network interface.
Corresponds to the JSON property subnetwork
38341 38342 38343 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38341 def subnetwork @subnetwork end |
#subnetwork_cidr_range ⇒ String
Output only. [Output Only] The CIDR range of the subnet from which the IPv4
internal
IP was allocated from.
Corresponds to the JSON property subnetworkCidrRange
38348 38349 38350 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38348 def subnetwork_cidr_range @subnetwork_cidr_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38355 38356 38357 38358 38359 38360 38361 38362 38363 38364 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38355 def update!(**args) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address) @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num) @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges) @service_class_id = args[:service_class_id] if args.key?(:service_class_id) @status = args[:status] if args.key?(:status) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range) end |