Class: Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A connection connected to this network attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint

Returns a new instance of NetworkAttachmentConnectedEndpoint.



37528
37529
37530
# File 'lib/google/apis/compute_beta/classes.rb', line 37528

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless. Corresponds to the JSON property ipAddress

Returns:

  • (String)


37485
37486
37487
# File 'lib/google/apis/compute_beta/classes.rb', line 37485

def ip_address
  @ip_address
end

#ipv6_addressString

The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


37492
37493
37494
# File 'lib/google/apis/compute_beta/classes.rb', line 37492

def ipv6_address
  @ipv6_address
end

#project_id_or_numString

The project id or number of the interface to which the IP was assigned. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


37497
37498
37499
# File 'lib/google/apis/compute_beta/classes.rb', line 37497

def project_id_or_num
  @project_id_or_num
end

#secondary_ip_cidr_rangesArray<String>

Alias IP ranges from the same subnetwork. Corresponds to the JSON property secondaryIpCidrRanges

Returns:

  • (Array<String>)


37502
37503
37504
# File 'lib/google/apis/compute_beta/classes.rb', line 37502

def secondary_ip_cidr_ranges
  @secondary_ip_cidr_ranges
end

#service_class_idString

The service class id of the producer service to which the IP was assigned. Corresponds to the JSON property serviceClassId

Returns:

  • (String)


37508
37509
37510
# File 'lib/google/apis/compute_beta/classes.rb', line 37508

def service_class_id
  @service_class_id
end

#statusString

The status of a connected endpoint to this network attachment. Corresponds to the JSON property status

Returns:

  • (String)


37513
37514
37515
# File 'lib/google/apis/compute_beta/classes.rb', line 37513

def status
  @status
end

#subnetworkString

The subnetwork used to assign the IP to the producer instance network interface. Corresponds to the JSON property subnetwork

Returns:

  • (String)


37519
37520
37521
# File 'lib/google/apis/compute_beta/classes.rb', line 37519

def subnetwork
  @subnetwork
end

#subnetwork_cidr_rangeString

Output only. [Output Only] The CIDR range of the subnet from which the IPv4 internal IP was allocated from. Corresponds to the JSON property subnetworkCidrRange

Returns:

  • (String)


37526
37527
37528
# File 'lib/google/apis/compute_beta/classes.rb', line 37526

def subnetwork_cidr_range
  @subnetwork_cidr_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37533
37534
37535
37536
37537
37538
37539
37540
37541
37542
# File 'lib/google/apis/compute_beta/classes.rb', line 37533

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
  @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges)
  @service_class_id = args[:service_class_id] if args.key?(:service_class_id)
  @status = args[:status] if args.key?(:status)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range)
end