Class: Google::Apis::ComputeBeta::NetworkAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A connection connected to this network attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentConnectedEndpoint

Returns a new instance of NetworkAttachmentConnectedEndpoint.



36712
36713
36714
# File 'lib/google/apis/compute_beta/classes.rb', line 36712

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_addressString

The IPv4 address assigned to the producer instance network interface. This value will be a range in case of Serverless. Corresponds to the JSON property ipAddress

Returns:

  • (String)


36675
36676
36677
# File 'lib/google/apis/compute_beta/classes.rb', line 36675

def ip_address
  @ip_address
end

#ipv6_addressString

The IPv6 address assigned to the producer instance network interface. This is only assigned when the stack types of both the instance network interface and the consumer subnet are IPv4_IPv6. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


36682
36683
36684
# File 'lib/google/apis/compute_beta/classes.rb', line 36682

def ipv6_address
  @ipv6_address
end

#project_id_or_numString

The project id or number of the interface to which the IP was assigned. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


36687
36688
36689
# File 'lib/google/apis/compute_beta/classes.rb', line 36687

def project_id_or_num
  @project_id_or_num
end

#secondary_ip_cidr_rangesArray<String>

Alias IP ranges from the same subnetwork. Corresponds to the JSON property secondaryIpCidrRanges

Returns:

  • (Array<String>)


36692
36693
36694
# File 'lib/google/apis/compute_beta/classes.rb', line 36692

def secondary_ip_cidr_ranges
  @secondary_ip_cidr_ranges
end

#statusString

The status of a connected endpoint to this network attachment. Corresponds to the JSON property status

Returns:

  • (String)


36697
36698
36699
# File 'lib/google/apis/compute_beta/classes.rb', line 36697

def status
  @status
end

#subnetworkString

The subnetwork used to assign the IP to the producer instance network interface. Corresponds to the JSON property subnetwork

Returns:

  • (String)


36703
36704
36705
# File 'lib/google/apis/compute_beta/classes.rb', line 36703

def subnetwork
  @subnetwork
end

#subnetwork_cidr_rangeString

Output only. [Output Only] The CIDR range of the subnet from which the IPv4 internal IP was allocated from. Corresponds to the JSON property subnetworkCidrRange

Returns:

  • (String)


36710
36711
36712
# File 'lib/google/apis/compute_beta/classes.rb', line 36710

def subnetwork_cidr_range
  @subnetwork_cidr_range
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36717
36718
36719
36720
36721
36722
36723
36724
36725
# File 'lib/google/apis/compute_beta/classes.rb', line 36717

def update!(**args)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
  @secondary_ip_cidr_ranges = args[:secondary_ip_cidr_ranges] if args.key?(:secondary_ip_cidr_ranges)
  @status = args[:status] if args.key?(:status)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @subnetwork_cidr_range = args[:subnetwork_cidr_range] if args.key?(:subnetwork_cidr_range)
end