Class: Google::Apis::ComputeBeta::NetworkAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkAttachment>
A list of NetworkAttachment resources.
-
#kind ⇒ String
Corresponds to the JSON property
kind. -
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkAttachmentList
constructor
A new instance of NetworkAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkAttachmentList
Returns a new instance of NetworkAttachmentList.
39014 39015 39016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39014 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38982 38983 38984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38982 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkAttachment>
A list of NetworkAttachment resources.
Corresponds to the JSON property items
38987 38988 38989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38987 def items @items end |
#kind ⇒ String
Corresponds to the JSON property kind
38992 38993 38994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38992 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39002 39003 39004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39002 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39007 39008 39009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39007 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39012 39013 39014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39012 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39019 39020 39021 39022 39023 39024 39025 39026 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39019 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |