Class: Google::Apis::ComputeBeta::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



38964
38965
38966
# File 'lib/google/apis/compute_beta/classes.rb', line 38964

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38932
38933
38934
# File 'lib/google/apis/compute_beta/classes.rb', line 38932

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



38937
38938
38939
# File 'lib/google/apis/compute_beta/classes.rb', line 38937

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


38942
38943
38944
# File 'lib/google/apis/compute_beta/classes.rb', line 38942

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38952
38953
38954
# File 'lib/google/apis/compute_beta/classes.rb', line 38952

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38957
38958
38959
# File 'lib/google/apis/compute_beta/classes.rb', line 38957

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38962
38963
38964
# File 'lib/google/apis/compute_beta/classes.rb', line 38962

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38969
38970
38971
38972
38973
38974
38975
38976
# File 'lib/google/apis/compute_beta/classes.rb', line 38969

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end