Class: Google::Apis::ComputeBeta::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



38950
38951
38952
# File 'lib/google/apis/compute_beta/classes.rb', line 38950

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38918
38919
38920
# File 'lib/google/apis/compute_beta/classes.rb', line 38918

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



38923
38924
38925
# File 'lib/google/apis/compute_beta/classes.rb', line 38923

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


38928
38929
38930
# File 'lib/google/apis/compute_beta/classes.rb', line 38928

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38938
38939
38940
# File 'lib/google/apis/compute_beta/classes.rb', line 38938

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38943
38944
38945
# File 'lib/google/apis/compute_beta/classes.rb', line 38943

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38948
38949
38950
# File 'lib/google/apis/compute_beta/classes.rb', line 38948

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38955
38956
38957
38958
38959
38960
38961
38962
# File 'lib/google/apis/compute_beta/classes.rb', line 38955

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end