Class: Google::Apis::ComputeBeta::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



38908
38909
38910
# File 'lib/google/apis/compute_beta/classes.rb', line 38908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38876
38877
38878
# File 'lib/google/apis/compute_beta/classes.rb', line 38876

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



38881
38882
38883
# File 'lib/google/apis/compute_beta/classes.rb', line 38881

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


38886
38887
38888
# File 'lib/google/apis/compute_beta/classes.rb', line 38886

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38896
38897
38898
# File 'lib/google/apis/compute_beta/classes.rb', line 38896

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38901
38902
38903
# File 'lib/google/apis/compute_beta/classes.rb', line 38901

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38906
38907
38908
# File 'lib/google/apis/compute_beta/classes.rb', line 38906

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38913
38914
38915
38916
38917
38918
38919
38920
# File 'lib/google/apis/compute_beta/classes.rb', line 38913

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end