Class: Google::Apis::ComputeBeta::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



38406
38407
38408
# File 'lib/google/apis/compute_beta/classes.rb', line 38406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38374
38375
38376
# File 'lib/google/apis/compute_beta/classes.rb', line 38374

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



38379
38380
38381
# File 'lib/google/apis/compute_beta/classes.rb', line 38379

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


38384
38385
38386
# File 'lib/google/apis/compute_beta/classes.rb', line 38384

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38394
38395
38396
# File 'lib/google/apis/compute_beta/classes.rb', line 38394

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38399
38400
38401
# File 'lib/google/apis/compute_beta/classes.rb', line 38399

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38404
38405
38406
# File 'lib/google/apis/compute_beta/classes.rb', line 38404

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38411
38412
38413
38414
38415
38416
38417
38418
# File 'lib/google/apis/compute_beta/classes.rb', line 38411

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end