Class: Google::Apis::ComputeBeta::NetworkAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkAttachmentList

Returns a new instance of NetworkAttachmentList.



35398
35399
35400
# File 'lib/google/apis/compute_beta/classes.rb', line 35398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35366
35367
35368
# File 'lib/google/apis/compute_beta/classes.rb', line 35366

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkAttachment>

A list of NetworkAttachment resources. Corresponds to the JSON property items



35371
35372
35373
# File 'lib/google/apis/compute_beta/classes.rb', line 35371

def items
  @items
end

#kindString

Corresponds to the JSON property kind

Returns:

  • (String)


35376
35377
35378
# File 'lib/google/apis/compute_beta/classes.rb', line 35376

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35386
35387
35388
# File 'lib/google/apis/compute_beta/classes.rb', line 35386

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35391
35392
35393
# File 'lib/google/apis/compute_beta/classes.rb', line 35391

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35396
35397
35398
# File 'lib/google/apis/compute_beta/classes.rb', line 35396

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35403
35404
35405
35406
35407
35408
35409
35410
# File 'lib/google/apis/compute_beta/classes.rb', line 35403

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end