Class: Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



39280
39281
39282
# File 'lib/google/apis/compute_beta/classes.rb', line 39280

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


39236
39237
39238
# File 'lib/google/apis/compute_beta/classes.rb', line 39236

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39241
39242
39243
# File 'lib/google/apis/compute_beta/classes.rb', line 39241

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



39246
39247
39248
# File 'lib/google/apis/compute_beta/classes.rb', line 39246

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


39253
39254
39255
# File 'lib/google/apis/compute_beta/classes.rb', line 39253

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39263
39264
39265
# File 'lib/google/apis/compute_beta/classes.rb', line 39263

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39268
39269
39270
# File 'lib/google/apis/compute_beta/classes.rb', line 39268

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39273
39274
39275
# File 'lib/google/apis/compute_beta/classes.rb', line 39273

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39278
39279
39280
# File 'lib/google/apis/compute_beta/classes.rb', line 39278

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39285
39286
39287
39288
39289
39290
39291
39292
39293
39294
# File 'lib/google/apis/compute_beta/classes.rb', line 39285

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end