Class: Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
constructor
A new instance of NetworkEdgeSecurityServiceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList
Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.
39216 39217 39218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39216 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
39172 39173 39174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39172 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39177 39178 39179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39177 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkEdgeSecurityServicesScopedList>
A list of NetworkEdgeSecurityServicesScopedList resources.
Corresponds to the JSON property items
39182 39183 39184 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39182 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkEdgeSecurityServiceAggregatedList for lists of
Network Edge Security Services.
Corresponds to the JSON property kind
39189 39190 39191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39189 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39199 39200 39201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39199 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39204 39205 39206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39204 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
39209 39210 39211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39209 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39214 39215 39216 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39214 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39221 39222 39223 39224 39225 39226 39227 39228 39229 39230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39221 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |