Class: Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



38736
38737
38738
# File 'lib/google/apis/compute_beta/classes.rb', line 38736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


38692
38693
38694
# File 'lib/google/apis/compute_beta/classes.rb', line 38692

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38697
38698
38699
# File 'lib/google/apis/compute_beta/classes.rb', line 38697

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



38702
38703
38704
# File 'lib/google/apis/compute_beta/classes.rb', line 38702

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


38709
38710
38711
# File 'lib/google/apis/compute_beta/classes.rb', line 38709

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38719
38720
38721
# File 'lib/google/apis/compute_beta/classes.rb', line 38719

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38724
38725
38726
# File 'lib/google/apis/compute_beta/classes.rb', line 38724

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38729
38730
38731
# File 'lib/google/apis/compute_beta/classes.rb', line 38729

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38734
38735
38736
# File 'lib/google/apis/compute_beta/classes.rb', line 38734

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38741
38742
38743
38744
38745
38746
38747
38748
38749
38750
# File 'lib/google/apis/compute_beta/classes.rb', line 38741

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end