Class: Google::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEdgeSecurityServiceAggregatedList

Returns a new instance of NetworkEdgeSecurityServiceAggregatedList.



35728
35729
35730
# File 'lib/google/apis/compute_beta/classes.rb', line 35728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


35684
35685
35686
# File 'lib/google/apis/compute_beta/classes.rb', line 35684

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


35689
35690
35691
# File 'lib/google/apis/compute_beta/classes.rb', line 35689

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEdgeSecurityServicesScopedList>

A list of NetworkEdgeSecurityServicesScopedList resources. Corresponds to the JSON property items



35694
35695
35696
# File 'lib/google/apis/compute_beta/classes.rb', line 35694

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkEdgeSecurityServiceAggregatedList for lists of Network Edge Security Services. Corresponds to the JSON property kind

Returns:

  • (String)


35701
35702
35703
# File 'lib/google/apis/compute_beta/classes.rb', line 35701

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


35711
35712
35713
# File 'lib/google/apis/compute_beta/classes.rb', line 35711

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


35716
35717
35718
# File 'lib/google/apis/compute_beta/classes.rb', line 35716

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


35721
35722
35723
# File 'lib/google/apis/compute_beta/classes.rb', line 35721

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEdgeSecurityServiceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



35726
35727
35728
# File 'lib/google/apis/compute_beta/classes.rb', line 35726

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



35733
35734
35735
35736
35737
35738
35739
35740
35741
35742
# File 'lib/google/apis/compute_beta/classes.rb', line 35733

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end