Class: Google::Apis::ComputeBeta::NetworkEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The network endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpoint

Returns a new instance of NetworkEndpoint.



37342
37343
37344
# File 'lib/google/apis/compute_beta/classes.rb', line 37342

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional metadata defined as annotations on the network endpoint. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


37288
37289
37290
# File 'lib/google/apis/compute_beta/classes.rb', line 37288

def annotations
  @annotations
end

#client_destination_portFixnum

Represents the port number to which PSC consumer sends packets. Optional. Only valid for network endpoint groups created withGCE_VM_IP_PORTMAP endpoint type. Corresponds to the JSON property clientDestinationPort

Returns:

  • (Fixnum)


37295
37296
37297
# File 'lib/google/apis/compute_beta/classes.rb', line 37295

def client_destination_port
  @client_destination_port
end

#fqdnString

Optional fully qualified domain name of network endpoint. This can only be specified when NetworkEndpointGroup.network_endpoint_type isNON_GCP_FQDN_PORT. Corresponds to the JSON property fqdn

Returns:

  • (String)


37301
37302
37303
# File 'lib/google/apis/compute_beta/classes.rb', line 37301

def fqdn
  @fqdn
end

#instanceString

The name or a URL of VM instance of this network endpoint. Optional, the field presence depends on the network endpoint type. The field is required for network endpoints of type GCE_VM_IP andGCE_VM_IP_PORT. The instance must be in the same zone of network endpoint group (for zonal NEGs) or in the zone within the region of the NEG (for regional NEGs). If the ipAddress is specified, it must belongs to the VM instance. The name must be 1-63 characters long, and comply withRFC1035 or be a valid URL pointing to an existing instance. Corresponds to the JSON property instance

Returns:

  • (String)


37314
37315
37316
# File 'lib/google/apis/compute_beta/classes.rb', line 37314

def instance
  @instance
end

#ip_addressString

Optional IPv4 address of network endpoint. The IP address must belong to a VM in Compute Engine (either the primary IP or as part of an aliased IP range). If the IP address is not specified, then the primary IP address for the VM instance in the network that the network endpoint group belongs to will be used. This field is redundant and need not be set for network endpoints of typeGCE_VM_IP. If set, it must be set to the primary internal IP address of the attached VM instance that matches the subnetwork of the NEG. The primary internal IP address from any NIC of a multi-NIC VM instance can be added to a NEG as long as it matches the NEG subnetwork. Corresponds to the JSON property ipAddress

Returns:

  • (String)


37328
37329
37330
# File 'lib/google/apis/compute_beta/classes.rb', line 37328

def ip_address
  @ip_address
end

#ipv6_addressString

Optional IPv6 address of network endpoint. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


37333
37334
37335
# File 'lib/google/apis/compute_beta/classes.rb', line 37333

def ipv6_address
  @ipv6_address
end

#portFixnum

Optional port number of network endpoint. If not specified, the defaultPort for the network endpoint group will be used. This field can not be set for network endpoints of typeGCE_VM_IP. Corresponds to the JSON property port

Returns:

  • (Fixnum)


37340
37341
37342
# File 'lib/google/apis/compute_beta/classes.rb', line 37340

def port
  @port
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37347
37348
37349
37350
37351
37352
37353
37354
37355
# File 'lib/google/apis/compute_beta/classes.rb', line 37347

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @client_destination_port = args[:client_destination_port] if args.key?(:client_destination_port)
  @fqdn = args[:fqdn] if args.key?(:fqdn)
  @instance = args[:instance] if args.key?(:instance)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @port = args[:port] if args.key?(:port)
end