Class: Google::Apis::ComputeBeta::NetworkEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a collection of network endpoints. A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview. Note: Use the following APIs to manage network endpoint groups:
- To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity NEGs): zonal
API
To manage NEGs with regional scope (such as regional internet NEGs, serverless NEGs, Private Service Connect NEGs): regional
API
To manage NEGs with global scope (such as global internet NEGs):global API
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#app_engine ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine
Configuration for an App Engine network endpoint group (NEG).
-
#cloud_function ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction
Configuration for a Cloud Function network endpoint group (NEG).
-
#cloud_run ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudRun
Configuration for a Cloud Run network endpoint group (NEG).
-
#creation_timestamp ⇒ String
Output only.
-
#default_port ⇒ Fixnum
The default port used if the port number is not specified in the network endpoint.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#load_balancer ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup
Load balancing specific fields for network endpoint group.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ String
The URL of the network to which all network endpoints in the NEG belong.
-
#network_endpoint_type ⇒ String
Type of network endpoints in this network endpoint group.
-
#psc_data ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupPscData
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
-
#psc_target_service ⇒ String
The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#serverless_deployment ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupServerlessDeployment
Configuration for a serverless network endpoint group (NEG).
-
#size ⇒ Fixnum
Output only.
-
#subnetwork ⇒ String
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroup
constructor
A new instance of NetworkEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroup
Returns a new instance of NetworkEndpointGroup.
39673 39674 39675 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39673 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Metadata defined as annotations on the network endpoint group.
Corresponds to the JSON property annotations
39523 39524 39525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39523 def annotations @annotations end |
#app_engine ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine
Configuration for an App Engine network endpoint group (NEG).
The service is optional, may be provided explicitly or in the
URL mask. The version is optional and can only be provided
explicitly or in the URL mask when service is present.
Note: App Engine service must be in the same project and located in the
same region as the Serverless NEG.
Corresponds to the JSON property appEngine
39533 39534 39535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39533 def app_engine @app_engine end |
#cloud_function ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction
Configuration for a Cloud Function network endpoint group (NEG).
The function must be provided explicitly or in the URL mask.
Note: Cloud Function must be in the same project and located in the same
region as the Serverless NEG.
Corresponds to the JSON property cloudFunction
39541 39542 39543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39541 def cloud_function @cloud_function end |
#cloud_run ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudRun
Configuration for a Cloud Run network endpoint group (NEG).
The service must be provided explicitly or in the URL mask.
The tag is optional, may be provided explicitly or in the URL
mask.
Note: Cloud Run service must be in the same project and located in the same
region as the Serverless NEG.
Corresponds to the JSON property cloudRun
39551 39552 39553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39551 def cloud_run @cloud_run end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
39557 39558 39559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39557 def @creation_timestamp end |
#default_port ⇒ Fixnum
The default port used if the port number is not specified in the network
endpoint.
Optional. If the network endpoint type is either GCE_VM_IP,SERVERLESS or
PRIVATE_SERVICE_CONNECT, this
field must not be specified.
Corresponds to the JSON property defaultPort
39566 39567 39568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39566 def default_port @default_port end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
39572 39573 39574 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39572 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
39579 39580 39581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39579 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
networkEndpointGroup for network endpoint group.
Corresponds to the JSON property kind
39585 39586 39587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39585 def kind @kind end |
#load_balancer ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup
Load balancing specific fields for network endpoint group.
Corresponds to the JSON property loadBalancer
39590 39591 39592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39590 def load_balancer @load_balancer end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
39601 39602 39603 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39601 def name @name end |
#network ⇒ String
The URL of the network to which all network endpoints in the NEG belong.
For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or
NON_GCP_PRIVATE_IP_PORT,
if this field is not specified, a default network will be used.
This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or
PRIVATE_SERVICE_CONNECT and for
global NEGs.
For all other network endpoint types, this field is required.
Corresponds to the JSON property network
39613 39614 39615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39613 def network @network end |
#network_endpoint_type ⇒ String
Type of network endpoints in this network endpoint group. Can be one
ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,
INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP.
Corresponds to the JSON property networkEndpointType
39620 39621 39622 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39620 def network_endpoint_type @network_endpoint_type end |
#psc_data ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupPscData
All data that is specifically relevant to only network endpoint groups of
type PRIVATE_SERVICE_CONNECT.
Corresponds to the JSON property pscData
39626 39627 39628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39626 def psc_data @psc_data end |
#psc_target_service ⇒ String
The target service url used to set up private service connection to
a Google API or a PSC Producer Service Attachment.
An example value is: asia-northeast3-cloudkms.googleapis.com.
Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT.
Corresponds to the JSON property pscTargetService
39634 39635 39636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39634 def psc_target_service @psc_target_service end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the network endpoint group is located.
Corresponds to the JSON property region
39640 39641 39642 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39640 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
39645 39646 39647 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39645 def self_link @self_link end |
#serverless_deployment ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupServerlessDeployment
Configuration for a serverless network endpoint group (NEG). Theplatform must
be provided.
Note: The target backend service must be in the same project and located in
the same region as the Serverless NEG.
Corresponds to the JSON property serverlessDeployment
39653 39654 39655 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39653 def serverless_deployment @serverless_deployment end |
#size ⇒ Fixnum
Output only. [Output only] Number of network endpoints in the network endpoint
group.
Corresponds to the JSON property size
39659 39660 39661 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39659 def size @size end |
#subnetwork ⇒ String
Optional URL of the subnetwork to which all network endpoints in the NEG
belong.
Corresponds to the JSON property subnetwork
39665 39666 39667 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39665 def subnetwork @subnetwork end |
#zone ⇒ String
Output only. [Output Only] The URL of thezone
where the network endpoint group is located.
Corresponds to the JSON property zone
39671 39672 39673 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39671 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39678 39679 39680 39681 39682 39683 39684 39685 39686 39687 39688 39689 39690 39691 39692 39693 39694 39695 39696 39697 39698 39699 39700 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39678 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @app_engine = args[:app_engine] if args.key?(:app_engine) @cloud_function = args[:cloud_function] if args.key?(:cloud_function) @cloud_run = args[:cloud_run] if args.key?(:cloud_run) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_port = args[:default_port] if args.key?(:default_port) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @load_balancer = args[:load_balancer] if args.key?(:load_balancer) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_endpoint_type = args[:network_endpoint_type] if args.key?(:network_endpoint_type) @psc_data = args[:psc_data] if args.key?(:psc_data) @psc_target_service = args[:psc_target_service] if args.key?(:psc_target_service) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @serverless_deployment = args[:serverless_deployment] if args.key?(:serverless_deployment) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |