Class: Google::Apis::ComputeBeta::NetworkEndpointGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a collection of network endpoints. A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview. Note: Use the following APIs to manage network endpoint groups:
- To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity NEGs): zonal
API
To manage NEGs with regional scope (such as regional internet NEGs, serverless NEGs, Private Service Connect NEGs): regional
API
To manage NEGs with global scope (such as global internet NEGs):global API
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#app_engine ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine
Configuration for an App Engine network endpoint group (NEG).
-
#cloud_function ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction
Configuration for a Cloud Function network endpoint group (NEG).
-
#cloud_run ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudRun
Configuration for a Cloud Run network endpoint group (NEG).
-
#creation_timestamp ⇒ String
Output only.
-
#default_port ⇒ Fixnum
The default port used if the port number is not specified in the network endpoint.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#load_balancer ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup
Load balancing specific fields for network endpoint group.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ String
The URL of the network to which all network endpoints in the NEG belong.
-
#network_endpoint_type ⇒ String
Type of network endpoints in this network endpoint group.
-
#psc_data ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupPscData
All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT.
-
#psc_target_service ⇒ String
The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#serverless_deployment ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupServerlessDeployment
Configuration for a serverless network endpoint group (NEG).
-
#size ⇒ Fixnum
Output only.
-
#subnetwork ⇒ String
Optional URL of the subnetwork to which all network endpoints in the NEG belong.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroup
constructor
A new instance of NetworkEndpointGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroup
Returns a new instance of NetworkEndpointGroup.
39118 39119 39120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39118 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Metadata defined as annotations on the network endpoint group.
Corresponds to the JSON property annotations
38974 38975 38976 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38974 def annotations @annotations end |
#app_engine ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine
Configuration for an App Engine network endpoint group (NEG).
The service is optional, may be provided explicitly or in the
URL mask. The version is optional and can only be provided
explicitly or in the URL mask when service is present.
Note: App Engine service must be in the same project and located in the
same region as the Serverless NEG.
Corresponds to the JSON property appEngine
38984 38985 38986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38984 def app_engine @app_engine end |
#cloud_function ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction
Configuration for a Cloud Function network endpoint group (NEG).
The function must be provided explicitly or in the URL mask.
Note: Cloud Function must be in the same project and located in the same
region as the Serverless NEG.
Corresponds to the JSON property cloudFunction
38992 38993 38994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38992 def cloud_function @cloud_function end |
#cloud_run ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupCloudRun
Configuration for a Cloud Run network endpoint group (NEG).
The service must be provided explicitly or in the URL mask.
The tag is optional, may be provided explicitly or in the URL
mask.
Note: Cloud Run service must be in the same project and located in the same
region as the Serverless NEG.
Corresponds to the JSON property cloudRun
39002 39003 39004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39002 def cloud_run @cloud_run end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
39008 39009 39010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39008 def @creation_timestamp end |
#default_port ⇒ Fixnum
The default port used if the port number is not specified in the network
endpoint.
Optional. If the network endpoint type is either GCE_VM_IP,SERVERLESS or
PRIVATE_SERVICE_CONNECT, this
field must not be specified.
Corresponds to the JSON property defaultPort
39017 39018 39019 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39017 def default_port @default_port end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
39023 39024 39025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39023 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
39030 39031 39032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39030 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
networkEndpointGroup for network endpoint group.
Corresponds to the JSON property kind
39036 39037 39038 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39036 def kind @kind end |
#load_balancer ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup
Load balancing specific fields for network endpoint group.
Corresponds to the JSON property loadBalancer
39041 39042 39043 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39041 def load_balancer @load_balancer end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
39052 39053 39054 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39052 def name @name end |
#network ⇒ String
The URL of the network to which all network endpoints in the NEG belong.
Uses default project network if unspecified.
Corresponds to the JSON property network
39058 39059 39060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39058 def network @network end |
#network_endpoint_type ⇒ String
Type of network endpoints in this network endpoint group. Can be one
ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT,
INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP.
Corresponds to the JSON property networkEndpointType
39065 39066 39067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39065 def network_endpoint_type @network_endpoint_type end |
#psc_data ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupPscData
All data that is specifically relevant to only network endpoint groups of
type PRIVATE_SERVICE_CONNECT.
Corresponds to the JSON property pscData
39071 39072 39073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39071 def psc_data @psc_data end |
#psc_target_service ⇒ String
The target service url used to set up private service connection to
a Google API or a PSC Producer Service Attachment.
An example value is: asia-northeast3-cloudkms.googleapis.com.
Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT.
Corresponds to the JSON property pscTargetService
39079 39080 39081 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39079 def psc_target_service @psc_target_service end |
#region ⇒ String
Output only. [Output Only] The URL of theregion
where the network endpoint group is located.
Corresponds to the JSON property region
39085 39086 39087 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39085 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
39090 39091 39092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39090 def self_link @self_link end |
#serverless_deployment ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupServerlessDeployment
Configuration for a serverless network endpoint group (NEG). Theplatform must
be provided.
Note: The target backend service must be in the same project and located in
the same region as the Serverless NEG.
Corresponds to the JSON property serverlessDeployment
39098 39099 39100 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39098 def serverless_deployment @serverless_deployment end |
#size ⇒ Fixnum
Output only. [Output only] Number of network endpoints in the network endpoint
group.
Corresponds to the JSON property size
39104 39105 39106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39104 def size @size end |
#subnetwork ⇒ String
Optional URL of the subnetwork to which all network endpoints in the NEG
belong.
Corresponds to the JSON property subnetwork
39110 39111 39112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39110 def subnetwork @subnetwork end |
#zone ⇒ String
Output only. [Output Only] The URL of thezone
where the network endpoint group is located.
Corresponds to the JSON property zone
39116 39117 39118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39116 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39123 39124 39125 39126 39127 39128 39129 39130 39131 39132 39133 39134 39135 39136 39137 39138 39139 39140 39141 39142 39143 39144 39145 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39123 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @app_engine = args[:app_engine] if args.key?(:app_engine) @cloud_function = args[:cloud_function] if args.key?(:cloud_function) @cloud_run = args[:cloud_run] if args.key?(:cloud_run) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_port = args[:default_port] if args.key?(:default_port) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @load_balancer = args[:load_balancer] if args.key?(:load_balancer) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @network_endpoint_type = args[:network_endpoint_type] if args.key?(:network_endpoint_type) @psc_data = args[:psc_data] if args.key?(:psc_data) @psc_target_service = args[:psc_target_service] if args.key?(:psc_target_service) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @serverless_deployment = args[:serverless_deployment] if args.key?(:serverless_deployment) @size = args[:size] if args.key?(:size) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) @zone = args[:zone] if args.key?(:zone) end |