Class: Google::Apis::ComputeBeta::NetworkEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a collection of network endpoints. A network endpoint group (NEG) defines how a set of endpoints should be reached, whether they are reachable, and where they are located. For more information about using NEGs for different use cases, seeNetwork endpoint groups overview. Note: Use the following APIs to manage network endpoint groups:

- To manage NEGs with zonal scope (such as zonal NEGs, hybrid connectivity NEGs): zonal

API

To manage NEGs with regional scope (such as regional internet NEGs, serverless NEGs, Private Service Connect NEGs): regional

API

To manage NEGs with global scope (such as global internet NEGs):global API

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroup

Returns a new instance of NetworkEndpointGroup.



38343
38344
38345
# File 'lib/google/apis/compute_beta/classes.rb', line 38343

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Metadata defined as annotations on the network endpoint group. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


38199
38200
38201
# File 'lib/google/apis/compute_beta/classes.rb', line 38199

def annotations
  @annotations
end

#app_engineGoogle::Apis::ComputeBeta::NetworkEndpointGroupAppEngine

Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property appEngine



38209
38210
38211
# File 'lib/google/apis/compute_beta/classes.rb', line 38209

def app_engine
  @app_engine
end

#cloud_functionGoogle::Apis::ComputeBeta::NetworkEndpointGroupCloudFunction

Configuration for a Cloud Function network endpoint group (NEG). The function must be provided explicitly or in the URL mask. Note: Cloud Function must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property cloudFunction



38217
38218
38219
# File 'lib/google/apis/compute_beta/classes.rb', line 38217

def cloud_function
  @cloud_function
end

#cloud_runGoogle::Apis::ComputeBeta::NetworkEndpointGroupCloudRun

Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property cloudRun



38227
38228
38229
# File 'lib/google/apis/compute_beta/classes.rb', line 38227

def cloud_run
  @cloud_run
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


38233
38234
38235
# File 'lib/google/apis/compute_beta/classes.rb', line 38233

def creation_timestamp
  @creation_timestamp
end

#default_portFixnum

The default port used if the port number is not specified in the network endpoint. Optional. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified. Corresponds to the JSON property defaultPort

Returns:

  • (Fixnum)


38242
38243
38244
# File 'lib/google/apis/compute_beta/classes.rb', line 38242

def default_port
  @default_port
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


38248
38249
38250
# File 'lib/google/apis/compute_beta/classes.rb', line 38248

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


38255
38256
38257
# File 'lib/google/apis/compute_beta/classes.rb', line 38255

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# networkEndpointGroup for network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


38261
38262
38263
# File 'lib/google/apis/compute_beta/classes.rb', line 38261

def kind
  @kind
end

#load_balancerGoogle::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup

Load balancing specific fields for network endpoint group. Corresponds to the JSON property loadBalancer



38266
38267
38268
# File 'lib/google/apis/compute_beta/classes.rb', line 38266

def load_balancer
  @load_balancer
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


38277
38278
38279
# File 'lib/google/apis/compute_beta/classes.rb', line 38277

def name
  @name
end

#networkString

The URL of the network to which all network endpoints in the NEG belong. Uses default project network if unspecified. Corresponds to the JSON property network

Returns:

  • (String)


38283
38284
38285
# File 'lib/google/apis/compute_beta/classes.rb', line 38283

def network
  @network
end

#network_endpoint_typeString

Type of network endpoints in this network endpoint group. Can be one ofGCE_VM_IP, GCE_VM_IP_PORT,NON_GCP_PRIVATE_IP_PORT, INTERNET_FQDN_PORT, INTERNET_IP_PORT, SERVERLESS,PRIVATE_SERVICE_CONNECT, GCE_VM_IP_PORTMAP. Corresponds to the JSON property networkEndpointType

Returns:

  • (String)


38290
38291
38292
# File 'lib/google/apis/compute_beta/classes.rb', line 38290

def network_endpoint_type
  @network_endpoint_type
end

#psc_dataGoogle::Apis::ComputeBeta::NetworkEndpointGroupPscData

All data that is specifically relevant to only network endpoint groups of type PRIVATE_SERVICE_CONNECT. Corresponds to the JSON property pscData



38296
38297
38298
# File 'lib/google/apis/compute_beta/classes.rb', line 38296

def psc_data
  @psc_data
end

#psc_target_serviceString

The target service url used to set up private service connection to a Google API or a PSC Producer Service Attachment. An example value is: asia-northeast3-cloudkms.googleapis.com. Optional. Only valid when networkEndpointType isPRIVATE_SERVICE_CONNECT. Corresponds to the JSON property pscTargetService

Returns:

  • (String)


38304
38305
38306
# File 'lib/google/apis/compute_beta/classes.rb', line 38304

def psc_target_service
  @psc_target_service
end

#regionString

Output only. [Output Only] The URL of theregion where the network endpoint group is located. Corresponds to the JSON property region

Returns:

  • (String)


38310
38311
38312
# File 'lib/google/apis/compute_beta/classes.rb', line 38310

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38315
38316
38317
# File 'lib/google/apis/compute_beta/classes.rb', line 38315

def self_link
  @self_link
end

#serverless_deploymentGoogle::Apis::ComputeBeta::NetworkEndpointGroupServerlessDeployment

Configuration for a serverless network endpoint group (NEG). Theplatform must be provided. Note: The target backend service must be in the same project and located in the same region as the Serverless NEG. Corresponds to the JSON property serverlessDeployment



38323
38324
38325
# File 'lib/google/apis/compute_beta/classes.rb', line 38323

def serverless_deployment
  @serverless_deployment
end

#sizeFixnum

Output only. [Output only] Number of network endpoints in the network endpoint group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


38329
38330
38331
# File 'lib/google/apis/compute_beta/classes.rb', line 38329

def size
  @size
end

#subnetworkString

Optional URL of the subnetwork to which all network endpoints in the NEG belong. Corresponds to the JSON property subnetwork

Returns:

  • (String)


38335
38336
38337
# File 'lib/google/apis/compute_beta/classes.rb', line 38335

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the network endpoint group is located. Corresponds to the JSON property zone

Returns:

  • (String)


38341
38342
38343
# File 'lib/google/apis/compute_beta/classes.rb', line 38341

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38348
38349
38350
38351
38352
38353
38354
38355
38356
38357
38358
38359
38360
38361
38362
38363
38364
38365
38366
38367
38368
38369
38370
# File 'lib/google/apis/compute_beta/classes.rb', line 38348

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @app_engine = args[:app_engine] if args.key?(:app_engine)
  @cloud_function = args[:cloud_function] if args.key?(:cloud_function)
  @cloud_run = args[:cloud_run] if args.key?(:cloud_run)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_port = args[:default_port] if args.key?(:default_port)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @load_balancer = args[:load_balancer] if args.key?(:load_balancer)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_endpoint_type = args[:network_endpoint_type] if args.key?(:network_endpoint_type)
  @psc_data = args[:psc_data] if args.key?(:psc_data)
  @psc_target_service = args[:psc_target_service] if args.key?(:psc_target_service)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @serverless_deployment = args[:serverless_deployment] if args.key?(:serverless_deployment)
  @size = args[:size] if args.key?(:size)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end