Class: Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



39727
39728
39729
# File 'lib/google/apis/compute_beta/classes.rb', line 39727

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39688
39689
39690
# File 'lib/google/apis/compute_beta/classes.rb', line 39688

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



39693
39694
39695
# File 'lib/google/apis/compute_beta/classes.rb', line 39693

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


39700
39701
39702
# File 'lib/google/apis/compute_beta/classes.rb', line 39700

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39710
39711
39712
# File 'lib/google/apis/compute_beta/classes.rb', line 39710

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39715
39716
39717
# File 'lib/google/apis/compute_beta/classes.rb', line 39715

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39720
39721
39722
# File 'lib/google/apis/compute_beta/classes.rb', line 39720

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39725
39726
39727
# File 'lib/google/apis/compute_beta/classes.rb', line 39725

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39732
39733
39734
39735
39736
39737
39738
39739
39740
# File 'lib/google/apis/compute_beta/classes.rb', line 39732

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end