Class: Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



39194
39195
39196
# File 'lib/google/apis/compute_beta/classes.rb', line 39194

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39155
39156
39157
# File 'lib/google/apis/compute_beta/classes.rb', line 39155

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



39160
39161
39162
# File 'lib/google/apis/compute_beta/classes.rb', line 39160

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


39167
39168
39169
# File 'lib/google/apis/compute_beta/classes.rb', line 39167

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39177
39178
39179
# File 'lib/google/apis/compute_beta/classes.rb', line 39177

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39182
39183
39184
# File 'lib/google/apis/compute_beta/classes.rb', line 39182

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39187
39188
39189
# File 'lib/google/apis/compute_beta/classes.rb', line 39187

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39192
39193
39194
# File 'lib/google/apis/compute_beta/classes.rb', line 39192

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39199
39200
39201
39202
39203
39204
39205
39206
39207
# File 'lib/google/apis/compute_beta/classes.rb', line 39199

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end