Class: Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList

Returns a new instance of NetworkEndpointGroupAggregatedList.



37602
37603
37604
# File 'lib/google/apis/compute_beta/classes.rb', line 37602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


37563
37564
37565
# File 'lib/google/apis/compute_beta/classes.rb', line 37563

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkEndpointGroupsScopedList>

A list of NetworkEndpointGroupsScopedList resources. Corresponds to the JSON property items



37568
37569
37570
# File 'lib/google/apis/compute_beta/classes.rb', line 37568

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupAggregatedList for aggregated lists of network endpoint groups. Corresponds to the JSON property kind

Returns:

  • (String)


37575
37576
37577
# File 'lib/google/apis/compute_beta/classes.rb', line 37575

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


37585
37586
37587
# File 'lib/google/apis/compute_beta/classes.rb', line 37585

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37590
37591
37592
# File 'lib/google/apis/compute_beta/classes.rb', line 37590

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


37595
37596
37597
# File 'lib/google/apis/compute_beta/classes.rb', line 37595

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



37600
37601
37602
# File 'lib/google/apis/compute_beta/classes.rb', line 37600

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37607
37608
37609
37610
37611
37612
37613
37614
37615
# File 'lib/google/apis/compute_beta/classes.rb', line 37607

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end