Class: Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkEndpointGroupsScopedList>
A list of NetworkEndpointGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList
constructor
A new instance of NetworkEndpointGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupAggregatedList
Returns a new instance of NetworkEndpointGroupAggregatedList.
36220 36221 36222 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36220 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
36181 36182 36183 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36181 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkEndpointGroupsScopedList>
A list of NetworkEndpointGroupsScopedList resources.
Corresponds to the JSON property items
36186 36187 36188 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36186 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupAggregatedList for aggregated
lists of network endpoint groups.
Corresponds to the JSON property kind
36193 36194 36195 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36193 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
36203 36204 36205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36203 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
36208 36209 36210 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36208 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
36213 36214 36215 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36213 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
36218 36219 36220 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36218 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
36225 36226 36227 36228 36229 36230 36231 36232 36233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 36225 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |