Class: Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupAppEngine
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration for an App Engine network endpoint group (NEG). The service is optional, may be provided explicitly or in the URL mask. The version is optional and can only be provided explicitly or in the URL mask when service is present. Note: App Engine service must be in the same project and located in the same region as the Serverless NEG.
Instance Attribute Summary collapse
-
#service ⇒ String
Optional serving service.
-
#url_mask ⇒ String
An URL mask is one of the main components of the Cloud Function.
-
#version ⇒ String
Optional serving version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupAppEngine
constructor
A new instance of NetworkEndpointGroupAppEngine.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupAppEngine
Returns a new instance of NetworkEndpointGroupAppEngine.
40380 40381 40382 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40380 def initialize(**args) update!(**args) end |
Instance Attribute Details
#service ⇒ String
Optional serving service.
The service name is case-sensitive and must be 1-63
characters long.
Example value: default, my-service.
Corresponds to the JSON property service
40354 40355 40356 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40354 def service @service end |
#url_mask ⇒ String
An URL
mask is one of the main components of the Cloud Function.
A template to parse service and version fields
from a request URL. URL mask allows for routing to multiple App Engine
services without having to create multiple Network Endpoint Groups and
backend services.
For example, the request URLsfoo1-dot-appname.appspot.com/v1 andfoo1-dot-
appname.appspot.com/v2 can be backed by the same
Serverless NEG with URL maskservice = "foo1", version = "v1"
and service = "foo1", version = "v2"
respectively.
Corresponds to the JSON property urlMask
40370 40371 40372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40370 def url_mask @url_mask end |
#version ⇒ String
Optional serving version.
The version name is case-sensitive and must be 1-100
characters long.
Example value: v1, v2.
Corresponds to the JSON property version
40378 40379 40380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40378 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40385 40386 40387 40388 40389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40385 def update!(**args) @service = args[:service] if args.key?(:service) @url_mask = args[:url_mask] if args.key?(:url_mask) @version = args[:version] if args.key?(:version) end |