Class: Google::Apis::ComputeBeta::NetworkEndpointGroupCloudRun

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration for a Cloud Run network endpoint group (NEG). The service must be provided explicitly or in the URL mask. The tag is optional, may be provided explicitly or in the URL mask. Note: Cloud Run service must be in the same project and located in the same region as the Serverless NEG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupCloudRun

Returns a new instance of NetworkEndpointGroupCloudRun.



40074
40075
40076
# File 'lib/google/apis/compute_beta/classes.rb', line 40074

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#serviceString

Cloud Run service is the main resource of Cloud Run. The service must be 1-63 characters long, and comply withRFC1035. Example value: "run-service". Corresponds to the JSON property service

Returns:

  • (String)


40048
40049
40050
# File 'lib/google/apis/compute_beta/classes.rb', line 40048

def service
  @service
end

#tagString

Optional Cloud Run tag represents the "named-revision" to provide additional fine-grained traffic routing information. The tag must be 1-63 characters long, and comply withRFC1035. Example value: "revision-0010". Corresponds to the JSON property tag

Returns:

  • (String)


40056
40057
40058
# File 'lib/google/apis/compute_beta/classes.rb', line 40056

def tag
  @tag
end

#url_maskString

An URL mask is one of the main components of the Cloud Function. A template to parse and fields from a request URL. URL mask allows for routing to multiple Run services without having to create multiple network endpoint groups and backend services. For example, request URLs foo1.domain.com/bar1 andfoo1.domain.com/bar2 can be backed by the same Serverless Network Endpoint Group (NEG) with URL mask.domain.com/. The URL mask will parse them to service="bar1", tag="foo1" and service="bar2", tag="foo2" respectively. Corresponds to the JSON property urlMask

Returns:

  • (String)


40072
40073
40074
# File 'lib/google/apis/compute_beta/classes.rb', line 40072

def url_mask
  @url_mask
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40079
40080
40081
40082
40083
# File 'lib/google/apis/compute_beta/classes.rb', line 40079

def update!(**args)
  @service = args[:service] if args.key?(:service)
  @tag = args[:tag] if args.key?(:tag)
  @url_mask = args[:url_mask] if args.key?(:url_mask)
end