Class: Google::Apis::ComputeBeta::NetworkEndpointGroupLbNetworkEndpointGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Load balancing specific fields for network endpoint group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupLbNetworkEndpointGroup

Returns a new instance of NetworkEndpointGroupLbNetworkEndpointGroup.



40063
40064
40065
# File 'lib/google/apis/compute_beta/classes.rb', line 40063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#default_portFixnum

The default port used if the port number is not specified in the network endpoint. If the network endpoint type is either GCE_VM_IP,SERVERLESS or PRIVATE_SERVICE_CONNECT, this field must not be specified. [Deprecated] This field is deprecated. Corresponds to the JSON property defaultPort

Returns:

  • (Fixnum)


40034
40035
40036
# File 'lib/google/apis/compute_beta/classes.rb', line 40034

def default_port
  @default_port
end

#networkString

The URL of the network to which all network endpoints in the NEG belong. For networkEndpointType GCE_VM_IP_PORT,GCE_VM_IP_PORTMAP or NON_GCP_PRIVATE_IP_PORT, if this field is not specified, a default network will be used. This field cannot be set for NEGs with networkEndpointType set toSERVERLESS or PRIVATE_SERVICE_CONNECT and for global NEGs. For all other network endpoint types, this field is required. [Deprecated] This field is deprecated. Corresponds to the JSON property network

Returns:

  • (String)


40047
40048
40049
# File 'lib/google/apis/compute_beta/classes.rb', line 40047

def network
  @network
end

#subnetworkString

Optional URL of the subnetwork to which all network endpoints in the NEG belong. [Deprecated] This field is deprecated. Corresponds to the JSON property subnetwork

Returns:

  • (String)


40054
40055
40056
# File 'lib/google/apis/compute_beta/classes.rb', line 40054

def subnetwork
  @subnetwork
end

#zoneString

Output only. [Output Only] The URL of thezone where the network endpoint group is located. [Deprecated] This field is deprecated. Corresponds to the JSON property zone

Returns:

  • (String)


40061
40062
40063
# File 'lib/google/apis/compute_beta/classes.rb', line 40061

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40068
40069
40070
40071
40072
40073
# File 'lib/google/apis/compute_beta/classes.rb', line 40068

def update!(**args)
  @default_port = args[:default_port] if args.key?(:default_port)
  @network = args[:network] if args.key?(:network)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @zone = args[:zone] if args.key?(:zone)
end