Class: Google::Apis::ComputeBeta::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



40131
40132
40133
# File 'lib/google/apis/compute_beta/classes.rb', line 40131

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40097
40098
40099
# File 'lib/google/apis/compute_beta/classes.rb', line 40097

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



40102
40103
40104
# File 'lib/google/apis/compute_beta/classes.rb', line 40102

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


40109
40110
40111
# File 'lib/google/apis/compute_beta/classes.rb', line 40109

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40119
40120
40121
# File 'lib/google/apis/compute_beta/classes.rb', line 40119

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40124
40125
40126
# File 'lib/google/apis/compute_beta/classes.rb', line 40124

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40129
40130
40131
# File 'lib/google/apis/compute_beta/classes.rb', line 40129

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40136
40137
40138
40139
40140
40141
40142
40143
# File 'lib/google/apis/compute_beta/classes.rb', line 40136

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end