Class: Google::Apis::ComputeBeta::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
40117 40118 40119 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40083 40084 40085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40083 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
40088 40089 40090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40088 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
40095 40096 40097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40095 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40105 40106 40107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40105 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40110 40111 40112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40110 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40115 40116 40117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40115 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40122 40123 40124 40125 40126 40127 40128 40129 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40122 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |