Class: Google::Apis::ComputeBeta::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



40075
40076
40077
# File 'lib/google/apis/compute_beta/classes.rb', line 40075

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40041
40042
40043
# File 'lib/google/apis/compute_beta/classes.rb', line 40041

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



40046
40047
40048
# File 'lib/google/apis/compute_beta/classes.rb', line 40046

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


40053
40054
40055
# File 'lib/google/apis/compute_beta/classes.rb', line 40053

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40063
40064
40065
# File 'lib/google/apis/compute_beta/classes.rb', line 40063

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40068
40069
40070
# File 'lib/google/apis/compute_beta/classes.rb', line 40068

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40073
40074
40075
# File 'lib/google/apis/compute_beta/classes.rb', line 40073

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40080
40081
40082
40083
40084
40085
40086
40087
# File 'lib/google/apis/compute_beta/classes.rb', line 40080

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end