Class: Google::Apis::ComputeBeta::NetworkEndpointGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupList
constructor
A new instance of NetworkEndpointGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupList
Returns a new instance of NetworkEndpointGroupList.
39514 39515 39516 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39514 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39480 39481 39482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39480 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointGroup>
A list of NetworkEndpointGroup resources.
Corresponds to the JSON property items
39485 39486 39487 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39485 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupList for network endpoint group
lists.
Corresponds to the JSON property kind
39492 39493 39494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39492 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39502 39503 39504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39502 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39507 39508 39509 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39507 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39512 39513 39514 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39512 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39519 39520 39521 39522 39523 39524 39525 39526 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39519 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |