Class: Google::Apis::ComputeBeta::NetworkEndpointGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupList

Returns a new instance of NetworkEndpointGroupList.



36540
36541
36542
# File 'lib/google/apis/compute_beta/classes.rb', line 36540

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


36506
36507
36508
# File 'lib/google/apis/compute_beta/classes.rb', line 36506

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkEndpointGroup>

A list of NetworkEndpointGroup resources. Corresponds to the JSON property items



36511
36512
36513
# File 'lib/google/apis/compute_beta/classes.rb', line 36511

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupList for network endpoint group lists. Corresponds to the JSON property kind

Returns:

  • (String)


36518
36519
36520
# File 'lib/google/apis/compute_beta/classes.rb', line 36518

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


36528
36529
36530
# File 'lib/google/apis/compute_beta/classes.rb', line 36528

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


36533
36534
36535
# File 'lib/google/apis/compute_beta/classes.rb', line 36533

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



36538
36539
36540
# File 'lib/google/apis/compute_beta/classes.rb', line 36538

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



36545
36546
36547
36548
36549
36550
36551
36552
# File 'lib/google/apis/compute_beta/classes.rb', line 36545

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end