Class: Google::Apis::ComputeBeta::NetworkEndpointGroupServerlessDeployment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration for a serverless network endpoint group (NEG). Theplatform must be provided. Note: The target backend service must be in the same project and located in the same region as the Serverless NEG.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupServerlessDeployment

Returns a new instance of NetworkEndpointGroupServerlessDeployment.



40239
40240
40241
# File 'lib/google/apis/compute_beta/classes.rb', line 40239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#platformString

The platform of the backend target(s) of this NEG. The only supported value is API Gateway: apigateway.googleapis.com. Corresponds to the JSON property platform

Returns:

  • (String)


40195
40196
40197
# File 'lib/google/apis/compute_beta/classes.rb', line 40195

def platform
  @platform
end

#resourceString

The user-defined name of the workload/instance. This value must be provided explicitly or in the urlMask. The resource identified by this value is platform-specific and is as follows:

  1. API Gateway: The gateway ID
  2. App Engine: The service name
  3. Cloud Functions: The function name
  4. Cloud Run: The service name Corresponds to the JSON property resource

Returns:

  • (String)


40208
40209
40210
# File 'lib/google/apis/compute_beta/classes.rb', line 40208

def resource
  @resource
end

#url_maskString

An URL mask is one of the main components of the Cloud Function. A template to parse platform-specific fields from a request URL. URL mask allows for routing to multiple resources on the same serverless platform without having to create multiple Network Endpoint Groups and backend resources. The fields parsed by this template are platform-specific and are as follows:

  1. API Gateway: The gateway ID
  2. App Engine: The service and version
  3. Cloud Functions: The function name
  4. Cloud Run: The service and tag Corresponds to the JSON property urlMask

Returns:

  • (String)


40225
40226
40227
# File 'lib/google/apis/compute_beta/classes.rb', line 40225

def url_mask
  @url_mask
end

#versionString

The optional resource version. The version identified by this value is platform-specific and is follows:

  1. API Gateway: Unused
  2. App Engine: The service version
  3. Cloud Functions: Unused
  4. Cloud Run: The service tag Corresponds to the JSON property version

Returns:

  • (String)


40237
40238
40239
# File 'lib/google/apis/compute_beta/classes.rb', line 40237

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40244
40245
40246
40247
40248
40249
# File 'lib/google/apis/compute_beta/classes.rb', line 40244

def update!(**args)
  @platform = args[:platform] if args.key?(:platform)
  @resource = args[:resource] if args.key?(:resource)
  @url_mask = args[:url_mask] if args.key?(:url_mask)
  @version = args[:version] if args.key?(:version)
end