Class: Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



40504
40505
40506
# File 'lib/google/apis/compute_beta/classes.rb', line 40504

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40475
40476
40477
# File 'lib/google/apis/compute_beta/classes.rb', line 40475

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



40480
40481
40482
# File 'lib/google/apis/compute_beta/classes.rb', line 40480

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


40487
40488
40489
# File 'lib/google/apis/compute_beta/classes.rb', line 40487

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40497
40498
40499
# File 'lib/google/apis/compute_beta/classes.rb', line 40497

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40502
40503
40504
# File 'lib/google/apis/compute_beta/classes.rb', line 40502

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40509
40510
40511
40512
40513
40514
40515
# File 'lib/google/apis/compute_beta/classes.rb', line 40509

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end