Class: Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
constructor
A new instance of NetworkEndpointGroupsListNetworkEndpoints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.
40440 40441 40442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40411 40412 40413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40411 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
Corresponds to the JSON property items
40416 40417 40418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40416 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupsListNetworkEndpoints for the list
of network endpoints in the specified network endpoint group.
Corresponds to the JSON property kind
40423 40424 40425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40423 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40433 40434 40435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40433 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40438 40439 40440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40438 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40445 40446 40447 40448 40449 40450 40451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40445 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |