Class: Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints

Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.



39837
39838
39839
# File 'lib/google/apis/compute_beta/classes.rb', line 39837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39808
39809
39810
# File 'lib/google/apis/compute_beta/classes.rb', line 39808

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkEndpointWithHealthStatus>

A list of NetworkEndpointWithHealthStatus resources. Corresponds to the JSON property items



39813
39814
39815
# File 'lib/google/apis/compute_beta/classes.rb', line 39813

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute# networkEndpointGroupsListNetworkEndpoints for the list of network endpoints in the specified network endpoint group. Corresponds to the JSON property kind

Returns:

  • (String)


39820
39821
39822
# File 'lib/google/apis/compute_beta/classes.rb', line 39820

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39830
39831
39832
# File 'lib/google/apis/compute_beta/classes.rb', line 39830

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39835
39836
39837
# File 'lib/google/apis/compute_beta/classes.rb', line 39835

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39842
39843
39844
39845
39846
39847
39848
# File 'lib/google/apis/compute_beta/classes.rb', line 39842

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end