Class: Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
constructor
A new instance of NetworkEndpointGroupsListNetworkEndpoints.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkEndpointGroupsListNetworkEndpoints
Returns a new instance of NetworkEndpointGroupsListNetworkEndpoints.
38245 38246 38247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38245 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38216 38217 38218 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38216 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkEndpointWithHealthStatus>
A list of NetworkEndpointWithHealthStatus resources.
Corresponds to the JSON property items
38221 38222 38223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38221 def items @items end |
#kind ⇒ String
Output only. [Output Only] The resource type, which is alwayscompute#
networkEndpointGroupsListNetworkEndpoints for the list
of network endpoints in the specified network endpoint group.
Corresponds to the JSON property kind
38228 38229 38230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38228 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38238 38239 38240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38238 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkEndpointGroupsListNetworkEndpoints::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38243 38244 38245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38243 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38250 38251 38252 38253 38254 38255 38256 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38250 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |