Class: Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



40761
40762
40763
# File 'lib/google/apis/compute_beta/classes.rb', line 40761

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40722
40723
40724
# File 'lib/google/apis/compute_beta/classes.rb', line 40722

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



40727
40728
40729
# File 'lib/google/apis/compute_beta/classes.rb', line 40727

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


40734
40735
40736
# File 'lib/google/apis/compute_beta/classes.rb', line 40734

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40744
40745
40746
# File 'lib/google/apis/compute_beta/classes.rb', line 40744

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40749
40750
40751
# File 'lib/google/apis/compute_beta/classes.rb', line 40749

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40754
40755
40756
# File 'lib/google/apis/compute_beta/classes.rb', line 40754

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40759
40760
40761
# File 'lib/google/apis/compute_beta/classes.rb', line 40759

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40766
40767
40768
40769
40770
40771
40772
40773
40774
# File 'lib/google/apis/compute_beta/classes.rb', line 40766

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end