Class: Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



40633
40634
40635
# File 'lib/google/apis/compute_beta/classes.rb', line 40633

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40594
40595
40596
# File 'lib/google/apis/compute_beta/classes.rb', line 40594

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



40599
40600
40601
# File 'lib/google/apis/compute_beta/classes.rb', line 40599

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


40606
40607
40608
# File 'lib/google/apis/compute_beta/classes.rb', line 40606

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40616
40617
40618
# File 'lib/google/apis/compute_beta/classes.rb', line 40616

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40621
40622
40623
# File 'lib/google/apis/compute_beta/classes.rb', line 40621

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40626
40627
40628
# File 'lib/google/apis/compute_beta/classes.rb', line 40626

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40631
40632
40633
# File 'lib/google/apis/compute_beta/classes.rb', line 40631

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40638
40639
40640
40641
40642
40643
40644
40645
40646
# File 'lib/google/apis/compute_beta/classes.rb', line 40638

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end