Class: Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList

Returns a new instance of NetworkFirewallPolicyAggregatedList.



38502
38503
38504
# File 'lib/google/apis/compute_beta/classes.rb', line 38502

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38463
38464
38465
# File 'lib/google/apis/compute_beta/classes.rb', line 38463

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::FirewallPoliciesScopedList>

A list of FirewallPoliciesScopedList resources. Corresponds to the JSON property items



38468
38469
38470
# File 'lib/google/apis/compute_beta/classes.rb', line 38468

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkFirewallPoliciesAggregatedList for lists of network firewall policies. Corresponds to the JSON property kind

Returns:

  • (String)


38475
38476
38477
# File 'lib/google/apis/compute_beta/classes.rb', line 38475

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38485
38486
38487
# File 'lib/google/apis/compute_beta/classes.rb', line 38485

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


38490
38491
38492
# File 'lib/google/apis/compute_beta/classes.rb', line 38490

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


38495
38496
38497
# File 'lib/google/apis/compute_beta/classes.rb', line 38495

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38500
38501
38502
# File 'lib/google/apis/compute_beta/classes.rb', line 38500

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38507
38508
38509
38510
38511
38512
38513
38514
38515
# File 'lib/google/apis/compute_beta/classes.rb', line 38507

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end