Class: Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::FirewallPoliciesScopedList>
A list of FirewallPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList
constructor
A new instance of NetworkFirewallPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkFirewallPolicyAggregatedList
Returns a new instance of NetworkFirewallPolicyAggregatedList.
37120 37121 37122 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
37081 37082 37083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37081 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::FirewallPoliciesScopedList>
A list of FirewallPoliciesScopedList resources.
Corresponds to the JSON property items
37086 37087 37088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37086 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkFirewallPoliciesAggregatedList for lists of
network firewall policies.
Corresponds to the JSON property kind
37093 37094 37095 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37093 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
37103 37104 37105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37103 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
37108 37109 37110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37108 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
37113 37114 37115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37113 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkFirewallPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
37118 37119 37120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37118 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37125 37126 37127 37128 37129 37130 37131 37132 37133 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37125 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |