Class: Google::Apis::ComputeBeta::NetworkInterface

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A network interface resource attached to an instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkInterface

Returns a new instance of NetworkInterface.



40426
40427
40428
# File 'lib/google/apis/compute_beta/classes.rb', line 40426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_configsArray<Google::Apis::ComputeBeta::AccessConfig>

An array of configurations for this interface. Currently, only one access config, ONE_TO_ONE_NAT, is supported. If there are noaccessConfigs specified, then this instance will have no external internet access. Corresponds to the JSON property accessConfigs



40249
40250
40251
# File 'lib/google/apis/compute_beta/classes.rb', line 40249

def access_configs
  @access_configs
end

#alias_ip_rangesArray<Google::Apis::ComputeBeta::AliasIpRange>

An array of alias IP ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpRanges



40255
40256
40257
# File 'lib/google/apis/compute_beta/classes.rb', line 40255

def alias_ip_ranges
  @alias_ip_ranges
end

#alias_ipv6_rangesArray<Google::Apis::ComputeBeta::AliasIpRange>

An array of alias IPv6 ranges for this network interface. You can only specify this field for network interfaces in VPC networks. Corresponds to the JSON property aliasIpv6Ranges



40261
40262
40263
# File 'lib/google/apis/compute_beta/classes.rb', line 40261

def alias_ipv6_ranges
  @alias_ipv6_ranges
end

#enable_vpc_scoped_dnsBoolean Also known as: enable_vpc_scoped_dns?

Optional. If true, DNS resolution will be enabled over this interface. Only valid with network_attachment. Corresponds to the JSON property enableVpcScopedDns

Returns:

  • (Boolean)


40268
40269
40270
# File 'lib/google/apis/compute_beta/classes.rb', line 40268

def enable_vpc_scoped_dns
  @enable_vpc_scoped_dns
end

#fingerprintString

Fingerprint hash of contents stored in this network interface. This field will be ignored when inserting an Instance or adding a NetworkInterface. An up-to-date fingerprint must be provided in order to update theNetworkInterface. The request will fail with error400 Bad Request if the fingerprint is not provided, or412 Precondition Failed if the fingerprint is out of date. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


40280
40281
40282
# File 'lib/google/apis/compute_beta/classes.rb', line 40280

def fingerprint
  @fingerprint
end

#igmp_queryString

Indicate whether igmp query is enabled on the network interface or not. If enabled, also indicates the version of IGMP supported. Corresponds to the JSON property igmpQuery

Returns:

  • (String)


40286
40287
40288
# File 'lib/google/apis/compute_beta/classes.rb', line 40286

def igmp_query
  @igmp_query
end

#internal_ipv6_prefix_lengthFixnum

The prefix length of the primary internal IPv6 range. Corresponds to the JSON property internalIpv6PrefixLength

Returns:

  • (Fixnum)


40291
40292
40293
# File 'lib/google/apis/compute_beta/classes.rb', line 40291

def internal_ipv6_prefix_length
  @internal_ipv6_prefix_length
end

#ipv6_access_configsArray<Google::Apis::ComputeBeta::AccessConfig>

An array of IPv6 access configurations for this interface. Currently, only one IPv6 access config, DIRECT_IPV6, is supported. If there is no ipv6AccessConfig specified, then this instance will have no external IPv6 Internet access. Corresponds to the JSON property ipv6AccessConfigs



40299
40300
40301
# File 'lib/google/apis/compute_beta/classes.rb', line 40299

def ipv6_access_configs
  @ipv6_access_configs
end

#ipv6_access_typeString

Output only. [Output Only] One of EXTERNAL, INTERNAL to indicate whether the IP can be accessed from the Internet. This field is always inherited from its subnetwork. Valid only if stackType is IPV4_IPV6. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


40308
40309
40310
# File 'lib/google/apis/compute_beta/classes.rb', line 40308

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_addressString

An IPv6 internal network address for this network interface. To use a static internal IP address, it must be unused and in the same region as the instance's zone. If not specified, Google Cloud will automatically assign an internal IPv6 address from the instance's subnetwork. Corresponds to the JSON property ipv6Address

Returns:

  • (String)


40316
40317
40318
# File 'lib/google/apis/compute_beta/classes.rb', line 40316

def ipv6_address
  @ipv6_address
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# networkInterface for network interfaces. Corresponds to the JSON property kind

Returns:

  • (String)


40322
40323
40324
# File 'lib/google/apis/compute_beta/classes.rb', line 40322

def kind
  @kind
end

#mac_addressString

Output only. [Output Only] MAC address assigned to this network interface. Corresponds to the JSON property macAddress

Returns:

  • (String)


40327
40328
40329
# File 'lib/google/apis/compute_beta/classes.rb', line 40327

def mac_address
  @mac_address
end

#nameString

[Output Only] The name of the network interface, which is generated by the server. For a VM, the network interface uses the nicN naming format. Where N is a value between 0 and7. The default interface value is nic0. Corresponds to the JSON property name

Returns:

  • (String)


40334
40335
40336
# File 'lib/google/apis/compute_beta/classes.rb', line 40334

def name
  @name
end

#networkString

URL of the VPC network resource for this instance. When creating an instance, if neither the network nor the subnetwork is specified, the default network global/networks/default is used. If the selected project doesn't have the default network, you must specify a network or subnet. If the network is not specified but the subnetwork is specified, the network is inferred. If you specify this property, you can specify the network as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


40352
40353
40354
# File 'lib/google/apis/compute_beta/classes.rb', line 40352

def network
  @network
end

#network_attachmentString

The URL of the network attachment that this interface should connect to in the following format: projects/project_number/regions/region_name/networkAttachments/ network_attachment_name. Corresponds to the JSON property networkAttachment

Returns:

  • (String)


40360
40361
40362
# File 'lib/google/apis/compute_beta/classes.rb', line 40360

def network_attachment
  @network_attachment
end

#network_ipString

An IPv4 internal IP address to assign to the instance for this network interface. If not specified by the user, an unused internal IP is assigned by the system. Corresponds to the JSON property networkIP

Returns:

  • (String)


40367
40368
40369
# File 'lib/google/apis/compute_beta/classes.rb', line 40367

def network_ip
  @network_ip
end

#nic_typeString

The type of vNIC to be used on this interface. This may be gVNIC or VirtioNet. Corresponds to the JSON property nicType

Returns:

  • (String)


40373
40374
40375
# File 'lib/google/apis/compute_beta/classes.rb', line 40373

def nic_type
  @nic_type
end

#parent_nic_nameString

Name of the parent network interface of a dynamic network interface. Corresponds to the JSON property parentNicName

Returns:

  • (String)


40378
40379
40380
# File 'lib/google/apis/compute_beta/classes.rb', line 40378

def parent_nic_name
  @parent_nic_name
end

#queue_countFixnum

The networking queue count that's specified by users for the network interface. Both Rx and Tx queues will be set to this number. It'll be empty if not specified by the users. Corresponds to the JSON property queueCount

Returns:

  • (Fixnum)


40385
40386
40387
# File 'lib/google/apis/compute_beta/classes.rb', line 40385

def queue_count
  @queue_count
end

#service_class_idString

Optional. Producer Service's Service class Id for the region of this network interface. Can only be used with network_attachment. It is not possible to use on its own however, network_attachment can be used without service_class_id. Corresponds to the JSON property serviceClassId

Returns:

  • (String)


40393
40394
40395
# File 'lib/google/apis/compute_beta/classes.rb', line 40393

def service_class_id
  @service_class_id
end

#stack_typeString

The stack type for this network interface. To assign only IPv4 addresses, use IPV4_ONLY. To assign both IPv4 and IPv6 addresses, useIPV4_IPV6. If not specified, IPV4_ONLY is used. This field can be both set at instance creation and update network interface operations. Corresponds to the JSON property stackType

Returns:

  • (String)


40402
40403
40404
# File 'lib/google/apis/compute_beta/classes.rb', line 40402

def stack_type
  @stack_type
end

#subnetworkString

The URL of the Subnetwork resource for this instance. If the network resource is inlegacy mode, do not specify this field. If the network is in auto subnet mode, specifying the subnetwork is optional. If the network is in custom subnet mode, specifying the subnetwork is required. If you specify this field, you can specify the subnetwork as a full or partial URL. For example, the following are all valid URLs:

Returns:

  • (String)


40418
40419
40420
# File 'lib/google/apis/compute_beta/classes.rb', line 40418

def subnetwork
  @subnetwork
end

#vlanFixnum

VLAN tag of a dynamic network interface, must be an integer in the range from 2 to 255 inclusively. Corresponds to the JSON property vlan

Returns:

  • (Fixnum)


40424
40425
40426
# File 'lib/google/apis/compute_beta/classes.rb', line 40424

def vlan
  @vlan
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40431
40432
40433
40434
40435
40436
40437
40438
40439
40440
40441
40442
40443
40444
40445
40446
40447
40448
40449
40450
40451
40452
40453
40454
40455
# File 'lib/google/apis/compute_beta/classes.rb', line 40431

def update!(**args)
  @access_configs = args[:access_configs] if args.key?(:access_configs)
  @alias_ip_ranges = args[:alias_ip_ranges] if args.key?(:alias_ip_ranges)
  @alias_ipv6_ranges = args[:alias_ipv6_ranges] if args.key?(:alias_ipv6_ranges)
  @enable_vpc_scoped_dns = args[:enable_vpc_scoped_dns] if args.key?(:enable_vpc_scoped_dns)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @igmp_query = args[:igmp_query] if args.key?(:igmp_query)
  @internal_ipv6_prefix_length = args[:internal_ipv6_prefix_length] if args.key?(:internal_ipv6_prefix_length)
  @ipv6_access_configs = args[:ipv6_access_configs] if args.key?(:ipv6_access_configs)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_address = args[:ipv6_address] if args.key?(:ipv6_address)
  @kind = args[:kind] if args.key?(:kind)
  @mac_address = args[:mac_address] if args.key?(:mac_address)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @network_attachment = args[:network_attachment] if args.key?(:network_attachment)
  @network_ip = args[:network_ip] if args.key?(:network_ip)
  @nic_type = args[:nic_type] if args.key?(:nic_type)
  @parent_nic_name = args[:parent_nic_name] if args.key?(:parent_nic_name)
  @queue_count = args[:queue_count] if args.key?(:queue_count)
  @service_class_id = args[:service_class_id] if args.key?(:service_class_id)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @subnetwork = args[:subnetwork] if args.key?(:subnetwork)
  @vlan = args[:vlan] if args.key?(:vlan)
end