Class: Google::Apis::ComputeBeta::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



41106
41107
41108
# File 'lib/google/apis/compute_beta/classes.rb', line 41106

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41073
41074
41075
# File 'lib/google/apis/compute_beta/classes.rb', line 41073

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Network>

A list of Network resources. Corresponds to the JSON property items



41078
41079
41080
# File 'lib/google/apis/compute_beta/classes.rb', line 41078

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


41084
41085
41086
# File 'lib/google/apis/compute_beta/classes.rb', line 41084

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41094
41095
41096
# File 'lib/google/apis/compute_beta/classes.rb', line 41094

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41099
41100
41101
# File 'lib/google/apis/compute_beta/classes.rb', line 41099

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41104
41105
41106
# File 'lib/google/apis/compute_beta/classes.rb', line 41104

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41111
41112
41113
41114
41115
41116
41117
41118
# File 'lib/google/apis/compute_beta/classes.rb', line 41111

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end