Class: Google::Apis::ComputeBeta::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
41056 41057 41058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41056 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41023 41024 41025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41023 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
Corresponds to the JSON property items
41028 41029 41030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41028 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
41034 41035 41036 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41034 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41044 41045 41046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41044 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41049 41050 41051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41049 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41054 41055 41056 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41054 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41061 41062 41063 41064 41065 41066 41067 41068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41061 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |