Class: Google::Apis::ComputeBeta::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
41042 41043 41044 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41009 41010 41011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41009 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
Corresponds to the JSON property items
41014 41015 41016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41014 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
41020 41021 41022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41020 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41030 41031 41032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41030 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41035 41036 41037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41035 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41040 41041 41042 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41040 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41047 41048 41049 41050 41051 41052 41053 41054 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41047 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |