Class: Google::Apis::ComputeBeta::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



41000
41001
41002
# File 'lib/google/apis/compute_beta/classes.rb', line 41000

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40967
40968
40969
# File 'lib/google/apis/compute_beta/classes.rb', line 40967

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Network>

A list of Network resources. Corresponds to the JSON property items



40972
40973
40974
# File 'lib/google/apis/compute_beta/classes.rb', line 40972

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


40978
40979
40980
# File 'lib/google/apis/compute_beta/classes.rb', line 40978

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40988
40989
40990
# File 'lib/google/apis/compute_beta/classes.rb', line 40988

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40993
40994
40995
# File 'lib/google/apis/compute_beta/classes.rb', line 40993

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40998
40999
41000
# File 'lib/google/apis/compute_beta/classes.rb', line 40998

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41005
41006
41007
41008
41009
41010
41011
41012
# File 'lib/google/apis/compute_beta/classes.rb', line 41005

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end