Class: Google::Apis::ComputeBeta::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
40439 40440 40441 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40406 40407 40408 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40406 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
Corresponds to the JSON property items
40411 40412 40413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40411 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
40417 40418 40419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40417 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40427 40428 40429 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40427 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40432 40433 40434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40432 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40437 40438 40439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40437 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40444 40445 40446 40447 40448 40449 40450 40451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40444 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |