Class: Google::Apis::ComputeBeta::NetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of networks.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkList

Returns a new instance of NetworkList.



39657
39658
39659
# File 'lib/google/apis/compute_beta/classes.rb', line 39657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39624
39625
39626
# File 'lib/google/apis/compute_beta/classes.rb', line 39624

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Network>

A list of Network resources. Corresponds to the JSON property items



39629
39630
39631
# File 'lib/google/apis/compute_beta/classes.rb', line 39629

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#networkList for lists of networks. Corresponds to the JSON property kind

Returns:

  • (String)


39635
39636
39637
# File 'lib/google/apis/compute_beta/classes.rb', line 39635

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39645
39646
39647
# File 'lib/google/apis/compute_beta/classes.rb', line 39645

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39650
39651
39652
# File 'lib/google/apis/compute_beta/classes.rb', line 39650

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39655
39656
39657
# File 'lib/google/apis/compute_beta/classes.rb', line 39655

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39662
39663
39664
39665
39666
39667
39668
39669
# File 'lib/google/apis/compute_beta/classes.rb', line 39662

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end