Class: Google::Apis::ComputeBeta::NetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of networks.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkList
constructor
A new instance of NetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkList
Returns a new instance of NetworkList.
38831 38832 38833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38798 38799 38800 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38798 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Network>
A list of Network resources.
Corresponds to the JSON property items
38803 38804 38805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38803 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#networkList for
lists of networks.
Corresponds to the JSON property kind
38809 38810 38811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38809 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38819 38820 38821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38819 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38824 38825 38826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38824 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38829 38830 38831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38829 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38836 38837 38838 38839 38840 38841 38842 38843 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38836 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |