Class: Google::Apis::ComputeBeta::NetworkPeering

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeering

Returns a new instance of NetworkPeering.



41228
41229
41230
# File 'lib/google/apis/compute_beta/classes.rb', line 41228

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_create_routesBoolean Also known as: auto_create_routes?

This field will be deprecated soon. Use theexchange_subnet_routes field instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE. Corresponds to the JSON property autoCreateRoutes

Returns:

  • (Boolean)


41129
41130
41131
# File 'lib/google/apis/compute_beta/classes.rb', line 41129

def auto_create_routes
  @auto_create_routes
end

#connection_statusGoogle::Apis::ComputeBeta::NetworkPeeringConnectionStatus

[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings. Corresponds to the JSON property connectionStatus



41138
41139
41140
# File 'lib/google/apis/compute_beta/classes.rb', line 41138

def connection_status
  @connection_status
end

#exchange_subnet_routesBoolean Also known as: exchange_subnet_routes?

Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE. Corresponds to the JSON property exchangeSubnetRoutes

Returns:

  • (Boolean)


41146
41147
41148
# File 'lib/google/apis/compute_beta/classes.rb', line 41146

def exchange_subnet_routes
  @exchange_subnet_routes
end

#export_custom_routesBoolean Also known as: export_custom_routes?

Whether to export the custom routes to peer network. The default value is false. Corresponds to the JSON property exportCustomRoutes

Returns:

  • (Boolean)


41153
41154
41155
# File 'lib/google/apis/compute_beta/classes.rb', line 41153

def export_custom_routes
  @export_custom_routes
end

#export_subnet_routes_with_public_ipBoolean Also known as: export_subnet_routes_with_public_ip?

Whether subnet routes with public IP range are exported. The default value is true, all subnet routes are exported.IPv4 special-use ranges are always exported to peers and are not controlled by this field. Corresponds to the JSON property exportSubnetRoutesWithPublicIp

Returns:

  • (Boolean)


41162
41163
41164
# File 'lib/google/apis/compute_beta/classes.rb', line 41162

def export_subnet_routes_with_public_ip
  @export_subnet_routes_with_public_ip
end

#import_custom_routesBoolean Also known as: import_custom_routes?

Whether to import the custom routes from peer network. The default value is false. Corresponds to the JSON property importCustomRoutes

Returns:

  • (Boolean)


41169
41170
41171
# File 'lib/google/apis/compute_beta/classes.rb', line 41169

def import_custom_routes
  @import_custom_routes
end

#import_subnet_routes_with_public_ipBoolean Also known as: import_subnet_routes_with_public_ip?

Whether subnet routes with public IP range are imported. The default value is false.IPv4 special-use ranges are always imported from peers and are not controlled by this field. Corresponds to the JSON property importSubnetRoutesWithPublicIp

Returns:

  • (Boolean)


41178
41179
41180
# File 'lib/google/apis/compute_beta/classes.rb', line 41178

def import_subnet_routes_with_public_ip
  @import_subnet_routes_with_public_ip
end

#nameString

Name of this peering. Provided by the client when the peering is created. The name must comply withRFC1035. Specifically, the name must be 1-63 characters long and match regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all the following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


41190
41191
41192
# File 'lib/google/apis/compute_beta/classes.rb', line 41190

def name
  @name
end

#networkString

The URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network. Corresponds to the JSON property network

Returns:

  • (String)


41198
41199
41200
# File 'lib/google/apis/compute_beta/classes.rb', line 41198

def network
  @network
end

#peer_mtuFixnum

Output only. [Output Only] Maximum Transmission Unit in bytes of the peer network. Corresponds to the JSON property peerMtu

Returns:

  • (Fixnum)


41204
41205
41206
# File 'lib/google/apis/compute_beta/classes.rb', line 41204

def peer_mtu
  @peer_mtu
end

#stack_typeString

Which IP version(s) of traffic and routes are allowed to be imported or exported between peer networks. The default value is IPV4_ONLY. Corresponds to the JSON property stackType

Returns:

  • (String)


41210
41211
41212
# File 'lib/google/apis/compute_beta/classes.rb', line 41210

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] State for the peering. Corresponds to the JSON property state

Returns:

  • (String)


41215
41216
41217
# File 'lib/google/apis/compute_beta/classes.rb', line 41215

def state
  @state
end

#state_detailsString

Output only. [Output Only] Details about the current state of the peering. Corresponds to the JSON property stateDetails

Returns:

  • (String)


41220
41221
41222
# File 'lib/google/apis/compute_beta/classes.rb', line 41220

def state_details
  @state_details
end

#update_strategyString

The update strategy determines the semantics for updates and deletes to the peering connection configuration. Corresponds to the JSON property updateStrategy

Returns:

  • (String)


41226
41227
41228
# File 'lib/google/apis/compute_beta/classes.rb', line 41226

def update_strategy
  @update_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41233
41234
41235
41236
41237
41238
41239
41240
41241
41242
41243
41244
41245
41246
41247
41248
# File 'lib/google/apis/compute_beta/classes.rb', line 41233

def update!(**args)
  @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes)
  @connection_status = args[:connection_status] if args.key?(:connection_status)
  @exchange_subnet_routes = args[:exchange_subnet_routes] if args.key?(:exchange_subnet_routes)
  @export_custom_routes = args[:export_custom_routes] if args.key?(:export_custom_routes)
  @export_subnet_routes_with_public_ip = args[:export_subnet_routes_with_public_ip] if args.key?(:export_subnet_routes_with_public_ip)
  @import_custom_routes = args[:import_custom_routes] if args.key?(:import_custom_routes)
  @import_subnet_routes_with_public_ip = args[:import_subnet_routes_with_public_ip] if args.key?(:import_subnet_routes_with_public_ip)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @peer_mtu = args[:peer_mtu] if args.key?(:peer_mtu)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @state_details = args[:state_details] if args.key?(:state_details)
  @update_strategy = args[:update_strategy] if args.key?(:update_strategy)
end