Class: Google::Apis::ComputeBeta::NetworkPeering
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPeering
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering.
Instance Attribute Summary collapse
-
#auto_create_routes ⇒ Boolean
(also: #auto_create_routes?)
This field will be deprecated soon.
-
#connection_status ⇒ Google::Apis::ComputeBeta::NetworkPeeringConnectionStatus
[Output Only] Describes the state of a peering connection, not just the local peering.
-
#exchange_subnet_routes ⇒ Boolean
(also: #exchange_subnet_routes?)
Indicates whether full mesh connectivity is created and managed automatically between peered networks.
-
#export_custom_routes ⇒ Boolean
(also: #export_custom_routes?)
Whether to export the custom routes to peer network.
-
#export_subnet_routes_with_public_ip ⇒ Boolean
(also: #export_subnet_routes_with_public_ip?)
Whether subnet routes with public IP range are exported.
-
#import_custom_routes ⇒ Boolean
(also: #import_custom_routes?)
Whether to import the custom routes from peer network.
-
#import_subnet_routes_with_public_ip ⇒ Boolean
(also: #import_subnet_routes_with_public_ip?)
Whether subnet routes with public IP range are imported.
-
#name ⇒ String
Name of this peering.
-
#network ⇒ String
The URL of the peer network.
-
#peer_mtu ⇒ Fixnum
Output only.
-
#stack_type ⇒ String
Which IP version(s) of traffic and routes are allowed to be imported or exported between peer networks.
-
#state ⇒ String
Output only.
-
#state_details ⇒ String
Output only.
-
#update_strategy ⇒ String
The update strategy determines the semantics for updates and deletes to the peering connection configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPeering
constructor
A new instance of NetworkPeering.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPeering
Returns a new instance of NetworkPeering.
39885 39886 39887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39885 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_create_routes ⇒ Boolean Also known as: auto_create_routes?
This field will be deprecated soon. Use theexchange_subnet_routes field
instead.
Indicates whether full mesh connectivity is created and managed
automatically between peered networks. Currently this field should always
be true since Google Compute Engine will automatically create and manage
subnetwork routes between two networks when peering state isACTIVE.
Corresponds to the JSON property autoCreateRoutes
39786 39787 39788 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39786 def auto_create_routes @auto_create_routes end |
#connection_status ⇒ Google::Apis::ComputeBeta::NetworkPeeringConnectionStatus
[Output Only] Describes the state of a peering connection, not just the
local peering. This field provides information about the effective settings
for the connection as a whole, including pending delete/update requests for
CONSENSUS peerings.
Corresponds to the JSON property connectionStatus
39795 39796 39797 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39795 def connection_status @connection_status end |
#exchange_subnet_routes ⇒ Boolean Also known as: exchange_subnet_routes?
Indicates whether full mesh connectivity is created and managed
automatically between peered networks. Currently this field should always
be true since Google Compute Engine will automatically create and manage
subnetwork routes between two networks when peering state isACTIVE.
Corresponds to the JSON property exchangeSubnetRoutes
39803 39804 39805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39803 def exchange_subnet_routes @exchange_subnet_routes end |
#export_custom_routes ⇒ Boolean Also known as: export_custom_routes?
Whether to export the custom routes to peer network. The default value is
false.
Corresponds to the JSON property exportCustomRoutes
39810 39811 39812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39810 def export_custom_routes @export_custom_routes end |
#export_subnet_routes_with_public_ip ⇒ Boolean Also known as: export_subnet_routes_with_public_ip?
Whether subnet routes with public IP range are exported. The default value
is true, all subnet routes are exported.IPv4
special-use ranges are always
exported to peers and are not controlled by this field.
Corresponds to the JSON property exportSubnetRoutesWithPublicIp
39819 39820 39821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39819 def export_subnet_routes_with_public_ip @export_subnet_routes_with_public_ip end |
#import_custom_routes ⇒ Boolean Also known as: import_custom_routes?
Whether to import the custom routes from peer network. The default value is
false.
Corresponds to the JSON property importCustomRoutes
39826 39827 39828 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39826 def import_custom_routes @import_custom_routes end |
#import_subnet_routes_with_public_ip ⇒ Boolean Also known as: import_subnet_routes_with_public_ip?
Whether subnet routes with public IP range are imported. The default value
is false.IPv4
special-use ranges are always
imported from peers and are not controlled by this field.
Corresponds to the JSON property importSubnetRoutesWithPublicIp
39835 39836 39837 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39835 def import_subnet_routes_with_public_ip @import_subnet_routes_with_public_ip end |
#name ⇒ String
Name of this peering. Provided by the client when the peering is created.
The name must comply withRFC1035.
Specifically, the name must be 1-63 characters long and match regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a
lowercase letter, and all the following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
39847 39848 39849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39847 def name @name end |
#network ⇒ String
The URL of the peer network. It can be either full URL or partial URL. The
peer network may belong to a different project. If the partial URL does not
contain project, it is assumed that the peer network is in the same project
as the current network.
Corresponds to the JSON property network
39855 39856 39857 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39855 def network @network end |
#peer_mtu ⇒ Fixnum
Output only. [Output Only] Maximum Transmission Unit in bytes of the peer
network.
Corresponds to the JSON property peerMtu
39861 39862 39863 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39861 def peer_mtu @peer_mtu end |
#stack_type ⇒ String
Which IP version(s) of traffic and routes are allowed to be imported or
exported between peer networks. The default value is IPV4_ONLY.
Corresponds to the JSON property stackType
39867 39868 39869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39867 def stack_type @stack_type end |
#state ⇒ String
Output only. [Output Only] State for the peering.
Corresponds to the JSON property state
39872 39873 39874 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39872 def state @state end |
#state_details ⇒ String
Output only. [Output Only] Details about the current state of the peering.
Corresponds to the JSON property stateDetails
39877 39878 39879 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39877 def state_details @state_details end |
#update_strategy ⇒ String
The update strategy determines the semantics for updates and deletes to the
peering connection configuration.
Corresponds to the JSON property updateStrategy
39883 39884 39885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39883 def update_strategy @update_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39890 39891 39892 39893 39894 39895 39896 39897 39898 39899 39900 39901 39902 39903 39904 39905 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39890 def update!(**args) @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes) @connection_status = args[:connection_status] if args.key?(:connection_status) @exchange_subnet_routes = args[:exchange_subnet_routes] if args.key?(:exchange_subnet_routes) @export_custom_routes = args[:export_custom_routes] if args.key?(:export_custom_routes) @export_subnet_routes_with_public_ip = args[:export_subnet_routes_with_public_ip] if args.key?(:export_subnet_routes_with_public_ip) @import_custom_routes = args[:import_custom_routes] if args.key?(:import_custom_routes) @import_subnet_routes_with_public_ip = args[:import_subnet_routes_with_public_ip] if args.key?(:import_subnet_routes_with_public_ip) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @peer_mtu = args[:peer_mtu] if args.key?(:peer_mtu) @stack_type = args[:stack_type] if args.key?(:stack_type) @state = args[:state] if args.key?(:state) @state_details = args[:state_details] if args.key?(:state_details) @update_strategy = args[:update_strategy] if args.key?(:update_strategy) end |