Class: Google::Apis::ComputeBeta::NetworkPeeringConnectionStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatus

Returns a new instance of NetworkPeeringConnectionStatus.



40776
40777
40778
# File 'lib/google/apis/compute_beta/classes.rb', line 40776

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consensus_stateGoogle::Apis::ComputeBeta::NetworkPeeringConnectionStatusConsensusState

The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS. Corresponds to the JSON property consensusState



40762
40763
40764
# File 'lib/google/apis/compute_beta/classes.rb', line 40762

def consensus_state
  @consensus_state
end

#traffic_configurationGoogle::Apis::ComputeBeta::NetworkPeeringConnectionStatusTrafficConfiguration

The active connectivity settings for the peering connection based on the settings of the network peerings. Corresponds to the JSON property trafficConfiguration



40768
40769
40770
# File 'lib/google/apis/compute_beta/classes.rb', line 40768

def traffic_configuration
  @traffic_configuration
end

#update_strategyString

The update strategy determines the update/delete semantics for this peering connection. Corresponds to the JSON property updateStrategy

Returns:

  • (String)


40774
40775
40776
# File 'lib/google/apis/compute_beta/classes.rb', line 40774

def update_strategy
  @update_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40781
40782
40783
40784
40785
# File 'lib/google/apis/compute_beta/classes.rb', line 40781

def update!(**args)
  @consensus_state = args[:consensus_state] if args.key?(:consensus_state)
  @traffic_configuration = args[:traffic_configuration] if args.key?(:traffic_configuration)
  @update_strategy = args[:update_strategy] if args.key?(:update_strategy)
end