Class: Google::Apis::ComputeBeta::NetworkPeeringConnectionStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatus

Returns a new instance of NetworkPeeringConnectionStatus.



39109
39110
39111
# File 'lib/google/apis/compute_beta/classes.rb', line 39109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consensus_stateGoogle::Apis::ComputeBeta::NetworkPeeringConnectionStatusConsensusState

The status of update/delete for a consensus peering connection. Only set when connection_status.update_strategy isCONSENSUS or a network peering is proposing to update the strategy to CONSENSUS. Corresponds to the JSON property consensusState



39095
39096
39097
# File 'lib/google/apis/compute_beta/classes.rb', line 39095

def consensus_state
  @consensus_state
end

#traffic_configurationGoogle::Apis::ComputeBeta::NetworkPeeringConnectionStatusTrafficConfiguration

The active connectivity settings for the peering connection based on the settings of the network peerings. Corresponds to the JSON property trafficConfiguration



39101
39102
39103
# File 'lib/google/apis/compute_beta/classes.rb', line 39101

def traffic_configuration
  @traffic_configuration
end

#update_strategyString

The update strategy determines the update/delete semantics for this peering connection. Corresponds to the JSON property updateStrategy

Returns:

  • (String)


39107
39108
39109
# File 'lib/google/apis/compute_beta/classes.rb', line 39107

def update_strategy
  @update_strategy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39114
39115
39116
39117
39118
# File 'lib/google/apis/compute_beta/classes.rb', line 39114

def update!(**args)
  @consensus_state = args[:consensus_state] if args.key?(:consensus_state)
  @traffic_configuration = args[:traffic_configuration] if args.key?(:traffic_configuration)
  @update_strategy = args[:update_strategy] if args.key?(:update_strategy)
end