Class: Google::Apis::ComputeBeta::NetworkPeeringConnectionStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPeeringConnectionStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] Describes the state of a peering connection, not just the local peering. This field provides information about the effective settings for the connection as a whole, including pending delete/update requests for CONSENSUS peerings.
Instance Attribute Summary collapse
-
#consensus_state ⇒ Google::Apis::ComputeBeta::NetworkPeeringConnectionStatusConsensusState
The status of update/delete for a consensus peering connection.
-
#traffic_configuration ⇒ Google::Apis::ComputeBeta::NetworkPeeringConnectionStatusTrafficConfiguration
The active connectivity settings for the peering connection based on the settings of the network peerings.
-
#update_strategy ⇒ String
The update strategy determines the update/delete semantics for this peering connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPeeringConnectionStatus
constructor
A new instance of NetworkPeeringConnectionStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPeeringConnectionStatus
Returns a new instance of NetworkPeeringConnectionStatus.
37721 37722 37723 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#consensus_state ⇒ Google::Apis::ComputeBeta::NetworkPeeringConnectionStatusConsensusState
The status of update/delete for a consensus peering connection. Only set
when connection_status.update_strategy isCONSENSUS or a network peering is
proposing to update the
strategy to CONSENSUS.
Corresponds to the JSON property consensusState
37707 37708 37709 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37707 def consensus_state @consensus_state end |
#traffic_configuration ⇒ Google::Apis::ComputeBeta::NetworkPeeringConnectionStatusTrafficConfiguration
The active connectivity settings for the peering connection based on the
settings of the network peerings.
Corresponds to the JSON property trafficConfiguration
37713 37714 37715 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37713 def traffic_configuration @traffic_configuration end |
#update_strategy ⇒ String
The update strategy determines the update/delete semantics for this
peering connection.
Corresponds to the JSON property updateStrategy
37719 37720 37721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37719 def update_strategy @update_strategy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
37726 37727 37728 37729 37730 |
# File 'lib/google/apis/compute_beta/classes.rb', line 37726 def update!(**args) @consensus_state = args[:consensus_state] if args.key?(:consensus_state) @traffic_configuration = args[:traffic_configuration] if args.key?(:traffic_configuration) @update_strategy = args[:update_strategy] if args.key?(:update_strategy) end |