Class: Google::Apis::ComputeBeta::NetworkPeeringConnectionStatusTrafficConfiguration

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPeeringConnectionStatusTrafficConfiguration

Returns a new instance of NetworkPeeringConnectionStatusTrafficConfiguration.



37797
37798
37799
# File 'lib/google/apis/compute_beta/classes.rb', line 37797

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#export_custom_routes_to_peerBoolean Also known as: export_custom_routes_to_peer?

Whether custom routes are being exported to the peer network. Corresponds to the JSON property exportCustomRoutesToPeer

Returns:

  • (Boolean)


37768
37769
37770
# File 'lib/google/apis/compute_beta/classes.rb', line 37768

def export_custom_routes_to_peer
  @export_custom_routes_to_peer
end

#export_subnet_routes_with_public_ip_to_peerBoolean Also known as: export_subnet_routes_with_public_ip_to_peer?

Whether subnet routes with public IP ranges are being exported to the peer network. Corresponds to the JSON property exportSubnetRoutesWithPublicIpToPeer

Returns:

  • (Boolean)


37775
37776
37777
# File 'lib/google/apis/compute_beta/classes.rb', line 37775

def export_subnet_routes_with_public_ip_to_peer
  @export_subnet_routes_with_public_ip_to_peer
end

#import_custom_routes_from_peerBoolean Also known as: import_custom_routes_from_peer?

Whether custom routes are being imported from the peer network. Corresponds to the JSON property importCustomRoutesFromPeer

Returns:

  • (Boolean)


37781
37782
37783
# File 'lib/google/apis/compute_beta/classes.rb', line 37781

def import_custom_routes_from_peer
  @import_custom_routes_from_peer
end

#import_subnet_routes_with_public_ip_from_peerBoolean Also known as: import_subnet_routes_with_public_ip_from_peer?

Whether subnet routes with public IP ranges are being imported from the peer network. Corresponds to the JSON property importSubnetRoutesWithPublicIpFromPeer

Returns:

  • (Boolean)


37788
37789
37790
# File 'lib/google/apis/compute_beta/classes.rb', line 37788

def import_subnet_routes_with_public_ip_from_peer
  @import_subnet_routes_with_public_ip_from_peer
end

#stack_typeString

Which IP version(s) of traffic and routes are being imported or exported between peer networks. Corresponds to the JSON property stackType

Returns:

  • (String)


37795
37796
37797
# File 'lib/google/apis/compute_beta/classes.rb', line 37795

def stack_type
  @stack_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37802
37803
37804
37805
37806
37807
37808
# File 'lib/google/apis/compute_beta/classes.rb', line 37802

def update!(**args)
  @export_custom_routes_to_peer = args[:export_custom_routes_to_peer] if args.key?(:export_custom_routes_to_peer)
  @export_subnet_routes_with_public_ip_to_peer = args[:export_subnet_routes_with_public_ip_to_peer] if args.key?(:export_subnet_routes_with_public_ip_to_peer)
  @import_custom_routes_from_peer = args[:import_custom_routes_from_peer] if args.key?(:import_custom_routes_from_peer)
  @import_subnet_routes_with_public_ip_from_peer = args[:import_subnet_routes_with_public_ip_from_peer] if args.key?(:import_subnet_routes_with_public_ip_from_peer)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
end