Class: Google::Apis::ComputeBeta::NetworkPoliciesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPoliciesScopedList

Returns a new instance of NetworkPoliciesScopedList.



37845
37846
37847
# File 'lib/google/apis/compute_beta/classes.rb', line 37845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#network_policiesArray<Google::Apis::ComputeBeta::NetworkPolicy>

A list of network policies contained in this scope. Corresponds to the JSON property networkPolicies



37837
37838
37839
# File 'lib/google/apis/compute_beta/classes.rb', line 37837

def network_policies
  @network_policies
end

#warningGoogle::Apis::ComputeBeta::NetworkPoliciesScopedList::Warning

Informational warning which replaces the list of network policies when the list is empty. Corresponds to the JSON property warning



37843
37844
37845
# File 'lib/google/apis/compute_beta/classes.rb', line 37843

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



37850
37851
37852
37853
# File 'lib/google/apis/compute_beta/classes.rb', line 37850

def update!(**args)
  @network_policies = args[:network_policies] if args.key?(:network_policies)
  @warning = args[:warning] if args.key?(:warning)
end