Class: Google::Apis::ComputeBeta::NetworkPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Network Policy resource.
Instance Attribute Summary collapse
-
#associations ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicyAssociation>
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#traffic_classification_rules ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicy
constructor
A new instance of NetworkPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicy
Returns a new instance of NetworkPolicy.
41598 41599 41600 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41598 def initialize(**args) update!(**args) end |
Instance Attribute Details
#associations ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicyAssociation>
Output only. [Output Only] A list of associations that belong to this network
policy.
Corresponds to the JSON property associations
41534 41535 41536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41534 def associations @associations end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
41540 41541 41542 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41540 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
41546 41547 41548 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41546 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
41552 41553 41554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41552 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#networkPolicy
for network policies
Corresponds to the JSON property kind
41558 41559 41560 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41558 def kind @kind end |
#name ⇒ String
Name of the resource.
Corresponds to the JSON property name
41563 41564 41565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41563 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional network policy
resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
41571 41572 41573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41571 def region @region end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Total count of all network policy rule tuples. A
network
policy can not exceed a set number of tuples.
Corresponds to the JSON property ruleTupleCount
41578 41579 41580 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41578 def rule_tuple_count @rule_tuple_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
41583 41584 41585 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41583 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
41589 41590 41591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41589 def self_link_with_id @self_link_with_id end |
#traffic_classification_rules ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule>
Output only. [Output Only] A list of traffic classification rules that belong
to this
policy.
Corresponds to the JSON property trafficClassificationRules
41596 41597 41598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41596 def traffic_classification_rules @traffic_classification_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41603 41604 41605 41606 41607 41608 41609 41610 41611 41612 41613 41614 41615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41603 def update!(**args) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @traffic_classification_rules = args[:traffic_classification_rules] if args.key?(:traffic_classification_rules) end |