Class: Google::Apis::ComputeBeta::NetworkPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Network Policy resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicy

Returns a new instance of NetworkPolicy.



41556
41557
41558
# File 'lib/google/apis/compute_beta/classes.rb', line 41556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::ComputeBeta::NetworkPolicyAssociation>

Output only. [Output Only] A list of associations that belong to this network policy. Corresponds to the JSON property associations



41492
41493
41494
# File 'lib/google/apis/compute_beta/classes.rb', line 41492

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


41498
41499
41500
# File 'lib/google/apis/compute_beta/classes.rb', line 41498

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


41504
41505
41506
# File 'lib/google/apis/compute_beta/classes.rb', line 41504

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


41510
41511
41512
# File 'lib/google/apis/compute_beta/classes.rb', line 41510

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#networkPolicy for network policies Corresponds to the JSON property kind

Returns:

  • (String)


41516
41517
41518
# File 'lib/google/apis/compute_beta/classes.rb', line 41516

def kind
  @kind
end

#nameString

Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


41521
41522
41523
# File 'lib/google/apis/compute_beta/classes.rb', line 41521

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the regional network policy resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


41529
41530
41531
# File 'lib/google/apis/compute_beta/classes.rb', line 41529

def region
  @region
end

#rule_tuple_countFixnum

Output only. [Output Only] Total count of all network policy rule tuples. A network policy can not exceed a set number of tuples. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


41536
41537
41538
# File 'lib/google/apis/compute_beta/classes.rb', line 41536

def rule_tuple_count
  @rule_tuple_count
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41541
41542
41543
# File 'lib/google/apis/compute_beta/classes.rb', line 41541

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


41547
41548
41549
# File 'lib/google/apis/compute_beta/classes.rb', line 41547

def self_link_with_id
  @self_link_with_id
end

#traffic_classification_rulesArray<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule>

Output only. [Output Only] A list of traffic classification rules that belong to this policy. Corresponds to the JSON property trafficClassificationRules



41554
41555
41556
# File 'lib/google/apis/compute_beta/classes.rb', line 41554

def traffic_classification_rules
  @traffic_classification_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41561
41562
41563
41564
41565
41566
41567
41568
41569
41570
41571
41572
41573
# File 'lib/google/apis/compute_beta/classes.rb', line 41561

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @traffic_classification_rules = args[:traffic_classification_rules] if args.key?(:traffic_classification_rules)
end