Class: Google::Apis::ComputeBeta::NetworkPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Network Policy resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicy

Returns a new instance of NetworkPolicy.



37999
38000
38001
# File 'lib/google/apis/compute_beta/classes.rb', line 37999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associationsArray<Google::Apis::ComputeBeta::NetworkPolicyAssociation>

Output only. [Output Only] A list of associations that belong to this network policy. Corresponds to the JSON property associations



37935
37936
37937
# File 'lib/google/apis/compute_beta/classes.rb', line 37935

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


37941
37942
37943
# File 'lib/google/apis/compute_beta/classes.rb', line 37941

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


37947
37948
37949
# File 'lib/google/apis/compute_beta/classes.rb', line 37947

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


37953
37954
37955
# File 'lib/google/apis/compute_beta/classes.rb', line 37953

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute#networkPolicy for network policies Corresponds to the JSON property kind

Returns:

  • (String)


37959
37960
37961
# File 'lib/google/apis/compute_beta/classes.rb', line 37959

def kind
  @kind
end

#nameString

Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


37964
37965
37966
# File 'lib/google/apis/compute_beta/classes.rb', line 37964

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the regional network policy resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


37972
37973
37974
# File 'lib/google/apis/compute_beta/classes.rb', line 37972

def region
  @region
end

#rule_tuple_countFixnum

Output only. [Output Only] Total count of all network policy rule tuples. A network policy can not exceed a set number of tuples. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


37979
37980
37981
# File 'lib/google/apis/compute_beta/classes.rb', line 37979

def rule_tuple_count
  @rule_tuple_count
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


37984
37985
37986
# File 'lib/google/apis/compute_beta/classes.rb', line 37984

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


37990
37991
37992
# File 'lib/google/apis/compute_beta/classes.rb', line 37990

def self_link_with_id
  @self_link_with_id
end

#traffic_classification_rulesArray<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule>

Output only. [Output Only] A list of traffic classification rules that belong to this policy. Corresponds to the JSON property trafficClassificationRules



37997
37998
37999
# File 'lib/google/apis/compute_beta/classes.rb', line 37997

def traffic_classification_rules
  @traffic_classification_rules
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38004
38005
38006
38007
38008
38009
38010
38011
38012
38013
38014
38015
38016
# File 'lib/google/apis/compute_beta/classes.rb', line 38004

def update!(**args)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @traffic_classification_rules = args[:traffic_classification_rules] if args.key?(:traffic_classification_rules)
end