Class: Google::Apis::ComputeBeta::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



41728
41729
41730
# File 'lib/google/apis/compute_beta/classes.rb', line 41728

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41689
41690
41691
# File 'lib/google/apis/compute_beta/classes.rb', line 41689

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



41694
41695
41696
# File 'lib/google/apis/compute_beta/classes.rb', line 41694

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


41701
41702
41703
# File 'lib/google/apis/compute_beta/classes.rb', line 41701

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41711
41712
41713
# File 'lib/google/apis/compute_beta/classes.rb', line 41711

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41716
41717
41718
# File 'lib/google/apis/compute_beta/classes.rb', line 41716

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41721
41722
41723
# File 'lib/google/apis/compute_beta/classes.rb', line 41721

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41726
41727
41728
# File 'lib/google/apis/compute_beta/classes.rb', line 41726

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41733
41734
41735
41736
41737
41738
41739
41740
41741
# File 'lib/google/apis/compute_beta/classes.rb', line 41733

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end