Class: Google::Apis::ComputeBeta::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



41678
41679
41680
# File 'lib/google/apis/compute_beta/classes.rb', line 41678

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41639
41640
41641
# File 'lib/google/apis/compute_beta/classes.rb', line 41639

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



41644
41645
41646
# File 'lib/google/apis/compute_beta/classes.rb', line 41644

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


41651
41652
41653
# File 'lib/google/apis/compute_beta/classes.rb', line 41651

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41661
41662
41663
# File 'lib/google/apis/compute_beta/classes.rb', line 41661

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41666
41667
41668
# File 'lib/google/apis/compute_beta/classes.rb', line 41666

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41671
41672
41673
# File 'lib/google/apis/compute_beta/classes.rb', line 41671

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41676
41677
41678
# File 'lib/google/apis/compute_beta/classes.rb', line 41676

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41683
41684
41685
41686
41687
41688
41689
41690
41691
# File 'lib/google/apis/compute_beta/classes.rb', line 41683

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end