Class: Google::Apis::ComputeBeta::NetworkPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAggregatedList
constructor
A new instance of NetworkPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAggregatedList
Returns a new instance of NetworkPolicyAggregatedList.
40279 40280 40281 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40279 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40240 40241 40242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40240 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
Corresponds to the JSON property items
40245 40246 40247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40245 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkPolicyAggregatedList for lists of
network policies.
Corresponds to the JSON property kind
40252 40253 40254 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40252 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40262 40263 40264 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40262 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40267 40268 40269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40267 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
40272 40273 40274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40272 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40277 40278 40279 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40277 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40284 40285 40286 40287 40288 40289 40290 40291 40292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40284 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |