Class: Google::Apis::ComputeBeta::NetworkPolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyAggregatedList

Returns a new instance of NetworkPolicyAggregatedList.



39453
39454
39455
# File 'lib/google/apis/compute_beta/classes.rb', line 39453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


39414
39415
39416
# File 'lib/google/apis/compute_beta/classes.rb', line 39414

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>

A list of NetworkPoliciesScopedList resources. Corresponds to the JSON property items



39419
39420
39421
# File 'lib/google/apis/compute_beta/classes.rb', line 39419

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# networkPolicyAggregatedList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


39426
39427
39428
# File 'lib/google/apis/compute_beta/classes.rb', line 39426

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


39436
39437
39438
# File 'lib/google/apis/compute_beta/classes.rb', line 39436

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


39441
39442
39443
# File 'lib/google/apis/compute_beta/classes.rb', line 39441

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


39446
39447
39448
# File 'lib/google/apis/compute_beta/classes.rb', line 39446

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



39451
39452
39453
# File 'lib/google/apis/compute_beta/classes.rb', line 39451

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



39458
39459
39460
39461
39462
39463
39464
39465
39466
# File 'lib/google/apis/compute_beta/classes.rb', line 39458

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end