Class: Google::Apis::ComputeBeta::NetworkPolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAggregatedList
constructor
A new instance of NetworkPolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAggregatedList
Returns a new instance of NetworkPolicyAggregatedList.
38065 38066 38067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38026 38027 38028 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38026 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NetworkPoliciesScopedList>
A list of NetworkPoliciesScopedList resources.
Corresponds to the JSON property items
38031 38032 38033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38031 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
networkPolicyAggregatedList for lists of
network policies.
Corresponds to the JSON property kind
38038 38039 38040 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38038 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38048 38049 38050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38048 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38053 38054 38055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38053 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
38058 38059 38060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38058 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38063 38064 38065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38063 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38070 38071 38072 38073 38074 38075 38076 38077 38078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38070 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |