Class: Google::Apis::ComputeBeta::NetworkPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#attachment_target ⇒ String
The target that the network policy is attached to.
-
#name ⇒ String
The name for an association.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAssociation
constructor
A new instance of NetworkPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAssociation
Returns a new instance of NetworkPolicyAssociation.
40379 40380 40381 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40379 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_target ⇒ String
The target that the network policy is attached to.
Corresponds to the JSON property attachmentTarget
40372 40373 40374 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40372 def @attachment_target end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
40377 40378 40379 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40377 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40384 40385 40386 40387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40384 def update!(**args) @attachment_target = args[:attachment_target] if args.key?(:attachment_target) @name = args[:name] if args.key?(:name) end |