Class: Google::Apis::ComputeBeta::NetworkPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#attachment_target ⇒ String
The target that the network policy is attached to.
-
#name ⇒ String
The name for an association.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyAssociation
constructor
A new instance of NetworkPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyAssociation
Returns a new instance of NetworkPolicyAssociation.
38165 38166 38167 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38165 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_target ⇒ String
The target that the network policy is attached to.
Corresponds to the JSON property attachmentTarget
38158 38159 38160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38158 def @attachment_target end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
38163 38164 38165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38163 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38170 38171 38172 38173 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38170 def update!(**args) @attachment_target = args[:attachment_target] if args.key?(:attachment_target) @name = args[:name] if args.key?(:name) end |