Class: Google::Apis::ComputeBeta::NetworkPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicy>
A list of NetworkPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyList
constructor
A new instance of NetworkPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyList
Returns a new instance of NetworkPolicyList.
41874 41875 41876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41874 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41846 41847 41848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41846 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicy>
A list of NetworkPolicy resources.
Corresponds to the JSON property items
41851 41852 41853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41851 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList
for lists of network policies.
Corresponds to the JSON property kind
41857 41858 41859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41857 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41867 41868 41869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41867 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41872 41873 41874 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41872 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41879 41880 41881 41882 41883 41884 41885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41879 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |