Class: Google::Apis::ComputeBeta::NetworkPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyList

Returns a new instance of NetworkPolicyList.



41810
41811
41812
# File 'lib/google/apis/compute_beta/classes.rb', line 41810

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41782
41783
41784
# File 'lib/google/apis/compute_beta/classes.rb', line 41782

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkPolicy>

A list of NetworkPolicy resources. Corresponds to the JSON property items



41787
41788
41789
# File 'lib/google/apis/compute_beta/classes.rb', line 41787

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


41793
41794
41795
# File 'lib/google/apis/compute_beta/classes.rb', line 41793

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41803
41804
41805
# File 'lib/google/apis/compute_beta/classes.rb', line 41803

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41808
41809
41810
# File 'lib/google/apis/compute_beta/classes.rb', line 41808

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41815
41816
41817
41818
41819
41820
41821
# File 'lib/google/apis/compute_beta/classes.rb', line 41815

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end