Class: Google::Apis::ComputeBeta::NetworkPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyList

Returns a new instance of NetworkPolicyList.



41768
41769
41770
# File 'lib/google/apis/compute_beta/classes.rb', line 41768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41740
41741
41742
# File 'lib/google/apis/compute_beta/classes.rb', line 41740

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkPolicy>

A list of NetworkPolicy resources. Corresponds to the JSON property items



41745
41746
41747
# File 'lib/google/apis/compute_beta/classes.rb', line 41745

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


41751
41752
41753
# File 'lib/google/apis/compute_beta/classes.rb', line 41751

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41761
41762
41763
# File 'lib/google/apis/compute_beta/classes.rb', line 41761

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41766
41767
41768
# File 'lib/google/apis/compute_beta/classes.rb', line 41766

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41773
41774
41775
41776
41777
41778
41779
# File 'lib/google/apis/compute_beta/classes.rb', line 41773

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end