Class: Google::Apis::ComputeBeta::NetworkPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyList

Returns a new instance of NetworkPolicyList.



41746
41747
41748
# File 'lib/google/apis/compute_beta/classes.rb', line 41746

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41718
41719
41720
# File 'lib/google/apis/compute_beta/classes.rb', line 41718

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkPolicy>

A list of NetworkPolicy resources. Corresponds to the JSON property items



41723
41724
41725
# File 'lib/google/apis/compute_beta/classes.rb', line 41723

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


41729
41730
41731
# File 'lib/google/apis/compute_beta/classes.rb', line 41729

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41739
41740
41741
# File 'lib/google/apis/compute_beta/classes.rb', line 41739

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41744
41745
41746
# File 'lib/google/apis/compute_beta/classes.rb', line 41744

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41751
41752
41753
41754
41755
41756
41757
# File 'lib/google/apis/compute_beta/classes.rb', line 41751

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end