Class: Google::Apis::ComputeBeta::NetworkPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicy>
A list of NetworkPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyList
constructor
A new instance of NetworkPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyList
Returns a new instance of NetworkPolicyList.
39599 39600 39601 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39599 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39571 39572 39573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39571 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicy>
A list of NetworkPolicy resources.
Corresponds to the JSON property items
39576 39577 39578 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39576 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList
for lists of network policies.
Corresponds to the JSON property kind
39582 39583 39584 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39582 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39592 39593 39594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39592 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39597 39598 39599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39597 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39604 39605 39606 39607 39608 39609 39610 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39604 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |