Class: Google::Apis::ComputeBeta::NetworkPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyList

Returns a new instance of NetworkPolicyList.



38211
38212
38213
# File 'lib/google/apis/compute_beta/classes.rb', line 38211

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


38183
38184
38185
# File 'lib/google/apis/compute_beta/classes.rb', line 38183

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkPolicy>

A list of NetworkPolicy resources. Corresponds to the JSON property items



38188
38189
38190
# File 'lib/google/apis/compute_beta/classes.rb', line 38188

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkPolicyList for lists of network policies. Corresponds to the JSON property kind

Returns:

  • (String)


38194
38195
38196
# File 'lib/google/apis/compute_beta/classes.rb', line 38194

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


38204
38205
38206
# File 'lib/google/apis/compute_beta/classes.rb', line 38204

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::NetworkPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



38209
38210
38211
# File 'lib/google/apis/compute_beta/classes.rb', line 38209

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



38216
38217
38218
38219
38220
38221
38222
# File 'lib/google/apis/compute_beta/classes.rb', line 38216

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end