Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a traffic classification rule that describes one or more match conditions along with the action to be taken when traffic matches this condition.
Instance Attribute Summary collapse
-
#action ⇒ Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction
The Action to perform when the client connection triggers the rule.
-
#description ⇒ String
An optional description for this resource.
-
#disabled ⇒ Boolean
(also: #disabled?)
Denotes whether the network policy rule is disabled.
-
#kind ⇒ String
Output only.
-
#match ⇒ Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcher
Represents a match condition that incoming traffic is evaluated against.
-
#priority ⇒ Fixnum
An integer indicating the priority of a rule in the list.
-
#rule_name ⇒ String
An optional name for the rule.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#target_secure_tags ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleSecureTag>
A list of secure tags that controls which instances the traffic classification rule applies to.
-
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating the sets of instances that are applied with this rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRule
constructor
A new instance of NetworkPolicyTrafficClassificationRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRule
Returns a new instance of NetworkPolicyTrafficClassificationRule.
41373 41374 41375 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41373 def initialize(**args) update!(**args) end |
Instance Attribute Details
#action ⇒ Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction
The Action to perform when the client connection triggers the rule.
Corresponds to the JSON property action
41300 41301 41302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41300 def action @action end |
#description ⇒ String
An optional description for this resource.
Corresponds to the JSON property description
41305 41306 41307 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41305 def description @description end |
#disabled ⇒ Boolean Also known as: disabled?
Denotes whether the network policy rule is disabled. When set to true,
the network policy rule is not enforced and traffic behaves as if it did
not exist. If this is unspecified, the network policy rule will be
enabled.
Corresponds to the JSON property disabled
41313 41314 41315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41313 def disabled @disabled end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
networkPolicyTrafficClassificationRule for network
policy traffic classification rules
Corresponds to the JSON property kind
41321 41322 41323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41321 def kind @kind end |
#match ⇒ Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcher
Represents a match condition that incoming traffic is evaluated against.
Exactly one field must be specified.
Corresponds to the JSON property match
41327 41328 41329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41327 def match @match end |
#priority ⇒ Fixnum
An integer indicating the priority of a rule in the list. The priority
must be a positive value between 1 and 2147482647.
The priority values from 2147482648 to 2147483647 (1000) are reserved for
system default network policy rules. Rules are evaluated from highest to
lowest priority where 1 is the highest priority and 2147483647 is the
lowest priority.
Corresponds to the JSON property priority
41337 41338 41339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41337 def priority @priority end |
#rule_name ⇒ String
An optional name for the rule. This field is not a unique identifier
and can be updated.
Corresponds to the JSON property ruleName
41343 41344 41345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41343 def rule_name @rule_name end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Calculation of the complexity of a single network
policy
rule.
Corresponds to the JSON property ruleTupleCount
41350 41351 41352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41350 def rule_tuple_count @rule_tuple_count end |
#target_secure_tags ⇒ Array<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleSecureTag>
A list of secure tags that controls which instances the traffic
classification rule applies to. If targetSecureTag are
specified, then the traffic classification rule applies only to instances
in the VPC network that have one of those EFFECTIVE secure tags, if all
the targetSecureTag are in INEFFECTIVE state, then this rule
will be ignored. targetSecureTag may not be set at the same
time as targetServiceAccounts. If neithertargetServiceAccounts nor
targetSecureTag are
specified, the traffic classification rule applies to all instances on
the specified network. Maximum number of target label tags allowed is
256.
Corresponds to the JSON property targetSecureTags
41365 41366 41367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41365 def @target_secure_tags end |
#target_service_accounts ⇒ Array<String>
A list of service accounts indicating the sets of instances that are
applied with this rule.
Corresponds to the JSON property targetServiceAccounts
41371 41372 41373 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41371 def target_service_accounts @target_service_accounts end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41378 41379 41380 41381 41382 41383 41384 41385 41386 41387 41388 41389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41378 def update!(**args) @action = args[:action] if args.key?(:action) @description = args[:description] if args.key?(:description) @disabled = args[:disabled] if args.key?(:disabled) @kind = args[:kind] if args.key?(:kind) @match = args[:match] if args.key?(:match) @priority = args[:priority] if args.key?(:priority) @rule_name = args[:rule_name] if args.key?(:rule_name) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @target_secure_tags = args[:target_secure_tags] if args.key?(:target_secure_tags) @target_service_accounts = args[:target_service_accounts] if args.key?(:target_service_accounts) end |