Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction

Returns a new instance of NetworkPolicyTrafficClassificationRuleAction.



42085
42086
42087
# File 'lib/google/apis/compute_beta/classes.rb', line 42085

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dscp_modeString

DSCP mode. When set to AUTO, the DSCP value will be picked automatically based on selected trafficClass. Otherwise,dscpValue needs to be explicitly specified. Corresponds to the JSON property dscpMode

Returns:

  • (String)


42068
42069
42070
# File 'lib/google/apis/compute_beta/classes.rb', line 42068

def dscp_mode
  @dscp_mode
end

#dscp_valueFixnum

Custom DSCP value from 0-63 range. Corresponds to the JSON property dscpValue

Returns:

  • (Fixnum)


42073
42074
42075
# File 'lib/google/apis/compute_beta/classes.rb', line 42073

def dscp_value
  @dscp_value
end

#traffic_classString

The traffic class that should be applied to the matching packet. Corresponds to the JSON property trafficClass

Returns:

  • (String)


42078
42079
42080
# File 'lib/google/apis/compute_beta/classes.rb', line 42078

def traffic_class
  @traffic_class
end

#typeString

Always "apply_traffic_classification" for traffic classification rules. Corresponds to the JSON property type

Returns:

  • (String)


42083
42084
42085
# File 'lib/google/apis/compute_beta/classes.rb', line 42083

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42090
42091
42092
42093
42094
42095
# File 'lib/google/apis/compute_beta/classes.rb', line 42090

def update!(**args)
  @dscp_mode = args[:dscp_mode] if args.key?(:dscp_mode)
  @dscp_value = args[:dscp_value] if args.key?(:dscp_value)
  @traffic_class = args[:traffic_class] if args.key?(:traffic_class)
  @type = args[:type] if args.key?(:type)
end