Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#dscp_mode ⇒ String
DSCP mode.
-
#dscp_value ⇒ Fixnum
Custom DSCP value from 0-63 range.
-
#traffic_class ⇒ String
The traffic class that should be applied to the matching packet.
-
#type ⇒ String
Always "apply_traffic_classification" for traffic classification rules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction
constructor
A new instance of NetworkPolicyTrafficClassificationRuleAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction
Returns a new instance of NetworkPolicyTrafficClassificationRuleAction.
41979 41980 41981 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dscp_mode ⇒ String
DSCP mode. When set to AUTO, the DSCP value will be picked
automatically based on selected trafficClass. Otherwise,dscpValue needs to be
explicitly specified.
Corresponds to the JSON property dscpMode
41962 41963 41964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41962 def dscp_mode @dscp_mode end |
#dscp_value ⇒ Fixnum
Custom DSCP value from 0-63 range.
Corresponds to the JSON property dscpValue
41967 41968 41969 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41967 def dscp_value @dscp_value end |
#traffic_class ⇒ String
The traffic class that should be applied to the matching packet.
Corresponds to the JSON property trafficClass
41972 41973 41974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41972 def traffic_class @traffic_class end |
#type ⇒ String
Always "apply_traffic_classification" for traffic classification rules.
Corresponds to the JSON property type
41977 41978 41979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41977 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41984 41985 41986 41987 41988 41989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41984 def update!(**args) @dscp_mode = args[:dscp_mode] if args.key?(:dscp_mode) @dscp_value = args[:dscp_value] if args.key?(:dscp_value) @traffic_class = args[:traffic_class] if args.key?(:traffic_class) @type = args[:type] if args.key?(:type) end |