Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#dscp_mode ⇒ String
DSCP mode.
-
#dscp_value ⇒ Fixnum
Custom DSCP value from 0-63 range.
-
#traffic_class ⇒ String
The traffic class that should be applied to the matching packet.
-
#type ⇒ String
Always "apply_traffic_classification" for traffic classification rules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction
constructor
A new instance of NetworkPolicyTrafficClassificationRuleAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleAction
Returns a new instance of NetworkPolicyTrafficClassificationRuleAction.
40636 40637 40638 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40636 def initialize(**args) update!(**args) end |
Instance Attribute Details
#dscp_mode ⇒ String
DSCP mode. When set to AUTO, the DSCP value will be picked
automatically based on selected trafficClass. Otherwise,dscpValue needs to be
explicitly specified.
Corresponds to the JSON property dscpMode
40619 40620 40621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40619 def dscp_mode @dscp_mode end |
#dscp_value ⇒ Fixnum
Custom DSCP value from 0-63 range.
Corresponds to the JSON property dscpValue
40624 40625 40626 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40624 def dscp_value @dscp_value end |
#traffic_class ⇒ String
The traffic class that should be applied to the matching packet.
Corresponds to the JSON property trafficClass
40629 40630 40631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40629 def traffic_class @traffic_class end |
#type ⇒ String
Always "apply_traffic_classification" for traffic classification rules.
Corresponds to the JSON property type
40634 40635 40636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40634 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40641 40642 40643 40644 40645 40646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40641 def update!(**args) @dscp_mode = args[:dscp_mode] if args.key?(:dscp_mode) @dscp_value = args[:dscp_value] if args.key?(:dscp_value) @traffic_class = args[:traffic_class] if args.key?(:traffic_class) @type = args[:type] if args.key?(:type) end |