Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcher

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a match condition that incoming traffic is evaluated against. Exactly one field must be specified.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcher

Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcher.



41992
41993
41994
# File 'lib/google/apis/compute_beta/classes.rb', line 41992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dest_ip_rangesArray<String>

CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000. Corresponds to the JSON property destIpRanges

Returns:

  • (Array<String>)


41979
41980
41981
# File 'lib/google/apis/compute_beta/classes.rb', line 41979

def dest_ip_ranges
  @dest_ip_ranges
end

#layer4_configsArray<Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config>

Pairs of IP protocols and ports that the rule should match. Corresponds to the JSON property layer4Configs



41984
41985
41986
# File 'lib/google/apis/compute_beta/classes.rb', line 41984

def layer4_configs
  @layer4_configs
end

#src_ip_rangesArray<String>

CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000. Corresponds to the JSON property srcIpRanges

Returns:

  • (Array<String>)


41990
41991
41992
# File 'lib/google/apis/compute_beta/classes.rb', line 41990

def src_ip_ranges
  @src_ip_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41997
41998
41999
42000
42001
# File 'lib/google/apis/compute_beta/classes.rb', line 41997

def update!(**args)
  @dest_ip_ranges = args[:dest_ip_ranges] if args.key?(:dest_ip_ranges)
  @layer4_configs = args[:layer4_configs] if args.key?(:layer4_configs)
  @src_ip_ranges = args[:src_ip_ranges] if args.key?(:src_ip_ranges)
end