Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcherLayer4Config

Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcherLayer4Config.



42025
42026
42027
# File 'lib/google/apis/compute_beta/classes.rb', line 42025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a traffic classification rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp,esp, ah, ipip,sctp), or the IP protocol number. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


42014
42015
42016
# File 'lib/google/apis/compute_beta/classes.rb', line 42014

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for UDP, TCP or SCTP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"],["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


42023
42024
42025
# File 'lib/google/apis/compute_beta/classes.rb', line 42023

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42030
42031
42032
42033
# File 'lib/google/apis/compute_beta/classes.rb', line 42030

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end