Class: Google::Apis::ComputeBeta::NetworkPolicyTrafficClassificationRuleMatcherLayer4Config

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkPolicyTrafficClassificationRuleMatcherLayer4Config

Returns a new instance of NetworkPolicyTrafficClassificationRuleMatcherLayer4Config.



40704
40705
40706
# File 'lib/google/apis/compute_beta/classes.rb', line 40704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ip_protocolString

The IP protocol to which this rule applies. The protocol type is required when creating a traffic classification rule. This value can either be one of the following well known protocol strings (tcp, udp, icmp,esp, ah, ipip,sctp), or the IP protocol number. Corresponds to the JSON property ipProtocol

Returns:

  • (String)


40693
40694
40695
# File 'lib/google/apis/compute_beta/classes.rb', line 40693

def ip_protocol
  @ip_protocol
end

#portsArray<String>

An optional list of ports to which this rule applies. This field is only applicable for UDP, TCP or SCTP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port. Example inputs include: ["22"],["80","443"], and ["12345-12349"]. Corresponds to the JSON property ports

Returns:

  • (Array<String>)


40702
40703
40704
# File 'lib/google/apis/compute_beta/classes.rb', line 40702

def ports
  @ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40709
40710
40711
40712
# File 'lib/google/apis/compute_beta/classes.rb', line 40709

def update!(**args)
  @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol)
  @ports = args[:ports] if args.key?(:ports)
end