Class: Google::Apis::ComputeBeta::NetworkProfileNetworkFeatures
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkProfileNetworkFeatures
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported.
-
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
-
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are allowed.
-
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
-
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
-
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
-
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
-
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
-
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network interfaces connected to this VPC.
-
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
-
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
-
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
-
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
-
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
-
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
-
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
-
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
-
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
-
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
-
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
-
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
-
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
-
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
-
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
-
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
-
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
-
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
-
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
-
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property
firewallPolicyTypes. -
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports.
-
#multicast ⇒ String
Specifies which type of multicast is supported.
-
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
-
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeBeta::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
-
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
-
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
-
#subnetwork_purposes ⇒ Array<String>
Output only.
-
#subnetwork_stack_types ⇒ Array<String>
Output only.
-
#unicast ⇒ String
Specifies which type of unicast is supported.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
constructor
A new instance of NetworkProfileNetworkFeatures.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfileNetworkFeatures
Returns a new instance of NetworkProfileNetworkFeatures.
42428 42429 42430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#address_purposes ⇒ Array<String>
Specifies what address purposes are supported. If empty, all address
purposes are supported.
Corresponds to the JSON property addressPurposes
42238 42239 42240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42238 def address_purposes @address_purposes end |
#allow_address_creation ⇒ String
Specifies whether address creation is allowed.
Corresponds to the JSON property allowAddressCreation
42243 42244 42245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42243 def allow_address_creation @allow_address_creation end |
#allow_alias_ip_ranges ⇒ String
Specifies whether alias IP ranges (and secondary address ranges) are
allowed.
Corresponds to the JSON property allowAliasIpRanges
42249 42250 42251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42249 def allow_alias_ip_ranges @allow_alias_ip_ranges end |
#allow_auto_mode_subnet ⇒ String
Specifies whether auto mode subnet creation is allowed.
Corresponds to the JSON property allowAutoModeSubnet
42254 42255 42256 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42254 def allow_auto_mode_subnet @allow_auto_mode_subnet end |
#allow_class_d_firewalls ⇒ String
Specifies whether firewalls for Class D address ranges are supported.
Corresponds to the JSON property allowClassDFirewalls
42259 42260 42261 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42259 def allow_class_d_firewalls @allow_class_d_firewalls end |
#allow_cloud_nat ⇒ String
Specifies whether cloud NAT creation is allowed.
Corresponds to the JSON property allowCloudNat
42264 42265 42266 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42264 def allow_cloud_nat @allow_cloud_nat end |
#allow_cloud_router ⇒ String
Specifies whether cloud router creation is allowed.
Corresponds to the JSON property allowCloudRouter
42269 42270 42271 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42269 def allow_cloud_router @allow_cloud_router end |
#allow_default_nic_attachment ⇒ String
Specifies whether default NIC attachment is allowed.
Corresponds to the JSON property allowDefaultNicAttachment
42274 42275 42276 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42274 def @allow_default_nic_attachment end |
#allow_external_ip_access ⇒ String
Specifies whether VMs are allowed to have external IP access on network
interfaces connected to this VPC.
Corresponds to the JSON property allowExternalIpAccess
42280 42281 42282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42280 def allow_external_ip_access @allow_external_ip_access end |
#allow_firewall_policy ⇒ String
Specifies whether firewall policy can be attached to the network.
Corresponds to the JSON property allowFirewallPolicy
42285 42286 42287 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42285 def allow_firewall_policy @allow_firewall_policy end |
#allow_interconnect ⇒ String
Specifies whether Cloud Interconnect creation is allowed.
Corresponds to the JSON property allowInterconnect
42290 42291 42292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42290 def allow_interconnect @allow_interconnect end |
#allow_ip_forwarding ⇒ String
Specifies whether IP forwarding is allowed.
Corresponds to the JSON property allowIpForwarding
42295 42296 42297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42295 def allow_ip_forwarding @allow_ip_forwarding end |
#allow_load_balancing ⇒ String
Specifies whether cloud load balancing is allowed.
Corresponds to the JSON property allowLoadBalancing
42300 42301 42302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42300 def allow_load_balancing @allow_load_balancing end |
#allow_multi_nic_in_same_network ⇒ String
Specifies whether multi-nic in the same network is allowed.
Corresponds to the JSON property allowMultiNicInSameNetwork
42305 42306 42307 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42305 def allow_multi_nic_in_same_network @allow_multi_nic_in_same_network end |
#allow_multi_nic_in_same_subnetwork ⇒ String
Specifies whether multi-nic in the same subnetwork is allowed.
Corresponds to the JSON property allowMultiNicInSameSubnetwork
42310 42311 42312 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42310 def allow_multi_nic_in_same_subnetwork @allow_multi_nic_in_same_subnetwork end |
#allow_multicast ⇒ String
Specifies whether multicast is allowed.
Corresponds to the JSON property allowMulticast
42315 42316 42317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42315 def allow_multicast @allow_multicast end |
#allow_ncc ⇒ String
Specifies whether NCC is allowed.
Corresponds to the JSON property allowNcc
42320 42321 42322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42320 def allow_ncc @allow_ncc end |
#allow_network_migration ⇒ String
Specifies whether VM network migration is allowed.
Corresponds to the JSON property allowNetworkMigration
42325 42326 42327 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42325 def allow_network_migration @allow_network_migration end |
#allow_packet_mirroring ⇒ String
Specifies whether Packet Mirroring 1.0 is supported.
Corresponds to the JSON property allowPacketMirroring
42330 42331 42332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42330 def allow_packet_mirroring @allow_packet_mirroring end |
#allow_private_google_access ⇒ String
Specifies whether private Google access is allowed.
Corresponds to the JSON property allowPrivateGoogleAccess
42335 42336 42337 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42335 def allow_private_google_access @allow_private_google_access end |
#allow_psc ⇒ String
Specifies whether PSC creation is allowed.
Corresponds to the JSON property allowPsc
42340 42341 42342 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42340 def allow_psc @allow_psc end |
#allow_same_network_unicast ⇒ String
Specifies whether unicast within the same network is allowed.
Corresponds to the JSON property allowSameNetworkUnicast
42345 42346 42347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42345 def allow_same_network_unicast @allow_same_network_unicast end |
#allow_static_routes ⇒ String
Specifies whether static route creation is allowed.
Corresponds to the JSON property allowStaticRoutes
42350 42351 42352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42350 def allow_static_routes @allow_static_routes end |
#allow_sub_interfaces ⇒ String
Specifies whether sub interfaces are allowed.
Corresponds to the JSON property allowSubInterfaces
42355 42356 42357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42355 def allow_sub_interfaces @allow_sub_interfaces end |
#allow_subnetwork_creation ⇒ String
Specifies whether subnetwork creation is allowed.
Corresponds to the JSON property allowSubnetworkCreation
42360 42361 42362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42360 def allow_subnetwork_creation @allow_subnetwork_creation end |
#allow_vpc_firewall_rules ⇒ String
Specifies whether VPC firewall rules can be created under the network.
Corresponds to the JSON property allowVpcFirewallRules
42365 42366 42367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42365 def allow_vpc_firewall_rules @allow_vpc_firewall_rules end |
#allow_vpc_peering ⇒ String
Specifies whether VPC peering is allowed.
Corresponds to the JSON property allowVpcPeering
42370 42371 42372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42370 def allow_vpc_peering @allow_vpc_peering end |
#allow_vpn ⇒ String
Specifies whether VPN creation is allowed.
Corresponds to the JSON property allowVpn
42375 42376 42377 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42375 def allow_vpn @allow_vpn end |
#firewall_policy_types ⇒ Array<String>
Corresponds to the JSON property firewallPolicyTypes
42380 42381 42382 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42380 def firewall_policy_types @firewall_policy_types end |
#interface_types ⇒ Array<String>
If set, limits the interface types that the network supports. If
empty, all interface types are supported.
Corresponds to the JSON property interfaceTypes
42386 42387 42388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42386 def interface_types @interface_types end |
#multicast ⇒ String
Specifies which type of multicast is supported.
Corresponds to the JSON property multicast
42391 42392 42393 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42391 def multicast @multicast end |
#predefined_network_internal_ipv6_range ⇒ String
Specifies a predefined internal IPv6 range for the network.
Corresponds to the JSON property predefinedNetworkInternalIpv6Range
42396 42397 42398 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42396 def predefined_network_internal_ipv6_range @predefined_network_internal_ipv6_range end |
#predefined_subnetwork_ranges ⇒ Array<Google::Apis::ComputeBeta::NetworkProfileNetworkFeaturesPredefinedSubnetworkRange>
Predefined subnetwork ranges for the network.
Corresponds to the JSON property predefinedSubnetworkRanges
42401 42402 42403 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42401 def predefined_subnetwork_ranges @predefined_subnetwork_ranges end |
#subnet_purposes ⇒ Array<String>
Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetPurposes
42406 42407 42408 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42406 def subnet_purposes @subnet_purposes end |
#subnet_stack_types ⇒ Array<String>
Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetStackTypes
42411 42412 42413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42411 def subnet_stack_types @subnet_stack_types end |
#subnetwork_purposes ⇒ Array<String>
Output only. Specifies which subnetwork purposes are supported.
Corresponds to the JSON property subnetworkPurposes
42416 42417 42418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42416 def subnetwork_purposes @subnetwork_purposes end |
#subnetwork_stack_types ⇒ Array<String>
Output only. Specifies which subnetwork stack types are supported.
Corresponds to the JSON property subnetworkStackTypes
42421 42422 42423 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42421 def subnetwork_stack_types @subnetwork_stack_types end |
#unicast ⇒ String
Specifies which type of unicast is supported.
Corresponds to the JSON property unicast
42426 42427 42428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42426 def unicast @unicast end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42433 42434 42435 42436 42437 42438 42439 42440 42441 42442 42443 42444 42445 42446 42447 42448 42449 42450 42451 42452 42453 42454 42455 42456 42457 42458 42459 42460 42461 42462 42463 42464 42465 42466 42467 42468 42469 42470 42471 42472 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42433 def update!(**args) @address_purposes = args[:address_purposes] if args.key?(:address_purposes) @allow_address_creation = args[:allow_address_creation] if args.key?(:allow_address_creation) @allow_alias_ip_ranges = args[:allow_alias_ip_ranges] if args.key?(:allow_alias_ip_ranges) @allow_auto_mode_subnet = args[:allow_auto_mode_subnet] if args.key?(:allow_auto_mode_subnet) @allow_class_d_firewalls = args[:allow_class_d_firewalls] if args.key?(:allow_class_d_firewalls) @allow_cloud_nat = args[:allow_cloud_nat] if args.key?(:allow_cloud_nat) @allow_cloud_router = args[:allow_cloud_router] if args.key?(:allow_cloud_router) @allow_default_nic_attachment = args[:allow_default_nic_attachment] if args.key?(:allow_default_nic_attachment) @allow_external_ip_access = args[:allow_external_ip_access] if args.key?(:allow_external_ip_access) @allow_firewall_policy = args[:allow_firewall_policy] if args.key?(:allow_firewall_policy) @allow_interconnect = args[:allow_interconnect] if args.key?(:allow_interconnect) @allow_ip_forwarding = args[:allow_ip_forwarding] if args.key?(:allow_ip_forwarding) @allow_load_balancing = args[:allow_load_balancing] if args.key?(:allow_load_balancing) @allow_multi_nic_in_same_network = args[:allow_multi_nic_in_same_network] if args.key?(:allow_multi_nic_in_same_network) @allow_multi_nic_in_same_subnetwork = args[:allow_multi_nic_in_same_subnetwork] if args.key?(:allow_multi_nic_in_same_subnetwork) @allow_multicast = args[:allow_multicast] if args.key?(:allow_multicast) @allow_ncc = args[:allow_ncc] if args.key?(:allow_ncc) @allow_network_migration = args[:allow_network_migration] if args.key?(:allow_network_migration) @allow_packet_mirroring = args[:allow_packet_mirroring] if args.key?(:allow_packet_mirroring) @allow_private_google_access = args[:allow_private_google_access] if args.key?(:allow_private_google_access) @allow_psc = args[:allow_psc] if args.key?(:allow_psc) @allow_same_network_unicast = args[:allow_same_network_unicast] if args.key?(:allow_same_network_unicast) @allow_static_routes = args[:allow_static_routes] if args.key?(:allow_static_routes) @allow_sub_interfaces = args[:allow_sub_interfaces] if args.key?(:allow_sub_interfaces) @allow_subnetwork_creation = args[:allow_subnetwork_creation] if args.key?(:allow_subnetwork_creation) @allow_vpc_firewall_rules = args[:allow_vpc_firewall_rules] if args.key?(:allow_vpc_firewall_rules) @allow_vpc_peering = args[:allow_vpc_peering] if args.key?(:allow_vpc_peering) @allow_vpn = args[:allow_vpn] if args.key?(:allow_vpn) @firewall_policy_types = args[:firewall_policy_types] if args.key?(:firewall_policy_types) @interface_types = args[:interface_types] if args.key?(:interface_types) @multicast = args[:multicast] if args.key?(:multicast) @predefined_network_internal_ipv6_range = args[:predefined_network_internal_ipv6_range] if args.key?(:predefined_network_internal_ipv6_range) @predefined_subnetwork_ranges = args[:predefined_subnetwork_ranges] if args.key?(:predefined_subnetwork_ranges) @subnet_purposes = args[:subnet_purposes] if args.key?(:subnet_purposes) @subnet_stack_types = args[:subnet_stack_types] if args.key?(:subnet_stack_types) @subnetwork_purposes = args[:subnetwork_purposes] if args.key?(:subnetwork_purposes) @subnetwork_stack_types = args[:subnetwork_stack_types] if args.key?(:subnetwork_stack_types) @unicast = args[:unicast] if args.key?(:unicast) end |