Class: Google::Apis::ComputeBeta::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



42654
42655
42656
# File 'lib/google/apis/compute_beta/classes.rb', line 42654

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


42608
42609
42610
# File 'lib/google/apis/compute_beta/classes.rb', line 42608

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42613
42614
42615
# File 'lib/google/apis/compute_beta/classes.rb', line 42613

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



42618
42619
42620
# File 'lib/google/apis/compute_beta/classes.rb', line 42618

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


42624
42625
42626
# File 'lib/google/apis/compute_beta/classes.rb', line 42624

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42636
42637
42638
# File 'lib/google/apis/compute_beta/classes.rb', line 42636

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42641
42642
42643
# File 'lib/google/apis/compute_beta/classes.rb', line 42641

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42647
42648
42649
# File 'lib/google/apis/compute_beta/classes.rb', line 42647

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42652
42653
42654
# File 'lib/google/apis/compute_beta/classes.rb', line 42652

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42659
42660
42661
42662
42663
42664
42665
42666
42667
42668
# File 'lib/google/apis/compute_beta/classes.rb', line 42659

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end