Class: Google::Apis::ComputeBeta::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
42590 42591 42592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42590 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
42544 42545 42546 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42544 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42549 42550 42551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42549 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
42554 42555 42556 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42554 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
42560 42561 42562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42560 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42572 42573 42574 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42572 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42577 42578 42579 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42577 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
42583 42584 42585 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42583 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42588 42589 42590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42588 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42595 42596 42597 42598 42599 42600 42601 42602 42603 42604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42595 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |