Class: Google::Apis::ComputeBeta::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
42046 42047 42048 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42046 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
42000 42001 42002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42000 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42005 42006 42007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42005 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
42010 42011 42012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42010 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
42016 42017 42018 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42016 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42028 42029 42030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42028 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42033 42034 42035 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42033 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
42039 42040 42041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42039 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42044 42045 42046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42044 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42051 42052 42053 42054 42055 42056 42057 42058 42059 42060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42051 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |