Class: Google::Apis::ComputeBeta::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



41987
41988
41989
# File 'lib/google/apis/compute_beta/classes.rb', line 41987

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


41941
41942
41943
# File 'lib/google/apis/compute_beta/classes.rb', line 41941

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41946
41947
41948
# File 'lib/google/apis/compute_beta/classes.rb', line 41946

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



41951
41952
41953
# File 'lib/google/apis/compute_beta/classes.rb', line 41951

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


41957
41958
41959
# File 'lib/google/apis/compute_beta/classes.rb', line 41957

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41969
41970
41971
# File 'lib/google/apis/compute_beta/classes.rb', line 41969

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41974
41975
41976
# File 'lib/google/apis/compute_beta/classes.rb', line 41974

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41980
41981
41982
# File 'lib/google/apis/compute_beta/classes.rb', line 41980

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41985
41986
41987
# File 'lib/google/apis/compute_beta/classes.rb', line 41985

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41992
41993
41994
41995
41996
41997
41998
41999
42000
42001
# File 'lib/google/apis/compute_beta/classes.rb', line 41992

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end