Class: Google::Apis::ComputeBeta::NetworkProfilesListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of network profiles.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworkProfilesListResponse

Returns a new instance of NetworkProfilesListResponse.



40379
40380
40381
# File 'lib/google/apis/compute_beta/classes.rb', line 40379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


40333
40334
40335
# File 'lib/google/apis/compute_beta/classes.rb', line 40333

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40338
40339
40340
# File 'lib/google/apis/compute_beta/classes.rb', line 40338

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NetworkProfile>

A list of NetworkProfile resources. Corresponds to the JSON property items



40343
40344
40345
# File 'lib/google/apis/compute_beta/classes.rb', line 40343

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList for network profiles. Corresponds to the JSON property kind

Returns:

  • (String)


40349
40350
40351
# File 'lib/google/apis/compute_beta/classes.rb', line 40349

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40361
40362
40363
# File 'lib/google/apis/compute_beta/classes.rb', line 40361

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40366
40367
40368
# File 'lib/google/apis/compute_beta/classes.rb', line 40366

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


40372
40373
40374
# File 'lib/google/apis/compute_beta/classes.rb', line 40372

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NetworkProfilesListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



40377
40378
40379
# File 'lib/google/apis/compute_beta/classes.rb', line 40377

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40384
40385
40386
40387
40388
40389
40390
40391
40392
40393
# File 'lib/google/apis/compute_beta/classes.rb', line 40384

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end