Class: Google::Apis::ComputeBeta::NetworkProfilesListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworkProfilesListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of network profiles.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkProfile>
A list of NetworkProfile resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworkProfilesListResponse
constructor
A new instance of NetworkProfilesListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworkProfilesListResponse
Returns a new instance of NetworkProfilesListResponse.
38991 38992 38993 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38991 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
38945 38946 38947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38945 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
38950 38951 38952 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38950 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NetworkProfile>
A list of NetworkProfile resources.
Corresponds to the JSON property items
38955 38956 38957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38955 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#networkProfileList
for network profiles.
Corresponds to the JSON property kind
38961 38962 38963 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38961 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value
for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken
to
continue paging through the results.
Corresponds to the JSON property nextPageToken
38973 38974 38975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38973 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
38978 38979 38980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38978 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
38984 38985 38986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38984 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NetworkProfilesListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
38989 38990 38991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38989 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
38996 38997 38998 38999 39000 39001 39002 39003 39004 39005 |
# File 'lib/google/apis/compute_beta/classes.rb', line 38996 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |