Class: Google::Apis::ComputeBeta::NetworksAddPeeringRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NetworksAddPeeringRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_create_routes ⇒ Boolean
(also: #auto_create_routes?)
This field will be deprecated soon.
-
#name ⇒ String
Name of the peering, which should conform to RFC1035.
-
#network_peering ⇒ Google::Apis::ComputeBeta::NetworkPeering
A network peering attached to a network resource.
-
#peer_network ⇒ String
URL of the peer network.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NetworksAddPeeringRequest
constructor
A new instance of NetworksAddPeeringRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NetworksAddPeeringRequest
Returns a new instance of NetworksAddPeeringRequest.
42714 42715 42716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_create_routes ⇒ Boolean Also known as: auto_create_routes?
This field will be deprecated soon. Useexchange_subnet_routes in
network_peering
instead.
Indicates whether full mesh connectivity is created and managed
automatically between peered networks. Currently this field should always
be true since Google Compute Engine will automatically create and manage
subnetwork routes between two networks when peering state isACTIVE.
Corresponds to the JSON property autoCreateRoutes
42691 42692 42693 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42691 def auto_create_routes @auto_create_routes end |
#name ⇒ String
Name of the peering, which should conform to RFC1035.
Corresponds to the JSON property name
42697 42698 42699 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42697 def name @name end |
#network_peering ⇒ Google::Apis::ComputeBeta::NetworkPeering
A network peering attached to a network resource. The message includes the
peering name, peer network, peering state, and a flag indicating whether
Google Compute Engine should automatically create routes for the peering.
Corresponds to the JSON property networkPeering
42704 42705 42706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42704 def network_peering @network_peering end |
#peer_network ⇒ String
URL of the peer network. It can be either full URL or partial URL. The
peer network may belong to a different project. If the partial URL does not
contain project, it is assumed that the peer network is in the same project
as the current network.
Corresponds to the JSON property peerNetwork
42712 42713 42714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42712 def peer_network @peer_network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42719 42720 42721 42722 42723 42724 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42719 def update!(**args) @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes) @name = args[:name] if args.key?(:name) @network_peering = args[:network_peering] if args.key?(:network_peering) @peer_network = args[:peer_network] if args.key?(:peer_network) end |