Class: Google::Apis::ComputeBeta::NetworksAddPeeringRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksAddPeeringRequest

Returns a new instance of NetworksAddPeeringRequest.



42175
42176
42177
# File 'lib/google/apis/compute_beta/classes.rb', line 42175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_create_routesBoolean Also known as: auto_create_routes?

This field will be deprecated soon. Useexchange_subnet_routes in network_peering instead. Indicates whether full mesh connectivity is created and managed automatically between peered networks. Currently this field should always be true since Google Compute Engine will automatically create and manage subnetwork routes between two networks when peering state isACTIVE. Corresponds to the JSON property autoCreateRoutes

Returns:

  • (Boolean)


42152
42153
42154
# File 'lib/google/apis/compute_beta/classes.rb', line 42152

def auto_create_routes
  @auto_create_routes
end

#nameString

Name of the peering, which should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


42158
42159
42160
# File 'lib/google/apis/compute_beta/classes.rb', line 42158

def name
  @name
end

#network_peeringGoogle::Apis::ComputeBeta::NetworkPeering

A network peering attached to a network resource. The message includes the peering name, peer network, peering state, and a flag indicating whether Google Compute Engine should automatically create routes for the peering. Corresponds to the JSON property networkPeering



42165
42166
42167
# File 'lib/google/apis/compute_beta/classes.rb', line 42165

def network_peering
  @network_peering
end

#peer_networkString

URL of the peer network. It can be either full URL or partial URL. The peer network may belong to a different project. If the partial URL does not contain project, it is assumed that the peer network is in the same project as the current network. Corresponds to the JSON property peerNetwork

Returns:

  • (String)


42173
42174
42175
# File 'lib/google/apis/compute_beta/classes.rb', line 42173

def peer_network
  @peer_network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42180
42181
42182
42183
42184
42185
# File 'lib/google/apis/compute_beta/classes.rb', line 42180

def update!(**args)
  @auto_create_routes = args[:auto_create_routes] if args.key?(:auto_create_routes)
  @name = args[:name] if args.key?(:name)
  @network_peering = args[:network_peering] if args.key?(:network_peering)
  @peer_network = args[:peer_network] if args.key?(:peer_network)
end