Class: Google::Apis::ComputeBeta::NetworksGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksGetEffectiveFirewallsResponse

Returns a new instance of NetworksGetEffectiveFirewallsResponse.



42229
42230
42231
# File 'lib/google/apis/compute_beta/classes.rb', line 42229

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policysArray<Google::Apis::ComputeBeta::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

[Output Only] Effective firewalls from firewall policy. It returns Global Network Firewall Policies and Hierarchical Firewall Policies. UseregionNetworkFirewallPolicies.getEffectiveFirewalls to get Regional Network Firewall Policies as well. Corresponds to the JSON property firewallPolicys



42217
42218
42219
# File 'lib/google/apis/compute_beta/classes.rb', line 42217

def firewall_policys
  @firewall_policys
end

#firewallsArray<Google::Apis::ComputeBeta::Firewall>

Effective firewalls on the network. Corresponds to the JSON property firewalls



42222
42223
42224
# File 'lib/google/apis/compute_beta/classes.rb', line 42222

def firewalls
  @firewalls
end

#organization_firewallsArray<Google::Apis::ComputeBeta::NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy>

Effective firewalls from organization policies. Corresponds to the JSON property organizationFirewalls



42227
42228
42229
# File 'lib/google/apis/compute_beta/classes.rb', line 42227

def organization_firewalls
  @organization_firewalls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42234
42235
42236
42237
42238
# File 'lib/google/apis/compute_beta/classes.rb', line 42234

def update!(**args)
  @firewall_policys = args[:firewall_policys] if args.key?(:firewall_policys)
  @firewalls = args[:firewalls] if args.key?(:firewalls)
  @organization_firewalls = args[:organization_firewalls] if args.key?(:organization_firewalls)
end