Class: Google::Apis::ComputeBeta::NetworksGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NetworksGetEffectiveFirewallsResponse

Returns a new instance of NetworksGetEffectiveFirewallsResponse.



40621
40622
40623
# File 'lib/google/apis/compute_beta/classes.rb', line 40621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policysArray<Google::Apis::ComputeBeta::NetworksGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

[Output Only] Effective firewalls from firewall policy. It returns Global Network Firewall Policies and Hierarchical Firewall Policies. UseregionNetworkFirewallPolicies.getEffectiveFirewalls to get Regional Network Firewall Policies as well. Corresponds to the JSON property firewallPolicys



40609
40610
40611
# File 'lib/google/apis/compute_beta/classes.rb', line 40609

def firewall_policys
  @firewall_policys
end

#firewallsArray<Google::Apis::ComputeBeta::Firewall>

Effective firewalls on the network. Corresponds to the JSON property firewalls



40614
40615
40616
# File 'lib/google/apis/compute_beta/classes.rb', line 40614

def firewalls
  @firewalls
end

#organization_firewallsArray<Google::Apis::ComputeBeta::NetworksGetEffectiveFirewallsResponseOrganizationFirewallPolicy>

Effective firewalls from organization policies. Corresponds to the JSON property organizationFirewalls



40619
40620
40621
# File 'lib/google/apis/compute_beta/classes.rb', line 40619

def organization_firewalls
  @organization_firewalls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40626
40627
40628
40629
40630
# File 'lib/google/apis/compute_beta/classes.rb', line 40626

def update!(**args)
  @firewall_policys = args[:firewall_policys] if args.key?(:firewall_policys)
  @firewalls = args[:firewalls] if args.key?(:firewalls)
  @organization_firewalls = args[:organization_firewalls] if args.key?(:organization_firewalls)
end