Class: Google::Apis::ComputeBeta::NodeGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroup

Returns a new instance of NodeGroup.



43171
43172
43173
# File 'lib/google/apis/compute_beta/classes.rb', line 43171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_policyGoogle::Apis::ComputeBeta::NodeGroupAutoscalingPolicy

Specifies how autoscaling should behave. Corresponds to the JSON property autoscalingPolicy



43065
43066
43067
# File 'lib/google/apis/compute_beta/classes.rb', line 43065

def autoscaling_policy
  @autoscaling_policy
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


43071
43072
43073
# File 'lib/google/apis/compute_beta/classes.rb', line 43071

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


43077
43078
43079
# File 'lib/google/apis/compute_beta/classes.rb', line 43077

def description
  @description
end

#fingerprintString

Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


43083
43084
43085
# File 'lib/google/apis/compute_beta/classes.rb', line 43083

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


43090
43091
43092
# File 'lib/google/apis/compute_beta/classes.rb', line 43090

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup for node group. Corresponds to the JSON property kind

Returns:

  • (String)


43096
43097
43098
# File 'lib/google/apis/compute_beta/classes.rb', line 43096

def kind
  @kind
end

#location_hintString

An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate. Corresponds to the JSON property locationHint

Returns:

  • (String)


43105
43106
43107
# File 'lib/google/apis/compute_beta/classes.rb', line 43105

def location_hint
  @location_hint
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


43111
43112
43113
# File 'lib/google/apis/compute_beta/classes.rb', line 43111

def maintenance_interval
  @maintenance_interval
end

#maintenance_policyString

Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Corresponds to the JSON property maintenancePolicy

Returns:

  • (String)


43120
43121
43122
# File 'lib/google/apis/compute_beta/classes.rb', line 43120

def maintenance_policy
  @maintenance_policy
end

#maintenance_windowGoogle::Apis::ComputeBeta::NodeGroupMaintenanceWindow

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window. Corresponds to the JSON property maintenanceWindow



43126
43127
43128
# File 'lib/google/apis/compute_beta/classes.rb', line 43126

def maintenance_window
  @maintenance_window
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


43138
43139
43140
# File 'lib/google/apis/compute_beta/classes.rb', line 43138

def name
  @name
end

#node_templateString

URL of the node template to create the node group from. Corresponds to the JSON property nodeTemplate

Returns:

  • (String)


43143
43144
43145
# File 'lib/google/apis/compute_beta/classes.rb', line 43143

def node_template
  @node_template
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43148
43149
43150
# File 'lib/google/apis/compute_beta/classes.rb', line 43148

def self_link
  @self_link
end

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



43153
43154
43155
# File 'lib/google/apis/compute_beta/classes.rb', line 43153

def share_settings
  @share_settings
end

#sizeFixnum

Output only. [Output Only] The total number of nodes in the node group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


43158
43159
43160
# File 'lib/google/apis/compute_beta/classes.rb', line 43158

def size
  @size
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


43163
43164
43165
# File 'lib/google/apis/compute_beta/classes.rb', line 43163

def status
  @status
end

#zoneString

Output only. [Output Only] The name of the zone where the node group resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


43169
43170
43171
# File 'lib/google/apis/compute_beta/classes.rb', line 43169

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43176
43177
43178
43179
43180
43181
43182
43183
43184
43185
43186
43187
43188
43189
43190
43191
43192
43193
43194
# File 'lib/google/apis/compute_beta/classes.rb', line 43176

def update!(**args)
  @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @name = args[:name] if args.key?(:name)
  @node_template = args[:node_template] if args.key?(:node_template)
  @self_link = args[:self_link] if args.key?(:self_link)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size = args[:size] if args.key?(:size)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end