Class: Google::Apis::ComputeBeta::NodeGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroup

Returns a new instance of NodeGroup.



43043
43044
43045
# File 'lib/google/apis/compute_beta/classes.rb', line 43043

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#autoscaling_policyGoogle::Apis::ComputeBeta::NodeGroupAutoscalingPolicy

Specifies how autoscaling should behave. Corresponds to the JSON property autoscalingPolicy



42937
42938
42939
# File 'lib/google/apis/compute_beta/classes.rb', line 42937

def autoscaling_policy
  @autoscaling_policy
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


42943
42944
42945
# File 'lib/google/apis/compute_beta/classes.rb', line 42943

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


42949
42950
42951
# File 'lib/google/apis/compute_beta/classes.rb', line 42949

def description
  @description
end

#fingerprintString

Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


42955
42956
42957
# File 'lib/google/apis/compute_beta/classes.rb', line 42955

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


42962
42963
42964
# File 'lib/google/apis/compute_beta/classes.rb', line 42962

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup for node group. Corresponds to the JSON property kind

Returns:

  • (String)


42968
42969
42970
# File 'lib/google/apis/compute_beta/classes.rb', line 42968

def kind
  @kind
end

#location_hintString

An opaque location hint used to place the Node close to other resources. This field is for use by internal tools that use the public API. The location hint here on the NodeGroup overrides any location_hint present in the NodeTemplate. Corresponds to the JSON property locationHint

Returns:

  • (String)


42977
42978
42979
# File 'lib/google/apis/compute_beta/classes.rb', line 42977

def location_hint
  @location_hint
end

#maintenance_intervalString

Specifies the frequency of planned maintenance events. The accepted values are: AS_NEEDED and RECURRENT. Corresponds to the JSON property maintenanceInterval

Returns:

  • (String)


42983
42984
42985
# File 'lib/google/apis/compute_beta/classes.rb', line 42983

def maintenance_interval
  @maintenance_interval
end

#maintenance_policyString

Specifies how to handle instances when a node in the group undergoes maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or MIGRATE_WITHIN_NODE_GROUP. The default value is DEFAULT. For more information, see Maintenance policies. Corresponds to the JSON property maintenancePolicy

Returns:

  • (String)


42992
42993
42994
# File 'lib/google/apis/compute_beta/classes.rb', line 42992

def maintenance_policy
  @maintenance_policy
end

#maintenance_windowGoogle::Apis::ComputeBeta::NodeGroupMaintenanceWindow

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window. Corresponds to the JSON property maintenanceWindow



42998
42999
43000
# File 'lib/google/apis/compute_beta/classes.rb', line 42998

def maintenance_window
  @maintenance_window
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


43010
43011
43012
# File 'lib/google/apis/compute_beta/classes.rb', line 43010

def name
  @name
end

#node_templateString

URL of the node template to create the node group from. Corresponds to the JSON property nodeTemplate

Returns:

  • (String)


43015
43016
43017
# File 'lib/google/apis/compute_beta/classes.rb', line 43015

def node_template
  @node_template
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43020
43021
43022
# File 'lib/google/apis/compute_beta/classes.rb', line 43020

def self_link
  @self_link
end

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



43025
43026
43027
# File 'lib/google/apis/compute_beta/classes.rb', line 43025

def share_settings
  @share_settings
end

#sizeFixnum

Output only. [Output Only] The total number of nodes in the node group. Corresponds to the JSON property size

Returns:

  • (Fixnum)


43030
43031
43032
# File 'lib/google/apis/compute_beta/classes.rb', line 43030

def size
  @size
end

#statusString

Corresponds to the JSON property status

Returns:

  • (String)


43035
43036
43037
# File 'lib/google/apis/compute_beta/classes.rb', line 43035

def status
  @status
end

#zoneString

Output only. [Output Only] The name of the zone where the node group resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


43041
43042
43043
# File 'lib/google/apis/compute_beta/classes.rb', line 43041

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43048
43049
43050
43051
43052
43053
43054
43055
43056
43057
43058
43059
43060
43061
43062
43063
43064
43065
43066
# File 'lib/google/apis/compute_beta/classes.rb', line 43048

def update!(**args)
  @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval)
  @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy)
  @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window)
  @name = args[:name] if args.key?(:name)
  @node_template = args[:node_template] if args.key?(:node_template)
  @self_link = args[:self_link] if args.key?(:self_link)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @size = args[:size] if args.key?(:size)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end