Class: Google::Apis::ComputeBeta::NodeGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.
Instance Attribute Summary collapse
-
#autoscaling_policy ⇒ Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Corresponds to the JSON property
fingerprintNOTE: Values are automatically base64 encoded/decoded in the client library. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_hint ⇒ String
An opaque location hint used to place the Node close to other resources.
-
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events.
-
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes maintenance.
-
#maintenance_window ⇒ Google::Apis::ComputeBeta::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#node_template ⇒ String
URL of the node template to create the node group from.
-
#self_link ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#size ⇒ Fixnum
Output only.
-
#status ⇒ String
Corresponds to the JSON property
status. -
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroup
constructor
A new instance of NodeGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroup
Returns a new instance of NodeGroup.
43043 43044 43045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43043 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_policy ⇒ Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
Corresponds to the JSON property autoscalingPolicy
42937 42938 42939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42937 def autoscaling_policy @autoscaling_policy end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
42943 42944 42945 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42943 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
42949 42950 42951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42949 def description @description end |
#fingerprint ⇒ String
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
42955 42956 42957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42955 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
42962 42963 42964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42962 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup
for node group.
Corresponds to the JSON property kind
42968 42969 42970 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42968 def kind @kind end |
#location_hint ⇒ String
An opaque location hint used to place the Node close to other
resources.
This field is for use by internal tools that use the public API.
The location hint here on the NodeGroup overrides any location_hint
present in the NodeTemplate.
Corresponds to the JSON property locationHint
42977 42978 42979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42977 def location_hint @location_hint end |
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events. The accepted values
are: AS_NEEDED and RECURRENT.
Corresponds to the JSON property maintenanceInterval
42983 42984 42985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42983 def maintenance_interval @maintenance_interval end |
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes
maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or
MIGRATE_WITHIN_NODE_GROUP.
The default value is DEFAULT. For more information, see
Maintenance policies.
Corresponds to the JSON property maintenancePolicy
42992 42993 42994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42992 def maintenance_policy @maintenance_policy end |
#maintenance_window ⇒ Google::Apis::ComputeBeta::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations. GCE's internal
maintenance will be performed within this window.
Corresponds to the JSON property maintenanceWindow
42998 42999 43000 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42998 def maintenance_window @maintenance_window end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
43010 43011 43012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43010 def name @name end |
#node_template ⇒ String
URL of the node template to create the node group from.
Corresponds to the JSON property nodeTemplate
43015 43016 43017 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43015 def node_template @node_template end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
43020 43021 43022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43020 def self_link @self_link end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
43025 43026 43027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43025 def share_settings @share_settings end |
#size ⇒ Fixnum
Output only. [Output Only] The total number of nodes in the node group.
Corresponds to the JSON property size
43030 43031 43032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43030 def size @size end |
#status ⇒ String
Corresponds to the JSON property status
43035 43036 43037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43035 def status @status end |
#zone ⇒ String
Output only. [Output Only] The name of the zone where the node group resides,
such as us-central1-a.
Corresponds to the JSON property zone
43041 43042 43043 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43041 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43048 43049 43050 43051 43052 43053 43054 43055 43056 43057 43058 43059 43060 43061 43062 43063 43064 43065 43066 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43048 def update!(**args) @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location_hint = args[:location_hint] if args.key?(:location_hint) @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @name = args[:name] if args.key?(:name) @node_template = args[:node_template] if args.key?(:node_template) @self_link = args[:self_link] if args.key?(:self_link) @share_settings = args[:share_settings] if args.key?(:share_settings) @size = args[:size] if args.key?(:size) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |