Class: Google::Apis::ComputeBeta::NodeGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a sole-tenant Node Group resource. A sole-tenant node is a physical server that is dedicated to hosting VM instances only for your specific project. Use sole-tenant nodes to keep your instances physically separated from instances in other projects, or to group your instances together on the same host hardware. For more information, readSole-tenant nodes.
Instance Attribute Summary collapse
-
#autoscaling_policy ⇒ Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Corresponds to the JSON property
fingerprintNOTE: Values are automatically base64 encoded/decoded in the client library. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#location_hint ⇒ String
An opaque location hint used to place the Node close to other resources.
-
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events.
-
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes maintenance.
-
#maintenance_window ⇒ Google::Apis::ComputeBeta::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#node_template ⇒ String
URL of the node template to create the node group from.
-
#self_link ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#size ⇒ Fixnum
Output only.
-
#status ⇒ String
Corresponds to the JSON property
status. -
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroup
constructor
A new instance of NodeGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroup
Returns a new instance of NodeGroup.
42504 42505 42506 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42504 def initialize(**args) update!(**args) end |
Instance Attribute Details
#autoscaling_policy ⇒ Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
Specifies how autoscaling should behave.
Corresponds to the JSON property autoscalingPolicy
42398 42399 42400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42398 def autoscaling_policy @autoscaling_policy end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
42404 42405 42406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42404 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
42410 42411 42412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42410 def description @description end |
#fingerprint ⇒ String
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
42416 42417 42418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42416 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
42423 42424 42425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42423 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#nodeGroup
for node group.
Corresponds to the JSON property kind
42429 42430 42431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42429 def kind @kind end |
#location_hint ⇒ String
An opaque location hint used to place the Node close to other
resources.
This field is for use by internal tools that use the public API.
The location hint here on the NodeGroup overrides any location_hint
present in the NodeTemplate.
Corresponds to the JSON property locationHint
42438 42439 42440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42438 def location_hint @location_hint end |
#maintenance_interval ⇒ String
Specifies the frequency of planned maintenance events. The accepted values
are: AS_NEEDED and RECURRENT.
Corresponds to the JSON property maintenanceInterval
42444 42445 42446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42444 def maintenance_interval @maintenance_interval end |
#maintenance_policy ⇒ String
Specifies how to handle instances when a node in the group undergoes
maintenance. Set to one of: DEFAULT,RESTART_IN_PLACE, or
MIGRATE_WITHIN_NODE_GROUP.
The default value is DEFAULT. For more information, see
Maintenance policies.
Corresponds to the JSON property maintenancePolicy
42453 42454 42455 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42453 def maintenance_policy @maintenance_policy end |
#maintenance_window ⇒ Google::Apis::ComputeBeta::NodeGroupMaintenanceWindow
Time window specified for daily maintenance operations. GCE's internal
maintenance will be performed within this window.
Corresponds to the JSON property maintenanceWindow
42459 42460 42461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42459 def maintenance_window @maintenance_window end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
42471 42472 42473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42471 def name @name end |
#node_template ⇒ String
URL of the node template to create the node group from.
Corresponds to the JSON property nodeTemplate
42476 42477 42478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42476 def node_template @node_template end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
42481 42482 42483 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42481 def self_link @self_link end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
42486 42487 42488 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42486 def share_settings @share_settings end |
#size ⇒ Fixnum
Output only. [Output Only] The total number of nodes in the node group.
Corresponds to the JSON property size
42491 42492 42493 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42491 def size @size end |
#status ⇒ String
Corresponds to the JSON property status
42496 42497 42498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42496 def status @status end |
#zone ⇒ String
Output only. [Output Only] The name of the zone where the node group resides,
such as us-central1-a.
Corresponds to the JSON property zone
42502 42503 42504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42502 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42509 42510 42511 42512 42513 42514 42515 42516 42517 42518 42519 42520 42521 42522 42523 42524 42525 42526 42527 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42509 def update!(**args) @autoscaling_policy = args[:autoscaling_policy] if args.key?(:autoscaling_policy) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @location_hint = args[:location_hint] if args.key?(:location_hint) @maintenance_interval = args[:maintenance_interval] if args.key?(:maintenance_interval) @maintenance_policy = args[:maintenance_policy] if args.key?(:maintenance_policy) @maintenance_window = args[:maintenance_window] if args.key?(:maintenance_window) @name = args[:name] if args.key?(:name) @node_template = args[:node_template] if args.key?(:node_template) @self_link = args[:self_link] if args.key?(:self_link) @share_settings = args[:share_settings] if args.key?(:share_settings) @size = args[:size] if args.key?(:size) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |