Class: Google::Apis::ComputeBeta::NodeGroupAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAggregatedList
constructor
A new instance of NodeGroupAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAggregatedList
Returns a new instance of NodeGroupAggregatedList.
43641 43642 43643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43641 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43602 43603 43604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43602 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NodeGroupsScopedList>
A list of NodeGroupsScopedList resources.
Corresponds to the JSON property items
43607 43608 43609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43607 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeGroupAggregatedList for aggregated lists of node
groups.
Corresponds to the JSON property kind
43614 43615 43616 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43614 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43624 43625 43626 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43624 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43629 43630 43631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43629 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
43634 43635 43636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43634 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43639 43640 43641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43639 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43646 43647 43648 43649 43650 43651 43652 43653 43654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43646 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |