Class: Google::Apis::ComputeBeta::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



42635
42636
42637
# File 'lib/google/apis/compute_beta/classes.rb', line 42635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42596
42597
42598
# File 'lib/google/apis/compute_beta/classes.rb', line 42596

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



42601
42602
42603
# File 'lib/google/apis/compute_beta/classes.rb', line 42601

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


42608
42609
42610
# File 'lib/google/apis/compute_beta/classes.rb', line 42608

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42618
42619
42620
# File 'lib/google/apis/compute_beta/classes.rb', line 42618

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42623
42624
42625
# File 'lib/google/apis/compute_beta/classes.rb', line 42623

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42628
42629
42630
# File 'lib/google/apis/compute_beta/classes.rb', line 42628

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42633
42634
42635
# File 'lib/google/apis/compute_beta/classes.rb', line 42633

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42640
42641
42642
42643
42644
42645
42646
42647
42648
# File 'lib/google/apis/compute_beta/classes.rb', line 42640

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end