Class: Google::Apis::ComputeBeta::NodeGroupAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupAggregatedList

Returns a new instance of NodeGroupAggregatedList.



42576
42577
42578
# File 'lib/google/apis/compute_beta/classes.rb', line 42576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42537
42538
42539
# File 'lib/google/apis/compute_beta/classes.rb', line 42537

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeGroupsScopedList>

A list of NodeGroupsScopedList resources. Corresponds to the JSON property items



42542
42543
42544
# File 'lib/google/apis/compute_beta/classes.rb', line 42542

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeGroupAggregatedList for aggregated lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


42549
42550
42551
# File 'lib/google/apis/compute_beta/classes.rb', line 42549

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42559
42560
42561
# File 'lib/google/apis/compute_beta/classes.rb', line 42559

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42564
42565
42566
# File 'lib/google/apis/compute_beta/classes.rb', line 42564

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42569
42570
42571
# File 'lib/google/apis/compute_beta/classes.rb', line 42569

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeGroupAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42574
42575
42576
# File 'lib/google/apis/compute_beta/classes.rb', line 42574

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42581
42582
42583
42584
42585
42586
42587
42588
42589
# File 'lib/google/apis/compute_beta/classes.rb', line 42581

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end