Class: Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have.
-
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
-
#mode ⇒ String
The autoscaling mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
constructor
A new instance of NodeGroupAutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
Returns a new instance of NodeGroupAutoscalingPolicy.
43287 43288 43289 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43287 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have. Must be set if
autoscaling is enabled. Maximum value allowed is 100.
Corresponds to the JSON property maxNodes
43273 43274 43275 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43273 def max_nodes @max_nodes end |
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
Corresponds to the JSON property minNodes
43278 43279 43280 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43278 def min_nodes @min_nodes end |
#mode ⇒ String
The autoscaling mode. Set to one of: ON, OFF,
or ONLY_SCALE_OUT. For more information, see
Autoscaler modes.
Corresponds to the JSON property mode
43285 43286 43287 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43285 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43292 43293 43294 43295 43296 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43292 def update!(**args) @max_nodes = args[:max_nodes] if args.key?(:max_nodes) @min_nodes = args[:min_nodes] if args.key?(:min_nodes) @mode = args[:mode] if args.key?(:mode) end |