Class: Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupAutoscalingPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have.
-
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
-
#mode ⇒ String
The autoscaling mode.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
constructor
A new instance of NodeGroupAutoscalingPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupAutoscalingPolicy
Returns a new instance of NodeGroupAutoscalingPolicy.
41076 41077 41078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41076 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_nodes ⇒ Fixnum
The maximum number of nodes that the group should have. Must be set if
autoscaling is enabled. Maximum value allowed is 100.
Corresponds to the JSON property maxNodes
41062 41063 41064 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41062 def max_nodes @max_nodes end |
#min_nodes ⇒ Fixnum
The minimum number of nodes that the group should have.
Corresponds to the JSON property minNodes
41067 41068 41069 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41067 def min_nodes @min_nodes end |
#mode ⇒ String
The autoscaling mode. Set to one of: ON, OFF,
or ONLY_SCALE_OUT. For more information, see
Autoscaler modes.
Corresponds to the JSON property mode
41074 41075 41076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41074 def mode @mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41081 41082 41083 41084 41085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41081 def update!(**args) @max_nodes = args[:max_nodes] if args.key?(:max_nodes) @min_nodes = args[:min_nodes] if args.key?(:min_nodes) @mode = args[:mode] if args.key?(:mode) end |