Class: Google::Apis::ComputeBeta::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
43801 43802 43803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43768 43769 43770 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43768 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
43773 43774 43775 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43773 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
43779 43780 43781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43779 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43789 43790 43791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43789 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43794 43795 43796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43794 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43799 43800 43801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43799 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43806 43807 43808 43809 43810 43811 43812 43813 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43806 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |