Class: Google::Apis::ComputeBeta::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



43275
43276
43277
# File 'lib/google/apis/compute_beta/classes.rb', line 43275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43242
43243
43244
# File 'lib/google/apis/compute_beta/classes.rb', line 43242

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



43247
43248
43249
# File 'lib/google/apis/compute_beta/classes.rb', line 43247

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


43253
43254
43255
# File 'lib/google/apis/compute_beta/classes.rb', line 43253

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43263
43264
43265
# File 'lib/google/apis/compute_beta/classes.rb', line 43263

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43268
43269
43270
# File 'lib/google/apis/compute_beta/classes.rb', line 43268

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43273
43274
43275
# File 'lib/google/apis/compute_beta/classes.rb', line 43273

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43280
43281
43282
43283
43284
43285
43286
43287
# File 'lib/google/apis/compute_beta/classes.rb', line 43280

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end