Class: Google::Apis::ComputeBeta::NodeGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of nodeGroups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupList

Returns a new instance of NodeGroupList.



42736
42737
42738
# File 'lib/google/apis/compute_beta/classes.rb', line 42736

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42703
42704
42705
# File 'lib/google/apis/compute_beta/classes.rb', line 42703

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeGroup>

A list of NodeGroup resources. Corresponds to the JSON property items



42708
42709
42710
# File 'lib/google/apis/compute_beta/classes.rb', line 42708

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeGroupList for lists of node groups. Corresponds to the JSON property kind

Returns:

  • (String)


42714
42715
42716
# File 'lib/google/apis/compute_beta/classes.rb', line 42714

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42724
42725
42726
# File 'lib/google/apis/compute_beta/classes.rb', line 42724

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42729
42730
42731
# File 'lib/google/apis/compute_beta/classes.rb', line 42729

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42734
42735
42736
# File 'lib/google/apis/compute_beta/classes.rb', line 42734

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42741
42742
42743
42744
42745
42746
42747
42748
# File 'lib/google/apis/compute_beta/classes.rb', line 42741

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end