Class: Google::Apis::ComputeBeta::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
41954 41955 41956 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41954 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41921 41922 41923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41921 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
41926 41927 41928 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41926 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
41932 41933 41934 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41932 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41942 41943 41944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41942 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41947 41948 41949 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41947 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41952 41953 41954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41952 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41959 41960 41961 41962 41963 41964 41965 41966 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41959 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |