Class: Google::Apis::ComputeBeta::NodeGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of nodeGroups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NodeGroup>
A list of NodeGroup resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeGroupList
constructor
A new instance of NodeGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeGroupList
Returns a new instance of NodeGroupList.
39740 39741 39742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
39707 39708 39709 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39707 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NodeGroup>
A list of NodeGroup resources.
Corresponds to the JSON property items
39712 39713 39714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39712 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeGroupList
for lists of node groups.
Corresponds to the JSON property kind
39718 39719 39720 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39718 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
39728 39729 39730 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39728 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
39733 39734 39735 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39733 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NodeGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
39738 39739 39740 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39738 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
39745 39746 39747 39748 39749 39750 39751 39752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 39745 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |