Class: Google::Apis::ComputeBeta::NodeGroupMaintenanceWindow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Time window specified for daily maintenance operations. GCE's internal maintenance will be performed within this window.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupMaintenanceWindow

Returns a new instance of NodeGroupMaintenanceWindow.



42841
42842
42843
# File 'lib/google/apis/compute_beta/classes.rb', line 42841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#maintenance_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maintenanceDuration



42832
42833
42834
# File 'lib/google/apis/compute_beta/classes.rb', line 42832

def maintenance_duration
  @maintenance_duration
end

#start_timeString

Start time of the window. This must be in UTC format that resolves to one of 00:00, 04:00, 08:00,12:00, 16:00, or 20:00. For example, both 13:00-5 and 08:00 are valid. Corresponds to the JSON property startTime

Returns:

  • (String)


42839
42840
42841
# File 'lib/google/apis/compute_beta/classes.rb', line 42839

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42846
42847
42848
42849
# File 'lib/google/apis/compute_beta/classes.rb', line 42846

def update!(**args)
  @maintenance_duration = args[:maintenance_duration] if args.key?(:maintenance_duration)
  @start_time = args[:start_time] if args.key?(:start_time)
end