Class: Google::Apis::ComputeBeta::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



43648
43649
43650
# File 'lib/google/apis/compute_beta/classes.rb', line 43648

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43613
43614
43615
# File 'lib/google/apis/compute_beta/classes.rb', line 43613

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



43618
43619
43620
# File 'lib/google/apis/compute_beta/classes.rb', line 43618

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


43625
43626
43627
# File 'lib/google/apis/compute_beta/classes.rb', line 43625

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43636
43637
43638
# File 'lib/google/apis/compute_beta/classes.rb', line 43636

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43641
43642
43643
# File 'lib/google/apis/compute_beta/classes.rb', line 43641

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



43646
43647
43648
# File 'lib/google/apis/compute_beta/classes.rb', line 43646

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43653
43654
43655
43656
43657
43658
43659
43660
# File 'lib/google/apis/compute_beta/classes.rb', line 43653

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end