Class: Google::Apis::ComputeBeta::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



43592
43593
43594
# File 'lib/google/apis/compute_beta/classes.rb', line 43592

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43557
43558
43559
# File 'lib/google/apis/compute_beta/classes.rb', line 43557

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



43562
43563
43564
# File 'lib/google/apis/compute_beta/classes.rb', line 43562

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


43569
43570
43571
# File 'lib/google/apis/compute_beta/classes.rb', line 43569

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43580
43581
43582
# File 'lib/google/apis/compute_beta/classes.rb', line 43580

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43585
43586
43587
# File 'lib/google/apis/compute_beta/classes.rb', line 43585

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



43590
43591
43592
# File 'lib/google/apis/compute_beta/classes.rb', line 43590

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43597
43598
43599
43600
43601
43602
43603
43604
# File 'lib/google/apis/compute_beta/classes.rb', line 43597

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end