Class: Google::Apis::ComputeBeta::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



43570
43571
43572
# File 'lib/google/apis/compute_beta/classes.rb', line 43570

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43535
43536
43537
# File 'lib/google/apis/compute_beta/classes.rb', line 43535

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



43540
43541
43542
# File 'lib/google/apis/compute_beta/classes.rb', line 43540

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


43547
43548
43549
# File 'lib/google/apis/compute_beta/classes.rb', line 43547

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43558
43559
43560
# File 'lib/google/apis/compute_beta/classes.rb', line 43558

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43563
43564
43565
# File 'lib/google/apis/compute_beta/classes.rb', line 43563

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



43568
43569
43570
# File 'lib/google/apis/compute_beta/classes.rb', line 43568

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43575
43576
43577
43578
43579
43580
43581
43582
# File 'lib/google/apis/compute_beta/classes.rb', line 43575

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end