Class: Google::Apis::ComputeBeta::NodeGroupsListNodes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeGroupsListNodes

Returns a new instance of NodeGroupsListNodes.



40035
40036
40037
# File 'lib/google/apis/compute_beta/classes.rb', line 40035

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


40000
40001
40002
# File 'lib/google/apis/compute_beta/classes.rb', line 40000

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeGroupNode>

A list of Node resources. Corresponds to the JSON property items



40005
40006
40007
# File 'lib/google/apis/compute_beta/classes.rb', line 40005

def items
  @items
end

#kindString

Output only. [Output Only] The resource type, which is alwayscompute. nodeGroupsListNodes for the list of nodes in the specified node group. Corresponds to the JSON property kind

Returns:

  • (String)


40012
40013
40014
# File 'lib/google/apis/compute_beta/classes.rb', line 40012

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


40023
40024
40025
# File 'lib/google/apis/compute_beta/classes.rb', line 40023

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


40028
40029
40030
# File 'lib/google/apis/compute_beta/classes.rb', line 40028

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeGroupsListNodes::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



40033
40034
40035
# File 'lib/google/apis/compute_beta/classes.rb', line 40033

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



40040
40041
40042
40043
40044
40045
40046
40047
# File 'lib/google/apis/compute_beta/classes.rb', line 40040

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end