Class: Google::Apis::ComputeBeta::NodeTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplate

Returns a new instance of NodeTemplate.



44005
44006
44007
# File 'lib/google/apis/compute_beta/classes.rb', line 44005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeBeta::AcceleratorConfig>

Corresponds to the JSON property accelerators



43904
43905
43906
# File 'lib/google/apis/compute_beta/classes.rb', line 43904

def accelerators
  @accelerators
end

#cpu_overcommit_typeString

CPU overcommit. Corresponds to the JSON property cpuOvercommitType

Returns:

  • (String)


43909
43910
43911
# File 'lib/google/apis/compute_beta/classes.rb', line 43909

def cpu_overcommit_type
  @cpu_overcommit_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


43915
43916
43917
# File 'lib/google/apis/compute_beta/classes.rb', line 43915

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


43921
43922
43923
# File 'lib/google/apis/compute_beta/classes.rb', line 43921

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::LocalDisk>

Corresponds to the JSON property disks



43926
43927
43928
# File 'lib/google/apis/compute_beta/classes.rb', line 43926

def disks
  @disks
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


43933
43934
43935
# File 'lib/google/apis/compute_beta/classes.rb', line 43933

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute# nodeTemplate for node templates. Corresponds to the JSON property kind

Returns:

  • (String)


43939
43940
43941
# File 'lib/google/apis/compute_beta/classes.rb', line 43939

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


43951
43952
43953
# File 'lib/google/apis/compute_beta/classes.rb', line 43951

def name
  @name
end

#node_affinity_labelsHash<String,String>

Labels to use for node affinity, which will be used in instance scheduling. Corresponds to the JSON property nodeAffinityLabels

Returns:

  • (Hash<String,String>)


43956
43957
43958
# File 'lib/google/apis/compute_beta/classes.rb', line 43956

def node_affinity_labels
  @node_affinity_labels
end

#node_typeString

The node type to use for nodes group that are created from this template. Corresponds to the JSON property nodeType

Returns:

  • (String)


43961
43962
43963
# File 'lib/google/apis/compute_beta/classes.rb', line 43961

def node_type
  @node_type
end

#node_type_flexibilityGoogle::Apis::ComputeBeta::NodeTemplateNodeTypeFlexibility

Do not use. Instead, use the node_type property. Corresponds to the JSON property nodeTypeFlexibility



43966
43967
43968
# File 'lib/google/apis/compute_beta/classes.rb', line 43966

def node_type_flexibility
  @node_type_flexibility
end

#regionString

Output only. [Output Only] The name of the region where the node template resides, such as us-central1. Corresponds to the JSON property region

Returns:

  • (String)


43973
43974
43975
# File 'lib/google/apis/compute_beta/classes.rb', line 43973

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43978
43979
43980
# File 'lib/google/apis/compute_beta/classes.rb', line 43978

def self_link
  @self_link
end

#server_bindingGoogle::Apis::ComputeBeta::ServerBinding

Sets the binding properties for the physical server. Valid values include:

  • [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
  • RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible See Sole-tenant node options for more information. Corresponds to the JSON property serverBinding


43991
43992
43993
# File 'lib/google/apis/compute_beta/classes.rb', line 43991

def server_binding
  @server_binding
end

#statusString

Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. Corresponds to the JSON property status

Returns:

  • (String)


43997
43998
43999
# File 'lib/google/apis/compute_beta/classes.rb', line 43997

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


44003
44004
44005
# File 'lib/google/apis/compute_beta/classes.rb', line 44003

def status_message
  @status_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44010
44011
44012
44013
44014
44015
44016
44017
44018
44019
44020
44021
44022
44023
44024
44025
44026
44027
# File 'lib/google/apis/compute_beta/classes.rb', line 44010

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @cpu_overcommit_type = args[:cpu_overcommit_type] if args.key?(:cpu_overcommit_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @node_affinity_labels = args[:node_affinity_labels] if args.key?(:node_affinity_labels)
  @node_type = args[:node_type] if args.key?(:node_type)
  @node_type_flexibility = args[:node_type_flexibility] if args.key?(:node_type_flexibility)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_binding = args[:server_binding] if args.key?(:server_binding)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
end