Class: Google::Apis::ComputeBeta::NodeTemplate

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplate

Returns a new instance of NodeTemplate.



41780
41781
41782
# File 'lib/google/apis/compute_beta/classes.rb', line 41780

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#acceleratorsArray<Google::Apis::ComputeBeta::AcceleratorConfig>

Corresponds to the JSON property accelerators



41679
41680
41681
# File 'lib/google/apis/compute_beta/classes.rb', line 41679

def accelerators
  @accelerators
end

#cpu_overcommit_typeString

CPU overcommit. Corresponds to the JSON property cpuOvercommitType

Returns:

  • (String)


41684
41685
41686
# File 'lib/google/apis/compute_beta/classes.rb', line 41684

def cpu_overcommit_type
  @cpu_overcommit_type
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


41690
41691
41692
# File 'lib/google/apis/compute_beta/classes.rb', line 41690

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


41696
41697
41698
# File 'lib/google/apis/compute_beta/classes.rb', line 41696

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::LocalDisk>

Corresponds to the JSON property disks



41701
41702
41703
# File 'lib/google/apis/compute_beta/classes.rb', line 41701

def disks
  @disks
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


41708
41709
41710
# File 'lib/google/apis/compute_beta/classes.rb', line 41708

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute# nodeTemplate for node templates. Corresponds to the JSON property kind

Returns:

  • (String)


41714
41715
41716
# File 'lib/google/apis/compute_beta/classes.rb', line 41714

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


41726
41727
41728
# File 'lib/google/apis/compute_beta/classes.rb', line 41726

def name
  @name
end

#node_affinity_labelsHash<String,String>

Labels to use for node affinity, which will be used in instance scheduling. Corresponds to the JSON property nodeAffinityLabels

Returns:

  • (Hash<String,String>)


41731
41732
41733
# File 'lib/google/apis/compute_beta/classes.rb', line 41731

def node_affinity_labels
  @node_affinity_labels
end

#node_typeString

The node type to use for nodes group that are created from this template. Corresponds to the JSON property nodeType

Returns:

  • (String)


41736
41737
41738
# File 'lib/google/apis/compute_beta/classes.rb', line 41736

def node_type
  @node_type
end

#node_type_flexibilityGoogle::Apis::ComputeBeta::NodeTemplateNodeTypeFlexibility

Do not use. Instead, use the node_type property. Corresponds to the JSON property nodeTypeFlexibility



41741
41742
41743
# File 'lib/google/apis/compute_beta/classes.rb', line 41741

def node_type_flexibility
  @node_type_flexibility
end

#regionString

Output only. [Output Only] The name of the region where the node template resides, such as us-central1. Corresponds to the JSON property region

Returns:

  • (String)


41748
41749
41750
# File 'lib/google/apis/compute_beta/classes.rb', line 41748

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41753
41754
41755
# File 'lib/google/apis/compute_beta/classes.rb', line 41753

def self_link
  @self_link
end

#server_bindingGoogle::Apis::ComputeBeta::ServerBinding

Sets the binding properties for the physical server. Valid values include:

  • [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
  • RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same physical server whenever possible See Sole-tenant node options for more information. Corresponds to the JSON property serverBinding


41766
41767
41768
# File 'lib/google/apis/compute_beta/classes.rb', line 41766

def server_binding
  @server_binding
end

#statusString

Output only. [Output Only] The status of the node template. One of the following values:CREATING, READY, and DELETING. Corresponds to the JSON property status

Returns:

  • (String)


41772
41773
41774
# File 'lib/google/apis/compute_beta/classes.rb', line 41772

def status
  @status
end

#status_messageString

Output only. [Output Only] An optional, human-readable explanation of the status. Corresponds to the JSON property statusMessage

Returns:

  • (String)


41778
41779
41780
# File 'lib/google/apis/compute_beta/classes.rb', line 41778

def status_message
  @status_message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41785
41786
41787
41788
41789
41790
41791
41792
41793
41794
41795
41796
41797
41798
41799
41800
41801
41802
# File 'lib/google/apis/compute_beta/classes.rb', line 41785

def update!(**args)
  @accelerators = args[:accelerators] if args.key?(:accelerators)
  @cpu_overcommit_type = args[:cpu_overcommit_type] if args.key?(:cpu_overcommit_type)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @node_affinity_labels = args[:node_affinity_labels] if args.key?(:node_affinity_labels)
  @node_type = args[:node_type] if args.key?(:node_type)
  @node_type_flexibility = args[:node_type_flexibility] if args.key?(:node_type_flexibility)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @server_binding = args[:server_binding] if args.key?(:server_binding)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
end