Class: Google::Apis::ComputeBeta::NodeTemplate
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeTemplate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represent a sole-tenant Node Template resource. You can use a template to define properties for nodes in a node group. For more information, readCreating node groups and instances.
Instance Attribute Summary collapse
-
#accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
Corresponds to the JSON property
accelerators. -
#cpu_overcommit_type ⇒ String
CPU overcommit.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#disks ⇒ Array<Google::Apis::ComputeBeta::LocalDisk>
Corresponds to the JSON property
disks. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#node_affinity_labels ⇒ Hash<String,String>
Labels to use for node affinity, which will be used in instance scheduling.
-
#node_type ⇒ String
The node type to use for nodes group that are created from this template.
-
#node_type_flexibility ⇒ Google::Apis::ComputeBeta::NodeTemplateNodeTypeFlexibility
Do not use.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#server_binding ⇒ Google::Apis::ComputeBeta::ServerBinding
Sets the binding properties for the physical server.
-
#status ⇒ String
Output only.
-
#status_message ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplate
constructor
A new instance of NodeTemplate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplate
Returns a new instance of NodeTemplate.
40392 40393 40394 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40392 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
Corresponds to the JSON property accelerators
40291 40292 40293 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40291 def accelerators @accelerators end |
#cpu_overcommit_type ⇒ String
CPU overcommit.
Corresponds to the JSON property cpuOvercommitType
40296 40297 40298 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40296 def cpu_overcommit_type @cpu_overcommit_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
40302 40303 40304 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40302 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
40308 40309 40310 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40308 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeBeta::LocalDisk>
Corresponds to the JSON property disks
40313 40314 40315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40313 def disks @disks end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
40320 40321 40322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40320 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#
nodeTemplate for node templates.
Corresponds to the JSON property kind
40326 40327 40328 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40326 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
40338 40339 40340 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40338 def name @name end |
#node_affinity_labels ⇒ Hash<String,String>
Labels to use for node affinity, which will be used in instance scheduling.
Corresponds to the JSON property nodeAffinityLabels
40343 40344 40345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40343 def node_affinity_labels @node_affinity_labels end |
#node_type ⇒ String
The node type to use for nodes group that are created from this template.
Corresponds to the JSON property nodeType
40348 40349 40350 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40348 def node_type @node_type end |
#node_type_flexibility ⇒ Google::Apis::ComputeBeta::NodeTemplateNodeTypeFlexibility
Do not use. Instead, use the node_type property.
Corresponds to the JSON property nodeTypeFlexibility
40353 40354 40355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40353 def node_type_flexibility @node_type_flexibility end |
#region ⇒ String
Output only. [Output Only] The name of the region where the node template
resides,
such as us-central1.
Corresponds to the JSON property region
40360 40361 40362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40360 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
40365 40366 40367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40365 def self_link @self_link end |
#server_binding ⇒ Google::Apis::ComputeBeta::ServerBinding
Sets the binding properties for the physical server. Valid values include:
- [Default] RESTART_NODE_ON_ANY_SERVER: Restarts VMs on any available physical server
- RESTART_NODE_ON_MINIMAL_SERVER: Restarts VMs on the same
physical server whenever possible
See Sole-tenant
node options for more information.
Corresponds to the JSON property
serverBinding
40378 40379 40380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40378 def server_binding @server_binding end |
#status ⇒ String
Output only. [Output Only] The status of the node template. One of the
following values:CREATING, READY, and DELETING.
Corresponds to the JSON property status
40384 40385 40386 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40384 def status @status end |
#status_message ⇒ String
Output only. [Output Only] An optional, human-readable explanation of the
status.
Corresponds to the JSON property statusMessage
40390 40391 40392 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40390 def @status_message end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40397 40398 40399 40400 40401 40402 40403 40404 40405 40406 40407 40408 40409 40410 40411 40412 40413 40414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40397 def update!(**args) @accelerators = args[:accelerators] if args.key?(:accelerators) @cpu_overcommit_type = args[:cpu_overcommit_type] if args.key?(:cpu_overcommit_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @node_affinity_labels = args[:node_affinity_labels] if args.key?(:node_affinity_labels) @node_type = args[:node_type] if args.key?(:node_type) @node_type_flexibility = args[:node_type_flexibility] if args.key?(:node_type_flexibility) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @server_binding = args[:server_binding] if args.key?(:server_binding) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) end |