Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



44076
44077
44078
# File 'lib/google/apis/compute_beta/classes.rb', line 44076

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44037
44038
44039
# File 'lib/google/apis/compute_beta/classes.rb', line 44037

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



44042
44043
44044
# File 'lib/google/apis/compute_beta/classes.rb', line 44042

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


44049
44050
44051
# File 'lib/google/apis/compute_beta/classes.rb', line 44049

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44059
44060
44061
# File 'lib/google/apis/compute_beta/classes.rb', line 44059

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44064
44065
44066
# File 'lib/google/apis/compute_beta/classes.rb', line 44064

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44069
44070
44071
# File 'lib/google/apis/compute_beta/classes.rb', line 44069

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44074
44075
44076
# File 'lib/google/apis/compute_beta/classes.rb', line 44074

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44081
44082
44083
44084
44085
44086
44087
44088
44089
# File 'lib/google/apis/compute_beta/classes.rb', line 44081

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end