Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



44062
44063
44064
# File 'lib/google/apis/compute_beta/classes.rb', line 44062

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44023
44024
44025
# File 'lib/google/apis/compute_beta/classes.rb', line 44023

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



44028
44029
44030
# File 'lib/google/apis/compute_beta/classes.rb', line 44028

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


44035
44036
44037
# File 'lib/google/apis/compute_beta/classes.rb', line 44035

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44045
44046
44047
# File 'lib/google/apis/compute_beta/classes.rb', line 44045

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44050
44051
44052
# File 'lib/google/apis/compute_beta/classes.rb', line 44050

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44055
44056
44057
# File 'lib/google/apis/compute_beta/classes.rb', line 44055

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44060
44061
44062
# File 'lib/google/apis/compute_beta/classes.rb', line 44060

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44067
44068
44069
44070
44071
44072
44073
44074
44075
# File 'lib/google/apis/compute_beta/classes.rb', line 44067

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end