Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



44020
44021
44022
# File 'lib/google/apis/compute_beta/classes.rb', line 44020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43981
43982
43983
# File 'lib/google/apis/compute_beta/classes.rb', line 43981

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



43986
43987
43988
# File 'lib/google/apis/compute_beta/classes.rb', line 43986

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


43993
43994
43995
# File 'lib/google/apis/compute_beta/classes.rb', line 43993

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44003
44004
44005
# File 'lib/google/apis/compute_beta/classes.rb', line 44003

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44008
44009
44010
# File 'lib/google/apis/compute_beta/classes.rb', line 44008

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44013
44014
44015
# File 'lib/google/apis/compute_beta/classes.rb', line 44013

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44018
44019
44020
# File 'lib/google/apis/compute_beta/classes.rb', line 44018

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44025
44026
44027
44028
44029
44030
44031
44032
44033
# File 'lib/google/apis/compute_beta/classes.rb', line 44025

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end