Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



43459
43460
43461
# File 'lib/google/apis/compute_beta/classes.rb', line 43459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43420
43421
43422
# File 'lib/google/apis/compute_beta/classes.rb', line 43420

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



43425
43426
43427
# File 'lib/google/apis/compute_beta/classes.rb', line 43425

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


43432
43433
43434
# File 'lib/google/apis/compute_beta/classes.rb', line 43432

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43442
43443
43444
# File 'lib/google/apis/compute_beta/classes.rb', line 43442

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43447
43448
43449
# File 'lib/google/apis/compute_beta/classes.rb', line 43447

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


43452
43453
43454
# File 'lib/google/apis/compute_beta/classes.rb', line 43452

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43457
43458
43459
# File 'lib/google/apis/compute_beta/classes.rb', line 43457

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43464
43465
43466
43467
43468
43469
43470
43471
43472
# File 'lib/google/apis/compute_beta/classes.rb', line 43464

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end