Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
43459 43460 43461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43420 43421 43422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43420 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
43425 43426 43427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43425 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
43432 43433 43434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43432 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43442 43443 43444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43442 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43447 43448 43449 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43447 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
43452 43453 43454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43452 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43457 43458 43459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43457 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43464 43465 43466 43467 43468 43469 43470 43471 43472 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43464 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |