Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateAggregatedList

Returns a new instance of NodeTemplateAggregatedList.



42677
42678
42679
# File 'lib/google/apis/compute_beta/classes.rb', line 42677

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


42638
42639
42640
# File 'lib/google/apis/compute_beta/classes.rb', line 42638

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>

A list of NodeTemplatesScopedList resources. Corresponds to the JSON property items



42643
42644
42645
# File 'lib/google/apis/compute_beta/classes.rb', line 42643

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute# nodeTemplateAggregatedList for aggregated lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


42650
42651
42652
# File 'lib/google/apis/compute_beta/classes.rb', line 42650

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


42660
42661
42662
# File 'lib/google/apis/compute_beta/classes.rb', line 42660

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42665
42666
42667
# File 'lib/google/apis/compute_beta/classes.rb', line 42665

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


42670
42671
42672
# File 'lib/google/apis/compute_beta/classes.rb', line 42670

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



42675
42676
42677
# File 'lib/google/apis/compute_beta/classes.rb', line 42675

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42682
42683
42684
42685
42686
42687
42688
42689
42690
# File 'lib/google/apis/compute_beta/classes.rb', line 42682

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end