Class: Google::Apis::ComputeBeta::NodeTemplateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeTemplateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateAggregatedList
constructor
A new instance of NodeTemplateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateAggregatedList
Returns a new instance of NodeTemplateAggregatedList.
40463 40464 40465 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
40424 40425 40426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40424 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::NodeTemplatesScopedList>
A list of NodeTemplatesScopedList resources.
Corresponds to the JSON property items
40429 40430 40431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40429 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#
nodeTemplateAggregatedList for aggregated lists of
node templates.
Corresponds to the JSON property kind
40436 40437 40438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40436 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
40446 40447 40448 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40446 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
40451 40452 40453 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40451 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
40456 40457 40458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40456 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
40461 40462 40463 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40461 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
40468 40469 40470 40471 40472 40473 40474 40475 40476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 40468 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |