Class: Google::Apis::ComputeBeta::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
44252 44253 44254 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44219 44220 44221 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44219 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
44224 44225 44226 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44224 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
44230 44231 44232 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44230 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44240 44241 44242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44240 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44245 44246 44247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44245 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44250 44251 44252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44250 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44257 44258 44259 44260 44261 44262 44263 44264 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44257 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |