Class: Google::Apis::ComputeBeta::NodeTemplateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of node templates.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeTemplateList

Returns a new instance of NodeTemplateList.



43644
43645
43646
# File 'lib/google/apis/compute_beta/classes.rb', line 43644

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


43611
43612
43613
# File 'lib/google/apis/compute_beta/classes.rb', line 43611

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NodeTemplate>

A list of NodeTemplate resources. Corresponds to the JSON property items



43616
43617
43618
# File 'lib/google/apis/compute_beta/classes.rb', line 43616

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#nodeTemplateList for lists of node templates. Corresponds to the JSON property kind

Returns:

  • (String)


43622
43623
43624
# File 'lib/google/apis/compute_beta/classes.rb', line 43622

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


43632
43633
43634
# File 'lib/google/apis/compute_beta/classes.rb', line 43632

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43637
43638
43639
# File 'lib/google/apis/compute_beta/classes.rb', line 43637

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NodeTemplateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



43642
43643
43644
# File 'lib/google/apis/compute_beta/classes.rb', line 43642

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43649
43650
43651
43652
43653
43654
43655
43656
# File 'lib/google/apis/compute_beta/classes.rb', line 43649

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end