Class: Google::Apis::ComputeBeta::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
42803 42804 42805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
42770 42771 42772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42770 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
42775 42776 42777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42775 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
42781 42782 42783 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42781 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
42791 42792 42793 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42791 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
42796 42797 42798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42796 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
42801 42802 42803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42801 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42808 42809 42810 42811 42812 42813 42814 42815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42808 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |