Class: Google::Apis::ComputeBeta::NodeTemplateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeTemplateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of node templates.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NodeTemplate>
A list of NodeTemplate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeTemplateList
constructor
A new instance of NodeTemplateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeTemplateList
Returns a new instance of NodeTemplateList.
41977 41978 41979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41977 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
41944 41945 41946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41944 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NodeTemplate>
A list of NodeTemplate resources.
Corresponds to the JSON property items
41949 41950 41951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41949 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#nodeTemplateList
for lists of node templates.
Corresponds to the JSON property kind
41955 41956 41957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41955 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
41965 41966 41967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41965 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
41970 41971 41972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41970 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NodeTemplateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
41975 41976 41977 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41975 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
41982 41983 41984 41985 41986 41987 41988 41989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 41982 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |