Class: Google::Apis::ComputeBeta::NodeType
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NodeType
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.
Instance Attribute Summary collapse
-
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this node type.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] An optional textual description of the resource.
-
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the node type.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#local_ssd_gb ⇒ Fixnum
[Output Only] Local SSD available to the node type, defined in GB.
-
#max_vms ⇒ Fixnum
Output only.
-
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the node type, defined in MB.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#self_link ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NodeType
constructor
A new instance of NodeType.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NodeType
Returns a new instance of NodeType.
44440 44441 44442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cpu_platform ⇒ String
[Output Only] The CPU platform used by this node type.
Corresponds to the JSON property cpuPlatform
44371 44372 44373 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44371 def cpu_platform @cpu_platform end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
44377 44378 44379 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44377 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
44382 44383 44384 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44382 def deprecated @deprecated end |
#description ⇒ String
[Output Only] An optional textual description of the resource.
Corresponds to the JSON property description
44387 44388 44389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44387 def description @description end |
#guest_cpus ⇒ Fixnum
[Output Only] The number of virtual CPUs that are available to the node
type.
Corresponds to the JSON property guestCpus
44393 44394 44395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44393 def guest_cpus @guest_cpus end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
44399 44400 44401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44399 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#nodeType
for node types.
Corresponds to the JSON property kind
44405 44406 44407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44405 def kind @kind end |
#local_ssd_gb ⇒ Fixnum
[Output Only] Local SSD available to the node type, defined in GB.
Corresponds to the JSON property localSsdGb
44410 44411 44412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44410 def local_ssd_gb @local_ssd_gb end |
#max_vms ⇒ Fixnum
Output only. [Output Only] Maximum number of VMs that can be created for this
node type.
Corresponds to the JSON property maxVms
44416 44417 44418 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44416 def max_vms @max_vms end |
#memory_mb ⇒ Fixnum
[Output Only] The amount of physical memory available to the node type,
defined in MB.
Corresponds to the JSON property memoryMb
44422 44423 44424 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44422 def memory_mb @memory_mb end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
44427 44428 44429 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44427 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
44432 44433 44434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44432 def self_link @self_link end |
#zone ⇒ String
Output only. [Output Only] The name of the zone where the node type resides,
such as us-central1-a.
Corresponds to the JSON property zone
44438 44439 44440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44438 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44445 44446 44447 44448 44449 44450 44451 44452 44453 44454 44455 44456 44457 44458 44459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44445 def update!(**args) @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb) @max_vms = args[:max_vms] if args.key?(:max_vms) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |