Class: Google::Apis::ComputeBeta::NodeType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeType

Returns a new instance of NodeType.



43938
43939
43940
# File 'lib/google/apis/compute_beta/classes.rb', line 43938

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_platformString

[Output Only] The CPU platform used by this node type. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


43869
43870
43871
# File 'lib/google/apis/compute_beta/classes.rb', line 43869

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


43875
43876
43877
# File 'lib/google/apis/compute_beta/classes.rb', line 43875

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeBeta::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



43880
43881
43882
# File 'lib/google/apis/compute_beta/classes.rb', line 43880

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


43885
43886
43887
# File 'lib/google/apis/compute_beta/classes.rb', line 43885

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the node type. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


43891
43892
43893
# File 'lib/google/apis/compute_beta/classes.rb', line 43891

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


43897
43898
43899
# File 'lib/google/apis/compute_beta/classes.rb', line 43897

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types. Corresponds to the JSON property kind

Returns:

  • (String)


43903
43904
43905
# File 'lib/google/apis/compute_beta/classes.rb', line 43903

def kind
  @kind
end

#local_ssd_gbFixnum

[Output Only] Local SSD available to the node type, defined in GB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


43908
43909
43910
# File 'lib/google/apis/compute_beta/classes.rb', line 43908

def local_ssd_gb
  @local_ssd_gb
end

#max_vmsFixnum

Output only. [Output Only] Maximum number of VMs that can be created for this node type. Corresponds to the JSON property maxVms

Returns:

  • (Fixnum)


43914
43915
43916
# File 'lib/google/apis/compute_beta/classes.rb', line 43914

def max_vms
  @max_vms
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the node type, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


43920
43921
43922
# File 'lib/google/apis/compute_beta/classes.rb', line 43920

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


43925
43926
43927
# File 'lib/google/apis/compute_beta/classes.rb', line 43925

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


43930
43931
43932
# File 'lib/google/apis/compute_beta/classes.rb', line 43930

def self_link
  @self_link
end

#zoneString

Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


43936
43937
43938
# File 'lib/google/apis/compute_beta/classes.rb', line 43936

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43943
43944
43945
43946
43947
43948
43949
43950
43951
43952
43953
43954
43955
43956
43957
# File 'lib/google/apis/compute_beta/classes.rb', line 43943

def update!(**args)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @max_vms = args[:max_vms] if args.key?(:max_vms)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end