Class: Google::Apis::ComputeBeta::NodeType

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represent a sole-tenant Node Type resource. Each node within a node group must have a node type. A node type specifies the total amount of cores and memory for that node. Currently, the only available node type is n1-node-96-624 node type that has 96 vCPUs and 624 GB of memory, available in multiple zones. For more information readNode types.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NodeType

Returns a new instance of NodeType.



42271
42272
42273
# File 'lib/google/apis/compute_beta/classes.rb', line 42271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cpu_platformString

[Output Only] The CPU platform used by this node type. Corresponds to the JSON property cpuPlatform

Returns:

  • (String)


42202
42203
42204
# File 'lib/google/apis/compute_beta/classes.rb', line 42202

def cpu_platform
  @cpu_platform
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


42208
42209
42210
# File 'lib/google/apis/compute_beta/classes.rb', line 42208

def creation_timestamp
  @creation_timestamp
end

#deprecatedGoogle::Apis::ComputeBeta::DeprecationStatus

Deprecation status for a public resource. Corresponds to the JSON property deprecated



42213
42214
42215
# File 'lib/google/apis/compute_beta/classes.rb', line 42213

def deprecated
  @deprecated
end

#descriptionString

[Output Only] An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


42218
42219
42220
# File 'lib/google/apis/compute_beta/classes.rb', line 42218

def description
  @description
end

#guest_cpusFixnum

[Output Only] The number of virtual CPUs that are available to the node type. Corresponds to the JSON property guestCpus

Returns:

  • (Fixnum)


42224
42225
42226
# File 'lib/google/apis/compute_beta/classes.rb', line 42224

def guest_cpus
  @guest_cpus
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


42230
42231
42232
# File 'lib/google/apis/compute_beta/classes.rb', line 42230

def id
  @id
end

#kindString

Output only. [Output Only] The type of the resource. Alwayscompute#nodeType for node types. Corresponds to the JSON property kind

Returns:

  • (String)


42236
42237
42238
# File 'lib/google/apis/compute_beta/classes.rb', line 42236

def kind
  @kind
end

#local_ssd_gbFixnum

[Output Only] Local SSD available to the node type, defined in GB. Corresponds to the JSON property localSsdGb

Returns:

  • (Fixnum)


42241
42242
42243
# File 'lib/google/apis/compute_beta/classes.rb', line 42241

def local_ssd_gb
  @local_ssd_gb
end

#max_vmsFixnum

Output only. [Output Only] Maximum number of VMs that can be created for this node type. Corresponds to the JSON property maxVms

Returns:

  • (Fixnum)


42247
42248
42249
# File 'lib/google/apis/compute_beta/classes.rb', line 42247

def max_vms
  @max_vms
end

#memory_mbFixnum

[Output Only] The amount of physical memory available to the node type, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


42253
42254
42255
# File 'lib/google/apis/compute_beta/classes.rb', line 42253

def memory_mb
  @memory_mb
end

#nameString

[Output Only] Name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


42258
42259
42260
# File 'lib/google/apis/compute_beta/classes.rb', line 42258

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


42263
42264
42265
# File 'lib/google/apis/compute_beta/classes.rb', line 42263

def self_link
  @self_link
end

#zoneString

Output only. [Output Only] The name of the zone where the node type resides, such as us-central1-a. Corresponds to the JSON property zone

Returns:

  • (String)


42269
42270
42271
# File 'lib/google/apis/compute_beta/classes.rb', line 42269

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



42276
42277
42278
42279
42280
42281
42282
42283
42284
42285
42286
42287
42288
42289
42290
# File 'lib/google/apis/compute_beta/classes.rb', line 42276

def update!(**args)
  @cpu_platform = args[:cpu_platform] if args.key?(:cpu_platform)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @deprecated = args[:deprecated] if args.key?(:deprecated)
  @description = args[:description] if args.key?(:description)
  @guest_cpus = args[:guest_cpus] if args.key?(:guest_cpus)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @local_ssd_gb = args[:local_ssd_gb] if args.key?(:local_ssd_gb)
  @max_vms = args[:max_vms] if args.key?(:max_vms)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @zone = args[:zone] if args.key?(:zone)
end