Class: Google::Apis::ComputeBeta::NotificationEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a notification endpoint. A notification endpoint resource defines an endpoint to receive notifications when there are status changes detected by the associated health check service. For more information, see Health checks overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpoint

Returns a new instance of NotificationEndpoint.



41324
41325
41326
# File 'lib/google/apis/compute_beta/classes.rb', line 41324

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


41272
41273
41274
# File 'lib/google/apis/compute_beta/classes.rb', line 41272

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


41278
41279
41280
# File 'lib/google/apis/compute_beta/classes.rb', line 41278

def description
  @description
end

#grpc_settingsGoogle::Apis::ComputeBeta::NotificationEndpointGrpcSettings

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint. Corresponds to the JSON property grpcSettings



41284
41285
41286
# File 'lib/google/apis/compute_beta/classes.rb', line 41284

def grpc_settings
  @grpc_settings
end

#idFixnum

Output only. [Output Only] A unique identifier for this resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


41291
41292
41293
# File 'lib/google/apis/compute_beta/classes.rb', line 41291

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


41297
41298
41299
# File 'lib/google/apis/compute_beta/classes.rb', line 41297

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


41308
41309
41310
# File 'lib/google/apis/compute_beta/classes.rb', line 41308

def name
  @name
end

#regionString

Output only. [Output Only] URL of the region where the notification endpoint resides. This field applies only to the regional resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


41317
41318
41319
# File 'lib/google/apis/compute_beta/classes.rb', line 41317

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41322
41323
41324
# File 'lib/google/apis/compute_beta/classes.rb', line 41322

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41329
41330
41331
41332
41333
41334
41335
41336
41337
41338
# File 'lib/google/apis/compute_beta/classes.rb', line 41329

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @grpc_settings = args[:grpc_settings] if args.key?(:grpc_settings)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end