Class: Google::Apis::ComputeBeta::NotificationEndpointGrpcSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a gRPC setting that describes one gRPC notification endpoint and the retry duration attempting to send notification to this endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointGrpcSettings

Returns a new instance of NotificationEndpointGrpcSettings.



41380
41381
41382
# File 'lib/google/apis/compute_beta/classes.rb', line 41380

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#authorityString

Optional. If specified, this field is used to set the authority header by the sender of notifications. See https://tools.ietf.org/html/rfc7540#section-8.1.2.3 Corresponds to the JSON property authority

Returns:

  • (String)


41351
41352
41353
# File 'lib/google/apis/compute_beta/classes.rb', line 41351

def authority
  @authority
end

#endpointString

Endpoint to which gRPC notifications are sent. This must be a valid gRPCLB DNS name. Corresponds to the JSON property endpoint

Returns:

  • (String)


41357
41358
41359
# File 'lib/google/apis/compute_beta/classes.rb', line 41357

def endpoint
  @endpoint
end

#payload_nameString

Optional. If specified, this field is used to populate the "name" field in gRPC requests. Corresponds to the JSON property payloadName

Returns:

  • (String)


41363
41364
41365
# File 'lib/google/apis/compute_beta/classes.rb', line 41363

def payload_name
  @payload_name
end

#resend_intervalGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property resendInterval



41371
41372
41373
# File 'lib/google/apis/compute_beta/classes.rb', line 41371

def resend_interval
  @resend_interval
end

#retry_duration_secFixnum

How much time (in seconds) is spent attempting notification retries until a successful response is received. Default is 30s. Limit is 20m (1200s). Must be a positive number. Corresponds to the JSON property retryDurationSec

Returns:

  • (Fixnum)


41378
41379
41380
# File 'lib/google/apis/compute_beta/classes.rb', line 41378

def retry_duration_sec
  @retry_duration_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41385
41386
41387
41388
41389
41390
41391
# File 'lib/google/apis/compute_beta/classes.rb', line 41385

def update!(**args)
  @authority = args[:authority] if args.key?(:authority)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @payload_name = args[:payload_name] if args.key?(:payload_name)
  @resend_interval = args[:resend_interval] if args.key?(:resend_interval)
  @retry_duration_sec = args[:retry_duration_sec] if args.key?(:retry_duration_sec)
end