Class: Google::Apis::ComputeBeta::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



45227
45228
45229
# File 'lib/google/apis/compute_beta/classes.rb', line 45227

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45194
45195
45196
# File 'lib/google/apis/compute_beta/classes.rb', line 45194

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



45199
45200
45201
# File 'lib/google/apis/compute_beta/classes.rb', line 45199

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


45205
45206
45207
# File 'lib/google/apis/compute_beta/classes.rb', line 45205

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45215
45216
45217
# File 'lib/google/apis/compute_beta/classes.rb', line 45215

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45220
45221
45222
# File 'lib/google/apis/compute_beta/classes.rb', line 45220

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45225
45226
45227
# File 'lib/google/apis/compute_beta/classes.rb', line 45225

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45232
45233
45234
45235
45236
45237
45238
45239
# File 'lib/google/apis/compute_beta/classes.rb', line 45232

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end