Class: Google::Apis::ComputeBeta::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



45099
45100
45101
# File 'lib/google/apis/compute_beta/classes.rb', line 45099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45066
45067
45068
# File 'lib/google/apis/compute_beta/classes.rb', line 45066

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



45071
45072
45073
# File 'lib/google/apis/compute_beta/classes.rb', line 45071

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


45077
45078
45079
# File 'lib/google/apis/compute_beta/classes.rb', line 45077

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45087
45088
45089
# File 'lib/google/apis/compute_beta/classes.rb', line 45087

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45092
45093
45094
# File 'lib/google/apis/compute_beta/classes.rb', line 45092

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45097
45098
45099
# File 'lib/google/apis/compute_beta/classes.rb', line 45097

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45104
45105
45106
45107
45108
45109
45110
45111
# File 'lib/google/apis/compute_beta/classes.rb', line 45104

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end