Class: Google::Apis::ComputeBeta::NotificationEndpointList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::NotificationEndpointList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::NotificationEndpoint>
A list of NotificationEndpoint resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ NotificationEndpointList
constructor
A new instance of NotificationEndpointList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ NotificationEndpointList
Returns a new instance of NotificationEndpointList.
45099 45100 45101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45099 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
45066 45067 45068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45066 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::NotificationEndpoint>
A list of NotificationEndpoint resources.
Corresponds to the JSON property items
45071 45072 45073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45071 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
notificationEndpoint for notification endpoints.
Corresponds to the JSON property kind
45077 45078 45079 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45077 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45087 45088 45089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45087 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45092 45093 45094 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45092 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::NotificationEndpointList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45097 45098 45099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45097 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45104 45105 45106 45107 45108 45109 45110 45111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45104 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |