Class: Google::Apis::ComputeBeta::NotificationEndpointList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ NotificationEndpointList

Returns a new instance of NotificationEndpointList.



44560
44561
44562
# File 'lib/google/apis/compute_beta/classes.rb', line 44560

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44527
44528
44529
# File 'lib/google/apis/compute_beta/classes.rb', line 44527

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::NotificationEndpoint>

A list of NotificationEndpoint resources. Corresponds to the JSON property items



44532
44533
44534
# File 'lib/google/apis/compute_beta/classes.rb', line 44532

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# notificationEndpoint for notification endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


44538
44539
44540
# File 'lib/google/apis/compute_beta/classes.rb', line 44538

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44548
44549
44550
# File 'lib/google/apis/compute_beta/classes.rb', line 44548

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44553
44554
44555
# File 'lib/google/apis/compute_beta/classes.rb', line 44553

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::NotificationEndpointList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44558
44559
44560
# File 'lib/google/apis/compute_beta/classes.rb', line 44558

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44565
44566
44567
44568
44569
44570
44571
44572
# File 'lib/google/apis/compute_beta/classes.rb', line 44565

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end