Class: Google::Apis::ComputeBeta::Operation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Operation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an Operation resource. Google Compute Engine has three Operation resources:
- Global
- Regional
Zonal You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses. Operations can be global, regional or zonal.
For global operations, use the
globalOperationsresource.For regional operations, use the
regionOperationsresource.For zonal operations, use the
zoneOperationsresource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.
Defined Under Namespace
Instance Attribute Summary collapse
-
#client_operation_id ⇒ String
[Output Only] The value of
requestIdif you provided it in the request. -
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
-
#description ⇒ String
[Output Only] A textual description of the operation, which is set when the operation is created.
-
#end_time ⇒ String
[Output Only] The time that this operation was completed.
-
#error ⇒ Google::Apis::ComputeBeta::Operation::Error
[Output Only] If errors are generated during processing of the operation, this field will be populated.
-
#get_version_operation_metadata ⇒ Google::Apis::ComputeBeta::GetVersionOperationMetadata
Corresponds to the JSON property
getVersionOperationMetadata. -
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as
NOT FOUND. -
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error status code that was returned.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation.
-
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
-
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::ComputeBeta::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property
instancesBulkInsertOperationMetadata. -
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the operation.
-
#operation_group_id ⇒ String
Output only.
-
#operation_type ⇒ String
[Output Only] The type of operation, such as
insert,update, ordelete, and so on. -
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
-
#region ⇒ String
[Output Only] The URL of the region where the operation resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadata
Output only.
-
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
-
#status ⇒ String
[Output Only] The status of the operation, which can be one of the following:
PENDING,RUNNING, orDONE. -
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the operation.
-
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation of the target resource.
-
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies.
-
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.comoralice_smith_identifier (global/workforcePools/example-com-us-employees). -
#warnings ⇒ Array<Google::Apis::ComputeBeta::Operation::Warning>
[Output Only] If warning messages are generated during processing of the operation, this field will be populated.
-
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Operation
constructor
A new instance of Operation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Operation
Returns a new instance of Operation.
45553 45554 45555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#client_operation_id ⇒ String
[Output Only] The value of requestId if you provided it in the request.
Not present otherwise.
Corresponds to the JSON property clientOperationId
45386 45387 45388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45386 def client_operation_id @client_operation_id end |
#creation_timestamp ⇒ String
[Deprecated] This field is deprecated.
Corresponds to the JSON property creationTimestamp
45391 45392 45393 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45391 def @creation_timestamp end |
#description ⇒ String
[Output Only] A textual description of the operation, which is
set when the operation is created.
Corresponds to the JSON property description
45397 45398 45399 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45397 def description @description end |
#end_time ⇒ String
[Output Only] The time that this operation was completed. This value is
inRFC3339
text format.
Corresponds to the JSON property endTime
45404 45405 45406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45404 def end_time @end_time end |
#error ⇒ Google::Apis::ComputeBeta::Operation::Error
[Output Only] If errors are generated during processing of the operation,
this field will be populated.
Corresponds to the JSON property error
45410 45411 45412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45410 def error @error end |
#get_version_operation_metadata ⇒ Google::Apis::ComputeBeta::GetVersionOperationMetadata
Corresponds to the JSON property getVersionOperationMetadata
45415 45416 45417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45415 def @get_version_operation_metadata end |
#http_error_message ⇒ String
[Output Only] If the operation fails, this field contains the HTTP error
message that was returned, such as NOT FOUND.
Corresponds to the JSON property httpErrorMessage
45421 45422 45423 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45421 def @http_error_message end |
#http_error_status_code ⇒ Fixnum
[Output Only] If the operation fails, this field contains the HTTP error
status code that was returned. For example, a 404 means the
resource was not found.
Corresponds to the JSON property httpErrorStatusCode
45428 45429 45430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45428 def http_error_status_code @http_error_status_code end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the operation. This identifier is
defined by the server.
Corresponds to the JSON property id
45434 45435 45436 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45434 def id @id end |
#insert_time ⇒ String
[Output Only] The time that this operation was requested.
This value is inRFC3339
text format.
Corresponds to the JSON property insertTime
45441 45442 45443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45441 def insert_time @insert_time end |
#instances_bulk_insert_operation_metadata ⇒ Google::Apis::ComputeBeta::InstancesBulkInsertOperationMetadata
Corresponds to the JSON property instancesBulkInsertOperationMetadata
45446 45447 45448 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45446 def @instances_bulk_insert_operation_metadata end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#operation
for
Operation resources.
Corresponds to the JSON property kind
45453 45454 45455 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45453 def kind @kind end |
#name ⇒ String
[Output Only] Name of the operation.
Corresponds to the JSON property name
45458 45459 45460 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45458 def name @name end |
#operation_group_id ⇒ String
Output only. [Output Only] An ID that represents a group of operations, such
as when a
group of operations results from a bulkInsert API request.
Corresponds to the JSON property operationGroupId
45465 45466 45467 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45465 def operation_group_id @operation_group_id end |
#operation_type ⇒ String
[Output Only] The type of operation, such as insert,
update, or delete, and so on.
Corresponds to the JSON property operationType
45471 45472 45473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45471 def operation_type @operation_type end |
#progress ⇒ Fixnum
[Output Only] An optional progress indicator that ranges from 0 to 100.
There is no requirement that this be linear or support any granularity of
operations. This should not be used to guess when the operation will be
complete. This number should monotonically increase as the operation
progresses.
Corresponds to the JSON property progress
45480 45481 45482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45480 def progress @progress end |
#region ⇒ String
[Output Only] The URL of the region where the operation resides. Only
applicable when performing regional operations.
Corresponds to the JSON property region
45486 45487 45488 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45486 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
45491 45492 45493 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45491 def self_link @self_link end |
#set_common_instance_metadata_operation_metadata ⇒ Google::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadata
Output only. [Output Only] If the operation is for projects.
setCommonInstanceMetadata,
this field will contain information on all underlying zonal actions and
their state.
Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata
45499 45500 45501 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45499 def @set_common_instance_metadata_operation_metadata end |
#start_time ⇒ String
[Output Only] The time that this operation was started by the server.
This value is inRFC3339
text format.
Corresponds to the JSON property startTime
45506 45507 45508 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45506 def start_time @start_time end |
#status ⇒ String
[Output Only] The status of the operation, which can be one of the
following:
PENDING, RUNNING, or DONE.
Corresponds to the JSON property status
45513 45514 45515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45513 def status @status end |
#status_message ⇒ String
[Output Only] An optional textual description of the current status of the
operation.
Corresponds to the JSON property statusMessage
45519 45520 45521 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45519 def @status_message end |
#target_id ⇒ Fixnum
[Output Only] The unique target ID, which identifies a specific incarnation
of the target resource.
Corresponds to the JSON property targetId
45525 45526 45527 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45525 def target_id @target_id end |
#target_link ⇒ String
[Output Only] The URL of the resource that the operation modifies. For
operations related to creating a snapshot, this points to the disk
that the snapshot was created from.
Corresponds to the JSON property targetLink
45532 45533 45534 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45532 def target_link @target_link end |
#user ⇒ String
[Output Only] User who requested the operation, for example:
user@example.com or
alice_smith_identifier (global/workforcePools/example-com-us-employees).
Corresponds to the JSON property user
45539 45540 45541 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45539 def user @user end |
#warnings ⇒ Array<Google::Apis::ComputeBeta::Operation::Warning>
[Output Only] If warning messages are generated during processing of the
operation, this field will be populated.
Corresponds to the JSON property warnings
45545 45546 45547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45545 def warnings @warnings end |
#zone ⇒ String
[Output Only] The URL of the zone where the operation resides. Only
applicable when performing per-zone operations.
Corresponds to the JSON property zone
45551 45552 45553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45551 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45558 45559 45560 45561 45562 45563 45564 45565 45566 45567 45568 45569 45570 45571 45572 45573 45574 45575 45576 45577 45578 45579 45580 45581 45582 45583 45584 45585 45586 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45558 def update!(**args) @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @end_time = args[:end_time] if args.key?(:end_time) @error = args[:error] if args.key?(:error) @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata) @http_error_message = args[:http_error_message] if args.key?(:http_error_message) @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code) @id = args[:id] if args.key?(:id) @insert_time = args[:insert_time] if args.key?(:insert_time) @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id) @operation_type = args[:operation_type] if args.key?(:operation_type) @progress = args[:progress] if args.key?(:progress) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata) @start_time = args[:start_time] if args.key?(:start_time) @status = args[:status] if args.key?(:status) @status_message = args[:status_message] if args.key?(:status_message) @target_id = args[:target_id] if args.key?(:target_id) @target_link = args[:target_link] if args.key?(:target_link) @user = args[:user] if args.key?(:user) @warnings = args[:warnings] if args.key?(:warnings) @zone = args[:zone] if args.key?(:zone) end |