Class: Google::Apis::ComputeBeta::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Operation resource. Google Compute Engine has three Operation resources:

  • Global
  • Regional
  • Zonal You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses. Operations can be global, regional or zonal.

  • For global operations, use the globalOperations resource.

  • For regional operations, use the regionOperations resource.

  • For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



45497
45498
45499
# File 'lib/google/apis/compute_beta/classes.rb', line 45497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] The value of requestId if you provided it in the request. Not present otherwise. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


45330
45331
45332
# File 'lib/google/apis/compute_beta/classes.rb', line 45330

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Deprecated] This field is deprecated. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


45335
45336
45337
# File 'lib/google/apis/compute_beta/classes.rb', line 45335

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


45341
45342
45343
# File 'lib/google/apis/compute_beta/classes.rb', line 45341

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is inRFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


45348
45349
45350
# File 'lib/google/apis/compute_beta/classes.rb', line 45348

def end_time
  @end_time
end

#errorGoogle::Apis::ComputeBeta::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



45354
45355
45356
# File 'lib/google/apis/compute_beta/classes.rb', line 45354

def error
  @error
end

#get_version_operation_metadataGoogle::Apis::ComputeBeta::GetVersionOperationMetadata

Corresponds to the JSON property getVersionOperationMetadata



45359
45360
45361
# File 'lib/google/apis/compute_beta/classes.rb', line 45359

def 
  @get_version_operation_metadata
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


45365
45366
45367
# File 'lib/google/apis/compute_beta/classes.rb', line 45365

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


45372
45373
45374
# File 'lib/google/apis/compute_beta/classes.rb', line 45372

def http_error_status_code
  @http_error_status_code
end

#idFixnum

[Output Only] The unique identifier for the operation. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


45378
45379
45380
# File 'lib/google/apis/compute_beta/classes.rb', line 45378

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is inRFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


45385
45386
45387
# File 'lib/google/apis/compute_beta/classes.rb', line 45385

def insert_time
  @insert_time
end

#instances_bulk_insert_operation_metadataGoogle::Apis::ComputeBeta::InstancesBulkInsertOperationMetadata

Corresponds to the JSON property instancesBulkInsertOperationMetadata



45390
45391
45392
# File 'lib/google/apis/compute_beta/classes.rb', line 45390

def 
  @instances_bulk_insert_operation_metadata
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


45397
45398
45399
# File 'lib/google/apis/compute_beta/classes.rb', line 45397

def kind
  @kind
end

#nameString

[Output Only] Name of the operation. Corresponds to the JSON property name

Returns:

  • (String)


45402
45403
45404
# File 'lib/google/apis/compute_beta/classes.rb', line 45402

def name
  @name
end

#operation_group_idString

Output only. [Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request. Corresponds to the JSON property operationGroupId

Returns:

  • (String)


45409
45410
45411
# File 'lib/google/apis/compute_beta/classes.rb', line 45409

def operation_group_id
  @operation_group_id
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


45415
45416
45417
# File 'lib/google/apis/compute_beta/classes.rb', line 45415

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


45424
45425
45426
# File 'lib/google/apis/compute_beta/classes.rb', line 45424

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


45430
45431
45432
# File 'lib/google/apis/compute_beta/classes.rb', line 45430

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45435
45436
45437
# File 'lib/google/apis/compute_beta/classes.rb', line 45435

def self_link
  @self_link
end

#set_common_instance_metadata_operation_metadataGoogle::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadata

Output only. [Output Only] If the operation is for projects. setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state. Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata



45443
45444
45445
# File 'lib/google/apis/compute_beta/classes.rb', line 45443

def 
  @set_common_instance_metadata_operation_metadata
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is inRFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


45450
45451
45452
# File 'lib/google/apis/compute_beta/classes.rb', line 45450

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


45457
45458
45459
# File 'lib/google/apis/compute_beta/classes.rb', line 45457

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


45463
45464
45465
# File 'lib/google/apis/compute_beta/classes.rb', line 45463

def status_message
  @status_message
end

#target_idFixnum

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


45469
45470
45471
# File 'lib/google/apis/compute_beta/classes.rb', line 45469

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


45476
45477
45478
# File 'lib/google/apis/compute_beta/classes.rb', line 45476

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: user@example.com or alice_smith_identifier (global/workforcePools/example-com-us-employees). Corresponds to the JSON property user

Returns:

  • (String)


45483
45484
45485
# File 'lib/google/apis/compute_beta/classes.rb', line 45483

def user
  @user
end

#warningsArray<Google::Apis::ComputeBeta::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



45489
45490
45491
# File 'lib/google/apis/compute_beta/classes.rb', line 45489

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


45495
45496
45497
# File 'lib/google/apis/compute_beta/classes.rb', line 45495

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45502
45503
45504
45505
45506
45507
45508
45509
45510
45511
45512
45513
45514
45515
45516
45517
45518
45519
45520
45521
45522
45523
45524
45525
45526
45527
45528
45529
45530
# File 'lib/google/apis/compute_beta/classes.rb', line 45502

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end