Class: Google::Apis::ComputeBeta::Operation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents an Operation resource. Google Compute Engine has three Operation resources:

  • Global
  • Regional
  • Zonal You can use an operation resource to manage asynchronous API requests. For more information, readHandling API responses. Operations can be global, regional or zonal.

  • For global operations, use the globalOperations resource.

  • For regional operations, use the regionOperations resource.

  • For zonal operations, use the zoneOperations resource. For more information, read Global, Regional, and Zonal Resources. Note that completed Operation resources have a limited retention period.

Defined Under Namespace

Classes: Error, Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Operation

Returns a new instance of Operation.



45475
45476
45477
# File 'lib/google/apis/compute_beta/classes.rb', line 45475

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#client_operation_idString

[Output Only] The value of requestId if you provided it in the request. Not present otherwise. Corresponds to the JSON property clientOperationId

Returns:

  • (String)


45308
45309
45310
# File 'lib/google/apis/compute_beta/classes.rb', line 45308

def client_operation_id
  @client_operation_id
end

#creation_timestampString

[Deprecated] This field is deprecated. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


45313
45314
45315
# File 'lib/google/apis/compute_beta/classes.rb', line 45313

def creation_timestamp
  @creation_timestamp
end

#descriptionString

[Output Only] A textual description of the operation, which is set when the operation is created. Corresponds to the JSON property description

Returns:

  • (String)


45319
45320
45321
# File 'lib/google/apis/compute_beta/classes.rb', line 45319

def description
  @description
end

#end_timeString

[Output Only] The time that this operation was completed. This value is inRFC3339 text format. Corresponds to the JSON property endTime

Returns:

  • (String)


45326
45327
45328
# File 'lib/google/apis/compute_beta/classes.rb', line 45326

def end_time
  @end_time
end

#errorGoogle::Apis::ComputeBeta::Operation::Error

[Output Only] If errors are generated during processing of the operation, this field will be populated. Corresponds to the JSON property error



45332
45333
45334
# File 'lib/google/apis/compute_beta/classes.rb', line 45332

def error
  @error
end

#get_version_operation_metadataGoogle::Apis::ComputeBeta::GetVersionOperationMetadata

Corresponds to the JSON property getVersionOperationMetadata



45337
45338
45339
# File 'lib/google/apis/compute_beta/classes.rb', line 45337

def 
  @get_version_operation_metadata
end

#http_error_messageString

[Output Only] If the operation fails, this field contains the HTTP error message that was returned, such as NOT FOUND. Corresponds to the JSON property httpErrorMessage

Returns:

  • (String)


45343
45344
45345
# File 'lib/google/apis/compute_beta/classes.rb', line 45343

def http_error_message
  @http_error_message
end

#http_error_status_codeFixnum

[Output Only] If the operation fails, this field contains the HTTP error status code that was returned. For example, a 404 means the resource was not found. Corresponds to the JSON property httpErrorStatusCode

Returns:

  • (Fixnum)


45350
45351
45352
# File 'lib/google/apis/compute_beta/classes.rb', line 45350

def http_error_status_code
  @http_error_status_code
end

#idFixnum

[Output Only] The unique identifier for the operation. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


45356
45357
45358
# File 'lib/google/apis/compute_beta/classes.rb', line 45356

def id
  @id
end

#insert_timeString

[Output Only] The time that this operation was requested. This value is inRFC3339 text format. Corresponds to the JSON property insertTime

Returns:

  • (String)


45363
45364
45365
# File 'lib/google/apis/compute_beta/classes.rb', line 45363

def insert_time
  @insert_time
end

#instances_bulk_insert_operation_metadataGoogle::Apis::ComputeBeta::InstancesBulkInsertOperationMetadata

Corresponds to the JSON property instancesBulkInsertOperationMetadata



45368
45369
45370
# File 'lib/google/apis/compute_beta/classes.rb', line 45368

def 
  @instances_bulk_insert_operation_metadata
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#operation for Operation resources. Corresponds to the JSON property kind

Returns:

  • (String)


45375
45376
45377
# File 'lib/google/apis/compute_beta/classes.rb', line 45375

def kind
  @kind
end

#nameString

[Output Only] Name of the operation. Corresponds to the JSON property name

Returns:

  • (String)


45380
45381
45382
# File 'lib/google/apis/compute_beta/classes.rb', line 45380

def name
  @name
end

#operation_group_idString

Output only. [Output Only] An ID that represents a group of operations, such as when a group of operations results from a bulkInsert API request. Corresponds to the JSON property operationGroupId

Returns:

  • (String)


45387
45388
45389
# File 'lib/google/apis/compute_beta/classes.rb', line 45387

def operation_group_id
  @operation_group_id
end

#operation_typeString

[Output Only] The type of operation, such as insert, update, or delete, and so on. Corresponds to the JSON property operationType

Returns:

  • (String)


45393
45394
45395
# File 'lib/google/apis/compute_beta/classes.rb', line 45393

def operation_type
  @operation_type
end

#progressFixnum

[Output Only] An optional progress indicator that ranges from 0 to 100. There is no requirement that this be linear or support any granularity of operations. This should not be used to guess when the operation will be complete. This number should monotonically increase as the operation progresses. Corresponds to the JSON property progress

Returns:

  • (Fixnum)


45402
45403
45404
# File 'lib/google/apis/compute_beta/classes.rb', line 45402

def progress
  @progress
end

#regionString

[Output Only] The URL of the region where the operation resides. Only applicable when performing regional operations. Corresponds to the JSON property region

Returns:

  • (String)


45408
45409
45410
# File 'lib/google/apis/compute_beta/classes.rb', line 45408

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45413
45414
45415
# File 'lib/google/apis/compute_beta/classes.rb', line 45413

def self_link
  @self_link
end

#set_common_instance_metadata_operation_metadataGoogle::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadata

Output only. [Output Only] If the operation is for projects. setCommonInstanceMetadata, this field will contain information on all underlying zonal actions and their state. Corresponds to the JSON property setCommonInstanceMetadataOperationMetadata



45421
45422
45423
# File 'lib/google/apis/compute_beta/classes.rb', line 45421

def 
  @set_common_instance_metadata_operation_metadata
end

#start_timeString

[Output Only] The time that this operation was started by the server. This value is inRFC3339 text format. Corresponds to the JSON property startTime

Returns:

  • (String)


45428
45429
45430
# File 'lib/google/apis/compute_beta/classes.rb', line 45428

def start_time
  @start_time
end

#statusString

[Output Only] The status of the operation, which can be one of the following: PENDING, RUNNING, or DONE. Corresponds to the JSON property status

Returns:

  • (String)


45435
45436
45437
# File 'lib/google/apis/compute_beta/classes.rb', line 45435

def status
  @status
end

#status_messageString

[Output Only] An optional textual description of the current status of the operation. Corresponds to the JSON property statusMessage

Returns:

  • (String)


45441
45442
45443
# File 'lib/google/apis/compute_beta/classes.rb', line 45441

def status_message
  @status_message
end

#target_idFixnum

[Output Only] The unique target ID, which identifies a specific incarnation of the target resource. Corresponds to the JSON property targetId

Returns:

  • (Fixnum)


45447
45448
45449
# File 'lib/google/apis/compute_beta/classes.rb', line 45447

def target_id
  @target_id
end

[Output Only] The URL of the resource that the operation modifies. For operations related to creating a snapshot, this points to the disk that the snapshot was created from. Corresponds to the JSON property targetLink

Returns:

  • (String)


45454
45455
45456
# File 'lib/google/apis/compute_beta/classes.rb', line 45454

def target_link
  @target_link
end

#userString

[Output Only] User who requested the operation, for example: user@example.com or alice_smith_identifier (global/workforcePools/example-com-us-employees). Corresponds to the JSON property user

Returns:

  • (String)


45461
45462
45463
# File 'lib/google/apis/compute_beta/classes.rb', line 45461

def user
  @user
end

#warningsArray<Google::Apis::ComputeBeta::Operation::Warning>

[Output Only] If warning messages are generated during processing of the operation, this field will be populated. Corresponds to the JSON property warnings



45467
45468
45469
# File 'lib/google/apis/compute_beta/classes.rb', line 45467

def warnings
  @warnings
end

#zoneString

[Output Only] The URL of the zone where the operation resides. Only applicable when performing per-zone operations. Corresponds to the JSON property zone

Returns:

  • (String)


45473
45474
45475
# File 'lib/google/apis/compute_beta/classes.rb', line 45473

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45480
45481
45482
45483
45484
45485
45486
45487
45488
45489
45490
45491
45492
45493
45494
45495
45496
45497
45498
45499
45500
45501
45502
45503
45504
45505
45506
45507
45508
# File 'lib/google/apis/compute_beta/classes.rb', line 45480

def update!(**args)
  @client_operation_id = args[:client_operation_id] if args.key?(:client_operation_id)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @end_time = args[:end_time] if args.key?(:end_time)
  @error = args[:error] if args.key?(:error)
  @get_version_operation_metadata = args[:get_version_operation_metadata] if args.key?(:get_version_operation_metadata)
  @http_error_message = args[:http_error_message] if args.key?(:http_error_message)
  @http_error_status_code = args[:http_error_status_code] if args.key?(:http_error_status_code)
  @id = args[:id] if args.key?(:id)
  @insert_time = args[:insert_time] if args.key?(:insert_time)
  @instances_bulk_insert_operation_metadata = args[:instances_bulk_insert_operation_metadata] if args.key?(:instances_bulk_insert_operation_metadata)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @operation_group_id = args[:operation_group_id] if args.key?(:operation_group_id)
  @operation_type = args[:operation_type] if args.key?(:operation_type)
  @progress = args[:progress] if args.key?(:progress)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @set_common_instance_metadata_operation_metadata = args[:set_common_instance_metadata_operation_metadata] if args.key?(:set_common_instance_metadata_operation_metadata)
  @start_time = args[:start_time] if args.key?(:start_time)
  @status = args[:status] if args.key?(:status)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target_id = args[:target_id] if args.key?(:target_id)
  @target_link = args[:target_link] if args.key?(:target_link)
  @user = args[:user] if args.key?(:user)
  @warnings = args[:warnings] if args.key?(:warnings)
  @zone = args[:zone] if args.key?(:zone)
end