Class: Google::Apis::ComputeBeta::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
45814 45815 45816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45814 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
45775 45776 45777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45775 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
45780 45781 45782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45780 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
operationAggregatedList
for aggregated lists of operations.
Corresponds to the JSON property kind
45787 45788 45789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45787 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45797 45798 45799 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45797 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45802 45803 45804 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45802 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
45807 45808 45809 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45807 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45812 45813 45814 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45812 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45819 45820 45821 45822 45823 45824 45825 45826 45827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45819 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |