Class: Google::Apis::ComputeBeta::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



45750
45751
45752
# File 'lib/google/apis/compute_beta/classes.rb', line 45750

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45711
45712
45713
# File 'lib/google/apis/compute_beta/classes.rb', line 45711

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



45716
45717
45718
# File 'lib/google/apis/compute_beta/classes.rb', line 45716

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


45723
45724
45725
# File 'lib/google/apis/compute_beta/classes.rb', line 45723

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45733
45734
45735
# File 'lib/google/apis/compute_beta/classes.rb', line 45733

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45738
45739
45740
# File 'lib/google/apis/compute_beta/classes.rb', line 45738

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


45743
45744
45745
# File 'lib/google/apis/compute_beta/classes.rb', line 45743

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45748
45749
45750
# File 'lib/google/apis/compute_beta/classes.rb', line 45748

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45755
45756
45757
45758
45759
45760
45761
45762
45763
# File 'lib/google/apis/compute_beta/classes.rb', line 45755

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end