Class: Google::Apis::ComputeBeta::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
45211 45212 45213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45211 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
45172 45173 45174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45172 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
45177 45178 45179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45177 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
operationAggregatedList
for aggregated lists of operations.
Corresponds to the JSON property kind
45184 45185 45186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45184 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45194 45195 45196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45194 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45199 45200 45201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45199 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
45204 45205 45206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45204 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45209 45210 45211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45209 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45216 45217 45218 45219 45220 45221 45222 45223 45224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45216 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |