Class: Google::Apis::ComputeBeta::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



44429
44430
44431
# File 'lib/google/apis/compute_beta/classes.rb', line 44429

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44390
44391
44392
# File 'lib/google/apis/compute_beta/classes.rb', line 44390

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



44395
44396
44397
# File 'lib/google/apis/compute_beta/classes.rb', line 44395

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


44402
44403
44404
# File 'lib/google/apis/compute_beta/classes.rb', line 44402

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44412
44413
44414
# File 'lib/google/apis/compute_beta/classes.rb', line 44412

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44417
44418
44419
# File 'lib/google/apis/compute_beta/classes.rb', line 44417

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44422
44423
44424
# File 'lib/google/apis/compute_beta/classes.rb', line 44422

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44427
44428
44429
# File 'lib/google/apis/compute_beta/classes.rb', line 44427

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44434
44435
44436
44437
44438
44439
44440
44441
44442
# File 'lib/google/apis/compute_beta/classes.rb', line 44434

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end