Class: Google::Apis::ComputeBeta::OperationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::OperationsScopedList>
[Output Only] A map of scoped operation lists.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationAggregatedList
constructor
A new instance of OperationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationAggregatedList
Returns a new instance of OperationAggregatedList.
43370 43371 43372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
43331 43332 43333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43331 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::OperationsScopedList>
[Output Only] A map of scoped operation lists.
Corresponds to the JSON property items
43336 43337 43338 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43336 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#
operationAggregatedList
for aggregated lists of operations.
Corresponds to the JSON property kind
43343 43344 43345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43343 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43353 43354 43355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43353 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43358 43359 43360 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43358 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
43363 43364 43365 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43363 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::OperationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43368 43369 43370 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43368 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43375 43376 43377 43378 43379 43380 43381 43382 43383 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43375 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |