Class: Google::Apis::ComputeBeta::OperationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationAggregatedList

Returns a new instance of OperationAggregatedList.



41982
41983
41984
# File 'lib/google/apis/compute_beta/classes.rb', line 41982

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


41943
41944
41945
# File 'lib/google/apis/compute_beta/classes.rb', line 41943

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::OperationsScopedList>

[Output Only] A map of scoped operation lists. Corresponds to the JSON property items



41948
41949
41950
# File 'lib/google/apis/compute_beta/classes.rb', line 41948

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute# operationAggregatedList for aggregated lists of operations. Corresponds to the JSON property kind

Returns:

  • (String)


41955
41956
41957
# File 'lib/google/apis/compute_beta/classes.rb', line 41955

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


41965
41966
41967
# File 'lib/google/apis/compute_beta/classes.rb', line 41965

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


41970
41971
41972
# File 'lib/google/apis/compute_beta/classes.rb', line 41970

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


41975
41976
41977
# File 'lib/google/apis/compute_beta/classes.rb', line 41975

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OperationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



41980
41981
41982
# File 'lib/google/apis/compute_beta/classes.rb', line 41980

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



41987
41988
41989
41990
41991
41992
41993
41994
41995
# File 'lib/google/apis/compute_beta/classes.rb', line 41987

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end