Class: Google::Apis::ComputeBeta::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
46008 46009 46010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46008 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
45974 45975 45976 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45974 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
45979 45980 45981 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45979 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
45986 45987 45988 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45986 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45996 45997 45998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45996 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46001 46002 46003 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46001 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46006 46007 46008 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46006 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46013 46014 46015 46016 46017 46018 46019 46020 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46013 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |