Class: Google::Apis::ComputeBeta::OperationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Operation resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationList

Returns a new instance of OperationList.



45878
45879
45880
# File 'lib/google/apis/compute_beta/classes.rb', line 45878

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45844
45845
45846
# File 'lib/google/apis/compute_beta/classes.rb', line 45844

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Operation>

[Output Only] A list of Operation resources. Corresponds to the JSON property items



45849
45850
45851
# File 'lib/google/apis/compute_beta/classes.rb', line 45849

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#operations for Operations resource. Corresponds to the JSON property kind

Returns:

  • (String)


45856
45857
45858
# File 'lib/google/apis/compute_beta/classes.rb', line 45856

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger than maxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45866
45867
45868
# File 'lib/google/apis/compute_beta/classes.rb', line 45866

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45871
45872
45873
# File 'lib/google/apis/compute_beta/classes.rb', line 45871

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::OperationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45876
45877
45878
# File 'lib/google/apis/compute_beta/classes.rb', line 45876

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45883
45884
45885
45886
45887
45888
45889
45890
# File 'lib/google/apis/compute_beta/classes.rb', line 45883

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end