Class: Google::Apis::ComputeBeta::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
45398 45399 45400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45398 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
45364 45365 45366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45364 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
45369 45370 45371 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45369 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
45376 45377 45378 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45376 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
45386 45387 45388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45386 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
45391 45392 45393 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45391 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
45396 45397 45398 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45396 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45403 45404 45405 45406 45407 45408 45409 45410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45403 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |