Class: Google::Apis::ComputeBeta::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
44557 44558 44559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44557 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
44523 44524 44525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44523 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
44528 44529 44530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44528 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
44535 44536 44537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44535 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44545 44546 44547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44545 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44550 44551 44552 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44550 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44555 44556 44557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44555 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44562 44563 44564 44565 44566 44567 44568 44569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44562 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |