Class: Google::Apis::ComputeBeta::OperationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OperationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Operation resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationList
constructor
A new instance of OperationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationList
Returns a new instance of OperationList.
43498 43499 43500 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
43464 43465 43466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43464 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Operation>
[Output Only] A list of Operation resources.
Corresponds to the JSON property items
43469 43470 43471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43469 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#operations for
Operations
resource.
Corresponds to the JSON property kind
43476 43477 43478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43476 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger than
maxResults, use the nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43486 43487 43488 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43486 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43491 43492 43493 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43491 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::OperationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43496 43497 43498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43496 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43503 43504 43505 43506 43507 43508 43509 43510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43503 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |