Class: Google::Apis::ComputeBeta::OrganizationRolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OrganizationRolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrganizationRolloutsListResponse
constructor
A new instance of OrganizationRolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrganizationRolloutsListResponse
Returns a new instance of OrganizationRolloutsListResponse.
46235 46236 46237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46235 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
46197 46198 46199 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46197 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46202 46203 46204 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46202 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
46207 46208 46209 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46207 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46217 46218 46219 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46217 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46222 46223 46224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46222 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
46228 46229 46230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46228 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46233 46234 46235 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46233 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46240 46241 46242 46243 46244 46245 46246 46247 46248 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46240 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |