Class: Google::Apis::ComputeBeta::OrganizationRolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OrganizationRolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OrganizationRolloutsListResponse
constructor
A new instance of OrganizationRolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OrganizationRolloutsListResponse
Returns a new instance of OrganizationRolloutsListResponse.
46185 46186 46187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46185 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
46147 46148 46149 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46147 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46152 46153 46154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46152 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
46157 46158 46159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46157 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46167 46168 46169 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46167 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46172 46173 46174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46172 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
46178 46179 46180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46178 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46183 46184 46185 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46183 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46190 46191 46192 46193 46194 46195 46196 46197 46198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46190 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |