Class: Google::Apis::ComputeBeta::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



46169
46170
46171
# File 'lib/google/apis/compute_beta/classes.rb', line 46169

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


46131
46132
46133
# File 'lib/google/apis/compute_beta/classes.rb', line 46131

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46136
46137
46138
# File 'lib/google/apis/compute_beta/classes.rb', line 46136

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



46141
46142
46143
# File 'lib/google/apis/compute_beta/classes.rb', line 46141

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46151
46152
46153
# File 'lib/google/apis/compute_beta/classes.rb', line 46151

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46156
46157
46158
# File 'lib/google/apis/compute_beta/classes.rb', line 46156

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46162
46163
46164
# File 'lib/google/apis/compute_beta/classes.rb', line 46162

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46167
46168
46169
# File 'lib/google/apis/compute_beta/classes.rb', line 46167

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46174
46175
46176
46177
46178
46179
46180
46181
46182
# File 'lib/google/apis/compute_beta/classes.rb', line 46174

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end