Class: Google::Apis::ComputeBeta::OrganizationRolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OrganizationRolloutsListResponse

Returns a new instance of OrganizationRolloutsListResponse.



46127
46128
46129
# File 'lib/google/apis/compute_beta/classes.rb', line 46127

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


46089
46090
46091
# File 'lib/google/apis/compute_beta/classes.rb', line 46089

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46094
46095
46096
# File 'lib/google/apis/compute_beta/classes.rb', line 46094

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



46099
46100
46101
# File 'lib/google/apis/compute_beta/classes.rb', line 46099

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46109
46110
46111
# File 'lib/google/apis/compute_beta/classes.rb', line 46109

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46114
46115
46116
# File 'lib/google/apis/compute_beta/classes.rb', line 46114

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46120
46121
46122
# File 'lib/google/apis/compute_beta/classes.rb', line 46120

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::OrganizationRolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46125
46126
46127
# File 'lib/google/apis/compute_beta/classes.rb', line 46125

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46132
46133
46134
46135
46136
46137
46138
46139
46140
# File 'lib/google/apis/compute_beta/classes.rb', line 46132

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end