Class: Google::Apis::ComputeBeta::OutlierDetection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OutlierDetection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.
Instance Attribute Summary collapse
-
#base_ejection_time ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#consecutive_errors ⇒ Fixnum
Number of consecutive errors before a backend endpoint is ejected from the load balancing pool.
-
#consecutive_gateway_failure ⇒ Fixnum
The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs.
-
#enforcing_consecutive_errors ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx.
-
#enforcing_consecutive_gateway_failure ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures.
-
#enforcing_success_rate ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics.
-
#interval ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#max_ejection_percent ⇒ Fixnum
Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met.
-
#success_rate_minimum_hosts ⇒ Fixnum
The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers.
-
#success_rate_request_volume ⇒ Fixnum
The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection.
-
#success_rate_stdev_factor ⇒ Fixnum
This factor is used to determine the ejection threshold for success rate outlier ejection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OutlierDetection
constructor
A new instance of OutlierDetection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OutlierDetection
Returns a new instance of OutlierDetection.
46842 46843 46844 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46842 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_ejection_time ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property baseEjectionTime
46757 46758 46759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46757 def base_ejection_time @base_ejection_time end |
#consecutive_errors ⇒ Fixnum
Number of consecutive errors before a backend endpoint is ejected from the
load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx
return code qualifies as an error. Defaults to 5.
Corresponds to the JSON property consecutiveErrors
46764 46765 46766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46764 def consecutive_errors @consecutive_errors end |
#consecutive_gateway_failure ⇒ Fixnum
The number of consecutive gateway failures (502, 503, 504 status or
connection errors that are mapped to one of those status codes) before a
consecutive gateway failure ejection occurs. Defaults to 3.
Corresponds to the JSON property consecutiveGatewayFailure
46771 46772 46773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46771 def consecutive_gateway_failure @consecutive_gateway_failure end |
#enforcing_consecutive_errors ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive 5xx. This setting can be
used to disable ejection or to ramp it up slowly. Defaults to 0.
Corresponds to the JSON property enforcingConsecutiveErrors
46778 46779 46780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46778 def enforcing_consecutive_errors @enforcing_consecutive_errors end |
#enforcing_consecutive_gateway_failure ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive gateway failures. This
setting can be used to disable ejection or to ramp it up slowly. Defaults
to 100.
Corresponds to the JSON property enforcingConsecutiveGatewayFailure
46786 46787 46788 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46786 def enforcing_consecutive_gateway_failure @enforcing_consecutive_gateway_failure end |
#enforcing_success_rate ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through success rate statistics. This setting
can be used to disable ejection or to ramp it up slowly. Defaults to 100.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property enforcingSuccessRate
46794 46795 46796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46794 def enforcing_success_rate @enforcing_success_rate end |
#interval ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property interval
46802 46803 46804 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46802 def interval @interval end |
#max_ejection_percent ⇒ Fixnum
Maximum percentage of backend endpoints in the load balancing pool for the
backend service that can be ejected if the ejection conditions are met.
Defaults to 50%.
Corresponds to the JSON property maxEjectionPercent
46809 46810 46811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46809 def max_ejection_percent @max_ejection_percent end |
#success_rate_minimum_hosts ⇒ Fixnum
The number of backend endpoints in the load balancing pool that must have
enough request volume to detect success rate outliers. If the number of
backend endpoints is fewer than this setting, outlier detection via success
rate statistics is not performed for any backend endpoint in the load
balancing pool. Defaults to 5.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateMinimumHosts
46819 46820 46821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46819 def success_rate_minimum_hosts @success_rate_minimum_hosts end |
#success_rate_request_volume ⇒ Fixnum
The minimum number of total requests that must be collected in one interval
(as defined by the interval duration above) to include this backend
endpoint in success rate based outlier detection. If the volume is lower
than this setting, outlier detection via success rate statistics is not
performed for that backend endpoint. Defaults to 100.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateRequestVolume
46829 46830 46831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46829 def success_rate_request_volume @success_rate_request_volume end |
#success_rate_stdev_factor ⇒ Fixnum
This factor is used to determine the ejection threshold for success rate
outlier ejection. The ejection threshold is the difference between the mean
success rate, and the product of this factor and the standard deviation of
the mean success rate: mean - (stdev * successRateStdevFactor). This factor
is divided by a thousand to get a double. That is, if the desired factor
is 1.9, the runtime value should be 1900. Defaults to 1900.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateStdevFactor
46840 46841 46842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46840 def success_rate_stdev_factor @success_rate_stdev_factor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46847 46848 46849 46850 46851 46852 46853 46854 46855 46856 46857 46858 46859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46847 def update!(**args) @base_ejection_time = args[:base_ejection_time] if args.key?(:base_ejection_time) @consecutive_errors = args[:consecutive_errors] if args.key?(:consecutive_errors) @consecutive_gateway_failure = args[:consecutive_gateway_failure] if args.key?(:consecutive_gateway_failure) @enforcing_consecutive_errors = args[:enforcing_consecutive_errors] if args.key?(:enforcing_consecutive_errors) @enforcing_consecutive_gateway_failure = args[:enforcing_consecutive_gateway_failure] if args.key?(:enforcing_consecutive_gateway_failure) @enforcing_success_rate = args[:enforcing_success_rate] if args.key?(:enforcing_success_rate) @interval = args[:interval] if args.key?(:interval) @max_ejection_percent = args[:max_ejection_percent] if args.key?(:max_ejection_percent) @success_rate_minimum_hosts = args[:success_rate_minimum_hosts] if args.key?(:success_rate_minimum_hosts) @success_rate_request_volume = args[:success_rate_request_volume] if args.key?(:success_rate_request_volume) @success_rate_stdev_factor = args[:success_rate_stdev_factor] if args.key?(:success_rate_stdev_factor) end |