Class: Google::Apis::ComputeBeta::OutlierDetection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::OutlierDetection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Settings controlling the eviction of unhealthy hosts from the load balancing pool for the backend service.
Instance Attribute Summary collapse
-
#base_ejection_time ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#consecutive_errors ⇒ Fixnum
Number of consecutive errors before a backend endpoint is ejected from the load balancing pool.
-
#consecutive_gateway_failure ⇒ Fixnum
The number of consecutive gateway failures (502, 503, 504 status or connection errors that are mapped to one of those status codes) before a consecutive gateway failure ejection occurs.
-
#enforcing_consecutive_errors ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive 5xx.
-
#enforcing_consecutive_gateway_failure ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through consecutive gateway failures.
-
#enforcing_success_rate ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an outlier status is detected through success rate statistics.
-
#interval ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#max_ejection_percent ⇒ Fixnum
Maximum percentage of backend endpoints in the load balancing pool for the backend service that can be ejected if the ejection conditions are met.
-
#success_rate_minimum_hosts ⇒ Fixnum
The number of backend endpoints in the load balancing pool that must have enough request volume to detect success rate outliers.
-
#success_rate_request_volume ⇒ Fixnum
The minimum number of total requests that must be collected in one interval (as defined by the interval duration above) to include this backend endpoint in success rate based outlier detection.
-
#success_rate_stdev_factor ⇒ Fixnum
This factor is used to determine the ejection threshold for success rate outlier ejection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OutlierDetection
constructor
A new instance of OutlierDetection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OutlierDetection
Returns a new instance of OutlierDetection.
42415 42416 42417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base_ejection_time ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property baseEjectionTime
42330 42331 42332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42330 def base_ejection_time @base_ejection_time end |
#consecutive_errors ⇒ Fixnum
Number of consecutive errors before a backend endpoint is ejected from the
load balancing pool. When the backend endpoint is accessed over HTTP, a 5xx
return code qualifies as an error. Defaults to 5.
Corresponds to the JSON property consecutiveErrors
42337 42338 42339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42337 def consecutive_errors @consecutive_errors end |
#consecutive_gateway_failure ⇒ Fixnum
The number of consecutive gateway failures (502, 503, 504 status or
connection errors that are mapped to one of those status codes) before a
consecutive gateway failure ejection occurs. Defaults to 3.
Corresponds to the JSON property consecutiveGatewayFailure
42344 42345 42346 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42344 def consecutive_gateway_failure @consecutive_gateway_failure end |
#enforcing_consecutive_errors ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive 5xx. This setting can be
used to disable ejection or to ramp it up slowly. Defaults to 0.
Corresponds to the JSON property enforcingConsecutiveErrors
42351 42352 42353 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42351 def enforcing_consecutive_errors @enforcing_consecutive_errors end |
#enforcing_consecutive_gateway_failure ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through consecutive gateway failures. This
setting can be used to disable ejection or to ramp it up slowly. Defaults
to 100.
Corresponds to the JSON property enforcingConsecutiveGatewayFailure
42359 42360 42361 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42359 def enforcing_consecutive_gateway_failure @enforcing_consecutive_gateway_failure end |
#enforcing_success_rate ⇒ Fixnum
The percentage chance that a backend endpoint will be ejected when an
outlier status is detected through success rate statistics. This setting
can be used to disable ejection or to ramp it up slowly. Defaults to 100.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property enforcingSuccessRate
42367 42368 42369 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42367 def enforcing_success_rate @enforcing_success_rate end |
#interval ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property interval
42375 42376 42377 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42375 def interval @interval end |
#max_ejection_percent ⇒ Fixnum
Maximum percentage of backend endpoints in the load balancing pool for the
backend service that can be ejected if the ejection conditions are met.
Defaults to 50%.
Corresponds to the JSON property maxEjectionPercent
42382 42383 42384 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42382 def max_ejection_percent @max_ejection_percent end |
#success_rate_minimum_hosts ⇒ Fixnum
The number of backend endpoints in the load balancing pool that must have
enough request volume to detect success rate outliers. If the number of
backend endpoints is fewer than this setting, outlier detection via success
rate statistics is not performed for any backend endpoint in the load
balancing pool. Defaults to 5.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateMinimumHosts
42392 42393 42394 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42392 def success_rate_minimum_hosts @success_rate_minimum_hosts end |
#success_rate_request_volume ⇒ Fixnum
The minimum number of total requests that must be collected in one interval
(as defined by the interval duration above) to include this backend
endpoint in success rate based outlier detection. If the volume is lower
than this setting, outlier detection via success rate statistics is not
performed for that backend endpoint. Defaults to 100.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateRequestVolume
42402 42403 42404 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42402 def success_rate_request_volume @success_rate_request_volume end |
#success_rate_stdev_factor ⇒ Fixnum
This factor is used to determine the ejection threshold for success rate
outlier ejection. The ejection threshold is the difference between the mean
success rate, and the product of this factor and the standard deviation of
the mean success rate: mean - (stdev * successRateStdevFactor). This factor
is divided by a thousand to get a double. That is, if the desired factor
is 1.9, the runtime value should be 1900. Defaults to 1900.
Not supported when the backend service uses Serverless NEG.
Corresponds to the JSON property successRateStdevFactor
42413 42414 42415 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42413 def success_rate_stdev_factor @success_rate_stdev_factor end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
42420 42421 42422 42423 42424 42425 42426 42427 42428 42429 42430 42431 42432 |
# File 'lib/google/apis/compute_beta/classes.rb', line 42420 def update!(**args) @base_ejection_time = args[:base_ejection_time] if args.key?(:base_ejection_time) @consecutive_errors = args[:consecutive_errors] if args.key?(:consecutive_errors) @consecutive_gateway_failure = args[:consecutive_gateway_failure] if args.key?(:consecutive_gateway_failure) @enforcing_consecutive_errors = args[:enforcing_consecutive_errors] if args.key?(:enforcing_consecutive_errors) @enforcing_consecutive_gateway_failure = args[:enforcing_consecutive_gateway_failure] if args.key?(:enforcing_consecutive_gateway_failure) @enforcing_success_rate = args[:enforcing_success_rate] if args.key?(:enforcing_success_rate) @interval = args[:interval] if args.key?(:interval) @max_ejection_percent = args[:max_ejection_percent] if args.key?(:max_ejection_percent) @success_rate_minimum_hosts = args[:success_rate_minimum_hosts] if args.key?(:success_rate_minimum_hosts) @success_rate_request_volume = args[:success_rate_request_volume] if args.key?(:success_rate_request_volume) @success_rate_stdev_factor = args[:success_rate_stdev_factor] if args.key?(:success_rate_stdev_factor) end |