Class: Google::Apis::ComputeBeta::PacketIntervals
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketIntervals
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Next free: 7
Instance Attribute Summary collapse
-
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
-
#duration ⇒ String
From how long ago in the past these intervals were observed.
-
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
-
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
-
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
-
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketIntervals
constructor
A new instance of PacketIntervals.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketIntervals
Returns a new instance of PacketIntervals.
46390 46391 46392 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46390 def initialize(**args) update!(**args) end |
Instance Attribute Details
#avg_ms ⇒ Fixnum
Average observed inter-packet interval in milliseconds.
Corresponds to the JSON property avgMs
46363 46364 46365 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46363 def avg_ms @avg_ms end |
#duration ⇒ String
From how long ago in the past these intervals were observed.
Corresponds to the JSON property duration
46368 46369 46370 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46368 def duration @duration end |
#max_ms ⇒ Fixnum
Maximum observed inter-packet interval in milliseconds.
Corresponds to the JSON property maxMs
46373 46374 46375 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46373 def max_ms @max_ms end |
#min_ms ⇒ Fixnum
Minimum observed inter-packet interval in milliseconds.
Corresponds to the JSON property minMs
46378 46379 46380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46378 def min_ms @min_ms end |
#num_intervals ⇒ Fixnum
Number of inter-packet intervals from which these statistics were derived.
Corresponds to the JSON property numIntervals
46383 46384 46385 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46383 def num_intervals @num_intervals end |
#type ⇒ String
The type of packets for which inter-packet intervals were computed.
Corresponds to the JSON property type
46388 46389 46390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46388 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46395 46396 46397 46398 46399 46400 46401 46402 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46395 def update!(**args) @avg_ms = args[:avg_ms] if args.key?(:avg_ms) @duration = args[:duration] if args.key?(:duration) @max_ms = args[:max_ms] if args.key?(:max_ms) @min_ms = args[:min_ms] if args.key?(:min_ms) @num_intervals = args[:num_intervals] if args.key?(:num_intervals) @type = args[:type] if args.key?(:type) end |