Class: Google::Apis::ComputeBeta::PacketMirroring
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroring
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, seeUsing Packet Mirroring.
Instance Attribute Summary collapse
-
#collector_ilb ⇒ Google::Apis::ComputeBeta::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#enable ⇒ String
Indicates whether or not this packet mirroring takes effect.
-
#filter ⇒ Google::Apis::ComputeBeta::PacketMirroringFilter
Filter for mirrored traffic.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#mirrored_resources ⇒ Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ Google::Apis::ComputeBeta::PacketMirroringNetworkInfo
Specifies the mirrored VPC network.
-
#priority ⇒ Fixnum
The priority of applying this configuration.
-
#region ⇒ String
[Output Only] URI of the region where the packetMirroring resides.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroring
constructor
A new instance of PacketMirroring.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroring
Returns a new instance of PacketMirroring.
46564 46565 46566 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collector_ilb ⇒ Google::Apis::ComputeBeta::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be
used as collector
for mirrored traffic.
The specified forwarding rule must have isMirroringCollector
set to true.
Corresponds to the JSON property collectorIlb
46480 46481 46482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46480 def collector_ilb @collector_ilb end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
46486 46487 46488 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46486 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
46492 46493 46494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46492 def description @description end |
#enable ⇒ String
Indicates whether or not this packet mirroring takes effect.
If set to FALSE, this packet mirroring policy will not be enforced on the
network.
The default is TRUE.
Corresponds to the JSON property enable
46500 46501 46502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46500 def enable @enable end |
#filter ⇒ Google::Apis::ComputeBeta::PacketMirroringFilter
Filter for mirrored traffic. If unspecified, all IPv4 traffic is mirrored.
Corresponds to the JSON property filter
46505 46506 46507 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46505 def filter @filter end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
46512 46513 46514 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46512 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#packetMirroring
for packet mirrorings.
Corresponds to the JSON property kind
46518 46519 46520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46518 def kind @kind end |
#mirrored_resources ⇒ Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos.
MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks
and/or tags for which traffic from/to all VM instances will be mirrored.
Corresponds to the JSON property mirroredResources
46525 46526 46527 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46525 def mirrored_resources @mirrored_resources end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
46536 46537 46538 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46536 def name @name end |
#network ⇒ Google::Apis::ComputeBeta::PacketMirroringNetworkInfo
Specifies the mirrored VPC network. Only packets in this network will be
mirrored. All mirrored VMs should have a NIC in the given network.
All mirrored subnetworks should belong to the given network.
Corresponds to the JSON property network
46543 46544 46545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46543 def network @network end |
#priority ⇒ Fixnum
The priority of applying this configuration. Priority is used to break ties
in cases where there is more than one matching rule. In the case of two
rules that apply for a given Instance, the one with the lowest-numbered
priority value wins.
Default value is 1000. Valid range is 0 through 65535.
Corresponds to the JSON property priority
46552 46553 46554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46552 def priority @priority end |
#region ⇒ String
[Output Only] URI of the region where the packetMirroring resides.
Corresponds to the JSON property region
46557 46558 46559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46557 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
46562 46563 46564 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46562 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46569 46570 46571 46572 46573 46574 46575 46576 46577 46578 46579 46580 46581 46582 46583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46569 def update!(**args) @collector_ilb = args[:collector_ilb] if args.key?(:collector_ilb) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable = args[:enable] if args.key?(:enable) @filter = args[:filter] if args.key?(:filter) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @mirrored_resources = args[:mirrored_resources] if args.key?(:mirrored_resources) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @priority = args[:priority] if args.key?(:priority) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |