Class: Google::Apis::ComputeBeta::PacketMirroring
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroring
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Packet Mirroring resource. Packet Mirroring clones the traffic of specified instances in your Virtual Private Cloud (VPC) network and forwards it to a collector destination, such as an instance group of an internal TCP/UDP load balancer, for analysis or examination. For more information about setting up Packet Mirroring, seeUsing Packet Mirroring.
Instance Attribute Summary collapse
-
#collector_ilb ⇒ Google::Apis::ComputeBeta::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be used as collector for mirrored traffic.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#enable ⇒ String
Indicates whether or not this packet mirroring takes effect.
-
#filter ⇒ Google::Apis::ComputeBeta::PacketMirroringFilter
Filter for mirrored traffic.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#mirrored_resources ⇒ Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos.
-
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
-
#network ⇒ Google::Apis::ComputeBeta::PacketMirroringNetworkInfo
Specifies the mirrored VPC network.
-
#priority ⇒ Fixnum
The priority of applying this configuration.
-
#region ⇒ String
[Output Only] URI of the region where the packetMirroring resides.
-
#self_link ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroring
constructor
A new instance of PacketMirroring.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroring
Returns a new instance of PacketMirroring.
45814 45815 45816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45814 def initialize(**args) update!(**args) end |
Instance Attribute Details
#collector_ilb ⇒ Google::Apis::ComputeBeta::PacketMirroringForwardingRuleInfo
The Forwarding Rule resource of typeloadBalancingScheme=INTERNAL that will be
used as collector
for mirrored traffic.
The specified forwarding rule must have isMirroringCollector
set to true.
Corresponds to the JSON property collectorIlb
45730 45731 45732 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45730 def collector_ilb @collector_ilb end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
45736 45737 45738 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45736 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
45742 45743 45744 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45742 def description @description end |
#enable ⇒ String
Indicates whether or not this packet mirroring takes effect.
If set to FALSE, this packet mirroring policy will not be enforced on the
network.
The default is TRUE.
Corresponds to the JSON property enable
45750 45751 45752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45750 def enable @enable end |
#filter ⇒ Google::Apis::ComputeBeta::PacketMirroringFilter
Filter for mirrored traffic. If unspecified, all IPv4 traffic is mirrored.
Corresponds to the JSON property filter
45755 45756 45757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45755 def filter @filter end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
45762 45763 45764 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45762 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#packetMirroring
for packet mirrorings.
Corresponds to the JSON property kind
45768 45769 45770 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45768 def kind @kind end |
#mirrored_resources ⇒ Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
PacketMirroring mirroredResourceInfos.
MirroredResourceInfo specifies a set of mirrored VM instances, subnetworks
and/or tags for which traffic from/to all VM instances will be mirrored.
Corresponds to the JSON property mirroredResources
45775 45776 45777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45775 def mirrored_resources @mirrored_resources end |
#name ⇒ String
Name of the resource; provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
45786 45787 45788 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45786 def name @name end |
#network ⇒ Google::Apis::ComputeBeta::PacketMirroringNetworkInfo
Specifies the mirrored VPC network. Only packets in this network will be
mirrored. All mirrored VMs should have a NIC in the given network.
All mirrored subnetworks should belong to the given network.
Corresponds to the JSON property network
45793 45794 45795 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45793 def network @network end |
#priority ⇒ Fixnum
The priority of applying this configuration. Priority is used to break ties
in cases where there is more than one matching rule. In the case of two
rules that apply for a given Instance, the one with the lowest-numbered
priority value wins.
Default value is 1000. Valid range is 0 through 65535.
Corresponds to the JSON property priority
45802 45803 45804 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45802 def priority @priority end |
#region ⇒ String
[Output Only] URI of the region where the packetMirroring resides.
Corresponds to the JSON property region
45807 45808 45809 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45807 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
45812 45813 45814 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45812 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45819 45820 45821 45822 45823 45824 45825 45826 45827 45828 45829 45830 45831 45832 45833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45819 def update!(**args) @collector_ilb = args[:collector_ilb] if args.key?(:collector_ilb) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable = args[:enable] if args.key?(:enable) @filter = args[:filter] if args.key?(:filter) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @mirrored_resources = args[:mirrored_resources] if args.key?(:mirrored_resources) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @priority = args[:priority] if args.key?(:priority) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |