Class: Google::Apis::ComputeBeta::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
46680 46681 46682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46643 46644 46645 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46643 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
46648 46649 46650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46648 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
46653 46654 46655 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46653 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46663 46664 46665 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46663 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46668 46669 46670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46668 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
46673 46674 46675 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46673 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46678 46679 46680 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46678 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46685 46686 46687 46688 46689 46690 46691 46692 46693 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46685 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |