Class: Google::Apis::ComputeBeta::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



46572
46573
46574
# File 'lib/google/apis/compute_beta/classes.rb', line 46572

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46535
46536
46537
# File 'lib/google/apis/compute_beta/classes.rb', line 46535

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



46540
46541
46542
# File 'lib/google/apis/compute_beta/classes.rb', line 46540

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


46545
46546
46547
# File 'lib/google/apis/compute_beta/classes.rb', line 46545

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46555
46556
46557
# File 'lib/google/apis/compute_beta/classes.rb', line 46555

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46560
46561
46562
# File 'lib/google/apis/compute_beta/classes.rb', line 46560

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46565
46566
46567
# File 'lib/google/apis/compute_beta/classes.rb', line 46565

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46570
46571
46572
# File 'lib/google/apis/compute_beta/classes.rb', line 46570

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46577
46578
46579
46580
46581
46582
46583
46584
46585
# File 'lib/google/apis/compute_beta/classes.rb', line 46577

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end