Class: Google::Apis::ComputeBeta::PacketMirroringAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroringAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of packetMirrorings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringAggregatedList
constructor
A new instance of PacketMirroringAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringAggregatedList
Returns a new instance of PacketMirroringAggregatedList.
46550 46551 46552 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46550 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46513 46514 46515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46513 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>
A list of PacketMirroring resources.
Corresponds to the JSON property items
46518 46519 46520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46518 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
46523 46524 46525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46523 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46533 46534 46535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46533 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46538 46539 46540 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46538 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
46543 46544 46545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46543 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46548 46549 46550 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46548 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46555 46556 46557 46558 46559 46560 46561 46562 46563 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46555 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |