Class: Google::Apis::ComputeBeta::PacketMirroringAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of packetMirrorings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringAggregatedList

Returns a new instance of PacketMirroringAggregatedList.



44039
44040
44041
# File 'lib/google/apis/compute_beta/classes.rb', line 44039

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44002
44003
44004
# File 'lib/google/apis/compute_beta/classes.rb', line 44002

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PacketMirroringsScopedList>

A list of PacketMirroring resources. Corresponds to the JSON property items



44007
44008
44009
# File 'lib/google/apis/compute_beta/classes.rb', line 44007

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


44012
44013
44014
# File 'lib/google/apis/compute_beta/classes.rb', line 44012

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44022
44023
44024
# File 'lib/google/apis/compute_beta/classes.rb', line 44022

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44027
44028
44029
# File 'lib/google/apis/compute_beta/classes.rb', line 44027

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44032
44033
44034
# File 'lib/google/apis/compute_beta/classes.rb', line 44032

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PacketMirroringAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44037
44038
44039
# File 'lib/google/apis/compute_beta/classes.rb', line 44037

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44044
44045
44046
44047
44048
44049
44050
44051
44052
# File 'lib/google/apis/compute_beta/classes.rb', line 44044

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end