Class: Google::Apis::ComputeBeta::PacketMirroringList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of PacketMirroring resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PacketMirroringList

Returns a new instance of PacketMirroringList.



46809
46810
46811
# File 'lib/google/apis/compute_beta/classes.rb', line 46809

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46776
46777
46778
# File 'lib/google/apis/compute_beta/classes.rb', line 46776

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PacketMirroring>

A list of PacketMirroring resources. Corresponds to the JSON property items



46781
46782
46783
# File 'lib/google/apis/compute_beta/classes.rb', line 46781

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#packetMirroring for packetMirrorings. Corresponds to the JSON property kind

Returns:

  • (String)


46787
46788
46789
# File 'lib/google/apis/compute_beta/classes.rb', line 46787

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46797
46798
46799
# File 'lib/google/apis/compute_beta/classes.rb', line 46797

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46802
46803
46804
# File 'lib/google/apis/compute_beta/classes.rb', line 46802

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PacketMirroringList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46807
46808
46809
# File 'lib/google/apis/compute_beta/classes.rb', line 46807

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46814
46815
46816
46817
46818
46819
46820
46821
# File 'lib/google/apis/compute_beta/classes.rb', line 46814

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end