Class: Google::Apis::ComputeBeta::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
46075 46076 46077 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46042 46043 46044 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46042 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
46047 46048 46049 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46047 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
46053 46054 46055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46053 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46063 46064 46065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46063 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46068 46069 46070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46068 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46073 46074 46075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46073 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46080 46081 46082 46083 46084 46085 46086 46087 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46080 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |