Class: Google::Apis::ComputeBeta::PacketMirroringList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroringList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of PacketMirroring resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PacketMirroring>
A list of PacketMirroring resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringList
constructor
A new instance of PacketMirroringList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringList
Returns a new instance of PacketMirroringList.
44234 44235 44236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44234 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
44201 44202 44203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44201 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PacketMirroring>
A list of PacketMirroring resources.
Corresponds to the JSON property items
44206 44207 44208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44206 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#packetMirroring
for packetMirrorings.
Corresponds to the JSON property kind
44212 44213 44214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44212 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
44222 44223 44224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44222 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
44227 44228 44229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44227 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PacketMirroringList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
44232 44233 44234 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44232 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44239 44240 44241 44242 44243 44244 44245 44246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44239 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |