Class: Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
-
#subnetworks ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be mirrored.
-
#tags ⇒ Array<String>
A set of mirrored tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
constructor
A new instance of PacketMirroringMirroredResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
Returns a new instance of PacketMirroringMirroredResourceInfo.
45405 45406 45407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45405 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
They must live in zones contained in the same region as this
packetMirroring.
Note that this config will apply only to those network interfaces of the
Instances that belong to the network specified in this packetMirroring.
You may specify a maximum of 50 Instances.
Corresponds to the JSON property instances
45390 45391 45392 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45390 def instances @instances end |
#subnetworks ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be
mirrored. They must live in the same region as this packetMirroring.
You may specify a maximum of 5 subnetworks.
Corresponds to the JSON property subnetworks
45397 45398 45399 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45397 def subnetworks @subnetworks end |
#tags ⇒ Array<String>
A set of mirrored tags. Traffic from/to all VM instances that have one or
more of these tags will be mirrored.
Corresponds to the JSON property tags
45403 45404 45405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45403 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
45410 45411 45412 45413 45414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 45410 def update!(**args) @instances = args[:instances] if args.key?(:instances) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @tags = args[:tags] if args.key?(:tags) end |