Class: Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#instances ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
-
#subnetworks ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be mirrored.
-
#tags ⇒ Array<String>
A set of mirrored tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
constructor
A new instance of PacketMirroringMirroredResourceInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PacketMirroringMirroredResourceInfo
Returns a new instance of PacketMirroringMirroredResourceInfo.
44346 44347 44348 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#instances ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoInstanceInfo>
A set of virtual machine instances that are being mirrored.
They must live in zones contained in the same region as this
packetMirroring.
Note that this config will apply only to those network interfaces of the
Instances that belong to the network specified in this packetMirroring.
You may specify a maximum of 50 Instances.
Corresponds to the JSON property instances
44331 44332 44333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44331 def instances @instances end |
#subnetworks ⇒ Array<Google::Apis::ComputeBeta::PacketMirroringMirroredResourceInfoSubnetInfo>
A set of subnetworks for which traffic from/to all VM instances will be
mirrored. They must live in the same region as this packetMirroring.
You may specify a maximum of 5 subnetworks.
Corresponds to the JSON property subnetworks
44338 44339 44340 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44338 def subnetworks @subnetworks end |
#tags ⇒ Array<String>
A set of mirrored tags. Traffic from/to all VM instances that have one or
more of these tags will be mirrored.
Corresponds to the JSON property tags
44344 44345 44346 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44344 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
44351 44352 44353 44354 44355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 44351 def update!(**args) @instances = args[:instances] if args.key?(:instances) @subnetworks = args[:subnetworks] if args.key?(:subnetworks) @tags = args[:tags] if args.key?(:tags) end |