Class: Google::Apis::ComputeBeta::PartnerMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Model definition of partner_metadata field. To be used in dedicated Partner Metadata methods and to be inlined in the Instance and InstanceTemplate resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PartnerMetadata

Returns a new instance of PartnerMetadata.



46398
46399
46400
# File 'lib/google/apis/compute_beta/classes.rb', line 46398

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Instance-level hash to be used for optimistic locking. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


46387
46388
46389
# File 'lib/google/apis/compute_beta/classes.rb', line 46387

def fingerprint
  @fingerprint
end

#partner_metadataHash<String,Google::Apis::ComputeBeta::StructuredEntries>

Partner Metadata assigned to the instance. A map from a subdomain to entries map. Subdomain name must be compliant withRFC1035 definition. The total size of all keys and values must be less than 2MB. Subdomain 'metadata.compute.googleapis.com' is reserverd for instance's metadata. Corresponds to the JSON property partnerMetadata



46396
46397
46398
# File 'lib/google/apis/compute_beta/classes.rb', line 46396

def 
  @partner_metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46403
46404
46405
46406
# File 'lib/google/apis/compute_beta/classes.rb', line 46403

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata)
end