Class: Google::Apis::ComputeBeta::PartnerMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PartnerMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Model definition of partner_metadata field. To be used in dedicated Partner Metadata methods and to be inlined in the Instance and InstanceTemplate resources.
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
Instance-level hash to be used for optimistic locking.
-
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeBeta::StructuredEntries>
Partner Metadata assigned to the instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PartnerMetadata
constructor
A new instance of PartnerMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PartnerMetadata
Returns a new instance of PartnerMetadata.
43169 43170 43171 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43169 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
Instance-level hash to be used for optimistic
locking.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
43158 43159 43160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43158 def fingerprint @fingerprint end |
#partner_metadata ⇒ Hash<String,Google::Apis::ComputeBeta::StructuredEntries>
Partner Metadata assigned to the instance. A map from a subdomain to
entries map. Subdomain name must be compliant withRFC1035
definition. The total size of all keys and values must be less than 2MB.
Subdomain 'metadata.compute.googleapis.com' is reserverd for instance's
metadata.
Corresponds to the JSON property partnerMetadata
43167 43168 43169 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43167 def @partner_metadata end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43174 43175 43176 43177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43174 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @partner_metadata = args[:partner_metadata] if args.key?(:partner_metadata) end |