Class: Google::Apis::ComputeBeta::PathMatcher
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PathMatcher
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A matcher for the path portion of the URL. The BackendService from the longest-matched rule will serve the URL. If no rule was matched, the default service is used.
Instance Attribute Summary collapse
-
#default_custom_error_response_policy ⇒ Google::Apis::ComputeBeta::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
-
#default_route_action ⇒ Google::Apis::ComputeBeta::HttpRouteAction
defaultRouteAction takes effect when none of the pathRules or routeRules match.
-
#default_service ⇒ String
The full or partial URL to the BackendService resource.
-
#default_url_redirect ⇒ Google::Apis::ComputeBeta::HttpRedirectAction
Specifies settings for an HTTP redirect.
-
#description ⇒ String
An optional description of this resource.
-
#header_action ⇒ Google::Apis::ComputeBeta::HttpHeaderAction
The request and response header transformations that take effect before the request is passed along to the selected backendService.
-
#name ⇒ String
The name to which this PathMatcher is referred by theHostRule.
-
#path_rules ⇒ Array<Google::Apis::ComputeBeta::PathRule>
The list of path rules.
-
#route_rules ⇒ Array<Google::Apis::ComputeBeta::HttpRouteRule>
The list of HTTP route rules.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PathMatcher
constructor
A new instance of PathMatcher.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PathMatcher
Returns a new instance of PathMatcher.
46565 46566 46567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46565 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_custom_error_response_policy ⇒ Google::Apis::ComputeBeta::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the
backend service or backend bucket responds with an error.
Corresponds to the JSON property defaultCustomErrorResponsePolicy
46478 46479 46480 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46478 def default_custom_error_response_policy @default_custom_error_response_policy end |
#default_route_action ⇒ Google::Apis::ComputeBeta::HttpRouteAction
defaultRouteAction takes effect when none of the
pathRules or routeRules match. The load balancer
performs advanced routing actions, such as URL rewrites and
header transformations, before forwarding the request to the
selected backend.
Only one of defaultUrlRedirect, defaultService
or defaultRouteAction.weightedBackendService can be set.
URL maps for classic Application Load Balancers only support
the urlRewrite action within a path matcher'sdefaultRouteAction.
Corresponds to the JSON property defaultRouteAction
46491 46492 46493 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46491 def default_route_action @default_route_action end |
#default_service ⇒ String
The full or partial URL to the BackendService resource. This URL is used if none of the pathRules orrouteRules defined by this PathMatcher are matched. For example, the following are all valid URLs to a BackendService resource:
- https://www.googleapis.com/compute/v1/projects/project/global/ backendServices/backendService
- compute/v1/projects/project/global/backendServices/backendService
global/backendServices/backendService If defaultRouteAction is also specified, advanced routing actions, such as URL rewrites, take effect before sending the request to the backend. Only one of defaultUrlRedirect, defaultService or defaultRouteAction.weightedBackendService can be set. Authorization requires one or more of the following Google IAM permissions on the specified resource default_service:
compute.backendBuckets.use
compute.backendServices.use Corresponds to the JSON property
defaultService
46518 46519 46520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46518 def default_service @default_service end |
#default_url_redirect ⇒ Google::Apis::ComputeBeta::HttpRedirectAction
Specifies settings for an HTTP redirect.
Corresponds to the JSON property defaultUrlRedirect
46523 46524 46525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46523 def default_url_redirect @default_url_redirect end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
46529 46530 46531 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46529 def description @description end |
#header_action ⇒ Google::Apis::ComputeBeta::HttpHeaderAction
The request and response header transformations that take effect before
the request is passed along to the selected backendService.
Corresponds to the JSON property headerAction
46535 46536 46537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46535 def header_action @header_action end |
#name ⇒ String
The name to which this PathMatcher is referred by theHostRule.
Corresponds to the JSON property name
46540 46541 46542 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46540 def name @name end |
#path_rules ⇒ Array<Google::Apis::ComputeBeta::PathRule>
The list of path rules. Use this list instead of routeRules
when routing based on simple path matching is all that's required. A path
rule can only include a wildcard character () after a
forward slash character ("/").
The order by which path rules are specified does not matter.
Matches are always done on the longest-path-first basis.
For example: a pathRule with a path /a/b/c/ will match
before /a/b/* irrespective of the order in which those paths appear in this
list.
Within a given pathMatcher, only one ofpathRules or routeRules must be set.
Corresponds to the JSON property pathRules
46554 46555 46556 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46554 def path_rules @path_rules end |
#route_rules ⇒ Array<Google::Apis::ComputeBeta::HttpRouteRule>
The list of HTTP route rules. Use this list instead ofpathRules when advanced
route matching and routing actions are
desired. routeRules are evaluated in order of priority, from
the lowest to highest number.
Within a given pathMatcher, you can set only one ofpathRules or routeRules.
Corresponds to the JSON property routeRules
46563 46564 46565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46563 def route_rules @route_rules end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46570 46571 46572 46573 46574 46575 46576 46577 46578 46579 46580 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46570 def update!(**args) @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy) @default_route_action = args[:default_route_action] if args.key?(:default_route_action) @default_service = args[:default_service] if args.key?(:default_service) @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect) @description = args[:description] if args.key?(:description) @header_action = args[:header_action] if args.key?(:header_action) @name = args[:name] if args.key?(:name) @path_rules = args[:path_rules] if args.key?(:path_rules) @route_rules = args[:route_rules] if args.key?(:route_rules) end |