Class: Google::Apis::ComputeBeta::PathRule
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PathRule
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A path-matching rule for a URL. If matched, will use the specifiedBackendService to handle the traffic arriving at this URL.
Instance Attribute Summary collapse
-
#custom_error_response_policy ⇒ Google::Apis::ComputeBeta::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
-
#paths ⇒ Array<String>
The list of path patterns to match.
-
#route_action ⇒ Google::Apis::ComputeBeta::HttpRouteAction
In response to a matching path, the load balancer performs advanced routing actions, such as URL rewrites and header transformations, before forwarding the request to the selected backend.
-
#service ⇒ String
The full or partial URL of the backend service resource to which traffic is directed if this rule is matched.
-
#url_redirect ⇒ Google::Apis::ComputeBeta::HttpRedirectAction
Specifies settings for an HTTP redirect.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PathRule
constructor
A new instance of PathRule.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PathRule
Returns a new instance of PathRule.
47263 47264 47265 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47263 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_error_response_policy ⇒ Google::Apis::ComputeBeta::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the
backend service or backend bucket responds with an error.
Corresponds to the JSON property customErrorResponsePolicy
47225 47226 47227 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47225 def custom_error_response_policy @custom_error_response_policy end |
#paths ⇒ Array<String>
The list of path patterns to match. Each must start with /
and the only place a * is allowed is at the end following
a /. The string fed to the path matcher does not include
any text after the first ? or #, and
those chars are not allowed here.
Corresponds to the JSON property paths
47234 47235 47236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47234 def paths @paths end |
#route_action ⇒ Google::Apis::ComputeBeta::HttpRouteAction
In response to a matching path, the load balancer
performs advanced routing actions, such as URL rewrites and header
transformations, before forwarding the request to the selected
backend.
Only one of urlRedirect, service orrouteAction.weightedBackendService can be
set.
URL maps for classic Application Load Balancers only support
the urlRewrite action within a path rule'srouteAction.
Corresponds to the JSON property routeAction
47246 47247 47248 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47246 def route_action @route_action end |
#service ⇒ String
The full or partial URL of the backend service resource to which traffic
is directed if this rule is matched. If routeAction is
also specified, advanced routing actions, such as URL rewrites,
take effect before sending the request to the backend.
Only one of urlRedirect, service orrouteAction.weightedBackendService can be
set.
Corresponds to the JSON property service
47256 47257 47258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47256 def service @service end |
#url_redirect ⇒ Google::Apis::ComputeBeta::HttpRedirectAction
Specifies settings for an HTTP redirect.
Corresponds to the JSON property urlRedirect
47261 47262 47263 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47261 def url_redirect @url_redirect end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47268 47269 47270 47271 47272 47273 47274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47268 def update!(**args) @custom_error_response_policy = args[:custom_error_response_policy] if args.key?(:custom_error_response_policy) @paths = args[:paths] if args.key?(:paths) @route_action = args[:route_action] if args.key?(:route_action) @service = args[:service] if args.key?(:service) @url_redirect = args[:url_redirect] if args.key?(:url_redirect) end |