Class: Google::Apis::ComputeBeta::PeriodicPartialMaintenanceSchedule

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The periodic partial maintenance schedule includes 52 weeks worth of maintenance windows. LINT.IfChange(PeriodicPartialMaintenanceSchedule)

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PeriodicPartialMaintenanceSchedule

Returns a new instance of PeriodicPartialMaintenanceSchedule.



47369
47370
47371
# File 'lib/google/apis/compute_beta/classes.rb', line 47369

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#sub_typeString

The maintenance type in which the zone is during the given window. Corresponds to the JSON property subType

Returns:

  • (String)


47312
47313
47314
# File 'lib/google/apis/compute_beta/classes.rb', line 47312

def sub_type
  @sub_type
end

#target_resourceString

The target resource that the maintenance window is for. For example, "projects/my-project/zones/us-central1-a". Corresponds to the JSON property targetResource

Returns:

  • (String)


47318
47319
47320
# File 'lib/google/apis/compute_beta/classes.rb', line 47318

def target_resource
  @target_resource
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


47323
47324
47325
# File 'lib/google/apis/compute_beta/classes.rb', line 47323

def type
  @type
end

#window_end_timeGoogle::Apis::ComputeBeta::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:

  • When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
  • When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
  • When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property windowEndTime


47345
47346
47347
# File 'lib/google/apis/compute_beta/classes.rb', line 47345

def window_end_time
  @window_end_time
end

#window_start_timeGoogle::Apis::ComputeBeta::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways:

  • When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC.
  • When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone.
  • When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property windowStartTime


47367
47368
47369
# File 'lib/google/apis/compute_beta/classes.rb', line 47367

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47374
47375
47376
47377
47378
47379
47380
# File 'lib/google/apis/compute_beta/classes.rb', line 47374

def update!(**args)
  @sub_type = args[:sub_type] if args.key?(:sub_type)
  @target_resource = args[:target_resource] if args.key?(:target_resource)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end