Class: Google::Apis::ComputeBeta::PreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Preserved state for a given instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreservedState

Returns a new instance of PreservedState.



43588
43589
43590
# File 'lib/google/apis/compute_beta/classes.rb', line 43588

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeBeta::PreservedStatePreservedDisk>

Preserved disks defined for this instance. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



43569
43570
43571
# File 'lib/google/apis/compute_beta/classes.rb', line 43569

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIp>

Preserved external IPs defined for this instance. This map is keyed with the name of the network interface. Corresponds to the JSON property externalIPs



43575
43576
43577
# File 'lib/google/apis/compute_beta/classes.rb', line 43575

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIp>

Preserved internal IPs defined for this instance. This map is keyed with the name of the network interface. Corresponds to the JSON property internalIPs



43581
43582
43583
# File 'lib/google/apis/compute_beta/classes.rb', line 43581

def internal_i_ps
  @internal_i_ps
end

#metadataHash<String,String>

Preserved metadata defined for this instance. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


43586
43587
43588
# File 'lib/google/apis/compute_beta/classes.rb', line 43586

def 
  @metadata
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43593
43594
43595
43596
43597
43598
# File 'lib/google/apis/compute_beta/classes.rb', line 43593

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
  @metadata = args[:metadata] if args.key?(:metadata)
end