Class: Google::Apis::ComputeBeta::PreservedStatePreservedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreservedStatePreservedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing, update, instance recreate operations.
-
#mode ⇒ String
The mode in which to attach this disk, either READ_WRITE orREAD_ONLY.
-
#source ⇒ String
The URL of the disk resource that is stateful and should be attached to the VM instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedDisk
constructor
A new instance of PreservedStatePreservedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedDisk
Returns a new instance of PreservedStatePreservedDisk.
47719 47720 47721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47719 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing,
update, instance recreate operations. This flag is used to configure
if the disk should be deleted after it is no longer used by the group,
e.g. when the given instance or the whole MIG is deleted.
Note: disks attached in READ_ONLY mode cannot be
auto-deleted.
Corresponds to the JSON property autoDelete
47704 47705 47706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47704 def auto_delete @auto_delete end |
#mode ⇒ String
The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not
specified, the default is to attach the
disk in READ_WRITE mode.
Corresponds to the JSON property mode
47711 47712 47713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47711 def mode @mode end |
#source ⇒ String
The URL of the disk resource that is stateful and should be attached
to the VM instance.
Corresponds to the JSON property source
47717 47718 47719 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47717 def source @source end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47724 47725 47726 47727 47728 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47724 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @mode = args[:mode] if args.key?(:mode) @source = args[:source] if args.key?(:source) end |