Class: Google::Apis::ComputeBeta::PreservedStatePreservedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreservedStatePreservedDisk

Returns a new instance of PreservedStatePreservedDisk.



43628
43629
43630
# File 'lib/google/apis/compute_beta/classes.rb', line 43628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteString

These stateful disks will never be deleted during autohealing, update, instance recreate operations. This flag is used to configure if the disk should be deleted after it is no longer used by the group, e.g. when the given instance or the whole MIG is deleted. Note: disks attached in READ_ONLY mode cannot be auto-deleted. Corresponds to the JSON property autoDelete

Returns:

  • (String)


43613
43614
43615
# File 'lib/google/apis/compute_beta/classes.rb', line 43613

def auto_delete
  @auto_delete
end

#modeString

The mode in which to attach this disk, either READ_WRITE orREAD_ONLY. If not specified, the default is to attach the disk in READ_WRITE mode. Corresponds to the JSON property mode

Returns:

  • (String)


43620
43621
43622
# File 'lib/google/apis/compute_beta/classes.rb', line 43620

def mode
  @mode
end

#sourceString

The URL of the disk resource that is stateful and should be attached to the VM instance. Corresponds to the JSON property source

Returns:

  • (String)


43626
43627
43628
# File 'lib/google/apis/compute_beta/classes.rb', line 43626

def source
  @source
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



43633
43634
43635
43636
43637
# File 'lib/google/apis/compute_beta/classes.rb', line 43633

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
end