Class: Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
-
#ip_address ⇒ Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIpIpAddress
Ip address representation Corresponds to the JSON property
ipAddress.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
constructor
A new instance of PreservedStatePreservedNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreservedStatePreservedNetworkIp
Returns a new instance of PreservedStatePreservedNetworkIp.
46946 46947 46948 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46946 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
46939 46940 46941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46939 def auto_delete @auto_delete end |
#ip_address ⇒ Google::Apis::ComputeBeta::PreservedStatePreservedNetworkIpIpAddress
Ip address representation
Corresponds to the JSON property ipAddress
46944 46945 46946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46944 def ip_address @ip_address end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46951 46952 46953 46954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46951 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) @ip_address = args[:ip_address] if args.key?(:ip_address) end |