Class: Google::Apis::ComputeBeta::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
47887 47888 47889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47887 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
47849 47850 47851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47849 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47854 47855 47856 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47854 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
47859 47860 47861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47859 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47869 47870 47871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47869 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47874 47875 47876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47874 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
47880 47881 47882 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47880 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47885 47886 47887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47885 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47892 47893 47894 47895 47896 47897 47898 47899 47900 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47892 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |