Class: Google::Apis::ComputeBeta::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
47813 47814 47815 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47813 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
47775 47776 47777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47775 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47780 47781 47782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47780 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
47785 47786 47787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47785 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47795 47796 47797 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47795 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47800 47801 47802 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47800 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
47806 47807 47808 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47806 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47811 47812 47813 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47811 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47818 47819 47820 47821 47822 47823 47824 47825 47826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47818 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |