Class: Google::Apis::ComputeBeta::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
47100 47101 47102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47100 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
47062 47063 47064 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47062 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47067 47068 47069 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47067 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
47072 47073 47074 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47072 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47082 47083 47084 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47082 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47087 47088 47089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47087 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
47093 47094 47095 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47093 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47098 47099 47100 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47098 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47105 47106 47107 47108 47109 47110 47111 47112 47113 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47105 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |