Class: Google::Apis::ComputeBeta::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



47041
47042
47043
# File 'lib/google/apis/compute_beta/classes.rb', line 47041

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


47003
47004
47005
# File 'lib/google/apis/compute_beta/classes.rb', line 47003

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47008
47009
47010
# File 'lib/google/apis/compute_beta/classes.rb', line 47008

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



47013
47014
47015
# File 'lib/google/apis/compute_beta/classes.rb', line 47013

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47023
47024
47025
# File 'lib/google/apis/compute_beta/classes.rb', line 47023

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47028
47029
47030
# File 'lib/google/apis/compute_beta/classes.rb', line 47028

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47034
47035
47036
# File 'lib/google/apis/compute_beta/classes.rb', line 47034

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47039
47040
47041
# File 'lib/google/apis/compute_beta/classes.rb', line 47039

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47046
47047
47048
47049
47050
47051
47052
47053
47054
# File 'lib/google/apis/compute_beta/classes.rb', line 47046

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end