Class: Google::Apis::ComputeBeta::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
46259 46260 46261 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
46221 46222 46223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46221 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46226 46227 46228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46226 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
46231 46232 46233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46231 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46241 46242 46243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46241 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46246 46247 46248 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46246 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
46252 46253 46254 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46252 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46257 46258 46259 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46257 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46264 46265 46266 46267 46268 46269 46270 46271 46272 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46264 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |