Class: Google::Apis::ComputeBeta::PreviewFeatureList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureList

Returns a new instance of PreviewFeatureList.



45200
45201
45202
# File 'lib/google/apis/compute_beta/classes.rb', line 45200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


45162
45163
45164
# File 'lib/google/apis/compute_beta/classes.rb', line 45162

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45167
45168
45169
# File 'lib/google/apis/compute_beta/classes.rb', line 45167

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PreviewFeature>

A list of PreviewFeature resources. Corresponds to the JSON property items



45172
45173
45174
# File 'lib/google/apis/compute_beta/classes.rb', line 45172

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45182
45183
45184
# File 'lib/google/apis/compute_beta/classes.rb', line 45182

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45187
45188
45189
# File 'lib/google/apis/compute_beta/classes.rb', line 45187

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


45193
45194
45195
# File 'lib/google/apis/compute_beta/classes.rb', line 45193

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PreviewFeatureList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



45198
45199
45200
# File 'lib/google/apis/compute_beta/classes.rb', line 45198

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45205
45206
45207
45208
45209
45210
45211
45212
45213
# File 'lib/google/apis/compute_beta/classes.rb', line 45205

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end