Class: Google::Apis::ComputeBeta::PreviewFeatureList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreviewFeatureList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureList
constructor
A new instance of PreviewFeatureList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureList
Returns a new instance of PreviewFeatureList.
43812 43813 43814 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43812 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
43774 43775 43776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43774 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
43779 43780 43781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43779 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PreviewFeature>
A list of PreviewFeature resources.
Corresponds to the JSON property items
43784 43785 43786 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43784 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
43794 43795 43796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43794 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
43799 43800 43801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43799 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
43805 43806 43807 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43805 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PreviewFeatureList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
43810 43811 43812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43810 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
43817 43818 43819 43820 43821 43822 43823 43824 43825 |
# File 'lib/google/apis/compute_beta/classes.rb', line 43817 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |