Class: Google::Apis::ComputeBeta::PreviewFeatureStatusReleaseStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PreviewFeatureStatusReleaseStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] The release status of the feature.
Instance Attribute Summary collapse
-
#stage ⇒ String
Output only.
-
#update_date ⇒ Google::Apis::ComputeBeta::Date
Represents a whole or partial calendar date, such as a birthday.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus
constructor
A new instance of PreviewFeatureStatusReleaseStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus
Returns a new instance of PreviewFeatureStatusReleaseStatus.
46452 46453 46454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#stage ⇒ String
Output only. [Output Only] The stage of the feature.
Corresponds to the JSON property stage
46433 46434 46435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46433 def stage @stage end |
#update_date ⇒ Google::Apis::ComputeBeta::Date
Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:
- A full date, with non-zero year, month, and day values.
- A month and day, with a zero year (for example, an anniversary).
- A year on its own, with a zero month and a zero day.
- A year and month, with a zero day (for example, a credit card expiration date). Related types:
- google.type.TimeOfDay
- google.type.DateTime
- google.protobuf.Timestamp
Corresponds to the JSON property
updateDate
46450 46451 46452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46450 def update_date @update_date end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46457 46458 46459 46460 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46457 def update!(**args) @stage = args[:stage] if args.key?(:stage) @update_date = args[:update_date] if args.key?(:update_date) end |