Class: Google::Apis::ComputeBeta::PreviewFeatureStatusReleaseStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] The release status of the feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreviewFeatureStatusReleaseStatus

Returns a new instance of PreviewFeatureStatusReleaseStatus.



44005
44006
44007
# File 'lib/google/apis/compute_beta/classes.rb', line 44005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stageString

Output only. [Output Only] The stage of the feature. Corresponds to the JSON property stage

Returns:

  • (String)


43986
43987
43988
# File 'lib/google/apis/compute_beta/classes.rb', line 43986

def stage
  @stage
end

#update_dateGoogle::Apis::ComputeBeta::Date

Represents a whole or partial calendar date, such as a birthday. The time of day and time zone are either specified elsewhere or are insignificant. The date is relative to the Gregorian Calendar. This can represent one of the following:

  • A full date, with non-zero year, month, and day values.
  • A month and day, with a zero year (for example, an anniversary).
  • A year on its own, with a zero month and a zero day.
  • A year and month, with a zero day (for example, a credit card expiration date). Related types:
  • google.type.TimeOfDay
  • google.type.DateTime
  • google.protobuf.Timestamp Corresponds to the JSON property updateDate


44003
44004
44005
# File 'lib/google/apis/compute_beta/classes.rb', line 44003

def update_date
  @update_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44010
44011
44012
44013
# File 'lib/google/apis/compute_beta/classes.rb', line 44010

def update!(**args)
  @stage = args[:stage] if args.key?(:stage)
  @update_date = args[:update_date] if args.key?(:update_date)
end