Class: Google::Apis::ComputeBeta::Project

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Project

Returns a new instance of Project.



47350
47351
47352
# File 'lib/google/apis/compute_beta/classes.rb', line 47350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cloud_armor_tierString

Output only. [Output Only] The Cloud Armor tier for this project. It can be one of the following values: CA_STANDARD,CA_ENTERPRISE_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property cloudArmorTier

Returns:

  • (String)


47258
47259
47260
# File 'lib/google/apis/compute_beta/classes.rb', line 47258

def cloud_armor_tier
  @cloud_armor_tier
end

#common_instance_metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property commonInstanceMetadata



47263
47264
47265
# File 'lib/google/apis/compute_beta/classes.rb', line 47263

def 
  @common_instance_metadata
end

#creation_timestampString

[Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


47269
47270
47271
# File 'lib/google/apis/compute_beta/classes.rb', line 47269

def creation_timestamp
  @creation_timestamp
end

#default_network_tierString

This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD. Initially the default network tier is PREMIUM. Corresponds to the JSON property defaultNetworkTier

Returns:

  • (String)


47277
47278
47279
# File 'lib/google/apis/compute_beta/classes.rb', line 47277

def default_network_tier
  @default_network_tier
end

#default_service_accountString

[Output Only] Default service account used by VMs running in this project. Corresponds to the JSON property defaultServiceAccount

Returns:

  • (String)


47282
47283
47284
# File 'lib/google/apis/compute_beta/classes.rb', line 47282

def 
  @default_service_account
end

#descriptionString

An optional textual description of the resource. Corresponds to the JSON property description

Returns:

  • (String)


47287
47288
47289
# File 'lib/google/apis/compute_beta/classes.rb', line 47287

def description
  @description
end

#enabled_featuresArray<String>

An optional list of restricted features enabled for use on this project. Corresponds to the JSON property enabledFeatures

Returns:

  • (Array<String>)


47292
47293
47294
# File 'lib/google/apis/compute_beta/classes.rb', line 47292

def enabled_features
  @enabled_features
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. This is not the project ID, and is just a unique ID used by Compute Engine to identify resources. Corresponds to the JSON property id

Returns:

  • (Fixnum)


47299
47300
47301
# File 'lib/google/apis/compute_beta/classes.rb', line 47299

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#project for projects. Corresponds to the JSON property kind

Returns:

  • (String)


47305
47306
47307
# File 'lib/google/apis/compute_beta/classes.rb', line 47305

def kind
  @kind
end

#managed_protection_tierString

Output only. [Output Only] The Cloud Armor Managed Protection (CAMP) tier for this project. It can be one of the following values:CA_STANDARD, CAMP_PLUS_PAYGO. If this field is not specified, it is assumed to beCA_STANDARD. Corresponds to the JSON property managedProtectionTier

Returns:

  • (String)


47313
47314
47315
# File 'lib/google/apis/compute_beta/classes.rb', line 47313

def managed_protection_tier
  @managed_protection_tier
end

#nameString

The project ID. For example: my-example-project. Use the project ID to make requests to Compute Engine. Corresponds to the JSON property name

Returns:

  • (String)


47319
47320
47321
# File 'lib/google/apis/compute_beta/classes.rb', line 47319

def name
  @name
end

#quotasArray<Google::Apis::ComputeBeta::Quota>

[Output Only] Quotas assigned to this project. Corresponds to the JSON property quotas



47324
47325
47326
# File 'lib/google/apis/compute_beta/classes.rb', line 47324

def quotas
  @quotas
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47329
47330
47331
# File 'lib/google/apis/compute_beta/classes.rb', line 47329

def self_link
  @self_link
end

#usage_export_locationGoogle::Apis::ComputeBeta::UsageExportLocation

The location in Cloud Storage and naming method of the daily usage report. Contains bucket_name and report_name prefix. Corresponds to the JSON property usageExportLocation



47335
47336
47337
# File 'lib/google/apis/compute_beta/classes.rb', line 47335

def usage_export_location
  @usage_export_location
end

#vm_dns_settingString

Output only. [Output Only] Default internal DNS setting used by VMs running in this project. Corresponds to the JSON property vmDnsSetting

Returns:

  • (String)


47341
47342
47343
# File 'lib/google/apis/compute_beta/classes.rb', line 47341

def vm_dns_setting
  @vm_dns_setting
end

#xpn_project_statusString

[Output Only] The role this project has in a shared VPC configuration. Currently, only projects with the host role, which is specified by the value HOST, are differentiated. Corresponds to the JSON property xpnProjectStatus

Returns:

  • (String)


47348
47349
47350
# File 'lib/google/apis/compute_beta/classes.rb', line 47348

def xpn_project_status
  @xpn_project_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47355
47356
47357
47358
47359
47360
47361
47362
47363
47364
47365
47366
47367
47368
47369
47370
47371
47372
# File 'lib/google/apis/compute_beta/classes.rb', line 47355

def update!(**args)
  @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier)
  @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier)
  @default_service_account = args[:default_service_account] if args.key?(:default_service_account)
  @description = args[:description] if args.key?(:description)
  @enabled_features = args[:enabled_features] if args.key?(:enabled_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @managed_protection_tier = args[:managed_protection_tier] if args.key?(:managed_protection_tier)
  @name = args[:name] if args.key?(:name)
  @quotas = args[:quotas] if args.key?(:quotas)
  @self_link = args[:self_link] if args.key?(:self_link)
  @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location)
  @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting)
  @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status)
end