Class: Google::Apis::ComputeBeta::Project
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Project
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Project resource. A project is used to organize resources in a Google Cloud Platform environment. For more information, read about the Resource Hierarchy.
Instance Attribute Summary collapse
-
#cloud_armor_tier ⇒ String
Output only.
-
#common_instance_metadata ⇒ Google::Apis::ComputeBeta::Metadata
A metadata key/value entry.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of the project and can only take the following values:PREMIUM, STANDARD.
-
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
-
#description ⇒ String
An optional textual description of the resource.
-
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#managed_protection_tier ⇒ String
Output only.
-
#name ⇒ String
The project ID.
-
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this project.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#usage_export_location ⇒ Google::Apis::ComputeBeta::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage report.
-
#vm_dns_setting ⇒ String
Output only.
-
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Project
constructor
A new instance of Project.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Project
Returns a new instance of Project.
46568 46569 46570 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cloud_armor_tier ⇒ String
Output only. [Output Only] The Cloud Armor tier for this project. It can be
one of the
following values: CA_STANDARD,CA_ENTERPRISE_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property cloudArmorTier
46476 46477 46478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46476 def cloud_armor_tier @cloud_armor_tier end |
#common_instance_metadata ⇒ Google::Apis::ComputeBeta::Metadata
A metadata key/value entry.
Corresponds to the JSON property commonInstanceMetadata
46481 46482 46483 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46481 def @common_instance_metadata end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
46487 46488 46489 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46487 def @creation_timestamp end |
#default_network_tier ⇒ String
This signifies the default network tier used for configuring resources of
the project and can only take the following values:PREMIUM, STANDARD.
Initially the default network
tier is PREMIUM.
Corresponds to the JSON property defaultNetworkTier
46495 46496 46497 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46495 def default_network_tier @default_network_tier end |
#default_service_account ⇒ String
[Output Only] Default service account used by VMs running in this project.
Corresponds to the JSON property defaultServiceAccount
46500 46501 46502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46500 def default_service_account @default_service_account end |
#description ⇒ String
An optional textual description of the resource.
Corresponds to the JSON property description
46505 46506 46507 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46505 def description @description end |
#enabled_features ⇒ Array<String>
An optional list of restricted features enabled for use on this project.
Corresponds to the JSON property enabledFeatures
46510 46511 46512 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46510 def enabled_features @enabled_features end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server. This is not the project ID, and is
just a unique ID used by Compute Engine to identify resources.
Corresponds to the JSON property id
46517 46518 46519 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46517 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#project for
projects.
Corresponds to the JSON property kind
46523 46524 46525 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46523 def kind @kind end |
#managed_protection_tier ⇒ String
Output only. [Output Only] The Cloud Armor Managed Protection (CAMP) tier for
this project. It can be one of the following values:CA_STANDARD,
CAMP_PLUS_PAYGO.
If this field is not specified, it is assumed to beCA_STANDARD.
Corresponds to the JSON property managedProtectionTier
46531 46532 46533 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46531 def managed_protection_tier @managed_protection_tier end |
#name ⇒ String
The project ID. For example: my-example-project. Use the
project ID to make requests to Compute Engine.
Corresponds to the JSON property name
46537 46538 46539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46537 def name @name end |
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this project.
Corresponds to the JSON property quotas
46542 46543 46544 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46542 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
46547 46548 46549 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46547 def self_link @self_link end |
#usage_export_location ⇒ Google::Apis::ComputeBeta::UsageExportLocation
The location in Cloud Storage and naming method of the daily usage
report. Contains bucket_name and report_name prefix.
Corresponds to the JSON property usageExportLocation
46553 46554 46555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46553 def usage_export_location @usage_export_location end |
#vm_dns_setting ⇒ String
Output only. [Output Only] Default internal DNS setting used by VMs running in
this project.
Corresponds to the JSON property vmDnsSetting
46559 46560 46561 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46559 def vm_dns_setting @vm_dns_setting end |
#xpn_project_status ⇒ String
[Output Only] The role this project has in a shared VPC configuration.
Currently, only projects with the host role, which is specified by the
value HOST, are differentiated.
Corresponds to the JSON property xpnProjectStatus
46566 46567 46568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46566 def xpn_project_status @xpn_project_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46573 46574 46575 46576 46577 46578 46579 46580 46581 46582 46583 46584 46585 46586 46587 46588 46589 46590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46573 def update!(**args) @cloud_armor_tier = args[:cloud_armor_tier] if args.key?(:cloud_armor_tier) @common_instance_metadata = args[:common_instance_metadata] if args.key?(:common_instance_metadata) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_network_tier = args[:default_network_tier] if args.key?(:default_network_tier) @default_service_account = args[:default_service_account] if args.key?(:default_service_account) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @managed_protection_tier = args[:managed_protection_tier] if args.key?(:managed_protection_tier) @name = args[:name] if args.key?(:name) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @usage_export_location = args[:usage_export_location] if args.key?(:usage_export_location) @vm_dns_setting = args[:vm_dns_setting] if args.key?(:vm_dns_setting) @xpn_project_status = args[:xpn_project_status] if args.key?(:xpn_project_status) end |