Class: Google::Apis::ComputeBeta::ProjectsGetXpnResources

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsGetXpnResources

Returns a new instance of ProjectsGetXpnResources.



45600
45601
45602
# File 'lib/google/apis/compute_beta/classes.rb', line 45600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# projectsGetXpnResources for lists of service resources (a.k.a service projects) Corresponds to the JSON property kind

Returns:

  • (String)


45581
45582
45583
# File 'lib/google/apis/compute_beta/classes.rb', line 45581

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45592
45593
45594
# File 'lib/google/apis/compute_beta/classes.rb', line 45592

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::ComputeBeta::XpnResourceId>

Service resources (a.k.a service projects) attached to this project as their shared VPC host. Corresponds to the JSON property resources



45598
45599
45600
# File 'lib/google/apis/compute_beta/classes.rb', line 45598

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45605
45606
45607
45608
45609
# File 'lib/google/apis/compute_beta/classes.rb', line 45605

def update!(**args)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
end