Class: Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsListXpnHostsRequest

Returns a new instance of ProjectsListXpnHostsRequest.



48334
48335
48336
# File 'lib/google/apis/compute_beta/classes.rb', line 48334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#organizationString

Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project. Corresponds to the JSON property organization

Returns:

  • (String)


48332
48333
48334
# File 'lib/google/apis/compute_beta/classes.rb', line 48332

def organization
  @organization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48339
48340
48341
# File 'lib/google/apis/compute_beta/classes.rb', line 48339

def update!(**args)
  @organization = args[:organization] if args.key?(:organization)
end