Class: Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ProjectsListXpnHostsRequest

Returns a new instance of ProjectsListXpnHostsRequest.



48260
48261
48262
# File 'lib/google/apis/compute_beta/classes.rb', line 48260

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#organizationString

Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects. If not specified, the organization will be inferred from the project. Corresponds to the JSON property organization

Returns:

  • (String)


48258
48259
48260
# File 'lib/google/apis/compute_beta/classes.rb', line 48258

def organization
  @organization
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48265
48266
48267
# File 'lib/google/apis/compute_beta/classes.rb', line 48265

def update!(**args)
  @organization = args[:organization] if args.key?(:organization)
end