Class: Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ProjectsListXpnHostsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to list shared VPC host projects.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
constructor
A new instance of ProjectsListXpnHostsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProjectsListXpnHostsRequest
Returns a new instance of ProjectsListXpnHostsRequest.
46682 46683 46684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#organization ⇒ String
Optional organization ID managed by Cloud Resource Manager, for which to
list shared VPC host projects. If not specified, the organization will be
inferred from the project.
Corresponds to the JSON property organization
46680 46681 46682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46680 def organization @organization end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46687 46688 46689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46687 def update!(**args) @organization = args[:organization] if args.key?(:organization) end |