Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
49060 49061 49062 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49060 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49027 49028 49029 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49027 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
49032 49033 49034 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49032 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
49038 49039 49040 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49038 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49048 49049 49050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49048 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49053 49054 49055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49053 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49058 49059 49060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49058 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49065 49066 49067 49068 49069 49070 49071 49072 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49065 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |