Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
48588 48589 48590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48588 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48555 48556 48557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48555 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
48560 48561 48562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48560 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
48566 48567 48568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48566 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48576 48577 48578 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48576 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48581 48582 48583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48581 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48586 48587 48588 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48586 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48593 48594 48595 48596 48597 48598 48599 48600 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48593 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |