Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicAdvertisedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixList
constructor
A new instance of PublicAdvertisedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixList
Returns a new instance of PublicAdvertisedPrefixList.
48492 48493 48494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
48459 48460 48461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48459 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>
A list of PublicAdvertisedPrefix resources.
Corresponds to the JSON property items
48464 48465 48466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48464 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicAdvertisedPrefix for public advertised prefixes.
Corresponds to the JSON property kind
48470 48471 48472 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48470 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48480 48481 48482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48480 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48485 48486 48487 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48485 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48490 48491 48492 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48490 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48497 48498 48499 48500 48501 48502 48503 48504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48497 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |