Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



47777
47778
47779
# File 'lib/google/apis/compute_beta/classes.rb', line 47777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47744
47745
47746
# File 'lib/google/apis/compute_beta/classes.rb', line 47744

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



47749
47750
47751
# File 'lib/google/apis/compute_beta/classes.rb', line 47749

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


47755
47756
47757
# File 'lib/google/apis/compute_beta/classes.rb', line 47755

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47765
47766
47767
# File 'lib/google/apis/compute_beta/classes.rb', line 47765

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47770
47771
47772
# File 'lib/google/apis/compute_beta/classes.rb', line 47770

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47775
47776
47777
# File 'lib/google/apis/compute_beta/classes.rb', line 47775

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47782
47783
47784
47785
47786
47787
47788
47789
# File 'lib/google/apis/compute_beta/classes.rb', line 47782

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end