Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicAdvertisedPrefixList

Returns a new instance of PublicAdvertisedPrefixList.



44489
44490
44491
# File 'lib/google/apis/compute_beta/classes.rb', line 44489

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44456
44457
44458
# File 'lib/google/apis/compute_beta/classes.rb', line 44456

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PublicAdvertisedPrefix>

A list of PublicAdvertisedPrefix resources. Corresponds to the JSON property items



44461
44462
44463
# File 'lib/google/apis/compute_beta/classes.rb', line 44461

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicAdvertisedPrefix for public advertised prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


44467
44468
44469
# File 'lib/google/apis/compute_beta/classes.rb', line 44467

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44477
44478
44479
# File 'lib/google/apis/compute_beta/classes.rb', line 44477

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44482
44483
44484
# File 'lib/google/apis/compute_beta/classes.rb', line 44482

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PublicAdvertisedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44487
44488
44489
# File 'lib/google/apis/compute_beta/classes.rb', line 44487

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44494
44495
44496
44497
44498
44499
44500
44501
# File 'lib/google/apis/compute_beta/classes.rb', line 44494

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end