Class: Google::Apis::ComputeBeta::PublicAdvertisedPrefixPublicDelegatedPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicAdvertisedPrefixPublicDelegatedPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a CIDR range which can be used to assign addresses.
Instance Attribute Summary collapse
-
#ip_range ⇒ String
The IP address range of the public delegated prefix Corresponds to the JSON property
ipRange. -
#name ⇒ String
The name of the public delegated prefix Corresponds to the JSON property
name. -
#project ⇒ String
The project number of the public delegated prefix Corresponds to the JSON property
project. -
#region ⇒ String
The region of the public delegated prefix if it is regional.
-
#status ⇒ String
The status of the public delegated prefix.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix
constructor
A new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicAdvertisedPrefixPublicDelegatedPrefix
Returns a new instance of PublicAdvertisedPrefixPublicDelegatedPrefix.
47895 47896 47897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47895 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_range ⇒ String
The IP address range of the public delegated prefix
Corresponds to the JSON property ipRange
47869 47870 47871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47869 def ip_range @ip_range end |
#name ⇒ String
The name of the public delegated prefix
Corresponds to the JSON property name
47874 47875 47876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47874 def name @name end |
#project ⇒ String
The project number of the public delegated prefix
Corresponds to the JSON property project
47879 47880 47881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47879 def project @project end |
#region ⇒ String
The region of the public delegated prefix if it is regional. If absent,
the prefix is global.
Corresponds to the JSON property region
47885 47886 47887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47885 def region @region end |
#status ⇒ String
The status of the public delegated prefix. Possible values are:
INITIALIZING: The public delegated prefix is being initialized and
addresses cannot be created yet.
ANNOUNCED: The public delegated prefix is active.
Corresponds to the JSON property status
47893 47894 47895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47893 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47900 47901 47902 47903 47904 47905 47906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47900 def update!(**args) @ip_range = args[:ip_range] if args.key?(:ip_range) @name = args[:name] if args.key?(:name) @project = args[:project] if args.key?(:project) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |