Class: Google::Apis::ComputeBeta::PublicDelegatedPrefix

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A PublicDelegatedPrefix resource represents an IP block within a PublicAdvertisedPrefix that is configured within a single cloud scope (global or region). IPs in the block can be allocated to resources within that scope. Public delegated prefixes may be further broken up into smaller IP blocks in the same scope as the parent block.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefix

Returns a new instance of PublicDelegatedPrefix.



48813
48814
48815
# File 'lib/google/apis/compute_beta/classes.rb', line 48813

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocatable_prefix_lengthFixnum

The allocatable prefix length supported by this public delegated prefix. This field is optional and cannot be set for prefixes in DELEGATION mode. It cannot be set for IPv4 prefixes either, and it always defaults to 32. Corresponds to the JSON property allocatablePrefixLength

Returns:

  • (Fixnum)


48659
48660
48661
# File 'lib/google/apis/compute_beta/classes.rb', line 48659

def allocatable_prefix_length
  @allocatable_prefix_length
end

#byoip_api_versionString

Output only. [Output Only] The version of BYOIP API. Corresponds to the JSON property byoipApiVersion

Returns:

  • (String)


48664
48665
48666
# File 'lib/google/apis/compute_beta/classes.rb', line 48664

def byoip_api_version
  @byoip_api_version
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


48670
48671
48672
# File 'lib/google/apis/compute_beta/classes.rb', line 48670

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


48676
48677
48678
# File 'lib/google/apis/compute_beta/classes.rb', line 48676

def description
  @description
end

#enable_enhanced_ipv4_allocationBoolean Also known as: enable_enhanced_ipv4_allocation?

Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations. Applicable for IPv4 PDPs only. Corresponds to the JSON property enableEnhancedIpv4Allocation

Returns:

  • (Boolean)


48682
48683
48684
# File 'lib/google/apis/compute_beta/classes.rb', line 48682

def enable_enhanced_ipv4_allocation
  @enable_enhanced_ipv4_allocation
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a new PublicDelegatedPrefix. An up-to-date fingerprint must be provided in order to update thePublicDelegatedPrefix, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a PublicDelegatedPrefix. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


48696
48697
48698
# File 'lib/google/apis/compute_beta/classes.rb', line 48696

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


48703
48704
48705
# File 'lib/google/apis/compute_beta/classes.rb', line 48703

def id
  @id
end

#ip_cidr_rangeString

The IP address range, in CIDR format, represented by this public delegated prefix. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


48709
48710
48711
# File 'lib/google/apis/compute_beta/classes.rb', line 48709

def ip_cidr_range
  @ip_cidr_range
end

#ipv6_access_typeString

Output only. [Output Only] The internet access type for IPv6 Public Delegated Prefixes. Inherited from parent prefix. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


48716
48717
48718
# File 'lib/google/apis/compute_beta/classes.rb', line 48716

def ipv6_access_type
  @ipv6_access_type
end

#is_live_migrationBoolean Also known as: is_live_migration?

If true, the prefix will be live migrated. Corresponds to the JSON property isLiveMigration

Returns:

  • (Boolean)


48721
48722
48723
# File 'lib/google/apis/compute_beta/classes.rb', line 48721

def is_live_migration
  @is_live_migration
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefix for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


48728
48729
48730
# File 'lib/google/apis/compute_beta/classes.rb', line 48728

def kind
  @kind
end

#modeString

The public delegated prefix mode for IPv6 only. Corresponds to the JSON property mode

Returns:

  • (String)


48733
48734
48735
# File 'lib/google/apis/compute_beta/classes.rb', line 48733

def mode
  @mode
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


48744
48745
48746
# File 'lib/google/apis/compute_beta/classes.rb', line 48744

def name
  @name
end

#parent_prefixString

The URL of parent prefix. Either PublicAdvertisedPrefix or PublicDelegatedPrefix. Corresponds to the JSON property parentPrefix

Returns:

  • (String)


48750
48751
48752
# File 'lib/google/apis/compute_beta/classes.rb', line 48750

def parent_prefix
  @parent_prefix
end

#public_delegated_sub_prefixsArray<Google::Apis::ComputeBeta::PublicDelegatedPrefixPublicDelegatedSubPrefix>

The list of sub public delegated prefixes that exist for this public delegated prefix. Corresponds to the JSON property publicDelegatedSubPrefixs



48756
48757
48758
# File 'lib/google/apis/compute_beta/classes.rb', line 48756

def public_delegated_sub_prefixs
  @public_delegated_sub_prefixs
end

#purposeString

Immutable. The purpose of the public delegated prefix. This field can only be set for the top-level global public delegated prefix. It is an output-only field for the sub-delegates that inherit the value from the top-level global public delegated prefix. Once the value is set, it cannot be changed. The field cannot be set for regional public delegated prefixes. The supported values are:

  • APPLICATION_AND_PROXY_LOAD_BALANCERS: The global public delegated prefix can only be used by Global External Application and Proxy Load Balancers to allocate addresses for forwarding rules. This is the default value.
  • PASSTHROUGH_LOAD_BALANCER_AVAILABILITY_GROUP0: The global public delegated prefix can only be used by Global External Passthrough Network Load Balancers to allocate Availability Group 0 addresses for forwarding rules.
  • PASSTHROUGH_LOAD_BALANCER_AVAILABILITY_GROUP1: The global public delegated prefix can only be used by Global External Passthrough Network Load Balancers to allocate Availability Group 1 addresses for forwarding rules. Corresponds to the JSON property purpose

Returns:

  • (String)


48781
48782
48783
# File 'lib/google/apis/compute_beta/classes.rb', line 48781

def purpose
  @purpose
end

#regionString

Output only. [Output Only] URL of the region where the public delegated prefix resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


48790
48791
48792
# File 'lib/google/apis/compute_beta/classes.rb', line 48790

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48795
48796
48797
# File 'lib/google/apis/compute_beta/classes.rb', line 48795

def self_link
  @self_link
end

#statusString

[Output Only] The status of the public delegated prefix, which can be one of following values:

  • INITIALIZING The public delegated prefix is being initialized and addresses cannot be created yet.
  • READY_TO_ANNOUNCE The public delegated prefix is a live migration prefix and is active.
  • ANNOUNCED The public delegated prefix is announced and ready to use.
  • DELETING The public delegated prefix is being deprovsioned.
  • ACTIVE The public delegated prefix is ready to use. Corresponds to the JSON property status

Returns:

  • (String)


48811
48812
48813
# File 'lib/google/apis/compute_beta/classes.rb', line 48811

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48818
48819
48820
48821
48822
48823
48824
48825
48826
48827
48828
48829
48830
48831
48832
48833
48834
48835
48836
48837
48838
# File 'lib/google/apis/compute_beta/classes.rb', line 48818

def update!(**args)
  @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length)
  @byoip_api_version = args[:byoip_api_version] if args.key?(:byoip_api_version)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @is_live_migration = args[:is_live_migration] if args.key?(:is_live_migration)
  @kind = args[:kind] if args.key?(:kind)
  @mode = args[:mode] if args.key?(:mode)
  @name = args[:name] if args.key?(:name)
  @parent_prefix = args[:parent_prefix] if args.key?(:parent_prefix)
  @public_delegated_sub_prefixs = args[:public_delegated_sub_prefixs] if args.key?(:public_delegated_sub_prefixs)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @status = args[:status] if args.key?(:status)
end