Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
constructor
A new instance of PublicDelegatedPrefixAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList
Returns a new instance of PublicDelegatedPrefixAggregatedList.
49441 49442 49443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49441 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49402 49403 49404 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49402 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>
A list of PublicDelegatedPrefixesScopedList resources.
Corresponds to the JSON property items
49407 49408 49409 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49407 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixAggregatedList for aggregated
lists of public delegated prefixes.
Corresponds to the JSON property kind
49414 49415 49416 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49414 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49424 49425 49426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49424 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49429 49430 49431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49429 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
49434 49435 49436 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49434 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49439 49440 49441 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49439 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49446 49447 49448 49449 49450 49451 49452 49453 49454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49446 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |