Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



48887
48888
48889
# File 'lib/google/apis/compute_beta/classes.rb', line 48887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48848
48849
48850
# File 'lib/google/apis/compute_beta/classes.rb', line 48848

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



48853
48854
48855
# File 'lib/google/apis/compute_beta/classes.rb', line 48853

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


48860
48861
48862
# File 'lib/google/apis/compute_beta/classes.rb', line 48860

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48870
48871
48872
# File 'lib/google/apis/compute_beta/classes.rb', line 48870

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48875
48876
48877
# File 'lib/google/apis/compute_beta/classes.rb', line 48875

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48880
48881
48882
# File 'lib/google/apis/compute_beta/classes.rb', line 48880

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48885
48886
48887
# File 'lib/google/apis/compute_beta/classes.rb', line 48885

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48892
48893
48894
48895
48896
48897
48898
48899
48900
# File 'lib/google/apis/compute_beta/classes.rb', line 48892

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end