Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



48150
48151
48152
# File 'lib/google/apis/compute_beta/classes.rb', line 48150

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48111
48112
48113
# File 'lib/google/apis/compute_beta/classes.rb', line 48111

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



48116
48117
48118
# File 'lib/google/apis/compute_beta/classes.rb', line 48116

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


48123
48124
48125
# File 'lib/google/apis/compute_beta/classes.rb', line 48123

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48133
48134
48135
# File 'lib/google/apis/compute_beta/classes.rb', line 48133

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48138
48139
48140
# File 'lib/google/apis/compute_beta/classes.rb', line 48138

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


48143
48144
48145
# File 'lib/google/apis/compute_beta/classes.rb', line 48143

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48148
48149
48150
# File 'lib/google/apis/compute_beta/classes.rb', line 48148

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48155
48156
48157
48158
48159
48160
48161
48162
48163
# File 'lib/google/apis/compute_beta/classes.rb', line 48155

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end