Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



47283
47284
47285
# File 'lib/google/apis/compute_beta/classes.rb', line 47283

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47244
47245
47246
# File 'lib/google/apis/compute_beta/classes.rb', line 47244

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



47249
47250
47251
# File 'lib/google/apis/compute_beta/classes.rb', line 47249

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


47256
47257
47258
# File 'lib/google/apis/compute_beta/classes.rb', line 47256

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47266
47267
47268
# File 'lib/google/apis/compute_beta/classes.rb', line 47266

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47271
47272
47273
# File 'lib/google/apis/compute_beta/classes.rb', line 47271

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47276
47277
47278
# File 'lib/google/apis/compute_beta/classes.rb', line 47276

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47281
47282
47283
# File 'lib/google/apis/compute_beta/classes.rb', line 47281

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47288
47289
47290
47291
47292
47293
47294
47295
47296
# File 'lib/google/apis/compute_beta/classes.rb', line 47288

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end