Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



46224
46225
46226
# File 'lib/google/apis/compute_beta/classes.rb', line 46224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46185
46186
46187
# File 'lib/google/apis/compute_beta/classes.rb', line 46185

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



46190
46191
46192
# File 'lib/google/apis/compute_beta/classes.rb', line 46190

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


46197
46198
46199
# File 'lib/google/apis/compute_beta/classes.rb', line 46197

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46207
46208
46209
# File 'lib/google/apis/compute_beta/classes.rb', line 46207

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46212
46213
46214
# File 'lib/google/apis/compute_beta/classes.rb', line 46212

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


46217
46218
46219
# File 'lib/google/apis/compute_beta/classes.rb', line 46217

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46222
46223
46224
# File 'lib/google/apis/compute_beta/classes.rb', line 46222

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46229
46230
46231
46232
46233
46234
46235
46236
46237
# File 'lib/google/apis/compute_beta/classes.rb', line 46229

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end