Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixAggregatedList

Returns a new instance of PublicDelegatedPrefixAggregatedList.



44836
44837
44838
# File 'lib/google/apis/compute_beta/classes.rb', line 44836

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


44797
44798
44799
# File 'lib/google/apis/compute_beta/classes.rb', line 44797

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::PublicDelegatedPrefixesScopedList>

A list of PublicDelegatedPrefixesScopedList resources. Corresponds to the JSON property items



44802
44803
44804
# File 'lib/google/apis/compute_beta/classes.rb', line 44802

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixAggregatedList for aggregated lists of public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


44809
44810
44811
# File 'lib/google/apis/compute_beta/classes.rb', line 44809

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


44819
44820
44821
# File 'lib/google/apis/compute_beta/classes.rb', line 44819

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


44824
44825
44826
# File 'lib/google/apis/compute_beta/classes.rb', line 44824

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


44829
44830
44831
# File 'lib/google/apis/compute_beta/classes.rb', line 44829

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



44834
44835
44836
# File 'lib/google/apis/compute_beta/classes.rb', line 44834

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



44841
44842
44843
44844
44845
44846
44847
44848
44849
# File 'lib/google/apis/compute_beta/classes.rb', line 44841

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end