Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicDelegatedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixList
constructor
A new instance of PublicDelegatedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixList
Returns a new instance of PublicDelegatedPrefixList.
49120 49121 49122 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49120 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49086 49087 49088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49086 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
Corresponds to the JSON property items
49091 49092 49093 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49091 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixList for public delegated
prefixes.
Corresponds to the JSON property kind
49098 49099 49100 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49098 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49108 49109 49110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49108 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49113 49114 49115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49113 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49118 49119 49120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49118 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49125 49126 49127 49128 49129 49130 49131 49132 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49125 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |