Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



49014
49015
49016
# File 'lib/google/apis/compute_beta/classes.rb', line 49014

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48980
48981
48982
# File 'lib/google/apis/compute_beta/classes.rb', line 48980

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



48985
48986
48987
# File 'lib/google/apis/compute_beta/classes.rb', line 48985

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


48992
48993
48994
# File 'lib/google/apis/compute_beta/classes.rb', line 48992

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49002
49003
49004
# File 'lib/google/apis/compute_beta/classes.rb', line 49002

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49007
49008
49009
# File 'lib/google/apis/compute_beta/classes.rb', line 49007

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49012
49013
49014
# File 'lib/google/apis/compute_beta/classes.rb', line 49012

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49019
49020
49021
49022
49023
49024
49025
49026
# File 'lib/google/apis/compute_beta/classes.rb', line 49019

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end