Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



48992
48993
48994
# File 'lib/google/apis/compute_beta/classes.rb', line 48992

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48958
48959
48960
# File 'lib/google/apis/compute_beta/classes.rb', line 48958

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



48963
48964
48965
# File 'lib/google/apis/compute_beta/classes.rb', line 48963

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


48970
48971
48972
# File 'lib/google/apis/compute_beta/classes.rb', line 48970

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48980
48981
48982
# File 'lib/google/apis/compute_beta/classes.rb', line 48980

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48985
48986
48987
# File 'lib/google/apis/compute_beta/classes.rb', line 48985

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48990
48991
48992
# File 'lib/google/apis/compute_beta/classes.rb', line 48990

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48997
48998
48999
49000
49001
49002
49003
49004
# File 'lib/google/apis/compute_beta/classes.rb', line 48997

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end