Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicDelegatedPrefixList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixList
constructor
A new instance of PublicDelegatedPrefixList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixList
Returns a new instance of PublicDelegatedPrefixList.
47410 47411 47412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47376 47377 47378 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47376 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::PublicDelegatedPrefix>
A list of PublicDelegatedPrefix resources.
Corresponds to the JSON property items
47381 47382 47383 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47381 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
publicDelegatedPrefixList for public delegated
prefixes.
Corresponds to the JSON property kind
47388 47389 47390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47388 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47398 47399 47400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47398 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47403 47404 47405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47403 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47408 47409 47410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47408 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47415 47416 47417 47418 47419 47420 47421 47422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47415 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |