Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PublicDelegatedPrefixList

Returns a new instance of PublicDelegatedPrefixList.



46351
46352
46353
# File 'lib/google/apis/compute_beta/classes.rb', line 46351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


46317
46318
46319
# File 'lib/google/apis/compute_beta/classes.rb', line 46317

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::PublicDelegatedPrefix>

A list of PublicDelegatedPrefix resources. Corresponds to the JSON property items



46322
46323
46324
# File 'lib/google/apis/compute_beta/classes.rb', line 46322

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# publicDelegatedPrefixList for public delegated prefixes. Corresponds to the JSON property kind

Returns:

  • (String)


46329
46330
46331
# File 'lib/google/apis/compute_beta/classes.rb', line 46329

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46339
46340
46341
# File 'lib/google/apis/compute_beta/classes.rb', line 46339

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


46344
46345
46346
# File 'lib/google/apis/compute_beta/classes.rb', line 46344

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::PublicDelegatedPrefixList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



46349
46350
46351
# File 'lib/google/apis/compute_beta/classes.rb', line 46349

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46356
46357
46358
46359
46360
46361
46362
46363
# File 'lib/google/apis/compute_beta/classes.rb', line 46356

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end