Class: Google::Apis::ComputeBeta::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::PublicDelegatedPrefixPublicDelegatedSubPrefix
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a sub PublicDelegatedPrefix.
Instance Attribute Summary collapse
-
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this PublicDelegatedSubPrefix.
-
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
-
#description ⇒ String
An optional description of this resource.
-
#enable_enhanced_ipv4_allocation ⇒ Boolean
(also: #enable_enhanced_ipv4_allocation?)
Output only.
-
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this sub public delegated prefix.
-
#ipv6_access_type ⇒ String
Output only.
-
#is_address ⇒ Boolean
(also: #is_address?)
Whether the sub prefix is delegated to create Address resources in the delegatee project.
-
#mode ⇒ String
The PublicDelegatedSubPrefix mode for IPv6 only.
-
#name ⇒ String
The name of the sub public delegated prefix.
-
#region ⇒ String
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
constructor
A new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ PublicDelegatedPrefixPublicDelegatedSubPrefix
Returns a new instance of PublicDelegatedPrefixPublicDelegatedSubPrefix.
47564 47565 47566 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47564 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocatable_prefix_length ⇒ Fixnum
The allocatable prefix length supported by this PublicDelegatedSubPrefix.
Corresponds to the JSON property allocatablePrefixLength
47502 47503 47504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47502 def allocatable_prefix_length @allocatable_prefix_length end |
#delegatee_project ⇒ String
Name of the project scoping this PublicDelegatedSubPrefix.
Corresponds to the JSON property delegateeProject
47507 47508 47509 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47507 def delegatee_project @delegatee_project end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
47513 47514 47515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47513 def description @description end |
#enable_enhanced_ipv4_allocation ⇒ Boolean Also known as: enable_enhanced_ipv4_allocation?
Output only. [Output Only] Whether this PDP supports enhanced IPv4 allocations.
Applicable for IPv4 PDPs only.
Corresponds to the JSON property enableEnhancedIpv4Allocation
47519 47520 47521 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47519 def enable_enhanced_ipv4_allocation @enable_enhanced_ipv4_allocation end |
#ip_cidr_range ⇒ String
The IP address range, in CIDR format, represented by this sub public
delegated prefix.
Corresponds to the JSON property ipCidrRange
47526 47527 47528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47526 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
Output only. [Output Only] The internet access type for IPv6 Public Delegated
Sub
Prefixes. Inherited from parent prefix.
Corresponds to the JSON property ipv6AccessType
47533 47534 47535 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47533 def ipv6_access_type @ipv6_access_type end |
#is_address ⇒ Boolean Also known as: is_address?
Whether the sub prefix is delegated to create Address resources in the
delegatee project.
Corresponds to the JSON property isAddress
47539 47540 47541 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47539 def is_address @is_address end |
#mode ⇒ String
The PublicDelegatedSubPrefix mode for IPv6 only.
Corresponds to the JSON property mode
47545 47546 47547 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47545 def mode @mode end |
#name ⇒ String
The name of the sub public delegated prefix.
Corresponds to the JSON property name
47550 47551 47552 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47550 def name @name end |
#region ⇒ String
Output only. [Output Only] The region of the sub public delegated prefix if it
is
regional. If absent, the sub prefix is global.
Corresponds to the JSON property region
47557 47558 47559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47557 def region @region end |
#status ⇒ String
Output only. [Output Only] The status of the sub public delegated prefix.
Corresponds to the JSON property status
47562 47563 47564 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47562 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47569 47570 47571 47572 47573 47574 47575 47576 47577 47578 47579 47580 47581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47569 def update!(**args) @allocatable_prefix_length = args[:allocatable_prefix_length] if args.key?(:allocatable_prefix_length) @delegatee_project = args[:delegatee_project] if args.key?(:delegatee_project) @description = args[:description] if args.key?(:description) @enable_enhanced_ipv4_allocation = args[:enable_enhanced_ipv4_allocation] if args.key?(:enable_enhanced_ipv4_allocation) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @is_address = args[:is_address] if args.key?(:is_address) @mode = args[:mode] if args.key?(:mode) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @status = args[:status] if args.key?(:status) end |