Class: Google::Apis::ComputeBeta::Reference
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Reference
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reference to a resource.
Instance Attribute Summary collapse
-
#kind ⇒ String
Output only.
-
#reference_type ⇒ String
A description of the reference type with no implied semantics.
-
#referrer ⇒ String
URL of the resource which refers to the target.
-
#target ⇒ String
URL of the resource to which this reference points.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Reference
constructor
A new instance of Reference.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Reference
Returns a new instance of Reference.
48674 48675 48676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#reference
for references.
Corresponds to the JSON property kind
48653 48654 48655 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48653 def kind @kind end |
#reference_type ⇒ String
A description of the reference type with no implied semantics. Possible values include:
- MEMBER_OF
Corresponds to the JSON property
referenceType
48662 48663 48664 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48662 def reference_type @reference_type end |
#referrer ⇒ String
URL of the resource which refers to the target.
Corresponds to the JSON property referrer
48667 48668 48669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48667 def referrer @referrer end |
#target ⇒ String
URL of the resource to which this reference points.
Corresponds to the JSON property target
48672 48673 48674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48672 def target @target end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48679 48680 48681 48682 48683 48684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48679 def update!(**args) @kind = args[:kind] if args.key?(:kind) @reference_type = args[:reference_type] if args.key?(:reference_type) @referrer = args[:referrer] if args.key?(:referrer) @target = args[:target] if args.key?(:target) end |