Class: Google::Apis::ComputeBeta::Region
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Region
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Region resource. A region is a geographical area where a resource is located. For more information, readRegions and Zones.
Defined Under Namespace
Classes: QuotaStatusWarning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#quota_status_warning ⇒ Google::Apis::ComputeBeta::Region::QuotaStatusWarning
Output only.
-
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this region.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
-
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of resource URLs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Region
constructor
A new instance of Region.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Region
Returns a new instance of Region.
49498 49499 49500 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
49435 49436 49437 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49435 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
49440 49441 49442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49440 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
49445 49446 49447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49445 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
49451 49452 49453 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49451 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#region for
regions.
Corresponds to the JSON property kind
49457 49458 49459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49457 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
49462 49463 49464 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49462 def name @name end |
#quota_status_warning ⇒ Google::Apis::ComputeBeta::Region::QuotaStatusWarning
Output only. [Output Only] Warning of fetching the quotas field for this
region. This
field is populated only if fetching of the quotas field fails.
Corresponds to the JSON property quotaStatusWarning
49469 49470 49471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49469 def quota_status_warning @quota_status_warning end |
#quotas ⇒ Array<Google::Apis::ComputeBeta::Quota>
[Output Only] Quotas assigned to this region.
Corresponds to the JSON property quotas
49474 49475 49476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49474 def quotas @quotas end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
49479 49480 49481 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49479 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the region, either UP orDOWN.
Corresponds to the JSON property status
49484 49485 49486 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49484 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
49489 49490 49491 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49489 def supports_pzs @supports_pzs end |
#zones ⇒ Array<String>
[Output Only] A list of zones available in this region, in the form of
resource URLs.
Corresponds to the JSON property zones
49496 49497 49498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49496 def zones @zones end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49503 49504 49505 49506 49507 49508 49509 49510 49511 49512 49513 49514 49515 49516 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49503 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @quota_status_warning = args[:quota_status_warning] if args.key?(:quota_status_warning) @quotas = args[:quotas] if args.key?(:quotas) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) @zones = args[:zones] if args.key?(:zones) end |