Class: Google::Apis::ComputeBeta::RegionAutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionAutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of autoscalers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAutoscalerList
constructor
A new instance of RegionAutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAutoscalerList
Returns a new instance of RegionAutoscalerList.
49786 49787 49788 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49786 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49754 49755 49756 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49754 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
49759 49760 49761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49759 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
49764 49765 49766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49764 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49774 49775 49776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49774 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49779 49780 49781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49779 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
49784 49785 49786 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49784 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49791 49792 49793 49794 49795 49796 49797 49798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49791 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |