Class: Google::Apis::ComputeBeta::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



49663
49664
49665
# File 'lib/google/apis/compute_beta/classes.rb', line 49663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49631
49632
49633
# File 'lib/google/apis/compute_beta/classes.rb', line 49631

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



49636
49637
49638
# File 'lib/google/apis/compute_beta/classes.rb', line 49636

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49641
49642
49643
# File 'lib/google/apis/compute_beta/classes.rb', line 49641

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49651
49652
49653
# File 'lib/google/apis/compute_beta/classes.rb', line 49651

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49656
49657
49658
# File 'lib/google/apis/compute_beta/classes.rb', line 49656

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49661
49662
49663
# File 'lib/google/apis/compute_beta/classes.rb', line 49661

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49668
49669
49670
49671
49672
49673
49674
49675
# File 'lib/google/apis/compute_beta/classes.rb', line 49668

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end