Class: Google::Apis::ComputeBeta::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



48926
48927
48928
# File 'lib/google/apis/compute_beta/classes.rb', line 48926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48894
48895
48896
# File 'lib/google/apis/compute_beta/classes.rb', line 48894

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



48899
48900
48901
# File 'lib/google/apis/compute_beta/classes.rb', line 48899

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


48904
48905
48906
# File 'lib/google/apis/compute_beta/classes.rb', line 48904

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48914
48915
48916
# File 'lib/google/apis/compute_beta/classes.rb', line 48914

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48919
48920
48921
# File 'lib/google/apis/compute_beta/classes.rb', line 48919

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48924
48925
48926
# File 'lib/google/apis/compute_beta/classes.rb', line 48924

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48931
48932
48933
48934
48935
48936
48937
48938
# File 'lib/google/apis/compute_beta/classes.rb', line 48931

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end