Class: Google::Apis::ComputeBeta::RegionAutoscalerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of autoscalers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionAutoscalerList

Returns a new instance of RegionAutoscalerList.



48051
48052
48053
# File 'lib/google/apis/compute_beta/classes.rb', line 48051

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48019
48020
48021
# File 'lib/google/apis/compute_beta/classes.rb', line 48019

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Autoscaler>

A list of Autoscaler resources. Corresponds to the JSON property items



48024
48025
48026
# File 'lib/google/apis/compute_beta/classes.rb', line 48024

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


48029
48030
48031
# File 'lib/google/apis/compute_beta/classes.rb', line 48029

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48039
48040
48041
# File 'lib/google/apis/compute_beta/classes.rb', line 48039

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48044
48045
48046
# File 'lib/google/apis/compute_beta/classes.rb', line 48044

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionAutoscalerList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



48049
48050
48051
# File 'lib/google/apis/compute_beta/classes.rb', line 48049

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48056
48057
48058
48059
48060
48061
48062
48063
# File 'lib/google/apis/compute_beta/classes.rb', line 48056

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end