Class: Google::Apis::ComputeBeta::RegionAutoscalerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionAutoscalerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of autoscalers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Autoscaler>
A list of Autoscaler resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionAutoscalerList
constructor
A new instance of RegionAutoscalerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionAutoscalerList
Returns a new instance of RegionAutoscalerList.
46992 46993 46994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46992 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
46960 46961 46962 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46960 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Autoscaler>
A list of Autoscaler resources.
Corresponds to the JSON property items
46965 46966 46967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46965 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
46970 46971 46972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46970 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
46980 46981 46982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46980 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
46985 46986 46987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46985 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionAutoscalerList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
46990 46991 46992 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46990 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
46997 46998 46999 47000 47001 47002 47003 47004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 46997 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |