Class: Google::Apis::ComputeBeta::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



50060
50061
50062
# File 'lib/google/apis/compute_beta/classes.rb', line 50060

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50027
50028
50029
# File 'lib/google/apis/compute_beta/classes.rb', line 50027

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



50032
50033
50034
# File 'lib/google/apis/compute_beta/classes.rb', line 50032

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


50037
50038
50039
# File 'lib/google/apis/compute_beta/classes.rb', line 50037

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50048
50049
50050
# File 'lib/google/apis/compute_beta/classes.rb', line 50048

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50053
50054
50055
# File 'lib/google/apis/compute_beta/classes.rb', line 50053

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



50058
50059
50060
# File 'lib/google/apis/compute_beta/classes.rb', line 50058

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50065
50066
50067
50068
50069
50070
50071
50072
# File 'lib/google/apis/compute_beta/classes.rb', line 50065

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end