Class: Google::Apis::ComputeBeta::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



49264
49265
49266
# File 'lib/google/apis/compute_beta/classes.rb', line 49264

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49231
49232
49233
# File 'lib/google/apis/compute_beta/classes.rb', line 49231

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



49236
49237
49238
# File 'lib/google/apis/compute_beta/classes.rb', line 49236

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


49241
49242
49243
# File 'lib/google/apis/compute_beta/classes.rb', line 49241

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49252
49253
49254
# File 'lib/google/apis/compute_beta/classes.rb', line 49252

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49257
49258
49259
# File 'lib/google/apis/compute_beta/classes.rb', line 49257

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



49262
49263
49264
# File 'lib/google/apis/compute_beta/classes.rb', line 49262

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49269
49270
49271
49272
49273
49274
49275
49276
# File 'lib/google/apis/compute_beta/classes.rb', line 49269

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end