Class: Google::Apis::ComputeBeta::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



48448
48449
48450
# File 'lib/google/apis/compute_beta/classes.rb', line 48448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48415
48416
48417
# File 'lib/google/apis/compute_beta/classes.rb', line 48415

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



48420
48421
48422
# File 'lib/google/apis/compute_beta/classes.rb', line 48420

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


48425
48426
48427
# File 'lib/google/apis/compute_beta/classes.rb', line 48425

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48436
48437
48438
# File 'lib/google/apis/compute_beta/classes.rb', line 48436

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48441
48442
48443
# File 'lib/google/apis/compute_beta/classes.rb', line 48441

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



48446
48447
48448
# File 'lib/google/apis/compute_beta/classes.rb', line 48446

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48453
48454
48455
48456
48457
48458
48459
48460
# File 'lib/google/apis/compute_beta/classes.rb', line 48453

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end