Class: Google::Apis::ComputeBeta::RegionInstanceGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of InstanceGroup resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupList

Returns a new instance of RegionInstanceGroupList.



45973
45974
45975
# File 'lib/google/apis/compute_beta/classes.rb', line 45973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


45940
45941
45942
# File 'lib/google/apis/compute_beta/classes.rb', line 45940

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroup>

A list of InstanceGroup resources. Corresponds to the JSON property items



45945
45946
45947
# File 'lib/google/apis/compute_beta/classes.rb', line 45945

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


45950
45951
45952
# File 'lib/google/apis/compute_beta/classes.rb', line 45950

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


45961
45962
45963
# File 'lib/google/apis/compute_beta/classes.rb', line 45961

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


45966
45967
45968
# File 'lib/google/apis/compute_beta/classes.rb', line 45966

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



45971
45972
45973
# File 'lib/google/apis/compute_beta/classes.rb', line 45971

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



45978
45979
45980
45981
45982
45983
45984
45985
# File 'lib/google/apis/compute_beta/classes.rb', line 45978

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end