Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
50810 50811 50812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50776 50777 50778 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50776 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
50781 50782 50783 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50781 def items @items end |
#kind ⇒ String
Output only. The resource type, which is always compute#
instanceGroupManagerList for a
list of managed instance groups that exist in th regional scope.
Corresponds to the JSON property kind
50788 50789 50790 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50788 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50798 50799 50800 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50798 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50803 50804 50805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50803 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
50808 50809 50810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50808 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50815 50816 50817 50818 50819 50820 50821 50822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50815 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |