Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



50329
50330
50331
# File 'lib/google/apis/compute_beta/classes.rb', line 50329

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50295
50296
50297
# File 'lib/google/apis/compute_beta/classes.rb', line 50295

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



50300
50301
50302
# File 'lib/google/apis/compute_beta/classes.rb', line 50300

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


50307
50308
50309
# File 'lib/google/apis/compute_beta/classes.rb', line 50307

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50317
50318
50319
# File 'lib/google/apis/compute_beta/classes.rb', line 50317

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50322
50323
50324
# File 'lib/google/apis/compute_beta/classes.rb', line 50322

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50327
50328
50329
# File 'lib/google/apis/compute_beta/classes.rb', line 50327

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50334
50335
50336
50337
50338
50339
50340
50341
# File 'lib/google/apis/compute_beta/classes.rb', line 50334

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end