Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of managed instance groups.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerList

Returns a new instance of RegionInstanceGroupManagerList.



50206
50207
50208
# File 'lib/google/apis/compute_beta/classes.rb', line 50206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50172
50173
50174
# File 'lib/google/apis/compute_beta/classes.rb', line 50172

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManager>

A list of InstanceGroupManager resources. Corresponds to the JSON property items



50177
50178
50179
# File 'lib/google/apis/compute_beta/classes.rb', line 50177

def items
  @items
end

#kindString

Output only. The resource type, which is always compute# instanceGroupManagerList for a list of managed instance groups that exist in th regional scope. Corresponds to the JSON property kind

Returns:

  • (String)


50184
50185
50186
# File 'lib/google/apis/compute_beta/classes.rb', line 50184

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50194
50195
50196
# File 'lib/google/apis/compute_beta/classes.rb', line 50194

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50199
50200
50201
# File 'lib/google/apis/compute_beta/classes.rb', line 50199

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50204
50205
50206
# File 'lib/google/apis/compute_beta/classes.rb', line 50204

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50211
50212
50213
50214
50215
50216
50217
50218
# File 'lib/google/apis/compute_beta/classes.rb', line 50211

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end