Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
50184 50185 50186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50184 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50150 50151 50152 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50150 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
50155 50156 50157 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50155 def items @items end |
#kind ⇒ String
Output only. The resource type, which is always compute#
instanceGroupManagerList for a
list of managed instance groups that exist in th regional scope.
Corresponds to the JSON property kind
50162 50163 50164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50162 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50172 50173 50174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50172 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
50177 50178 50179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50177 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
50182 50183 50184 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50182 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50189 50190 50191 50192 50193 50194 50195 50196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50189 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |