Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupManagerList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of managed instance groups.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
A list of InstanceGroupManager resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupManagerList
constructor
A new instance of RegionInstanceGroupManagerList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupManagerList
Returns a new instance of RegionInstanceGroupManagerList.
49410 49411 49412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Output only. Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
49376 49377 49378 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49376 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::InstanceGroupManager>
A list of InstanceGroupManager resources.
Corresponds to the JSON property items
49381 49382 49383 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49381 def items @items end |
#kind ⇒ String
Output only. The resource type, which is always compute#
instanceGroupManagerList for a
list of managed instance groups that exist in th regional scope.
Corresponds to the JSON property kind
49388 49389 49390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49388 def kind @kind end |
#next_page_token ⇒ String
Output only. This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
49398 49399 49400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49398 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. Server-defined URL for this resource.
Corresponds to the JSON property selfLink
49403 49404 49405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49403 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionInstanceGroupManagerList::Warning
Output only. Informational warning message.
Corresponds to the JSON property warning
49408 49409 49410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49408 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
49415 49416 49417 49418 49419 49420 49421 49422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49415 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |