Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



50568
50569
50570
# File 'lib/google/apis/compute_beta/classes.rb', line 50568

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50523
50524
50525
# File 'lib/google/apis/compute_beta/classes.rb', line 50523

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50528
50529
50530
# File 'lib/google/apis/compute_beta/classes.rb', line 50528

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



50533
50534
50535
# File 'lib/google/apis/compute_beta/classes.rb', line 50533

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


50540
50541
50542
# File 'lib/google/apis/compute_beta/classes.rb', line 50540

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50550
50551
50552
# File 'lib/google/apis/compute_beta/classes.rb', line 50550

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50555
50556
50557
# File 'lib/google/apis/compute_beta/classes.rb', line 50555

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50561
50562
50563
# File 'lib/google/apis/compute_beta/classes.rb', line 50561

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50566
50567
50568
# File 'lib/google/apis/compute_beta/classes.rb', line 50566

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50573
50574
50575
50576
50577
50578
50579
50580
50581
50582
# File 'lib/google/apis/compute_beta/classes.rb', line 50573

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end