Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



50486
50487
50488
# File 'lib/google/apis/compute_beta/classes.rb', line 50486

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50441
50442
50443
# File 'lib/google/apis/compute_beta/classes.rb', line 50441

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50446
50447
50448
# File 'lib/google/apis/compute_beta/classes.rb', line 50446

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



50451
50452
50453
# File 'lib/google/apis/compute_beta/classes.rb', line 50451

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


50458
50459
50460
# File 'lib/google/apis/compute_beta/classes.rb', line 50458

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50468
50469
50470
# File 'lib/google/apis/compute_beta/classes.rb', line 50468

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50473
50474
50475
# File 'lib/google/apis/compute_beta/classes.rb', line 50473

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50479
50480
50481
# File 'lib/google/apis/compute_beta/classes.rb', line 50479

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50484
50485
50486
# File 'lib/google/apis/compute_beta/classes.rb', line 50484

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50491
50492
50493
50494
50495
50496
50497
50498
50499
50500
# File 'lib/google/apis/compute_beta/classes.rb', line 50491

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end