Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



50363
50364
50365
# File 'lib/google/apis/compute_beta/classes.rb', line 50363

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50318
50319
50320
# File 'lib/google/apis/compute_beta/classes.rb', line 50318

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50323
50324
50325
# File 'lib/google/apis/compute_beta/classes.rb', line 50323

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



50328
50329
50330
# File 'lib/google/apis/compute_beta/classes.rb', line 50328

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


50335
50336
50337
# File 'lib/google/apis/compute_beta/classes.rb', line 50335

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50345
50346
50347
# File 'lib/google/apis/compute_beta/classes.rb', line 50345

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50350
50351
50352
# File 'lib/google/apis/compute_beta/classes.rb', line 50350

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50356
50357
50358
# File 'lib/google/apis/compute_beta/classes.rb', line 50356

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50361
50362
50363
# File 'lib/google/apis/compute_beta/classes.rb', line 50361

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50368
50369
50370
50371
50372
50373
50374
50375
50376
50377
# File 'lib/google/apis/compute_beta/classes.rb', line 50368

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end