Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagerResizeRequestsListResponse

Returns a new instance of RegionInstanceGroupManagerResizeRequestsListResponse.



50341
50342
50343
# File 'lib/google/apis/compute_beta/classes.rb', line 50341

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50296
50297
50298
# File 'lib/google/apis/compute_beta/classes.rb', line 50296

def etag
  @etag
end

#idString

Output only. Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50301
50302
50303
# File 'lib/google/apis/compute_beta/classes.rb', line 50301

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceGroupManagerResizeRequest>

A list of Resize Request resources. Corresponds to the JSON property items



50306
50307
50308
# File 'lib/google/apis/compute_beta/classes.rb', line 50306

def items
  @items
end

#kindString

Output only. Type of the resource. Alwayscompute# regionInstanceGroupManagerResizeRequestList for a list of Resize Requests. Corresponds to the JSON property kind

Returns:

  • (String)


50313
50314
50315
# File 'lib/google/apis/compute_beta/classes.rb', line 50313

def kind
  @kind
end

#next_page_tokenString

Output only. This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50323
50324
50325
# File 'lib/google/apis/compute_beta/classes.rb', line 50323

def next_page_token
  @next_page_token
end

Output only. Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50328
50329
50330
# File 'lib/google/apis/compute_beta/classes.rb', line 50328

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50334
50335
50336
# File 'lib/google/apis/compute_beta/classes.rb', line 50334

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagerResizeRequestsListResponse::Warning

Output only. Informational warning message. Corresponds to the JSON property warning



50339
50340
50341
# File 'lib/google/apis/compute_beta/classes.rb', line 50339

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50346
50347
50348
50349
50350
50351
50352
50353
50354
50355
# File 'lib/google/apis/compute_beta/classes.rb', line 50346

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end