Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagersApplyUpdatesRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

RegionInstanceGroupManagers.applyUpdatesToInstances

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersApplyUpdatesRequest

Returns a new instance of RegionInstanceGroupManagersApplyUpdatesRequest.



50547
50548
50549
# File 'lib/google/apis/compute_beta/classes.rb', line 50547

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#all_instancesBoolean Also known as: all_instances?

Flag to update all instances instead of specified list of “instances”. If the flag is set to true then the instances may not be specified in the request. Corresponds to the JSON property allInstances

Returns:

  • (Boolean)


50496
50497
50498
# File 'lib/google/apis/compute_beta/classes.rb', line 50496

def all_instances
  @all_instances
end

#allowed_actionsArray<String>

Actions that are allowed to update instances within MIG. Corresponds to the JSON property allowedActions

Returns:

  • (Array<String>)


50502
50503
50504
# File 'lib/google/apis/compute_beta/classes.rb', line 50502

def allowed_actions
  @allowed_actions
end

#instancesArray<String>

The list of URLs of one or more instances for which you want to apply updates. Each URL can be a full URL or a partial URL, such aszones/[ZONE]/ instances/[INSTANCE_NAME]. Corresponds to the JSON property instances

Returns:

  • (Array<String>)


50509
50510
50511
# File 'lib/google/apis/compute_beta/classes.rb', line 50509

def instances
  @instances
end

#minimal_actionString

The minimal action that you want to perform on each instance during the update:

  • REPLACE: At minimum, delete the instance and create it again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all. By default, the minimum action is NONE. If your update requires a more disruptive action than you set with this flag, the necessary action is performed to execute the update. Corresponds to the JSON property minimalAction

Returns:

  • (String)


50528
50529
50530
# File 'lib/google/apis/compute_beta/classes.rb', line 50528

def minimal_action
  @minimal_action
end

#most_disruptive_allowed_actionString

The most disruptive action that you want to perform on each instance during the update:

  • REPLACE: Delete the instance and create it again.
  • RESTART: Stop the instance and start it again.
  • REFRESH: Do not stop the instance and limit disruption as much as possible.
  • NONE: Do not disrupt the instance at all. By default, the most disruptive allowed action is REPLACE. If your update requires a more disruptive action than you set with this flag, the update request will fail. Corresponds to the JSON property mostDisruptiveAllowedAction

Returns:

  • (String)


50545
50546
50547
# File 'lib/google/apis/compute_beta/classes.rb', line 50545

def most_disruptive_allowed_action
  @most_disruptive_allowed_action
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50552
50553
50554
50555
50556
50557
50558
# File 'lib/google/apis/compute_beta/classes.rb', line 50552

def update!(**args)
  @all_instances = args[:all_instances] if args.key?(:all_instances)
  @allowed_actions = args[:allowed_actions] if args.key?(:allowed_actions)
  @instances = args[:instances] if args.key?(:instances)
  @minimal_action = args[:minimal_action] if args.key?(:minimal_action)
  @most_disruptive_allowed_action = args[:most_disruptive_allowed_action] if args.key?(:most_disruptive_allowed_action)
end