Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagersListInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp

Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.



49077
49078
49079
# File 'lib/google/apis/compute_beta/classes.rb', line 49077

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeBeta::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



49059
49060
49061
# File 'lib/google/apis/compute_beta/classes.rb', line 49059

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49070
49071
49072
# File 'lib/google/apis/compute_beta/classes.rb', line 49070

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagersListInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



49075
49076
49077
# File 'lib/google/apis/compute_beta/classes.rb', line 49075

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49082
49083
49084
49085
49086
# File 'lib/google/apis/compute_beta/classes.rb', line 49082

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end