Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagersListInstanceConfigsResp

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstanceConfigsResp

Returns a new instance of RegionInstanceGroupManagersListInstanceConfigsResp.



46602
46603
46604
# File 'lib/google/apis/compute_beta/classes.rb', line 46602

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#itemsArray<Google::Apis::ComputeBeta::PerInstanceConfig>

Output only. [Output Only] The list of PerInstanceConfig. Corresponds to the JSON property items



46584
46585
46586
# File 'lib/google/apis/compute_beta/classes.rb', line 46584

def items
  @items
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


46595
46596
46597
# File 'lib/google/apis/compute_beta/classes.rb', line 46595

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupManagersListInstanceConfigsResp::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



46600
46601
46602
# File 'lib/google/apis/compute_beta/classes.rb', line 46600

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



46607
46608
46609
46610
46611
# File 'lib/google/apis/compute_beta/classes.rb', line 46607

def update!(**args)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end