Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagersListInstancesResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersListInstancesResponse

Returns a new instance of RegionInstanceGroupManagersListInstancesResponse.



50793
50794
50795
# File 'lib/google/apis/compute_beta/classes.rb', line 50793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#managed_instancesArray<Google::Apis::ComputeBeta::ManagedInstance>

A list of managed instances. Corresponds to the JSON property managedInstances



50780
50781
50782
# File 'lib/google/apis/compute_beta/classes.rb', line 50780

def managed_instances
  @managed_instances
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50791
50792
50793
# File 'lib/google/apis/compute_beta/classes.rb', line 50791

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50798
50799
50800
50801
# File 'lib/google/apis/compute_beta/classes.rb', line 50798

def update!(**args)
  @managed_instances = args[:managed_instances] if args.key?(:managed_instances)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end