Class: Google::Apis::ComputeBeta::RegionInstanceGroupManagersSetTargetPoolsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupManagersSetTargetPoolsRequest

Returns a new instance of RegionInstanceGroupManagersSetTargetPoolsRequest.



51048
51049
51050
# File 'lib/google/apis/compute_beta/classes.rb', line 51048

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

Fingerprint of the target pools information, which is a hash of the contents. This field is used for optimistic locking when you update the target pool entries. This field is optional. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


51039
51040
51041
# File 'lib/google/apis/compute_beta/classes.rb', line 51039

def fingerprint
  @fingerprint
end

#target_poolsArray<String>

The URL of all TargetPool resources to which instances in theinstanceGroup field are added. The target pools automatically apply to all of the instances in the managed instance group. Corresponds to the JSON property targetPools

Returns:

  • (Array<String>)


51046
51047
51048
# File 'lib/google/apis/compute_beta/classes.rb', line 51046

def target_pools
  @target_pools
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51053
51054
51055
51056
# File 'lib/google/apis/compute_beta/classes.rb', line 51053

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @target_pools = args[:target_pools] if args.key?(:target_pools)
end