Class: Google::Apis::ComputeBeta::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



51278
51279
51280
# File 'lib/google/apis/compute_beta/classes.rb', line 51278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51245
51246
51247
# File 'lib/google/apis/compute_beta/classes.rb', line 51245

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



51250
51251
51252
# File 'lib/google/apis/compute_beta/classes.rb', line 51250

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


51255
51256
51257
# File 'lib/google/apis/compute_beta/classes.rb', line 51255

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51266
51267
51268
# File 'lib/google/apis/compute_beta/classes.rb', line 51266

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51271
51272
51273
# File 'lib/google/apis/compute_beta/classes.rb', line 51271

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



51276
51277
51278
# File 'lib/google/apis/compute_beta/classes.rb', line 51276

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51283
51284
51285
51286
51287
51288
51289
51290
# File 'lib/google/apis/compute_beta/classes.rb', line 51283

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end