Class: Google::Apis::ComputeBeta::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



51196
51197
51198
# File 'lib/google/apis/compute_beta/classes.rb', line 51196

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51163
51164
51165
# File 'lib/google/apis/compute_beta/classes.rb', line 51163

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



51168
51169
51170
# File 'lib/google/apis/compute_beta/classes.rb', line 51168

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


51173
51174
51175
# File 'lib/google/apis/compute_beta/classes.rb', line 51173

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51184
51185
51186
# File 'lib/google/apis/compute_beta/classes.rb', line 51184

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51189
51190
51191
# File 'lib/google/apis/compute_beta/classes.rb', line 51189

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



51194
51195
51196
# File 'lib/google/apis/compute_beta/classes.rb', line 51194

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51201
51202
51203
51204
51205
51206
51207
51208
# File 'lib/google/apis/compute_beta/classes.rb', line 51201

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end