Class: Google::Apis::ComputeBeta::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



50271
50272
50273
# File 'lib/google/apis/compute_beta/classes.rb', line 50271

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50238
50239
50240
# File 'lib/google/apis/compute_beta/classes.rb', line 50238

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



50243
50244
50245
# File 'lib/google/apis/compute_beta/classes.rb', line 50243

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


50248
50249
50250
# File 'lib/google/apis/compute_beta/classes.rb', line 50248

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50259
50260
50261
# File 'lib/google/apis/compute_beta/classes.rb', line 50259

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50264
50265
50266
# File 'lib/google/apis/compute_beta/classes.rb', line 50264

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



50269
50270
50271
# File 'lib/google/apis/compute_beta/classes.rb', line 50269

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50276
50277
50278
50279
50280
50281
50282
50283
# File 'lib/google/apis/compute_beta/classes.rb', line 50276

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end