Class: Google::Apis::ComputeBeta::RegionInstanceGroupsListInstances

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsListInstances

Returns a new instance of RegionInstanceGroupsListInstances.



48372
48373
48374
# File 'lib/google/apis/compute_beta/classes.rb', line 48372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48339
48340
48341
# File 'lib/google/apis/compute_beta/classes.rb', line 48339

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::InstanceWithNamedPorts>

A list of InstanceWithNamedPorts resources. Corresponds to the JSON property items



48344
48345
48346
# File 'lib/google/apis/compute_beta/classes.rb', line 48344

def items
  @items
end

#kindString

Output only. The resource type. Corresponds to the JSON property kind

Returns:

  • (String)


48349
48350
48351
# File 'lib/google/apis/compute_beta/classes.rb', line 48349

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48360
48361
48362
# File 'lib/google/apis/compute_beta/classes.rb', line 48360

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48365
48366
48367
# File 'lib/google/apis/compute_beta/classes.rb', line 48365

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionInstanceGroupsListInstances::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



48370
48371
48372
# File 'lib/google/apis/compute_beta/classes.rb', line 48370

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48377
48378
48379
48380
48381
48382
48383
48384
# File 'lib/google/apis/compute_beta/classes.rb', line 48377

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end