Class: Google::Apis::ComputeBeta::RegionInstanceGroupsSetNamedPortsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest

Returns a new instance of RegionInstanceGroupsSetNamedPortsRequest.



51208
51209
51210
# File 'lib/google/apis/compute_beta/classes.rb', line 51208

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fingerprintString

The fingerprint of the named ports information for this instance group. Use this optional property to prevent conflicts when multiple users change the named ports settings concurrently. Obtain the fingerprint with theinstanceGroups.get method. Then, include the fingerprint in your request to ensure that you do not overwrite changes that were applied from another concurrent request. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


51201
51202
51203
# File 'lib/google/apis/compute_beta/classes.rb', line 51201

def fingerprint
  @fingerprint
end

#named_portsArray<Google::Apis::ComputeBeta::NamedPort>

The list of named ports to set for this instance group. Corresponds to the JSON property namedPorts



51206
51207
51208
# File 'lib/google/apis/compute_beta/classes.rb', line 51206

def named_ports
  @named_ports
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51213
51214
51215
51216
# File 'lib/google/apis/compute_beta/classes.rb', line 51213

def update!(**args)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @named_ports = args[:named_ports] if args.key?(:named_ports)
end