Class: Google::Apis::ComputeBeta::RegionInstanceGroupsSetNamedPortsRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionInstanceGroupsSetNamedPortsRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
-
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
The list of named ports to set for this instance group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest
constructor
A new instance of RegionInstanceGroupsSetNamedPortsRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionInstanceGroupsSetNamedPortsRequest
Returns a new instance of RegionInstanceGroupsSetNamedPortsRequest.
48507 48508 48509 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48507 def initialize(**args) update!(**args) end |
Instance Attribute Details
#fingerprint ⇒ String
The fingerprint of the named ports information for this instance group.
Use this optional property to prevent conflicts when multiple users change
the named ports settings concurrently. Obtain the fingerprint with
theinstanceGroups.get
method. Then, include the fingerprint in your request to ensure that you
do not overwrite changes that were applied from another
concurrent request.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
48500 48501 48502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48500 def fingerprint @fingerprint end |
#named_ports ⇒ Array<Google::Apis::ComputeBeta::NamedPort>
The list of named ports to set for this instance group.
Corresponds to the JSON property namedPorts
48505 48506 48507 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48505 def named_ports @named_ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48512 48513 48514 48515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48512 def update!(**args) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @named_ports = args[:named_ports] if args.key?(:named_ports) end |