Class: Google::Apis::ComputeBeta::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
51464 51465 51466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51464 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51431 51432 51433 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51431 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Region>
A list of Region resources.
Corresponds to the JSON property items
51436 51437 51438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51436 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
51442 51443 51444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51442 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51452 51453 51454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51452 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51457 51458 51459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51457 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51462 51463 51464 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51462 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51469 51470 51471 51472 51473 51474 51475 51476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51469 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |