Class: Google::Apis::ComputeBeta::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



51382
51383
51384
# File 'lib/google/apis/compute_beta/classes.rb', line 51382

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51349
51350
51351
# File 'lib/google/apis/compute_beta/classes.rb', line 51349

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Region>

A list of Region resources. Corresponds to the JSON property items



51354
51355
51356
# File 'lib/google/apis/compute_beta/classes.rb', line 51354

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


51360
51361
51362
# File 'lib/google/apis/compute_beta/classes.rb', line 51360

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51370
51371
51372
# File 'lib/google/apis/compute_beta/classes.rb', line 51370

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51375
51376
51377
# File 'lib/google/apis/compute_beta/classes.rb', line 51375

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51380
51381
51382
# File 'lib/google/apis/compute_beta/classes.rb', line 51380

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51387
51388
51389
51390
51391
51392
51393
51394
# File 'lib/google/apis/compute_beta/classes.rb', line 51387

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end