Class: Google::Apis::ComputeBeta::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



51259
51260
51261
# File 'lib/google/apis/compute_beta/classes.rb', line 51259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51226
51227
51228
# File 'lib/google/apis/compute_beta/classes.rb', line 51226

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Region>

A list of Region resources. Corresponds to the JSON property items



51231
51232
51233
# File 'lib/google/apis/compute_beta/classes.rb', line 51231

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


51237
51238
51239
# File 'lib/google/apis/compute_beta/classes.rb', line 51237

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51247
51248
51249
# File 'lib/google/apis/compute_beta/classes.rb', line 51247

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51252
51253
51254
# File 'lib/google/apis/compute_beta/classes.rb', line 51252

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51257
51258
51259
# File 'lib/google/apis/compute_beta/classes.rb', line 51257

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51264
51265
51266
51267
51268
51269
51270
51271
# File 'lib/google/apis/compute_beta/classes.rb', line 51264

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end