Class: Google::Apis::ComputeBeta::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



50516
50517
50518
# File 'lib/google/apis/compute_beta/classes.rb', line 50516

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50483
50484
50485
# File 'lib/google/apis/compute_beta/classes.rb', line 50483

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Region>

A list of Region resources. Corresponds to the JSON property items



50488
50489
50490
# File 'lib/google/apis/compute_beta/classes.rb', line 50488

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


50494
50495
50496
# File 'lib/google/apis/compute_beta/classes.rb', line 50494

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50504
50505
50506
# File 'lib/google/apis/compute_beta/classes.rb', line 50504

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50509
50510
50511
# File 'lib/google/apis/compute_beta/classes.rb', line 50509

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50514
50515
50516
# File 'lib/google/apis/compute_beta/classes.rb', line 50514

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50521
50522
50523
50524
50525
50526
50527
50528
# File 'lib/google/apis/compute_beta/classes.rb', line 50521

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end