Class: Google::Apis::ComputeBeta::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



50457
50458
50459
# File 'lib/google/apis/compute_beta/classes.rb', line 50457

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50424
50425
50426
# File 'lib/google/apis/compute_beta/classes.rb', line 50424

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Region>

A list of Region resources. Corresponds to the JSON property items



50429
50430
50431
# File 'lib/google/apis/compute_beta/classes.rb', line 50429

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


50435
50436
50437
# File 'lib/google/apis/compute_beta/classes.rb', line 50435

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50445
50446
50447
# File 'lib/google/apis/compute_beta/classes.rb', line 50445

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50450
50451
50452
# File 'lib/google/apis/compute_beta/classes.rb', line 50450

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50455
50456
50457
# File 'lib/google/apis/compute_beta/classes.rb', line 50455

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50462
50463
50464
50465
50466
50467
50468
50469
# File 'lib/google/apis/compute_beta/classes.rb', line 50462

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end