Class: Google::Apis::ComputeBeta::RegionList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of region resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionList

Returns a new instance of RegionList.



49645
49646
49647
# File 'lib/google/apis/compute_beta/classes.rb', line 49645

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49612
49613
49614
# File 'lib/google/apis/compute_beta/classes.rb', line 49612

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Region>

A list of Region resources. Corresponds to the JSON property items



49617
49618
49619
# File 'lib/google/apis/compute_beta/classes.rb', line 49617

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#regionList for lists of regions. Corresponds to the JSON property kind

Returns:

  • (String)


49623
49624
49625
# File 'lib/google/apis/compute_beta/classes.rb', line 49623

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49633
49634
49635
# File 'lib/google/apis/compute_beta/classes.rb', line 49633

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49638
49639
49640
# File 'lib/google/apis/compute_beta/classes.rb', line 49638

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RegionList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49643
49644
49645
# File 'lib/google/apis/compute_beta/classes.rb', line 49643

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49650
49651
49652
49653
49654
49655
49656
49657
# File 'lib/google/apis/compute_beta/classes.rb', line 49650

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end