Class: Google::Apis::ComputeBeta::RegionList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RegionList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of region resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Region>
A list of Region resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RegionList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RegionList
constructor
A new instance of RegionList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RegionList
Returns a new instance of RegionList.
47170 47171 47172 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47170 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
47137 47138 47139 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47137 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Region>
A list of Region resources.
Corresponds to the JSON property items
47142 47143 47144 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47142 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#regionList for
lists of regions.
Corresponds to the JSON property kind
47148 47149 47150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47148 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
47158 47159 47160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47158 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
47163 47164 47165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47163 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RegionList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
47168 47169 47170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47168 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
47175 47176 47177 47178 47179 47180 47181 47182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 47175 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |