Class: Google::Apis::ComputeBeta::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Returns a new instance of RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.



51555
51556
51557
# File 'lib/google/apis/compute_beta/classes.rb', line 51555

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policysArray<Google::Apis::ComputeBeta::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

Output only. [Output only] Effective firewalls from firewall policy. It applies to Regional Network Firewall Policies in the specified region, Global Network Firewall Policies and Hierachial Firewall Policies which are associated with the network. Corresponds to the JSON property firewallPolicys



51548
51549
51550
# File 'lib/google/apis/compute_beta/classes.rb', line 51548

def firewall_policys
  @firewall_policys
end

#firewallsArray<Google::Apis::ComputeBeta::Firewall>

Effective firewalls on the network. Corresponds to the JSON property firewalls



51553
51554
51555
# File 'lib/google/apis/compute_beta/classes.rb', line 51553

def firewalls
  @firewalls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51560
51561
51562
51563
# File 'lib/google/apis/compute_beta/classes.rb', line 51560

def update!(**args)
  @firewall_policys = args[:firewall_policys] if args.key?(:firewall_policys)
  @firewalls = args[:firewalls] if args.key?(:firewalls)
end