Class: Google::Apis::ComputeBeta::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse

Returns a new instance of RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponse.



50657
50658
50659
# File 'lib/google/apis/compute_beta/classes.rb', line 50657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#firewall_policysArray<Google::Apis::ComputeBeta::RegionNetworkFirewallPoliciesGetEffectiveFirewallsResponseEffectiveFirewallPolicy>

Output only. [Output only] Effective firewalls from firewall policy. It applies to Regional Network Firewall Policies in the specified region, Global Network Firewall Policies and Hierachial Firewall Policies which are associated with the network. Corresponds to the JSON property firewallPolicys



50650
50651
50652
# File 'lib/google/apis/compute_beta/classes.rb', line 50650

def firewall_policys
  @firewall_policys
end

#firewallsArray<Google::Apis::ComputeBeta::Firewall>

Effective firewalls on the network. Corresponds to the JSON property firewalls



50655
50656
50657
# File 'lib/google/apis/compute_beta/classes.rb', line 50655

def firewalls
  @firewalls
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50662
50663
50664
50665
# File 'lib/google/apis/compute_beta/classes.rb', line 50662

def update!(**args)
  @firewall_policys = args[:firewall_policys] if args.key?(:firewall_policys)
  @firewalls = args[:firewalls] if args.key?(:firewalls)
end