Class: Google::Apis::ComputeBeta::ReliabilityRisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReliabilityRisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a ReliabilityRisk resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional textual description of the resource; provided when the resource is created.
-
#details ⇒ Google::Apis::ComputeBeta::RiskDetails
Detailed insights and metrics about a detected reliability risk.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#recommendation ⇒ Google::Apis::ComputeBeta::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisk
constructor
A new instance of ReliabilityRisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisk
Returns a new instance of ReliabilityRisk.
51943 51944 51945 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
51896 51897 51898 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51896 def @creation_timestamp end |
#description ⇒ String
An optional textual description of the resource; provided when the
resource is created.
Corresponds to the JSON property description
51902 51903 51904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51902 def description @description end |
#details ⇒ Google::Apis::ComputeBeta::RiskDetails
Detailed insights and metrics about a detected reliability risk.
Corresponds to the JSON property details
51907 51908 51909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51907 def details @details end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51913 51914 51915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51913 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#reliabilityRisk
for reliability risks.
Corresponds to the JSON property kind
51919 51920 51921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51919 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long and
comply with RFC1035.
Corresponds to the JSON property name
51925 51926 51927 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51925 def name @name end |
#recommendation ⇒ Google::Apis::ComputeBeta::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
Corresponds to the JSON property recommendation
51930 51931 51932 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51930 def recommendation @recommendation end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
51935 51936 51937 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51935 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
51941 51942 51943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51941 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51948 51949 51950 51951 51952 51953 51954 51955 51956 51957 51958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51948 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @recommendation = args[:recommendation] if args.key?(:recommendation) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |