Class: Google::Apis::ComputeBeta::ReliabilityRisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReliabilityRisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a ReliabilityRisk resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional textual description of the resource; provided when the resource is created.
-
#details ⇒ Google::Apis::ComputeBeta::RiskDetails
Detailed insights and metrics about a detected reliability risk.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#recommendation ⇒ Google::Apis::ComputeBeta::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisk
constructor
A new instance of ReliabilityRisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisk
Returns a new instance of ReliabilityRisk.
51861 51862 51863 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51861 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp in RFC3339
text format.
Corresponds to the JSON property creationTimestamp
51814 51815 51816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51814 def @creation_timestamp end |
#description ⇒ String
An optional textual description of the resource; provided when the
resource is created.
Corresponds to the JSON property description
51820 51821 51822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51820 def description @description end |
#details ⇒ Google::Apis::ComputeBeta::RiskDetails
Detailed insights and metrics about a detected reliability risk.
Corresponds to the JSON property details
51825 51826 51827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51825 def details @details end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51831 51832 51833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51831 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#reliabilityRisk
for reliability risks.
Corresponds to the JSON property kind
51837 51838 51839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51837 def kind @kind end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long and
comply with RFC1035.
Corresponds to the JSON property name
51843 51844 51845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51843 def name @name end |
#recommendation ⇒ Google::Apis::ComputeBeta::RiskRecommendation
Recommendation for mitigating a reliability risk, including a reference URL.
Corresponds to the JSON property recommendation
51848 51849 51850 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51848 def recommendation @recommendation end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
51853 51854 51855 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51853 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
51859 51860 51861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51859 def self_link_with_id @self_link_with_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51866 51867 51868 51869 51870 51871 51872 51873 51874 51875 51876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51866 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @details = args[:details] if args.key?(:details) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @recommendation = args[:recommendation] if args.key?(:recommendation) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) end |