Class: Google::Apis::ComputeBeta::ReliabilityRisksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReliabilityRisksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response message for the List method of ReliabilityRisksService.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
[Output Only] An ETag of the resource.
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReliabilityRisk>
A list of ReliabilityRisk resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReliabilityRisksListResponse
constructor
A new instance of ReliabilityRisksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReliabilityRisksListResponse
Returns a new instance of ReliabilityRisksListResponse.
52006 52007 52008 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
[Output Only] An ETag of the resource.
Corresponds to the JSON property etag
51968 51969 51970 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51968 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51973 51974 51975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51973 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReliabilityRisk>
A list of ReliabilityRisk resources.
Corresponds to the JSON property items
51978 51979 51980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51978 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51988 51989 51990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51988 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51993 51994 51995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51993 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
51999 52000 52001 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51999 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ReliabilityRisksListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52004 52005 52006 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52004 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52011 52012 52013 52014 52015 52016 52017 52018 52019 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52011 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |