Class: Google::Apis::ComputeBeta::ReliabilityRisksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response message for the List method of ReliabilityRisksService.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReliabilityRisksListResponse

Returns a new instance of ReliabilityRisksListResponse.



51956
51957
51958
# File 'lib/google/apis/compute_beta/classes.rb', line 51956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51918
51919
51920
# File 'lib/google/apis/compute_beta/classes.rb', line 51918

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51923
51924
51925
# File 'lib/google/apis/compute_beta/classes.rb', line 51923

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReliabilityRisk>

A list of ReliabilityRisk resources. Corresponds to the JSON property items



51928
51929
51930
# File 'lib/google/apis/compute_beta/classes.rb', line 51928

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51938
51939
51940
# File 'lib/google/apis/compute_beta/classes.rb', line 51938

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51943
51944
51945
# File 'lib/google/apis/compute_beta/classes.rb', line 51943

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51949
51950
51951
# File 'lib/google/apis/compute_beta/classes.rb', line 51949

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReliabilityRisksListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51954
51955
51956
# File 'lib/google/apis/compute_beta/classes.rb', line 51954

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51961
51962
51963
51964
51965
51966
51967
51968
51969
# File 'lib/google/apis/compute_beta/classes.rb', line 51961

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end