Class: Google::Apis::ComputeBeta::ReliabilityRisksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response message for the List method of ReliabilityRisksService.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReliabilityRisksListResponse

Returns a new instance of ReliabilityRisksListResponse.



51924
51925
51926
# File 'lib/google/apis/compute_beta/classes.rb', line 51924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51886
51887
51888
# File 'lib/google/apis/compute_beta/classes.rb', line 51886

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51891
51892
51893
# File 'lib/google/apis/compute_beta/classes.rb', line 51891

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReliabilityRisk>

A list of ReliabilityRisk resources. Corresponds to the JSON property items



51896
51897
51898
# File 'lib/google/apis/compute_beta/classes.rb', line 51896

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51906
51907
51908
# File 'lib/google/apis/compute_beta/classes.rb', line 51906

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51911
51912
51913
# File 'lib/google/apis/compute_beta/classes.rb', line 51911

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51917
51918
51919
# File 'lib/google/apis/compute_beta/classes.rb', line 51917

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReliabilityRisksListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51922
51923
51924
# File 'lib/google/apis/compute_beta/classes.rb', line 51922

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51929
51930
51931
51932
51933
51934
51935
51936
51937
# File 'lib/google/apis/compute_beta/classes.rb', line 51929

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end