Class: Google::Apis::ComputeBeta::Reservation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reservation resource. A reservation ensures that capacity is held in a specific zone even if the reserved VMs are not running. For more information, read Reserving zonal resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Reservation

Returns a new instance of Reservation.



47785
47786
47787
# File 'lib/google/apis/compute_beta/classes.rb', line 47785

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advanced_deployment_controlGoogle::Apis::ComputeBeta::ReservationAdvancedDeploymentControl

Advance control for cluster management, applicable only to DENSE deployment type reservations. Corresponds to the JSON property advancedDeploymentControl



47613
47614
47615
# File 'lib/google/apis/compute_beta/classes.rb', line 47613

def advanced_deployment_control
  @advanced_deployment_control
end

#aggregate_reservationGoogle::Apis::ComputeBeta::AllocationAggregateReservation

This reservation type is specified by total resource amounts (e.g. total count of CPUs) and can account for multiple instance SKUs. In other words, one can create instances of varying shapes against this reservation. Corresponds to the JSON property aggregateReservation



47620
47621
47622
# File 'lib/google/apis/compute_beta/classes.rb', line 47620

def aggregate_reservation
  @aggregate_reservation
end

#commitmentString

Output only. [Output Only] Full or partial URL to a parent commitment. This field displays for reservations that are tied to a commitment. Corresponds to the JSON property commitment

Returns:

  • (String)


47627
47628
47629
# File 'lib/google/apis/compute_beta/classes.rb', line 47627

def commitment
  @commitment
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


47633
47634
47635
# File 'lib/google/apis/compute_beta/classes.rb', line 47633

def creation_timestamp
  @creation_timestamp
end

#delete_after_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property deleteAfterDuration



47641
47642
47643
# File 'lib/google/apis/compute_beta/classes.rb', line 47641

def delete_after_duration
  @delete_after_duration
end

#delete_at_timeString

Absolute time in future when the reservation will be auto-deleted by Compute Engine. Timestamp is represented inRFC3339 text format. Corresponds to the JSON property deleteAtTime

Returns:

  • (String)


47648
47649
47650
# File 'lib/google/apis/compute_beta/classes.rb', line 47648

def delete_at_time
  @delete_at_time
end

#deployment_typeString

Specifies the deployment strategy for this reservation. Corresponds to the JSON property deploymentType

Returns:

  • (String)


47653
47654
47655
# File 'lib/google/apis/compute_beta/classes.rb', line 47653

def deployment_type
  @deployment_type
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


47659
47660
47661
# File 'lib/google/apis/compute_beta/classes.rb', line 47659

def description
  @description
end

#enable_emergent_maintenanceBoolean Also known as: enable_emergent_maintenance?

Indicates whether Compute Engine allows unplanned maintenance for your VMs; for example, to fix hardware errors. Corresponds to the JSON property enableEmergentMaintenance

Returns:

  • (Boolean)


47665
47666
47667
# File 'lib/google/apis/compute_beta/classes.rb', line 47665

def enable_emergent_maintenance
  @enable_emergent_maintenance
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


47673
47674
47675
# File 'lib/google/apis/compute_beta/classes.rb', line 47673

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#reservations for reservations. Corresponds to the JSON property kind

Returns:

  • (String)


47679
47680
47681
# File 'lib/google/apis/compute_beta/classes.rb', line 47679

def kind
  @kind
end

#linked_commitmentsArray<String>

Output only. [Output Only] Full or partial URL to parent commitments. This field displays for reservations that are tied to multiple commitments. Corresponds to the JSON property linkedCommitments

Returns:

  • (Array<String>)


47686
47687
47688
# File 'lib/google/apis/compute_beta/classes.rb', line 47686

def linked_commitments
  @linked_commitments
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


47698
47699
47700
# File 'lib/google/apis/compute_beta/classes.rb', line 47698

def name
  @name
end

#protection_tierString

Protection tier for the workload which specifies the workload expectations in the event of infrastructure failures at data center (e.g. power and/or cooling failures). Corresponds to the JSON property protectionTier

Returns:

  • (String)


47705
47706
47707
# File 'lib/google/apis/compute_beta/classes.rb', line 47705

def protection_tier
  @protection_tier
end

#reservation_modeString

Output only. [Output only] Indicates the reservation mode of the reservation. Corresponds to the JSON property reservationMode

Returns:

  • (String)


47710
47711
47712
# File 'lib/google/apis/compute_beta/classes.rb', line 47710

def reservation_mode
  @reservation_mode
end

#reservation_sharing_policyGoogle::Apis::ComputeBeta::AllocationReservationSharingPolicy

Specify the reservation sharing policy. If unspecified, the reservation will not be shared with Google Cloud managed services. Corresponds to the JSON property reservationSharingPolicy



47716
47717
47718
# File 'lib/google/apis/compute_beta/classes.rb', line 47716

def reservation_sharing_policy
  @reservation_sharing_policy
end

#resource_policiesHash<String,String>

Resource policies to be added to this reservation. The key is defined by user, and the value is resource policy url. This is to define placement policy with reservation. Corresponds to the JSON property resourcePolicies

Returns:

  • (Hash<String,String>)


47723
47724
47725
# File 'lib/google/apis/compute_beta/classes.rb', line 47723

def resource_policies
  @resource_policies
end

#resource_statusGoogle::Apis::ComputeBeta::AllocationResourceStatus

[Output Only] Contains output only fields. Corresponds to the JSON property resourceStatus



47728
47729
47730
# File 'lib/google/apis/compute_beta/classes.rb', line 47728

def resource_status
  @resource_status
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


47733
47734
47735
# File 'lib/google/apis/compute_beta/classes.rb', line 47733

def satisfies_pzs
  @satisfies_pzs
end

#scheduling_typeString

The type of maintenance for the reservation. Corresponds to the JSON property schedulingType

Returns:

  • (String)


47739
47740
47741
# File 'lib/google/apis/compute_beta/classes.rb', line 47739

def scheduling_type
  @scheduling_type
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47745
47746
47747
# File 'lib/google/apis/compute_beta/classes.rb', line 47745

def self_link
  @self_link
end

#share_settingsGoogle::Apis::ComputeBeta::ShareSettings

The share setting for reservations and sole tenancy node groups. Corresponds to the JSON property shareSettings



47750
47751
47752
# File 'lib/google/apis/compute_beta/classes.rb', line 47750

def share_settings
  @share_settings
end

#specific_reservationGoogle::Apis::ComputeBeta::AllocationSpecificSkuReservation

This reservation type allows to pre allocate specific instance configuration. Corresponds to the JSON property specificReservation



47756
47757
47758
# File 'lib/google/apis/compute_beta/classes.rb', line 47756

def specific_reservation
  @specific_reservation
end

#specific_reservation_requiredBoolean Also known as: specific_reservation_required?

Indicates whether the reservation can be consumed by VMs with affinity for "any" reservation. If the field is set, then only VMs that target the reservation by name can consume from this reservation. Corresponds to the JSON property specificReservationRequired

Returns:

  • (Boolean)


47763
47764
47765
# File 'lib/google/apis/compute_beta/classes.rb', line 47763

def specific_reservation_required
  @specific_reservation_required
end

#statusString

Output only. [Output Only] The status of the reservation.

  • CREATING: Reservation resources are being allocated.
  • READY: Reservation resources have been allocated, and the reservation is ready for use.
  • DELETING: Reservation deletion is in progress.
  • UPDATING: Reservation update is in progress. Corresponds to the JSON property status

Returns:

  • (String)


47777
47778
47779
# File 'lib/google/apis/compute_beta/classes.rb', line 47777

def status
  @status
end

#zoneString

Zone in which the reservation resides. A zone must be provided if the reservation is created within a commitment. Corresponds to the JSON property zone

Returns:

  • (String)


47783
47784
47785
# File 'lib/google/apis/compute_beta/classes.rb', line 47783

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47790
47791
47792
47793
47794
47795
47796
47797
47798
47799
47800
47801
47802
47803
47804
47805
47806
47807
47808
47809
47810
47811
47812
47813
47814
47815
47816
47817
# File 'lib/google/apis/compute_beta/classes.rb', line 47790

def update!(**args)
  @advanced_deployment_control = args[:advanced_deployment_control] if args.key?(:advanced_deployment_control)
  @aggregate_reservation = args[:aggregate_reservation] if args.key?(:aggregate_reservation)
  @commitment = args[:commitment] if args.key?(:commitment)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @delete_after_duration = args[:delete_after_duration] if args.key?(:delete_after_duration)
  @delete_at_time = args[:delete_at_time] if args.key?(:delete_at_time)
  @deployment_type = args[:deployment_type] if args.key?(:deployment_type)
  @description = args[:description] if args.key?(:description)
  @enable_emergent_maintenance = args[:enable_emergent_maintenance] if args.key?(:enable_emergent_maintenance)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @linked_commitments = args[:linked_commitments] if args.key?(:linked_commitments)
  @name = args[:name] if args.key?(:name)
  @protection_tier = args[:protection_tier] if args.key?(:protection_tier)
  @reservation_mode = args[:reservation_mode] if args.key?(:reservation_mode)
  @reservation_sharing_policy = args[:reservation_sharing_policy] if args.key?(:reservation_sharing_policy)
  @resource_policies = args[:resource_policies] if args.key?(:resource_policies)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @scheduling_type = args[:scheduling_type] if args.key?(:scheduling_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @share_settings = args[:share_settings] if args.key?(:share_settings)
  @specific_reservation = args[:specific_reservation] if args.key?(:specific_reservation)
  @specific_reservation_required = args[:specific_reservation_required] if args.key?(:specific_reservation_required)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end