Class: Google::Apis::ComputeBeta::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



52418
52419
52420
# File 'lib/google/apis/compute_beta/classes.rb', line 52418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52381
52382
52383
# File 'lib/google/apis/compute_beta/classes.rb', line 52381

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



52386
52387
52388
# File 'lib/google/apis/compute_beta/classes.rb', line 52386

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52391
52392
52393
# File 'lib/google/apis/compute_beta/classes.rb', line 52391

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52401
52402
52403
# File 'lib/google/apis/compute_beta/classes.rb', line 52401

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52406
52407
52408
# File 'lib/google/apis/compute_beta/classes.rb', line 52406

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52411
52412
52413
# File 'lib/google/apis/compute_beta/classes.rb', line 52411

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52416
52417
52418
# File 'lib/google/apis/compute_beta/classes.rb', line 52416

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52423
52424
52425
52426
52427
52428
52429
52430
52431
# File 'lib/google/apis/compute_beta/classes.rb', line 52423

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end