Class: Google::Apis::ComputeBeta::ReservationAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of reservations.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ReservationsScopedList>
A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationAggregatedList
constructor
A new instance of ReservationAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationAggregatedList
Returns a new instance of ReservationAggregatedList.
52037 52038 52039 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52037 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52000 52001 52002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52000 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ReservationsScopedList>
A list of Allocation resources.
Corresponds to the JSON property items
52005 52006 52007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52005 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
52010 52011 52012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52010 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52020 52021 52022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52020 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52025 52026 52027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52025 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
52030 52031 52032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52030 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52035 52036 52037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52035 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52042 52043 52044 52045 52046 52047 52048 52049 52050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52042 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |