Class: Google::Apis::ComputeBeta::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



50445
50446
50447
# File 'lib/google/apis/compute_beta/classes.rb', line 50445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50408
50409
50410
# File 'lib/google/apis/compute_beta/classes.rb', line 50408

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



50413
50414
50415
# File 'lib/google/apis/compute_beta/classes.rb', line 50413

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


50418
50419
50420
# File 'lib/google/apis/compute_beta/classes.rb', line 50418

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50428
50429
50430
# File 'lib/google/apis/compute_beta/classes.rb', line 50428

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50433
50434
50435
# File 'lib/google/apis/compute_beta/classes.rb', line 50433

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50438
50439
50440
# File 'lib/google/apis/compute_beta/classes.rb', line 50438

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50443
50444
50445
# File 'lib/google/apis/compute_beta/classes.rb', line 50443

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50450
50451
50452
50453
50454
50455
50456
50457
50458
# File 'lib/google/apis/compute_beta/classes.rb', line 50450

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end