Class: Google::Apis::ComputeBeta::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



49326
49327
49328
# File 'lib/google/apis/compute_beta/classes.rb', line 49326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49289
49290
49291
# File 'lib/google/apis/compute_beta/classes.rb', line 49289

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



49294
49295
49296
# File 'lib/google/apis/compute_beta/classes.rb', line 49294

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49299
49300
49301
# File 'lib/google/apis/compute_beta/classes.rb', line 49299

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49309
49310
49311
# File 'lib/google/apis/compute_beta/classes.rb', line 49309

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49314
49315
49316
# File 'lib/google/apis/compute_beta/classes.rb', line 49314

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


49319
49320
49321
# File 'lib/google/apis/compute_beta/classes.rb', line 49319

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49324
49325
49326
# File 'lib/google/apis/compute_beta/classes.rb', line 49324

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49331
49332
49333
49334
49335
49336
49337
49338
49339
# File 'lib/google/apis/compute_beta/classes.rb', line 49331

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end