Class: Google::Apis::ComputeBeta::ReservationAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of reservations.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationAggregatedList

Returns a new instance of ReservationAggregatedList.



47924
47925
47926
# File 'lib/google/apis/compute_beta/classes.rb', line 47924

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


47887
47888
47889
# File 'lib/google/apis/compute_beta/classes.rb', line 47887

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ReservationsScopedList>

A list of Allocation resources. Corresponds to the JSON property items



47892
47893
47894
# File 'lib/google/apis/compute_beta/classes.rb', line 47892

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


47897
47898
47899
# File 'lib/google/apis/compute_beta/classes.rb', line 47897

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


47907
47908
47909
# File 'lib/google/apis/compute_beta/classes.rb', line 47907

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


47912
47913
47914
# File 'lib/google/apis/compute_beta/classes.rb', line 47912

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


47917
47918
47919
# File 'lib/google/apis/compute_beta/classes.rb', line 47917

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ReservationAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



47922
47923
47924
# File 'lib/google/apis/compute_beta/classes.rb', line 47922

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



47929
47930
47931
47932
47933
47934
47935
47936
47937
# File 'lib/google/apis/compute_beta/classes.rb', line 47929

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end