Class: Google::Apis::ComputeBeta::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeBeta::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
52606 52607 52608 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52606 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
52512 52513 52514 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52512 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
52517 52518 52519 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52517 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeBeta::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
52522 52523 52524 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52522 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
52529 52530 52531 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52529 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
52536 52537 52538 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52536 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
52543 52544 52545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52543 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
52549 52550 52551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52549 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
52557 52558 52559 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52557 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
52562 52563 52564 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52562 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
52567 52568 52569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52567 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
52574 52575 52576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52574 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
52582 52583 52584 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52582 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
52588 52589 52590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52588 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
52594 52595 52596 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52594 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
52599 52600 52601 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52599 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
52604 52605 52606 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52604 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52611 52612 52613 52614 52615 52616 52617 52618 52619 52620 52621 52622 52623 52624 52625 52626 52627 52628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52611 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |