Class: Google::Apis::ComputeBeta::ReservationBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reservation block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlock

Returns a new instance of ReservationBlock.



52247
52248
52249
# File 'lib/google/apis/compute_beta/classes.rb', line 52247

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#block_health_infoGoogle::Apis::ComputeBeta::ReservationBlockHealthInfo

Health information for the reservation block. Corresponds to the JSON property blockHealthInfo



52152
52153
52154
# File 'lib/google/apis/compute_beta/classes.rb', line 52152

def block_health_info
  @block_health_info
end

#countFixnum

Output only. [Output Only] The number of resources that are allocated in this reservation block. Corresponds to the JSON property count

Returns:

  • (Fixnum)


52158
52159
52160
# File 'lib/google/apis/compute_beta/classes.rb', line 52158

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52163
52164
52165
# File 'lib/google/apis/compute_beta/classes.rb', line 52163

def creation_timestamp
  @creation_timestamp
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52170
52171
52172
# File 'lib/google/apis/compute_beta/classes.rb', line 52170

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation block. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


52177
52178
52179
# File 'lib/google/apis/compute_beta/classes.rb', line 52177

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


52184
52185
52186
# File 'lib/google/apis/compute_beta/classes.rb', line 52184

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationBlock for reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


52190
52191
52192
# File 'lib/google/apis/compute_beta/classes.rb', line 52190

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


52198
52199
52200
# File 'lib/google/apis/compute_beta/classes.rb', line 52198

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeBeta::ReservationBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation block. Corresponds to the JSON property physicalTopology



52203
52204
52205
# File 'lib/google/apis/compute_beta/classes.rb', line 52203

def physical_topology
  @physical_topology
end

#reservation_maintenanceGoogle::Apis::ComputeBeta::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationMaintenance



52208
52209
52210
# File 'lib/google/apis/compute_beta/classes.rb', line 52208

def reservation_maintenance
  @reservation_maintenance
end

#reservation_sub_block_countFixnum

Output only. [Output Only] The number of reservation subBlocks associated with this reservation block. Corresponds to the JSON property reservationSubBlockCount

Returns:

  • (Fixnum)


52215
52216
52217
# File 'lib/google/apis/compute_beta/classes.rb', line 52215

def reservation_sub_block_count
  @reservation_sub_block_count
end

#reservation_sub_block_in_use_countFixnum

Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use. Corresponds to the JSON property reservationSubBlockInUseCount

Returns:

  • (Fixnum)


52223
52224
52225
# File 'lib/google/apis/compute_beta/classes.rb', line 52223

def reservation_sub_block_in_use_count
  @reservation_sub_block_in_use_count
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52229
52230
52231
# File 'lib/google/apis/compute_beta/classes.rb', line 52229

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


52235
52236
52237
# File 'lib/google/apis/compute_beta/classes.rb', line 52235

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation block. Corresponds to the JSON property status

Returns:

  • (String)


52240
52241
52242
# File 'lib/google/apis/compute_beta/classes.rb', line 52240

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation block resides. Corresponds to the JSON property zone

Returns:

  • (String)


52245
52246
52247
# File 'lib/google/apis/compute_beta/classes.rb', line 52245

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52252
52253
52254
52255
52256
52257
52258
52259
52260
52261
52262
52263
52264
52265
52266
52267
52268
52269
# File 'lib/google/apis/compute_beta/classes.rb', line 52252

def update!(**args)
  @block_health_info = args[:block_health_info] if args.key?(:block_health_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance)
  @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count)
  @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end