Class: Google::Apis::ComputeBeta::ReservationBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reservation block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlock

Returns a new instance of ReservationBlock.



49514
49515
49516
# File 'lib/google/apis/compute_beta/classes.rb', line 49514

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#countFixnum

Output only. [Output Only] The number of resources that are allocated in this reservation block. Corresponds to the JSON property count

Returns:

  • (Fixnum)


49420
49421
49422
# File 'lib/google/apis/compute_beta/classes.rb', line 49420

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


49425
49426
49427
# File 'lib/google/apis/compute_beta/classes.rb', line 49425

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeBeta::ReservationBlockHealthInfo

Health information for the reservation block. Corresponds to the JSON property healthInfo



49430
49431
49432
# File 'lib/google/apis/compute_beta/classes.rb', line 49430

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


49437
49438
49439
# File 'lib/google/apis/compute_beta/classes.rb', line 49437

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation block. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


49444
49445
49446
# File 'lib/google/apis/compute_beta/classes.rb', line 49444

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


49451
49452
49453
# File 'lib/google/apis/compute_beta/classes.rb', line 49451

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationBlock for reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


49457
49458
49459
# File 'lib/google/apis/compute_beta/classes.rb', line 49457

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation block generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


49465
49466
49467
# File 'lib/google/apis/compute_beta/classes.rb', line 49465

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeBeta::ReservationBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation block. Corresponds to the JSON property physicalTopology



49470
49471
49472
# File 'lib/google/apis/compute_beta/classes.rb', line 49470

def physical_topology
  @physical_topology
end

#reservation_maintenanceGoogle::Apis::ComputeBeta::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationMaintenance



49475
49476
49477
# File 'lib/google/apis/compute_beta/classes.rb', line 49475

def reservation_maintenance
  @reservation_maintenance
end

#reservation_sub_block_countFixnum

Output only. [Output Only] The number of reservation subBlocks associated with this reservation block. Corresponds to the JSON property reservationSubBlockCount

Returns:

  • (Fixnum)


49482
49483
49484
# File 'lib/google/apis/compute_beta/classes.rb', line 49482

def reservation_sub_block_count
  @reservation_sub_block_count
end

#reservation_sub_block_in_use_countFixnum

Output only. [Output Only] The number of in-use reservation subBlocks associated with this reservation block. If at least one VM is running on a subBlock, it is considered in-use. Corresponds to the JSON property reservationSubBlockInUseCount

Returns:

  • (Fixnum)


49490
49491
49492
# File 'lib/google/apis/compute_beta/classes.rb', line 49490

def reservation_sub_block_in_use_count
  @reservation_sub_block_in_use_count
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49496
49497
49498
# File 'lib/google/apis/compute_beta/classes.rb', line 49496

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


49502
49503
49504
# File 'lib/google/apis/compute_beta/classes.rb', line 49502

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation block. Corresponds to the JSON property status

Returns:

  • (String)


49507
49508
49509
# File 'lib/google/apis/compute_beta/classes.rb', line 49507

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation block resides. Corresponds to the JSON property zone

Returns:

  • (String)


49512
49513
49514
# File 'lib/google/apis/compute_beta/classes.rb', line 49512

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49519
49520
49521
49522
49523
49524
49525
49526
49527
49528
49529
49530
49531
49532
49533
49534
49535
49536
# File 'lib/google/apis/compute_beta/classes.rb', line 49519

def update!(**args)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance)
  @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count)
  @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end