Class: Google::Apis::ComputeBeta::ReservationBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation block resource.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeBeta::ReservationBlockHealthInfo
Health information for the reservation block.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
Output only.
-
#reservation_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#reservation_sub_block_count ⇒ Fixnum
Output only.
-
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlock
constructor
A new instance of ReservationBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlock
Returns a new instance of ReservationBlock.
48112 48113 48114 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48112 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Output only. [Output Only] The number of resources that are allocated in this
reservation block.
Corresponds to the JSON property count
48018 48019 48020 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48018 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
48023 48024 48025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48023 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeBeta::ReservationBlockHealthInfo
Health information for the reservation block.
Corresponds to the JSON property healthInfo
48028 48029 48030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48028 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
48035 48036 48037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48035 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation block.
Corresponds to the JSON property inUseCount
48042 48043 48044 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48042 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
48049 48050 48051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48049 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationBlock for reservation blocks.
Corresponds to the JSON property kind
48055 48056 48057 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48055 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation block generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
48063 48064 48065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48063 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation block.
Corresponds to the JSON property physicalTopology
48068 48069 48070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48068 def physical_topology @physical_topology end |
#reservation_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationMaintenance
48073 48074 48075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48073 def reservation_maintenance @reservation_maintenance end |
#reservation_sub_block_count ⇒ Fixnum
Output only. [Output Only] The number of reservation subBlocks associated with
this
reservation block.
Corresponds to the JSON property reservationSubBlockCount
48080 48081 48082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48080 def reservation_sub_block_count @reservation_sub_block_count end |
#reservation_sub_block_in_use_count ⇒ Fixnum
Output only. [Output Only] The number of in-use reservation subBlocks
associated with
this reservation block. If at least one VM is running on a subBlock, it is
considered in-use.
Corresponds to the JSON property reservationSubBlockInUseCount
48088 48089 48090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48088 def reservation_sub_block_in_use_count @reservation_sub_block_in_use_count end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
48094 48095 48096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48094 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
48100 48101 48102 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48100 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation block.
Corresponds to the JSON property status
48105 48106 48107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48105 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation block resides.
Corresponds to the JSON property zone
48110 48111 48112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48110 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48117 48118 48119 48120 48121 48122 48123 48124 48125 48126 48127 48128 48129 48130 48131 48132 48133 48134 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48117 def update!(**args) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_maintenance = args[:reservation_maintenance] if args.key?(:reservation_maintenance) @reservation_sub_block_count = args[:reservation_sub_block_count] if args.key?(:reservation_sub_block_count) @reservation_sub_block_in_use_count = args[:reservation_sub_block_in_use_count] if args.key?(:reservation_sub_block_in_use_count) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |