Class: Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation block.
-
#instances ⇒ Array<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
constructor
A new instance of ReservationBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
Returns a new instance of ReservationBlockPhysicalTopology.
52300 52301 52302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52300 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
52288 52289 52290 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52288 def block @block end |
#cluster ⇒ String
The cluster name of the reservation block.
Corresponds to the JSON property cluster
52293 52294 52295 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52293 def cluster @cluster end |
#instances ⇒ Array<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>
Output only. The detailed instances information for a given Block
Corresponds to the JSON property instances
52298 52299 52300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52298 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52305 52306 52307 52308 52309 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52305 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @instances = args[:instances] if args.key?(:instances) end |