Class: Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation block.
-
#instances ⇒ Array<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
constructor
A new instance of ReservationBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
Returns a new instance of ReservationBlockPhysicalTopology.
51520 51521 51522 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51520 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
51508 51509 51510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51508 def block @block end |
#cluster ⇒ String
The cluster name of the reservation block.
Corresponds to the JSON property cluster
51513 51514 51515 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51513 def cluster @cluster end |
#instances ⇒ Array<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>
Output only. The detailed instances information for a given Block
Corresponds to the JSON property instances
51518 51519 51520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51518 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51525 51526 51527 51528 51529 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51525 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @instances = args[:instances] if args.key?(:instances) end |