Class: Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopology

Returns a new instance of ReservationBlockPhysicalTopology.



50708
50709
50710
# File 'lib/google/apis/compute_beta/classes.rb', line 50708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The hash of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


50696
50697
50698
# File 'lib/google/apis/compute_beta/classes.rb', line 50696

def block
  @block
end

#clusterString

The cluster name of the reservation block. Corresponds to the JSON property cluster

Returns:

  • (String)


50701
50702
50703
# File 'lib/google/apis/compute_beta/classes.rb', line 50701

def cluster
  @cluster
end

#instancesArray<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>

Output only. The detailed instances information for a given Block Corresponds to the JSON property instances



50706
50707
50708
# File 'lib/google/apis/compute_beta/classes.rb', line 50706

def instances
  @instances
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50713
50714
50715
50716
50717
# File 'lib/google/apis/compute_beta/classes.rb', line 50713

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @instances = args[:instances] if args.key?(:instances)
end