Class: Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation block.
-
#instances ⇒ Array<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
constructor
A new instance of ReservationBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlockPhysicalTopology
Returns a new instance of ReservationBlockPhysicalTopology.
48187 48188 48189 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48187 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
48175 48176 48177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48175 def block @block end |
#cluster ⇒ String
The cluster name of the reservation block.
Corresponds to the JSON property cluster
48180 48181 48182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48180 def cluster @cluster end |
#instances ⇒ Array<Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstance>
Output only. The detailed instances information for a given Block
Corresponds to the JSON property instances
48185 48186 48187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48185 def instances @instances end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48192 48193 48194 48195 48196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48192 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @instances = args[:instances] if args.key?(:instances) end |