Class: Google::Apis::ComputeBeta::ReservationBlockPhysicalTopologyInstancePhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The PhysicalHostTopology of the instance within a Block resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlockPhysicalTopologyInstancePhysicalHostTopology

Returns a new instance of ReservationBlockPhysicalTopologyInstancePhysicalHostTopology.



48244
48245
48246
# File 'lib/google/apis/compute_beta/classes.rb', line 48244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hostString

Host hash for a given instance Corresponds to the JSON property host

Returns:

  • (String)


48237
48238
48239
# File 'lib/google/apis/compute_beta/classes.rb', line 48237

def host
  @host
end

#sub_blockString

Sub block hash for a given instance Corresponds to the JSON property subBlock

Returns:

  • (String)


48242
48243
48244
# File 'lib/google/apis/compute_beta/classes.rb', line 48242

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48249
48250
48251
48252
# File 'lib/google/apis/compute_beta/classes.rb', line 48249

def update!(**args)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end