Class: Google::Apis::ComputeBeta::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



52427
52428
52429
# File 'lib/google/apis/compute_beta/classes.rb', line 52427

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52394
52395
52396
# File 'lib/google/apis/compute_beta/classes.rb', line 52394

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



52399
52400
52401
# File 'lib/google/apis/compute_beta/classes.rb', line 52399

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


52405
52406
52407
# File 'lib/google/apis/compute_beta/classes.rb', line 52405

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52415
52416
52417
# File 'lib/google/apis/compute_beta/classes.rb', line 52415

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52420
52421
52422
# File 'lib/google/apis/compute_beta/classes.rb', line 52420

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



52425
52426
52427
# File 'lib/google/apis/compute_beta/classes.rb', line 52425

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52432
52433
52434
52435
52436
52437
52438
52439
# File 'lib/google/apis/compute_beta/classes.rb', line 52432

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end