Class: Google::Apis::ComputeBeta::ReservationBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation blocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationBlock>
A list of reservation block resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationBlocksListResponse
constructor
A new instance of ReservationBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationBlocksListResponse
Returns a new instance of ReservationBlocksListResponse.
52427 52428 52429 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52427 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52394 52395 52396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52394 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationBlock>
A list of reservation block resources.
Corresponds to the JSON property items
52399 52400 52401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52399 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationBlock for a list of reservation
blocks.
Corresponds to the JSON property kind
52405 52406 52407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52405 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52415 52416 52417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52415 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52420 52421 52422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52420 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
52425 52426 52427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52425 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52432 52433 52434 52435 52436 52437 52438 52439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52432 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |