Class: Google::Apis::ComputeBeta::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



51647
51648
51649
# File 'lib/google/apis/compute_beta/classes.rb', line 51647

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51614
51615
51616
# File 'lib/google/apis/compute_beta/classes.rb', line 51614

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



51619
51620
51621
# File 'lib/google/apis/compute_beta/classes.rb', line 51619

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


51625
51626
51627
# File 'lib/google/apis/compute_beta/classes.rb', line 51625

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51635
51636
51637
# File 'lib/google/apis/compute_beta/classes.rb', line 51635

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51640
51641
51642
# File 'lib/google/apis/compute_beta/classes.rb', line 51640

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



51645
51646
51647
# File 'lib/google/apis/compute_beta/classes.rb', line 51645

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51652
51653
51654
51655
51656
51657
51658
51659
# File 'lib/google/apis/compute_beta/classes.rb', line 51652

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end