Class: Google::Apis::ComputeBeta::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



49716
49717
49718
# File 'lib/google/apis/compute_beta/classes.rb', line 49716

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49683
49684
49685
# File 'lib/google/apis/compute_beta/classes.rb', line 49683

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



49688
49689
49690
# File 'lib/google/apis/compute_beta/classes.rb', line 49688

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


49694
49695
49696
# File 'lib/google/apis/compute_beta/classes.rb', line 49694

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49704
49705
49706
# File 'lib/google/apis/compute_beta/classes.rb', line 49704

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49709
49710
49711
# File 'lib/google/apis/compute_beta/classes.rb', line 49709

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



49714
49715
49716
# File 'lib/google/apis/compute_beta/classes.rb', line 49714

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49721
49722
49723
49724
49725
49726
49727
49728
# File 'lib/google/apis/compute_beta/classes.rb', line 49721

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end