Class: Google::Apis::ComputeBeta::ReservationBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation blocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationBlocksListResponse

Returns a new instance of ReservationBlocksListResponse.



48314
48315
48316
# File 'lib/google/apis/compute_beta/classes.rb', line 48314

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48281
48282
48283
# File 'lib/google/apis/compute_beta/classes.rb', line 48281

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationBlock>

A list of reservation block resources. Corresponds to the JSON property items



48286
48287
48288
# File 'lib/google/apis/compute_beta/classes.rb', line 48286

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationBlock for a list of reservation blocks. Corresponds to the JSON property kind

Returns:

  • (String)


48292
48293
48294
# File 'lib/google/apis/compute_beta/classes.rb', line 48292

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48302
48303
48304
# File 'lib/google/apis/compute_beta/classes.rb', line 48302

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48307
48308
48309
# File 'lib/google/apis/compute_beta/classes.rb', line 48307

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



48312
48313
48314
# File 'lib/google/apis/compute_beta/classes.rb', line 48312

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48319
48320
48321
48322
48323
48324
48325
48326
# File 'lib/google/apis/compute_beta/classes.rb', line 48319

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end