Class: Google::Apis::ComputeBeta::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



52902
52903
52904
# File 'lib/google/apis/compute_beta/classes.rb', line 52902

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52869
52870
52871
# File 'lib/google/apis/compute_beta/classes.rb', line 52869

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



52874
52875
52876
# File 'lib/google/apis/compute_beta/classes.rb', line 52874

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


52880
52881
52882
# File 'lib/google/apis/compute_beta/classes.rb', line 52880

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52890
52891
52892
# File 'lib/google/apis/compute_beta/classes.rb', line 52890

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52895
52896
52897
# File 'lib/google/apis/compute_beta/classes.rb', line 52895

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52900
52901
52902
# File 'lib/google/apis/compute_beta/classes.rb', line 52900

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52907
52908
52909
52910
52911
52912
52913
52914
# File 'lib/google/apis/compute_beta/classes.rb', line 52907

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end