Class: Google::Apis::ComputeBeta::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
52902 52903 52904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
52869 52870 52871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52869 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
52874 52875 52876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52874 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
52880 52881 52882 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52880 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52890 52891 52892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52890 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52895 52896 52897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52895 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52900 52901 52902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52900 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52907 52908 52909 52910 52911 52912 52913 52914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52907 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |