Class: Google::Apis::ComputeBeta::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
52553 52554 52555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52553 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
52520 52521 52522 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52520 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
52525 52526 52527 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52525 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
52531 52532 52533 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52531 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52541 52542 52543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52541 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52546 52547 52548 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52546 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52551 52552 52553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52551 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52558 52559 52560 52561 52562 52563 52564 52565 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52558 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |