Class: Google::Apis::ComputeBeta::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
51832 51833 51834 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51832 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51799 51800 51801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51799 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
51804 51805 51806 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51804 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
51810 51811 51812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51810 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51820 51821 51822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51820 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51825 51826 51827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51825 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51830 51831 51832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51830 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51837 51838 51839 51840 51841 51842 51843 51844 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51837 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |