Class: Google::Apis::ComputeBeta::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
51773 51774 51775 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
51740 51741 51742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51740 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
51745 51746 51747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51745 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
51751 51752 51753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51751 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51761 51762 51763 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51761 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51766 51767 51768 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51766 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51771 51772 51773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51771 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51778 51779 51780 51781 51782 51783 51784 51785 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51778 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |