Class: Google::Apis::ComputeBeta::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



50961
50962
50963
# File 'lib/google/apis/compute_beta/classes.rb', line 50961

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50928
50929
50930
# File 'lib/google/apis/compute_beta/classes.rb', line 50928

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



50933
50934
50935
# File 'lib/google/apis/compute_beta/classes.rb', line 50933

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


50939
50940
50941
# File 'lib/google/apis/compute_beta/classes.rb', line 50939

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50949
50950
50951
# File 'lib/google/apis/compute_beta/classes.rb', line 50949

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50954
50955
50956
# File 'lib/google/apis/compute_beta/classes.rb', line 50954

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50959
50960
50961
# File 'lib/google/apis/compute_beta/classes.rb', line 50959

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50966
50967
50968
50969
50970
50971
50972
50973
# File 'lib/google/apis/compute_beta/classes.rb', line 50966

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end