Class: Google::Apis::ComputeBeta::ReservationList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationList

Returns a new instance of ReservationList.



49842
49843
49844
# File 'lib/google/apis/compute_beta/classes.rb', line 49842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49809
49810
49811
# File 'lib/google/apis/compute_beta/classes.rb', line 49809

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Reservation>

[Output Only] A list of Allocation resources. Corresponds to the JSON property items



49814
49815
49816
# File 'lib/google/apis/compute_beta/classes.rb', line 49814

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Always compute#reservationsList for listsof reservations Corresponds to the JSON property kind

Returns:

  • (String)


49820
49821
49822
# File 'lib/google/apis/compute_beta/classes.rb', line 49820

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49830
49831
49832
# File 'lib/google/apis/compute_beta/classes.rb', line 49830

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49835
49836
49837
# File 'lib/google/apis/compute_beta/classes.rb', line 49835

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49840
49841
49842
# File 'lib/google/apis/compute_beta/classes.rb', line 49840

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49847
49848
49849
49850
49851
49852
49853
49854
# File 'lib/google/apis/compute_beta/classes.rb', line 49847

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end