Class: Google::Apis::ComputeBeta::ReservationList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationList
constructor
A new instance of ReservationList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationList
Returns a new instance of ReservationList.
48440 48441 48442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48440 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
48407 48408 48409 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48407 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Reservation>
[Output Only] A list of Allocation resources.
Corresponds to the JSON property items
48412 48413 48414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48412 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Always compute#reservationsList
for listsof reservations
Corresponds to the JSON property kind
48418 48419 48420 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48418 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
48428 48429 48430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48428 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
48433 48434 48435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48433 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
48438 48439 48440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48438 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48445 48446 48447 48448 48449 48450 48451 48452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48445 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |