Class: Google::Apis::ComputeBeta::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
52006 52007 52008 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52006 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
51949 51950 51951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51949 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
51956 51957 51958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51956 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
51962 51963 51964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51962 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
51967 51968 51969 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51967 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
51972 51973 51974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51972 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
51978 51979 51980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51978 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
51984 51985 51986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51984 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
51989 51990 51991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51989 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
51994 51995 51996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51994 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
51999 52000 52001 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51999 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
52004 52005 52006 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52004 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52011 52012 52013 52014 52015 52016 52017 52018 52019 52020 52021 52022 52023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52011 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |