Class: Google::Apis::ComputeBeta::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
51135 51136 51137 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
51078 51079 51080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51078 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
51085 51086 51087 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51085 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
51091 51092 51093 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51091 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
51096 51097 51098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51096 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
51101 51102 51103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51101 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
51107 51108 51109 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51107 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
51113 51114 51115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51113 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
51118 51119 51120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51118 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
51123 51124 51125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51123 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
51128 51129 51130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51128 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
51133 51134 51135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51133 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51140 51141 51142 51143 51144 51145 51146 51147 51148 51149 51150 51151 51152 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51140 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |