Class: Google::Apis::ComputeBeta::ReservationSlot
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlot
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation slot resource.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlot
constructor
A new instance of ReservationSlot.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlot
Returns a new instance of ReservationSlot.
50016 50017 50018 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50016 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] The creation timestamp, formatted asRFC3339 text.
Corresponds to the JSON property creationTimestamp
49959 49960 49961 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49959 def @creation_timestamp end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for this resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
49966 49967 49968 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49966 def id @id end |
#kind ⇒ String
Output only. [Output Only] The type of resource. Alwayscompute#reservationSlot
for reservation slots.
Corresponds to the JSON property kind
49972 49973 49974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49972 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of the reservation slot.
Corresponds to the JSON property name
49977 49978 49979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49977 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology
Output only. [Output Only] The physical topology of the reservation slot.
Corresponds to the JSON property physicalTopology
49982 49983 49984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49982 def physical_topology @physical_topology end |
#self_link ⇒ String
Output only. [Output Only] A server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
49988 49989 49990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49988 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] A server-defined URL for this resource with the
resource ID.
Corresponds to the JSON property selfLinkWithId
49994 49995 49996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49994 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeBeta::ShareSettings
The share setting for reservations and sole tenancy node groups.
Corresponds to the JSON property shareSettings
49999 50000 50001 |
# File 'lib/google/apis/compute_beta/classes.rb', line 49999 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The state of the reservation slot.
Corresponds to the JSON property state
50004 50005 50006 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50004 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::ReservationSlotStatus
Output only. [Output Only] The status of the reservation slot.
Corresponds to the JSON property status
50009 50010 50011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50009 def status @status end |
#zone ⇒ String
Output only. [Output Only] The zone in which the reservation slot resides.
Corresponds to the JSON property zone
50014 50015 50016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50014 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50021 50022 50023 50024 50025 50026 50027 50028 50029 50030 50031 50032 50033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50021 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |