Class: Google::Apis::ComputeBeta::ReservationSlotPhysicalTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotPhysicalTopology

Returns a new instance of ReservationSlotPhysicalTopology.



52772
52773
52774
# File 'lib/google/apis/compute_beta/classes.rb', line 52772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#blockString

The unique identifier of the capacity block within the cluster. Corresponds to the JSON property block

Returns:

  • (String)


52754
52755
52756
# File 'lib/google/apis/compute_beta/classes.rb', line 52754

def block
  @block
end

#clusterString

The cluster name of the reservation sub-block. Corresponds to the JSON property cluster

Returns:

  • (String)


52759
52760
52761
# File 'lib/google/apis/compute_beta/classes.rb', line 52759

def cluster
  @cluster
end

#hostString

The unique identifier of the capacity host within the capacity sub-block. Corresponds to the JSON property host

Returns:

  • (String)


52764
52765
52766
# File 'lib/google/apis/compute_beta/classes.rb', line 52764

def host
  @host
end

#sub_blockString

The unique identifier of the capacity sub-block within the capacity block. Corresponds to the JSON property subBlock

Returns:

  • (String)


52770
52771
52772
# File 'lib/google/apis/compute_beta/classes.rb', line 52770

def sub_block
  @sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52777
52778
52779
52780
52781
52782
# File 'lib/google/apis/compute_beta/classes.rb', line 52777

def update!(**args)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @sub_block = args[:sub_block] if args.key?(:sub_block)
end