Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
53325 53326 53327 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53325 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53292 53293 53294 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53292 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
53297 53298 53299 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53297 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
53303 53304 53305 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53303 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53313 53314 53315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53313 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
53318 53319 53320 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53318 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
53323 53324 53325 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53323 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53330 53331 53332 53333 53334 53335 53336 53337 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53330 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |