Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



53275
53276
53277
# File 'lib/google/apis/compute_beta/classes.rb', line 53275

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53242
53243
53244
# File 'lib/google/apis/compute_beta/classes.rb', line 53242

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



53247
53248
53249
# File 'lib/google/apis/compute_beta/classes.rb', line 53247

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


53253
53254
53255
# File 'lib/google/apis/compute_beta/classes.rb', line 53253

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53263
53264
53265
# File 'lib/google/apis/compute_beta/classes.rb', line 53263

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53268
53269
53270
# File 'lib/google/apis/compute_beta/classes.rb', line 53268

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



53273
53274
53275
# File 'lib/google/apis/compute_beta/classes.rb', line 53273

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53280
53281
53282
53283
53284
53285
53286
53287
# File 'lib/google/apis/compute_beta/classes.rb', line 53280

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end