Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



52894
52895
52896
# File 'lib/google/apis/compute_beta/classes.rb', line 52894

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52861
52862
52863
# File 'lib/google/apis/compute_beta/classes.rb', line 52861

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



52866
52867
52868
# File 'lib/google/apis/compute_beta/classes.rb', line 52866

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


52872
52873
52874
# File 'lib/google/apis/compute_beta/classes.rb', line 52872

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52882
52883
52884
# File 'lib/google/apis/compute_beta/classes.rb', line 52882

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52887
52888
52889
# File 'lib/google/apis/compute_beta/classes.rb', line 52887

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



52892
52893
52894
# File 'lib/google/apis/compute_beta/classes.rb', line 52892

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52899
52900
52901
52902
52903
52904
52905
52906
# File 'lib/google/apis/compute_beta/classes.rb', line 52899

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end