Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation slots within a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSlotsListResponse

Returns a new instance of ReservationSlotsListResponse.



52173
52174
52175
# File 'lib/google/apis/compute_beta/classes.rb', line 52173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

The unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52140
52141
52142
# File 'lib/google/apis/compute_beta/classes.rb', line 52140

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationSlot>

A list of reservation slot resources. Corresponds to the JSON property items



52145
52146
52147
# File 'lib/google/apis/compute_beta/classes.rb', line 52145

def items
  @items
end

#kindString

The type of resource. Alwayscompute#reservationSlot for a list of reservation slots. Corresponds to the JSON property kind

Returns:

  • (String)


52151
52152
52153
# File 'lib/google/apis/compute_beta/classes.rb', line 52151

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52161
52162
52163
# File 'lib/google/apis/compute_beta/classes.rb', line 52161

def next_page_token
  @next_page_token
end

The server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52166
52167
52168
# File 'lib/google/apis/compute_beta/classes.rb', line 52166

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationSlotsListResponse::Warning

An informational warning message. Corresponds to the JSON property warning



52171
52172
52173
# File 'lib/google/apis/compute_beta/classes.rb', line 52171

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52178
52179
52180
52181
52182
52183
52184
52185
# File 'lib/google/apis/compute_beta/classes.rb', line 52178

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end