Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
52114 52115 52116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52114 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52081 52082 52083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52081 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
52086 52087 52088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52086 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
52092 52093 52094 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52092 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52102 52103 52104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52102 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
52107 52108 52109 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52107 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
52112 52113 52114 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52112 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52119 52120 52121 52122 52123 52124 52125 52126 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52119 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |