Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
51302 51303 51304 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51302 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51269 51270 51271 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51269 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
51274 51275 51276 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51274 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
51280 51281 51282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51280 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51290 51291 51292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51290 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
51295 51296 51297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51295 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
51300 51301 51302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51300 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51307 51308 51309 51310 51311 51312 51313 51314 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51307 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |