Class: Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSlotsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation slots within a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
-
#kind ⇒ String
The type of resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
The server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSlotsListResponse
constructor
A new instance of ReservationSlotsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSlotsListResponse
Returns a new instance of ReservationSlotsListResponse.
50164 50165 50166 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
The unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
50131 50132 50133 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50131 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSlot>
A list of reservation slot resources.
Corresponds to the JSON property items
50136 50137 50138 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50136 def items @items end |
#kind ⇒ String
The type of resource. Alwayscompute#reservationSlot for a list of reservation
slots.
Corresponds to the JSON property kind
50142 50143 50144 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50142 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
50152 50153 50154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50152 def next_page_token @next_page_token end |
#self_link ⇒ String
The server-defined URL for this resource.
Corresponds to the JSON property selfLink
50157 50158 50159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50157 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSlotsListResponse::Warning
An informational warning message.
Corresponds to the JSON property warning
50162 50163 50164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50162 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50169 50170 50171 50172 50173 50174 50175 50176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50169 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |