Class: Google::Apis::ComputeBeta::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation subBlock resource.
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Google::Apis::ComputeBeta::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlock
constructor
A new instance of ReservationSubBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlock
Returns a new instance of ReservationSubBlock.
53452 53453 53454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Google::Apis::ComputeBeta::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
Corresponds to the JSON property acceleratorTopologiesInfo
53367 53368 53369 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53367 def accelerator_topologies_info @accelerator_topologies_info end |
#count ⇒ Fixnum
Output only. [Output Only] The number of hosts that are allocated in this
reservation subBlock.
Corresponds to the JSON property count
53373 53374 53375 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53373 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
53378 53379 53380 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53378 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
Corresponds to the JSON property healthInfo
53383 53384 53385 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53383 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
53390 53391 53392 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53390 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation subBlock.
Corresponds to the JSON property inUseCount
53397 53398 53399 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53397 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
53404 53405 53406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53404 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationSubBlock for reservation subBlocks.
Corresponds to the JSON property kind
53410 53411 53412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53410 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation subBlock generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
53418 53419 53420 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53418 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation subBlock.
Corresponds to the JSON property physicalTopology
53423 53424 53425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53423 def physical_topology @physical_topology end |
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationSubBlockMaintenance
53428 53429 53430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53428 def reservation_sub_block_maintenance @reservation_sub_block_maintenance end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
53434 53435 53436 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53434 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
53440 53441 53442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53440 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation subBlock.
Corresponds to the JSON property status
53445 53446 53447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53445 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation subBlock resides.
Corresponds to the JSON property zone
53450 53451 53452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53450 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53457 53458 53459 53460 53461 53462 53463 53464 53465 53466 53467 53468 53469 53470 53471 53472 53473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53457 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |