Class: Google::Apis::ComputeBeta::ReservationSubBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reservation subBlock resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlock

Returns a new instance of ReservationSubBlock.



53093
53094
53095
# File 'lib/google/apis/compute_beta/classes.rb', line 53093

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologies_infoGoogle::Apis::ComputeBeta::AcceleratorTopologiesInfo

Info for accelerator topologies within a densely packed reservation. Corresponds to the JSON property acceleratorTopologiesInfo



53008
53009
53010
# File 'lib/google/apis/compute_beta/classes.rb', line 53008

def accelerator_topologies_info
  @accelerator_topologies_info
end

#countFixnum

Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock. Corresponds to the JSON property count

Returns:

  • (Fixnum)


53014
53015
53016
# File 'lib/google/apis/compute_beta/classes.rb', line 53014

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


53019
53020
53021
# File 'lib/google/apis/compute_beta/classes.rb', line 53019

def creation_timestamp
  @creation_timestamp
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


53026
53027
53028
# File 'lib/google/apis/compute_beta/classes.rb', line 53026

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


53033
53034
53035
# File 'lib/google/apis/compute_beta/classes.rb', line 53033

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


53040
53041
53042
# File 'lib/google/apis/compute_beta/classes.rb', line 53040

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationSubBlock for reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


53046
53047
53048
# File 'lib/google/apis/compute_beta/classes.rb', line 53046

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


53054
53055
53056
# File 'lib/google/apis/compute_beta/classes.rb', line 53054

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation subBlock. Corresponds to the JSON property physicalTopology



53059
53060
53061
# File 'lib/google/apis/compute_beta/classes.rb', line 53059

def physical_topology
  @physical_topology
end

#reservation_sub_block_maintenanceGoogle::Apis::ComputeBeta::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationSubBlockMaintenance



53064
53065
53066
# File 'lib/google/apis/compute_beta/classes.rb', line 53064

def reservation_sub_block_maintenance
  @reservation_sub_block_maintenance
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53070
53071
53072
# File 'lib/google/apis/compute_beta/classes.rb', line 53070

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


53076
53077
53078
# File 'lib/google/apis/compute_beta/classes.rb', line 53076

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation subBlock. Corresponds to the JSON property status

Returns:

  • (String)


53081
53082
53083
# File 'lib/google/apis/compute_beta/classes.rb', line 53081

def status
  @status
end

#sub_block_health_infoGoogle::Apis::ComputeBeta::ReservationSubBlockHealthInfo

Health information for the reservation subBlock. Corresponds to the JSON property subBlockHealthInfo



53086
53087
53088
# File 'lib/google/apis/compute_beta/classes.rb', line 53086

def sub_block_health_info
  @sub_block_health_info
end

#zoneString

Output only. [Output Only] Zone in which the reservation subBlock resides. Corresponds to the JSON property zone

Returns:

  • (String)


53091
53092
53093
# File 'lib/google/apis/compute_beta/classes.rb', line 53091

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53098
53099
53100
53101
53102
53103
53104
53105
53106
53107
53108
53109
53110
53111
53112
53113
53114
# File 'lib/google/apis/compute_beta/classes.rb', line 53098

def update!(**args)
  @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @sub_block_health_info = args[:sub_block_health_info] if args.key?(:sub_block_health_info)
  @zone = args[:zone] if args.key?(:zone)
end