Class: Google::Apis::ComputeBeta::ReservationSubBlock

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a reservation subBlock resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlock

Returns a new instance of ReservationSubBlock.



52350
52351
52352
# File 'lib/google/apis/compute_beta/classes.rb', line 52350

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologies_infoGoogle::Apis::ComputeBeta::AcceleratorTopologiesInfo

Info for accelerator topologies within a densely packed reservation. Corresponds to the JSON property acceleratorTopologiesInfo



52265
52266
52267
# File 'lib/google/apis/compute_beta/classes.rb', line 52265

def accelerator_topologies_info
  @accelerator_topologies_info
end

#countFixnum

Output only. [Output Only] The number of hosts that are allocated in this reservation subBlock. Corresponds to the JSON property count

Returns:

  • (Fixnum)


52271
52272
52273
# File 'lib/google/apis/compute_beta/classes.rb', line 52271

def count
  @count
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


52276
52277
52278
# File 'lib/google/apis/compute_beta/classes.rb', line 52276

def creation_timestamp
  @creation_timestamp
end

#health_infoGoogle::Apis::ComputeBeta::ReservationSubBlockHealthInfo

Health information for the reservation subBlock. Corresponds to the JSON property healthInfo



52281
52282
52283
# File 'lib/google/apis/compute_beta/classes.rb', line 52281

def health_info
  @health_info
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


52288
52289
52290
# File 'lib/google/apis/compute_beta/classes.rb', line 52288

def id
  @id
end

#in_use_countFixnum

Output only. [Output Only] The number of instances that are currently in use on this reservation subBlock. Corresponds to the JSON property inUseCount

Returns:

  • (Fixnum)


52295
52296
52297
# File 'lib/google/apis/compute_beta/classes.rb', line 52295

def in_use_count
  @in_use_count
end

#in_use_host_countFixnum

Output only. Number of hosts currently in use. If there is one or more Instances running on the host, it is considered in use. Corresponds to the JSON property inUseHostCount

Returns:

  • (Fixnum)


52302
52303
52304
# File 'lib/google/apis/compute_beta/classes.rb', line 52302

def in_use_host_count
  @in_use_host_count
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# reservationSubBlock for reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


52308
52309
52310
# File 'lib/google/apis/compute_beta/classes.rb', line 52308

def kind
  @kind
end

#nameString

Output only. [Output Only] The name of this reservation subBlock generated by Google Compute Engine. The name must be 1-63 characters long, and comply with RFC1035 @pattern a-z? Corresponds to the JSON property name

Returns:

  • (String)


52316
52317
52318
# File 'lib/google/apis/compute_beta/classes.rb', line 52316

def name
  @name
end

#physical_topologyGoogle::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology

Output only. [Output Only] The physical topology of the reservation subBlock. Corresponds to the JSON property physicalTopology



52321
52322
52323
# File 'lib/google/apis/compute_beta/classes.rb', line 52321

def physical_topology
  @physical_topology
end

#reservation_sub_block_maintenanceGoogle::Apis::ComputeBeta::GroupMaintenanceInfo

Maintenance Info for ReservationBlocks. Corresponds to the JSON property reservationSubBlockMaintenance



52326
52327
52328
# File 'lib/google/apis/compute_beta/classes.rb', line 52326

def reservation_sub_block_maintenance
  @reservation_sub_block_maintenance
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52332
52333
52334
# File 'lib/google/apis/compute_beta/classes.rb', line 52332

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


52338
52339
52340
# File 'lib/google/apis/compute_beta/classes.rb', line 52338

def self_link_with_id
  @self_link_with_id
end

#statusString

Output only. [Output Only] Status of the reservation subBlock. Corresponds to the JSON property status

Returns:

  • (String)


52343
52344
52345
# File 'lib/google/apis/compute_beta/classes.rb', line 52343

def status
  @status
end

#zoneString

Output only. [Output Only] Zone in which the reservation subBlock resides. Corresponds to the JSON property zone

Returns:

  • (String)


52348
52349
52350
# File 'lib/google/apis/compute_beta/classes.rb', line 52348

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52355
52356
52357
52358
52359
52360
52361
52362
52363
52364
52365
52366
52367
52368
52369
52370
52371
# File 'lib/google/apis/compute_beta/classes.rb', line 52355

def update!(**args)
  @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info)
  @count = args[:count] if args.key?(:count)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @health_info = args[:health_info] if args.key?(:health_info)
  @id = args[:id] if args.key?(:id)
  @in_use_count = args[:in_use_count] if args.key?(:in_use_count)
  @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @physical_topology = args[:physical_topology] if args.key?(:physical_topology)
  @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @status = args[:status] if args.key?(:status)
  @zone = args[:zone] if args.key?(:zone)
end