Class: Google::Apis::ComputeBeta::ReservationSubBlock
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlock
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a reservation subBlock resource.
Instance Attribute Summary collapse
-
#accelerator_topologies_info ⇒ Google::Apis::ComputeBeta::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
-
#count ⇒ Fixnum
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#health_info ⇒ Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
-
#id ⇒ Fixnum
Output only.
-
#in_use_count ⇒ Fixnum
Output only.
-
#in_use_host_count ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology
Output only.
-
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlock
constructor
A new instance of ReservationSubBlock.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlock
Returns a new instance of ReservationSubBlock.
52291 52292 52293 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52291 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topologies_info ⇒ Google::Apis::ComputeBeta::AcceleratorTopologiesInfo
Info for accelerator topologies within a densely packed reservation.
Corresponds to the JSON property acceleratorTopologiesInfo
52206 52207 52208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52206 def accelerator_topologies_info @accelerator_topologies_info end |
#count ⇒ Fixnum
Output only. [Output Only] The number of hosts that are allocated in this
reservation subBlock.
Corresponds to the JSON property count
52212 52213 52214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52212 def count @count end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339 text format.
Corresponds to the JSON property creationTimestamp
52217 52218 52219 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52217 def @creation_timestamp end |
#health_info ⇒ Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
Health information for the reservation subBlock.
Corresponds to the JSON property healthInfo
52222 52223 52224 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52222 def health_info @health_info end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
52229 52230 52231 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52229 def id @id end |
#in_use_count ⇒ Fixnum
Output only. [Output Only] The number of instances that are currently in use
on this
reservation subBlock.
Corresponds to the JSON property inUseCount
52236 52237 52238 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52236 def in_use_count @in_use_count end |
#in_use_host_count ⇒ Fixnum
Output only. Number of hosts currently in use. If there is one or more
Instances running
on the host, it is considered in use.
Corresponds to the JSON property inUseHostCount
52243 52244 52245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52243 def in_use_host_count @in_use_host_count end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
reservationSubBlock for reservation subBlocks.
Corresponds to the JSON property kind
52249 52250 52251 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52249 def kind @kind end |
#name ⇒ String
Output only. [Output Only] The name of this reservation subBlock generated by
Google
Compute Engine. The name must be 1-63 characters long, and comply with
RFC1035 @pattern a-z?
Corresponds to the JSON property name
52257 52258 52259 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52257 def name @name end |
#physical_topology ⇒ Google::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology
Output only. [Output Only] The physical topology of the reservation subBlock.
Corresponds to the JSON property physicalTopology
52262 52263 52264 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52262 def physical_topology @physical_topology end |
#reservation_sub_block_maintenance ⇒ Google::Apis::ComputeBeta::GroupMaintenanceInfo
Maintenance Info for ReservationBlocks.
Corresponds to the JSON property reservationSubBlockMaintenance
52267 52268 52269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52267 def reservation_sub_block_maintenance @reservation_sub_block_maintenance end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
52273 52274 52275 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52273 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
52279 52280 52281 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52279 def self_link_with_id @self_link_with_id end |
#status ⇒ String
Output only. [Output Only] Status of the reservation subBlock.
Corresponds to the JSON property status
52284 52285 52286 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52284 def status @status end |
#zone ⇒ String
Output only. [Output Only] Zone in which the reservation subBlock resides.
Corresponds to the JSON property zone
52289 52290 52291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52289 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52296 52297 52298 52299 52300 52301 52302 52303 52304 52305 52306 52307 52308 52309 52310 52311 52312 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52296 def update!(**args) @accelerator_topologies_info = args[:accelerator_topologies_info] if args.key?(:accelerator_topologies_info) @count = args[:count] if args.key?(:count) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @health_info = args[:health_info] if args.key?(:health_info) @id = args[:id] if args.key?(:id) @in_use_count = args[:in_use_count] if args.key?(:in_use_count) @in_use_host_count = args[:in_use_host_count] if args.key?(:in_use_host_count) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @physical_topology = args[:physical_topology] if args.key?(:physical_topology) @reservation_sub_block_maintenance = args[:reservation_sub_block_maintenance] if args.key?(:reservation_sub_block_maintenance) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @status = args[:status] if args.key?(:status) @zone = args[:zone] if args.key?(:zone) end |