Class: Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Health information for the reservation subBlock.
Instance Attribute Summary collapse
-
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
-
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
-
#health_status ⇒ String
The health status of the reservation subBlock.
-
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
-
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
constructor
A new instance of ReservationSubBlockHealthInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
Returns a new instance of ReservationSubBlockHealthInfo.
52346 52347 52348 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52346 def initialize(**args) update!(**args) end |
Instance Attribute Details
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
Corresponds to the JSON property degradedHostCount
52322 52323 52324 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52322 def degraded_host_count @degraded_host_count end |
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property degradedInfraCount
52328 52329 52330 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52328 def degraded_infra_count @degraded_infra_count end |
#health_status ⇒ String
The health status of the reservation subBlock.
Corresponds to the JSON property healthStatus
52333 52334 52335 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52333 def health_status @health_status end |
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
Corresponds to the JSON property healthyHostCount
52338 52339 52340 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52338 def healthy_host_count @healthy_host_count end |
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property healthyInfraCount
52344 52345 52346 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52344 def healthy_infra_count @healthy_infra_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52351 52352 52353 52354 52355 52356 52357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52351 def update!(**args) @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count) @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count) @health_status = args[:health_status] if args.key?(:health_status) @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count) @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count) end |