Class: Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Health information for the reservation subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlockHealthInfo

Returns a new instance of ReservationSubBlockHealthInfo.



50396
50397
50398
# File 'lib/google/apis/compute_beta/classes.rb', line 50396

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#degraded_host_countFixnum

The number of degraded hosts in the reservation subBlock. Corresponds to the JSON property degradedHostCount

Returns:

  • (Fixnum)


50372
50373
50374
# File 'lib/google/apis/compute_beta/classes.rb', line 50372

def degraded_host_count
  @degraded_host_count
end

#degraded_infra_countFixnum

The number of degraded infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property degradedInfraCount

Returns:

  • (Fixnum)


50378
50379
50380
# File 'lib/google/apis/compute_beta/classes.rb', line 50378

def degraded_infra_count
  @degraded_infra_count
end

#health_statusString

The health status of the reservation subBlock. Corresponds to the JSON property healthStatus

Returns:

  • (String)


50383
50384
50385
# File 'lib/google/apis/compute_beta/classes.rb', line 50383

def health_status
  @health_status
end

#healthy_host_countFixnum

The number of healthy hosts in the reservation subBlock. Corresponds to the JSON property healthyHostCount

Returns:

  • (Fixnum)


50388
50389
50390
# File 'lib/google/apis/compute_beta/classes.rb', line 50388

def healthy_host_count
  @healthy_host_count
end

#healthy_infra_countFixnum

The number of healthy infrastructure (e.g NV link domain) in the reservation subblock. Corresponds to the JSON property healthyInfraCount

Returns:

  • (Fixnum)


50394
50395
50396
# File 'lib/google/apis/compute_beta/classes.rb', line 50394

def healthy_infra_count
  @healthy_infra_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50401
50402
50403
50404
50405
50406
50407
# File 'lib/google/apis/compute_beta/classes.rb', line 50401

def update!(**args)
  @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count)
  @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count)
  @health_status = args[:health_status] if args.key?(:health_status)
  @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count)
  @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count)
end