Class: Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlockHealthInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Health information for the reservation subBlock.
Instance Attribute Summary collapse
-
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
-
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the reservation subblock.
-
#health_status ⇒ String
The health status of the reservation subBlock.
-
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
-
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the reservation subblock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
constructor
A new instance of ReservationSubBlockHealthInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockHealthInfo
Returns a new instance of ReservationSubBlockHealthInfo.
48672 48673 48674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48672 def initialize(**args) update!(**args) end |
Instance Attribute Details
#degraded_host_count ⇒ Fixnum
The number of degraded hosts in the reservation subBlock.
Corresponds to the JSON property degradedHostCount
48648 48649 48650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48648 def degraded_host_count @degraded_host_count end |
#degraded_infra_count ⇒ Fixnum
The number of degraded infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property degradedInfraCount
48654 48655 48656 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48654 def degraded_infra_count @degraded_infra_count end |
#health_status ⇒ String
The health status of the reservation subBlock.
Corresponds to the JSON property healthStatus
48659 48660 48661 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48659 def health_status @health_status end |
#healthy_host_count ⇒ Fixnum
The number of healthy hosts in the reservation subBlock.
Corresponds to the JSON property healthyHostCount
48664 48665 48666 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48664 def healthy_host_count @healthy_host_count end |
#healthy_infra_count ⇒ Fixnum
The number of healthy infrastructure (e.g NV link domain) in the
reservation subblock.
Corresponds to the JSON property healthyInfraCount
48670 48671 48672 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48670 def healthy_infra_count @healthy_infra_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
48677 48678 48679 48680 48681 48682 48683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 48677 def update!(**args) @degraded_host_count = args[:degraded_host_count] if args.key?(:degraded_host_count) @degraded_infra_count = args[:degraded_infra_count] if args.key?(:degraded_infra_count) @health_status = args[:health_status] if args.key?(:health_status) @healthy_host_count = args[:healthy_host_count] if args.key?(:healthy_host_count) @healthy_infra_count = args[:healthy_infra_count] if args.key?(:healthy_infra_count) end |