Class: Google::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlockPhysicalTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#block ⇒ String
The hash of the capacity block within the cluster.
-
#cluster ⇒ String
The cluster name of the reservation subBlock.
-
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
constructor
A new instance of ReservationSubBlockPhysicalTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlockPhysicalTopology
Returns a new instance of ReservationSubBlockPhysicalTopology.
53159 53160 53161 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
The hash of the capacity block within the cluster.
Corresponds to the JSON property block
53147 53148 53149 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53147 def block @block end |
#cluster ⇒ String
The cluster name of the reservation subBlock.
Corresponds to the JSON property cluster
53152 53153 53154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53152 def cluster @cluster end |
#sub_block ⇒ String
The hash of the capacity sub-block within the capacity block.
Corresponds to the JSON property subBlock
53157 53158 53159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53157 def sub_block @sub_block end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53164 53165 53166 53167 53168 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53164 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @sub_block = args[:sub_block] if args.key?(:sub_block) end |