Class: Google::Apis::ComputeBeta::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
54080 54081 54082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54046 54047 54048 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54046 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
54051 54052 54053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54051 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
54058 54059 54060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54058 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54068 54069 54070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54068 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54073 54074 54075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54073 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
54078 54079 54080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54078 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54085 54086 54087 54088 54089 54090 54091 54092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54085 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |