Class: Google::Apis::ComputeBeta::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
53681 53682 53683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53681 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53647 53648 53649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53647 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
53652 53653 53654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53652 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
53659 53660 53661 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53659 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53669 53670 53671 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53669 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53674 53675 53676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53674 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
53679 53680 53681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53679 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53686 53687 53688 53689 53690 53691 53692 53693 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53686 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |