Class: Google::Apis::ComputeBeta::ReservationSubBlocksListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlocksListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of reservation subBlocks under a single reservation.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlock>
A list of reservation subBlock resources.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning
Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksListResponse
constructor
A new instance of ReservationSubBlocksListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksListResponse
Returns a new instance of ReservationSubBlocksListResponse.
53631 53632 53633 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53631 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53597 53598 53599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53597 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlock>
A list of reservation subBlock resources.
Corresponds to the JSON property items
53602 53603 53604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53602 def items @items end |
#kind ⇒ String
Type of the resource. Alwayscompute#reservationSubBlock for a list of
reservation
subBlocks.
Corresponds to the JSON property kind
53609 53610 53611 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53609 def kind @kind end |
#next_page_token ⇒ String
This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53619 53620 53621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53619 def next_page_token @next_page_token end |
#self_link ⇒ String
Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53624 53625 53626 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53624 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning
Informational warning message.
Corresponds to the JSON property warning
53629 53630 53631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53629 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53636 53637 53638 53639 53640 53641 53642 53643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53636 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |