Class: Google::Apis::ComputeBeta::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



53250
53251
53252
# File 'lib/google/apis/compute_beta/classes.rb', line 53250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53216
53217
53218
# File 'lib/google/apis/compute_beta/classes.rb', line 53216

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



53221
53222
53223
# File 'lib/google/apis/compute_beta/classes.rb', line 53221

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


53228
53229
53230
# File 'lib/google/apis/compute_beta/classes.rb', line 53228

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53238
53239
53240
# File 'lib/google/apis/compute_beta/classes.rb', line 53238

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53243
53244
53245
# File 'lib/google/apis/compute_beta/classes.rb', line 53243

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



53248
53249
53250
# File 'lib/google/apis/compute_beta/classes.rb', line 53248

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53255
53256
53257
53258
53259
53260
53261
53262
# File 'lib/google/apis/compute_beta/classes.rb', line 53255

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end