Class: Google::Apis::ComputeBeta::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



52529
52530
52531
# File 'lib/google/apis/compute_beta/classes.rb', line 52529

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52495
52496
52497
# File 'lib/google/apis/compute_beta/classes.rb', line 52495

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



52500
52501
52502
# File 'lib/google/apis/compute_beta/classes.rb', line 52500

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


52507
52508
52509
# File 'lib/google/apis/compute_beta/classes.rb', line 52507

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52517
52518
52519
# File 'lib/google/apis/compute_beta/classes.rb', line 52517

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52522
52523
52524
# File 'lib/google/apis/compute_beta/classes.rb', line 52522

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



52527
52528
52529
# File 'lib/google/apis/compute_beta/classes.rb', line 52527

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52534
52535
52536
52537
52538
52539
52540
52541
# File 'lib/google/apis/compute_beta/classes.rb', line 52534

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end