Class: Google::Apis::ComputeBeta::ReservationSubBlocksListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of reservation subBlocks under a single reservation.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksListResponse

Returns a new instance of ReservationSubBlocksListResponse.



48777
48778
48779
# File 'lib/google/apis/compute_beta/classes.rb', line 48777

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


48743
48744
48745
# File 'lib/google/apis/compute_beta/classes.rb', line 48743

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ReservationSubBlock>

A list of reservation subBlock resources. Corresponds to the JSON property items



48748
48749
48750
# File 'lib/google/apis/compute_beta/classes.rb', line 48748

def items
  @items
end

#kindString

Type of the resource. Alwayscompute#reservationSubBlock for a list of reservation subBlocks. Corresponds to the JSON property kind

Returns:

  • (String)


48755
48756
48757
# File 'lib/google/apis/compute_beta/classes.rb', line 48755

def kind
  @kind
end

#next_page_tokenString

This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


48765
48766
48767
# File 'lib/google/apis/compute_beta/classes.rb', line 48765

def next_page_token
  @next_page_token
end

Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


48770
48771
48772
# File 'lib/google/apis/compute_beta/classes.rb', line 48770

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ReservationSubBlocksListResponse::Warning

Informational warning message. Corresponds to the JSON property warning



48775
48776
48777
# File 'lib/google/apis/compute_beta/classes.rb', line 48775

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48782
48783
48784
48785
48786
48787
48788
48789
# File 'lib/google/apis/compute_beta/classes.rb', line 48782

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end