Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
-
#failure_component ⇒ String
The component that experienced the fault.
-
#fault_reasons ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
constructor
A new instance of ReservationSubBlocksReportFaultyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
Returns a new instance of ReservationSubBlocksReportFaultyRequest.
52574 52575 52576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52574 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
Corresponds to the JSON property disruptionSchedule
52562 52563 52564 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52562 def disruption_schedule @disruption_schedule end |
#failure_component ⇒ String
The component that experienced the fault.
Corresponds to the JSON property failureComponent
52567 52568 52569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52567 def failure_component @failure_component end |
#fault_reasons ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Corresponds to the JSON property faultReasons
52572 52573 52574 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52572 def fault_reasons @fault_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52579 52580 52581 52582 52583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52579 def update!(**args) @disruption_schedule = args[:disruption_schedule] if args.key?(:disruption_schedule) @failure_component = args[:failure_component] if args.key?(:failure_component) @fault_reasons = args[:fault_reasons] if args.key?(:fault_reasons) end |