Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
-
#failure_component ⇒ String
The component that experienced the fault.
-
#fault_reasons ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
constructor
A new instance of ReservationSubBlocksReportFaultyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
Returns a new instance of ReservationSubBlocksReportFaultyRequest.
51762 51763 51764 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51762 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
Corresponds to the JSON property disruptionSchedule
51750 51751 51752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51750 def disruption_schedule @disruption_schedule end |
#failure_component ⇒ String
The component that experienced the fault.
Corresponds to the JSON property failureComponent
51755 51756 51757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51755 def failure_component @failure_component end |
#fault_reasons ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Corresponds to the JSON property faultReasons
51760 51761 51762 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51760 def fault_reasons @fault_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51767 51768 51769 51770 51771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51767 def update!(**args) @disruption_schedule = args[:disruption_schedule] if args.key?(:disruption_schedule) @failure_component = args[:failure_component] if args.key?(:failure_component) @fault_reasons = args[:fault_reasons] if args.key?(:fault_reasons) end |