Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
-
#failure_component ⇒ String
The component that experienced the fault.
-
#fault_reasons ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
constructor
A new instance of ReservationSubBlocksReportFaultyRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequest
Returns a new instance of ReservationSubBlocksReportFaultyRequest.
50605 50606 50607 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disruption_schedule ⇒ String
The disruption schedule for the subBlock.
Corresponds to the JSON property disruptionSchedule
50593 50594 50595 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50593 def disruption_schedule @disruption_schedule end |
#failure_component ⇒ String
The component that experienced the fault.
Corresponds to the JSON property failureComponent
50598 50599 50600 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50598 def failure_component @failure_component end |
#fault_reasons ⇒ Array<Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason>
The reasons for the fault experienced with the subBlock.
Corresponds to the JSON property faultReasons
50603 50604 50605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50603 def fault_reasons @fault_reasons end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50610 50611 50612 50613 50614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50610 def update!(**args) @disruption_schedule = args[:disruption_schedule] if args.key?(:disruption_schedule) @failure_component = args[:failure_component] if args.key?(:failure_component) @fault_reasons = args[:fault_reasons] if args.key?(:fault_reasons) end |