Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



52659
52660
52661
# File 'lib/google/apis/compute_beta/classes.rb', line 52659

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


52652
52653
52654
# File 'lib/google/apis/compute_beta/classes.rb', line 52652

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


52657
52658
52659
# File 'lib/google/apis/compute_beta/classes.rb', line 52657

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52664
52665
52666
52667
# File 'lib/google/apis/compute_beta/classes.rb', line 52664

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end