Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



52600
52601
52602
# File 'lib/google/apis/compute_beta/classes.rb', line 52600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


52593
52594
52595
# File 'lib/google/apis/compute_beta/classes.rb', line 52593

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


52598
52599
52600
# File 'lib/google/apis/compute_beta/classes.rb', line 52598

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52605
52606
52607
52608
# File 'lib/google/apis/compute_beta/classes.rb', line 52605

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end