Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



50631
50632
50633
# File 'lib/google/apis/compute_beta/classes.rb', line 50631

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


50624
50625
50626
# File 'lib/google/apis/compute_beta/classes.rb', line 50624

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


50629
50630
50631
# File 'lib/google/apis/compute_beta/classes.rb', line 50629

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50636
50637
50638
50639
# File 'lib/google/apis/compute_beta/classes.rb', line 50636

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end