Class: Google::Apis::ComputeBeta::ReservationSubBlocksReportFaultyRequestFaultReason

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The reason for the fault experienced with the subBlock.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationSubBlocksReportFaultyRequestFaultReason

Returns a new instance of ReservationSubBlocksReportFaultyRequestFaultReason.



48907
48908
48909
# File 'lib/google/apis/compute_beta/classes.rb', line 48907

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#behaviorString

The behavior of the fault experienced with the subBlock. Corresponds to the JSON property behavior

Returns:

  • (String)


48900
48901
48902
# File 'lib/google/apis/compute_beta/classes.rb', line 48900

def behavior
  @behavior
end

#descriptionString

The description of the fault experienced with the subBlock. Corresponds to the JSON property description

Returns:

  • (String)


48905
48906
48907
# File 'lib/google/apis/compute_beta/classes.rb', line 48905

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



48912
48913
48914
48915
# File 'lib/google/apis/compute_beta/classes.rb', line 48912

def update!(**args)
  @behavior = args[:behavior] if args.key?(:behavior)
  @description = args[:description] if args.key?(:description)
end