Class: Google::Apis::ComputeBeta::ResourcePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Corresponds to the JSON property
description. -
#disk_consistency_group_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
-
#group_placement_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
-
#id ⇒ Fixnum
Output only.
-
#instance_schedule_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#region ⇒ String
Corresponds to the JSON property
region. -
#resource_status ⇒ Google::Apis::ComputeBeta::ResourcePolicyResourceStatus
Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#snapshot_schedule_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk.
-
#status ⇒ String
Output only.
-
#workload_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicy
constructor
A new instance of ResourcePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicy
Returns a new instance of ResourcePolicy.
54190 54191 54192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54190 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
54105 54106 54107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54105 def @creation_timestamp end |
#description ⇒ String
Corresponds to the JSON property description
54110 54111 54112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54110 def description @description end |
#disk_consistency_group_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyDiskConsistencyGroupPolicy
Resource policy for disk consistency groups.
Corresponds to the JSON property diskConsistencyGroupPolicy
54115 54116 54117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54115 def disk_consistency_group_policy @disk_consistency_group_policy end |
#group_placement_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy
A GroupPlacementPolicy specifies resource placement configuration.
It specifies the failure bucket separation
Corresponds to the JSON property groupPlacementPolicy
54121 54122 54123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54121 def group_placement_policy @group_placement_policy end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
54128 54129 54130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54128 def id @id end |
#instance_schedule_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy
An InstanceSchedulePolicy specifies when and how frequent certain
operations are performed on the instance.
Corresponds to the JSON property instanceSchedulePolicy
54134 54135 54136 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54134 def instance_schedule_policy @instance_schedule_policy end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
resource_policies for resource policies.
Corresponds to the JSON property kind
54140 54141 54142 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54140 def kind @kind end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The resource name must be 1-63 characters long, and comply
withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
54152 54153 54154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54152 def name @name end |
#region ⇒ String
Corresponds to the JSON property region
54157 54158 54159 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54157 def region @region end |
#resource_status ⇒ Google::Apis::ComputeBeta::ResourcePolicyResourceStatus
Contains output only fields.
Use this sub-message for all output fields set on ResourcePolicy.
The internal structure of this "status" field should mimic the structure
of ResourcePolicy proto specification.
Corresponds to the JSON property resourceStatus
54165 54166 54167 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54165 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
54171 54172 54173 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54171 def self_link @self_link end |
#snapshot_schedule_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicy
A snapshot schedule policy specifies when and how frequently snapshots are
to be created for the target disk. Also specifies how many and how long
these scheduled snapshots should be retained.
Corresponds to the JSON property snapshotSchedulePolicy
54178 54179 54180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54178 def snapshot_schedule_policy @snapshot_schedule_policy end |
#status ⇒ String
Output only. [Output Only] The status of resource policy creation.
Corresponds to the JSON property status
54183 54184 54185 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54183 def status @status end |
#workload_policy ⇒ Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy
Represents the workload policy.
Corresponds to the JSON property workloadPolicy
54188 54189 54190 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54188 def workload_policy @workload_policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54195 54196 54197 54198 54199 54200 54201 54202 54203 54204 54205 54206 54207 54208 54209 54210 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54195 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy) @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy) @id = args[:id] if args.key?(:id) @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy) @status = args[:status] if args.key?(:status) @workload_policy = args[:workload_policy] if args.key?(:workload_policy) end |