Class: Google::Apis::ComputeBeta::ResourcePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Resource Policy resource. You can use resource policies to schedule actions for some Compute Engine resources. For example, you can use them toschedule persistent disk snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicy

Returns a new instance of ResourcePolicy.



53831
53832
53833
# File 'lib/google/apis/compute_beta/classes.rb', line 53831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


53746
53747
53748
# File 'lib/google/apis/compute_beta/classes.rb', line 53746

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Corresponds to the JSON property description

Returns:

  • (String)


53751
53752
53753
# File 'lib/google/apis/compute_beta/classes.rb', line 53751

def description
  @description
end

#disk_consistency_group_policyGoogle::Apis::ComputeBeta::ResourcePolicyDiskConsistencyGroupPolicy

Resource policy for disk consistency groups. Corresponds to the JSON property diskConsistencyGroupPolicy



53756
53757
53758
# File 'lib/google/apis/compute_beta/classes.rb', line 53756

def disk_consistency_group_policy
  @disk_consistency_group_policy
end

#group_placement_policyGoogle::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation Corresponds to the JSON property groupPlacementPolicy



53762
53763
53764
# File 'lib/google/apis/compute_beta/classes.rb', line 53762

def group_placement_policy
  @group_placement_policy
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


53769
53770
53771
# File 'lib/google/apis/compute_beta/classes.rb', line 53769

def id
  @id
end

#instance_schedule_policyGoogle::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance. Corresponds to the JSON property instanceSchedulePolicy



53775
53776
53777
# File 'lib/google/apis/compute_beta/classes.rb', line 53775

def instance_schedule_policy
  @instance_schedule_policy
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# resource_policies for resource policies. Corresponds to the JSON property kind

Returns:

  • (String)


53781
53782
53783
# File 'lib/google/apis/compute_beta/classes.rb', line 53781

def kind
  @kind
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The resource name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


53793
53794
53795
# File 'lib/google/apis/compute_beta/classes.rb', line 53793

def name
  @name
end

#regionString

Corresponds to the JSON property region

Returns:

  • (String)


53798
53799
53800
# File 'lib/google/apis/compute_beta/classes.rb', line 53798

def region
  @region
end

#resource_statusGoogle::Apis::ComputeBeta::ResourcePolicyResourceStatus

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification. Corresponds to the JSON property resourceStatus



53806
53807
53808
# File 'lib/google/apis/compute_beta/classes.rb', line 53806

def resource_status
  @resource_status
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53812
53813
53814
# File 'lib/google/apis/compute_beta/classes.rb', line 53812

def self_link
  @self_link
end

#snapshot_schedule_policyGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicy

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained. Corresponds to the JSON property snapshotSchedulePolicy



53819
53820
53821
# File 'lib/google/apis/compute_beta/classes.rb', line 53819

def snapshot_schedule_policy
  @snapshot_schedule_policy
end

#statusString

Output only. [Output Only] The status of resource policy creation. Corresponds to the JSON property status

Returns:

  • (String)


53824
53825
53826
# File 'lib/google/apis/compute_beta/classes.rb', line 53824

def status
  @status
end

#workload_policyGoogle::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy

Represents the workload policy. Corresponds to the JSON property workloadPolicy



53829
53830
53831
# File 'lib/google/apis/compute_beta/classes.rb', line 53829

def workload_policy
  @workload_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53836
53837
53838
53839
53840
53841
53842
53843
53844
53845
53846
53847
53848
53849
53850
53851
# File 'lib/google/apis/compute_beta/classes.rb', line 53836

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_consistency_group_policy = args[:disk_consistency_group_policy] if args.key?(:disk_consistency_group_policy)
  @group_placement_policy = args[:group_placement_policy] if args.key?(:group_placement_policy)
  @id = args[:id] if args.key?(:id)
  @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @region = args[:region] if args.key?(:region)
  @resource_status = args[:resource_status] if args.key?(:resource_status)
  @self_link = args[:self_link] if args.key?(:self_link)
  @snapshot_schedule_policy = args[:snapshot_schedule_policy] if args.key?(:snapshot_schedule_policy)
  @status = args[:status] if args.key?(:status)
  @workload_policy = args[:workload_policy] if args.key?(:workload_policy)
end