Class: Google::Apis::ComputeBeta::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
54711 54712 54713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54669 54670 54671 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54669 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54674 54675 54676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54674 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
54679 54680 54681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54679 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
54684 54685 54686 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54684 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54694 54695 54696 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54694 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54699 54700 54701 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54699 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
54704 54705 54706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54704 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54709 54710 54711 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54709 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54716 54717 54718 54719 54720 54721 54722 54723 54724 54725 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54716 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |