Class: Google::Apis::ComputeBeta::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



53160
53161
53162
# File 'lib/google/apis/compute_beta/classes.rb', line 53160

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53118
53119
53120
# File 'lib/google/apis/compute_beta/classes.rb', line 53118

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53123
53124
53125
# File 'lib/google/apis/compute_beta/classes.rb', line 53123

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



53128
53129
53130
# File 'lib/google/apis/compute_beta/classes.rb', line 53128

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


53133
53134
53135
# File 'lib/google/apis/compute_beta/classes.rb', line 53133

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53143
53144
53145
# File 'lib/google/apis/compute_beta/classes.rb', line 53143

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53148
53149
53150
# File 'lib/google/apis/compute_beta/classes.rb', line 53148

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53153
53154
53155
# File 'lib/google/apis/compute_beta/classes.rb', line 53153

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53158
53159
53160
# File 'lib/google/apis/compute_beta/classes.rb', line 53158

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53165
53166
53167
53168
53169
53170
53171
53172
53173
53174
# File 'lib/google/apis/compute_beta/classes.rb', line 53165

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end