Class: Google::Apis::ComputeBeta::ResourcePolicyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of resourcePolicies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyAggregatedList
constructor
A new instance of ResourcePolicyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyAggregatedList
Returns a new instance of ResourcePolicyAggregatedList.
53101 53102 53103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53101 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53059 53060 53061 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53059 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
53064 53065 53066 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53064 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>
A list of ResourcePolicy resources.
Corresponds to the JSON property items
53069 53070 53071 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53069 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
53074 53075 53076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53074 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53084 53085 53086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53084 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53089 53090 53091 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53089 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
53094 53095 53096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53094 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53099 53100 53101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53099 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53106 53107 53108 53109 53110 53111 53112 53113 53114 53115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53106 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |