Class: Google::Apis::ComputeBeta::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



52289
52290
52291
# File 'lib/google/apis/compute_beta/classes.rb', line 52289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


52247
52248
52249
# File 'lib/google/apis/compute_beta/classes.rb', line 52247

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


52252
52253
52254
# File 'lib/google/apis/compute_beta/classes.rb', line 52252

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



52257
52258
52259
# File 'lib/google/apis/compute_beta/classes.rb', line 52257

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


52262
52263
52264
# File 'lib/google/apis/compute_beta/classes.rb', line 52262

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


52272
52273
52274
# File 'lib/google/apis/compute_beta/classes.rb', line 52272

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52277
52278
52279
# File 'lib/google/apis/compute_beta/classes.rb', line 52277

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


52282
52283
52284
# File 'lib/google/apis/compute_beta/classes.rb', line 52282

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



52287
52288
52289
# File 'lib/google/apis/compute_beta/classes.rb', line 52287

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52294
52295
52296
52297
52298
52299
52300
52301
52302
52303
# File 'lib/google/apis/compute_beta/classes.rb', line 52294

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end