Class: Google::Apis::ComputeBeta::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



51132
51133
51134
# File 'lib/google/apis/compute_beta/classes.rb', line 51132

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


51090
51091
51092
# File 'lib/google/apis/compute_beta/classes.rb', line 51090

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51095
51096
51097
# File 'lib/google/apis/compute_beta/classes.rb', line 51095

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



51100
51101
51102
# File 'lib/google/apis/compute_beta/classes.rb', line 51100

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


51105
51106
51107
# File 'lib/google/apis/compute_beta/classes.rb', line 51105

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51115
51116
51117
# File 'lib/google/apis/compute_beta/classes.rb', line 51115

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51120
51121
51122
# File 'lib/google/apis/compute_beta/classes.rb', line 51120

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


51125
51126
51127
# File 'lib/google/apis/compute_beta/classes.rb', line 51125

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51130
51131
51132
# File 'lib/google/apis/compute_beta/classes.rb', line 51130

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51137
51138
51139
51140
51141
51142
51143
51144
51145
51146
# File 'lib/google/apis/compute_beta/classes.rb', line 51137

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end