Class: Google::Apis::ComputeBeta::ResourcePolicyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of resourcePolicies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyAggregatedList

Returns a new instance of ResourcePolicyAggregatedList.



49408
49409
49410
# File 'lib/google/apis/compute_beta/classes.rb', line 49408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


49366
49367
49368
# File 'lib/google/apis/compute_beta/classes.rb', line 49366

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


49371
49372
49373
# File 'lib/google/apis/compute_beta/classes.rb', line 49371

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::ResourcePoliciesScopedList>

A list of ResourcePolicy resources. Corresponds to the JSON property items



49376
49377
49378
# File 'lib/google/apis/compute_beta/classes.rb', line 49376

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


49381
49382
49383
# File 'lib/google/apis/compute_beta/classes.rb', line 49381

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


49391
49392
49393
# File 'lib/google/apis/compute_beta/classes.rb', line 49391

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


49396
49397
49398
# File 'lib/google/apis/compute_beta/classes.rb', line 49396

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


49401
49402
49403
# File 'lib/google/apis/compute_beta/classes.rb', line 49401

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



49406
49407
49408
# File 'lib/google/apis/compute_beta/classes.rb', line 49406

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49413
49414
49415
49416
49417
49418
49419
49420
49421
49422
# File 'lib/google/apis/compute_beta/classes.rb', line 49413

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end