Class: Google::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy

Returns a new instance of ResourcePolicyGroupPlacementPolicy.



54499
54500
54501
# File 'lib/google/apis/compute_beta/classes.rb', line 54499

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


54457
54458
54459
# File 'lib/google/apis/compute_beta/classes.rb', line 54457

def accelerator_topology_mode
  @accelerator_topology_mode
end

#availability_domain_countFixnum

The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network. Corresponds to the JSON property availabilityDomainCount

Returns:

  • (Fixnum)


54464
54465
54466
# File 'lib/google/apis/compute_beta/classes.rb', line 54464

def availability_domain_count
  @availability_domain_count
end

#collocationString

Specifies network collocation Corresponds to the JSON property collocation

Returns:

  • (String)


54469
54470
54471
# File 'lib/google/apis/compute_beta/classes.rb', line 54469

def collocation
  @collocation
end

#gpu_topologyString

Specifies the shape of the GPU slice, in slice based GPU families eg. A4X. Corresponds to the JSON property gpuTopology

Returns:

  • (String)


54475
54476
54477
# File 'lib/google/apis/compute_beta/classes.rb', line 54475

def gpu_topology
  @gpu_topology
end

#max_distanceFixnum

Specifies the number of max logical switches. Corresponds to the JSON property maxDistance

Returns:

  • (Fixnum)


54480
54481
54482
# File 'lib/google/apis/compute_beta/classes.rb', line 54480

def max_distance
  @max_distance
end

#slice_countFixnum

Specifies the number of slices in a multislice workload. Corresponds to the JSON property sliceCount

Returns:

  • (Fixnum)


54485
54486
54487
# File 'lib/google/apis/compute_beta/classes.rb', line 54485

def slice_count
  @slice_count
end

#tpu_topologyString

Specifies the shape of the TPU slice Corresponds to the JSON property tpuTopology

Returns:

  • (String)


54490
54491
54492
# File 'lib/google/apis/compute_beta/classes.rb', line 54490

def tpu_topology
  @tpu_topology
end

#vm_countFixnum

Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


54497
54498
54499
# File 'lib/google/apis/compute_beta/classes.rb', line 54497

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54504
54505
54506
54507
54508
54509
54510
54511
54512
54513
# File 'lib/google/apis/compute_beta/classes.rb', line 54504

def update!(**args)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count)
  @collocation = args[:collocation] if args.key?(:collocation)
  @gpu_topology = args[:gpu_topology] if args.key?(:gpu_topology)
  @max_distance = args[:max_distance] if args.key?(:max_distance)
  @slice_count = args[:slice_count] if args.key?(:slice_count)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end