Class: Google::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation
Instance Attribute Summary collapse
-
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology.
-
#availability_domain_count ⇒ Fixnum
The number of availability domains to spread instances across.
-
#collocation ⇒ String
Specifies network collocation Corresponds to the JSON property
collocation. -
#gpu_topology ⇒ String
Specifies the shape of the GPU slice, in slice based GPU families eg.
-
#max_distance ⇒ Fixnum
Specifies the number of max logical switches.
-
#slice_count ⇒ Fixnum
Specifies the number of slices in a multislice workload.
-
#tpu_topology ⇒ String
Specifies the shape of the TPU slice Corresponds to the JSON property
tpuTopology. -
#vm_count ⇒ Fixnum
Number of VMs in this placement group.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy
constructor
A new instance of ResourcePolicyGroupPlacementPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy
Returns a new instance of ResourcePolicyGroupPlacementPolicy.
54090 54091 54092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Corresponds to the JSON property acceleratorTopologyMode
54048 54049 54050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54048 def accelerator_topology_mode @accelerator_topology_mode end |
#availability_domain_count ⇒ Fixnum
The number of availability domains to spread instances across. If two
instances are in different availability domain, they are not in the same
low latency network.
Corresponds to the JSON property availabilityDomainCount
54055 54056 54057 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54055 def availability_domain_count @availability_domain_count end |
#collocation ⇒ String
Specifies network collocation
Corresponds to the JSON property collocation
54060 54061 54062 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54060 def collocation @collocation end |
#gpu_topology ⇒ String
Specifies the shape of the GPU slice, in slice based GPU families eg.
A4X.
Corresponds to the JSON property gpuTopology
54066 54067 54068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54066 def gpu_topology @gpu_topology end |
#max_distance ⇒ Fixnum
Specifies the number of max logical switches.
Corresponds to the JSON property maxDistance
54071 54072 54073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54071 def max_distance @max_distance end |
#slice_count ⇒ Fixnum
Specifies the number of slices in a multislice workload.
Corresponds to the JSON property sliceCount
54076 54077 54078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54076 def slice_count @slice_count end |
#tpu_topology ⇒ String
Specifies the shape of the TPU slice
Corresponds to the JSON property tpuTopology
54081 54082 54083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54081 def tpu_topology @tpu_topology end |
#vm_count ⇒ Fixnum
Number of VMs in this placement group. Google does not recommend that you
use this field unless you use a compact policy and you want your policy
to work only if it contains this exact number of VMs.
Corresponds to the JSON property vmCount
54088 54089 54090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54088 def vm_count @vm_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54095 54096 54097 54098 54099 54100 54101 54102 54103 54104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54095 def update!(**args) @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode) @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count) @collocation = args[:collocation] if args.key?(:collocation) @gpu_topology = args[:gpu_topology] if args.key?(:gpu_topology) @max_distance = args[:max_distance] if args.key?(:max_distance) @slice_count = args[:slice_count] if args.key?(:slice_count) @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology) @vm_count = args[:vm_count] if args.key?(:vm_count) end |