Class: Google::Apis::ComputeBeta::ResourcePolicyGroupPlacementPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A GroupPlacementPolicy specifies resource placement configuration. It specifies the failure bucket separation

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyGroupPlacementPolicy

Returns a new instance of ResourcePolicyGroupPlacementPolicy.



51319
51320
51321
# File 'lib/google/apis/compute_beta/classes.rb', line 51319

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


51277
51278
51279
# File 'lib/google/apis/compute_beta/classes.rb', line 51277

def accelerator_topology_mode
  @accelerator_topology_mode
end

#availability_domain_countFixnum

The number of availability domains to spread instances across. If two instances are in different availability domain, they are not in the same low latency network. Corresponds to the JSON property availabilityDomainCount

Returns:

  • (Fixnum)


51284
51285
51286
# File 'lib/google/apis/compute_beta/classes.rb', line 51284

def availability_domain_count
  @availability_domain_count
end

#collocationString

Specifies network collocation Corresponds to the JSON property collocation

Returns:

  • (String)


51289
51290
51291
# File 'lib/google/apis/compute_beta/classes.rb', line 51289

def collocation
  @collocation
end

#gpu_topologyString

Specifies the shape of the GPU slice, in slice based GPU families eg. A4X. Corresponds to the JSON property gpuTopology

Returns:

  • (String)


51295
51296
51297
# File 'lib/google/apis/compute_beta/classes.rb', line 51295

def gpu_topology
  @gpu_topology
end

#max_distanceFixnum

Specifies the number of max logical switches. Corresponds to the JSON property maxDistance

Returns:

  • (Fixnum)


51300
51301
51302
# File 'lib/google/apis/compute_beta/classes.rb', line 51300

def max_distance
  @max_distance
end

#slice_countFixnum

Specifies the number of slices in a multislice workload. Corresponds to the JSON property sliceCount

Returns:

  • (Fixnum)


51305
51306
51307
# File 'lib/google/apis/compute_beta/classes.rb', line 51305

def slice_count
  @slice_count
end

#tpu_topologyString

Specifies the shape of the TPU slice Corresponds to the JSON property tpuTopology

Returns:

  • (String)


51310
51311
51312
# File 'lib/google/apis/compute_beta/classes.rb', line 51310

def tpu_topology
  @tpu_topology
end

#vm_countFixnum

Number of VMs in this placement group. Google does not recommend that you use this field unless you use a compact policy and you want your policy to work only if it contains this exact number of VMs. Corresponds to the JSON property vmCount

Returns:

  • (Fixnum)


51317
51318
51319
# File 'lib/google/apis/compute_beta/classes.rb', line 51317

def vm_count
  @vm_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51324
51325
51326
51327
51328
51329
51330
51331
51332
51333
# File 'lib/google/apis/compute_beta/classes.rb', line 51324

def update!(**args)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @availability_domain_count = args[:availability_domain_count] if args.key?(:availability_domain_count)
  @collocation = args[:collocation] if args.key?(:collocation)
  @gpu_topology = args[:gpu_topology] if args.key?(:gpu_topology)
  @max_distance = args[:max_distance] if args.key?(:max_distance)
  @slice_count = args[:slice_count] if args.key?(:slice_count)
  @tpu_topology = args[:tpu_topology] if args.key?(:tpu_topology)
  @vm_count = args[:vm_count] if args.key?(:vm_count)
end