Class: Google::Apis::ComputeBeta::ResourcePolicyHourlyCycle

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Time window specified for hourly operations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyHourlyCycle

Returns a new instance of ResourcePolicyHourlyCycle.



49635
49636
49637
# File 'lib/google/apis/compute_beta/classes.rb', line 49635

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

Output only. [Output only] Duration of the time window, automatically chosen to be smallest possible in the given scenario. Corresponds to the JSON property duration

Returns:

  • (String)


49621
49622
49623
# File 'lib/google/apis/compute_beta/classes.rb', line 49621

def duration
  @duration
end

#hours_in_cycleFixnum

Defines a schedule with units measured in hours. The value determines how many hours pass between the start of each cycle. Corresponds to the JSON property hoursInCycle

Returns:

  • (Fixnum)


49627
49628
49629
# File 'lib/google/apis/compute_beta/classes.rb', line 49627

def hours_in_cycle
  @hours_in_cycle
end

#start_timeString

Time within the window to start the operations. It must be in format "HH:MM", where HH : [00-23] and MM : [00-00] GMT. Corresponds to the JSON property startTime

Returns:

  • (String)


49633
49634
49635
# File 'lib/google/apis/compute_beta/classes.rb', line 49633

def start_time
  @start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



49640
49641
49642
49643
49644
# File 'lib/google/apis/compute_beta/classes.rb', line 49640

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @hours_in_cycle = args[:hours_in_cycle] if args.key?(:hours_in_cycle)
  @start_time = args[:start_time] if args.key?(:start_time)
end