Class: Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy

Returns a new instance of ResourcePolicyInstanceSchedulePolicy.



54152
54153
54154
# File 'lib/google/apis/compute_beta/classes.rb', line 54152

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#expiration_timeString

The expiration time of the schedule. The timestamp is an RFC3339 string. Corresponds to the JSON property expirationTime

Returns:

  • (String)


54128
54129
54130
# File 'lib/google/apis/compute_beta/classes.rb', line 54128

def expiration_time
  @expiration_time
end

#start_timeString

The start time of the schedule. The timestamp is an RFC3339 string. Corresponds to the JSON property startTime

Returns:

  • (String)


54133
54134
54135
# File 'lib/google/apis/compute_beta/classes.rb', line 54133

def start_time
  @start_time
end

#time_zoneString

Specifies the time zone to be used in interpreting Schedule.schedule. The value of this field must be a time zone name from the tz database: https://wikipedia.org/wiki/Tz_database. Corresponds to the JSON property timeZone

Returns:

  • (String)


54140
54141
54142
# File 'lib/google/apis/compute_beta/classes.rb', line 54140

def time_zone
  @time_zone
end

#vm_start_scheduleGoogle::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule

Schedule for an instance operation. Corresponds to the JSON property vmStartSchedule



54145
54146
54147
# File 'lib/google/apis/compute_beta/classes.rb', line 54145

def vm_start_schedule
  @vm_start_schedule
end

#vm_stop_scheduleGoogle::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule

Schedule for an instance operation. Corresponds to the JSON property vmStopSchedule



54150
54151
54152
# File 'lib/google/apis/compute_beta/classes.rb', line 54150

def vm_stop_schedule
  @vm_stop_schedule
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54157
54158
54159
54160
54161
54162
54163
# File 'lib/google/apis/compute_beta/classes.rb', line 54157

def update!(**args)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
  @start_time = args[:start_time] if args.key?(:start_time)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule)
  @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule)
end