Class: Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
Instance Attribute Summary collapse
-
#expiration_time ⇒ String
The expiration time of the schedule.
-
#start_time ⇒ String
The start time of the schedule.
-
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
-
#vm_start_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
-
#vm_stop_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
constructor
A new instance of ResourcePolicyInstanceSchedulePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
Returns a new instance of ResourcePolicyInstanceSchedulePolicy.
53431 53432 53433 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_time ⇒ String
The expiration time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property expirationTime
53407 53408 53409 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53407 def expiration_time @expiration_time end |
#start_time ⇒ String
The start time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property startTime
53412 53413 53414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53412 def start_time @start_time end |
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
The value of this field must be a time zone name from the tz database:
https://wikipedia.org/wiki/Tz_database.
Corresponds to the JSON property timeZone
53419 53420 53421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53419 def time_zone @time_zone end |
#vm_start_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStartSchedule
53424 53425 53426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53424 def vm_start_schedule @vm_start_schedule end |
#vm_stop_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStopSchedule
53429 53430 53431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53429 def vm_stop_schedule @vm_stop_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53436 53437 53438 53439 53440 53441 53442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53436 def update!(**args) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @start_time = args[:start_time] if args.key?(:start_time) @time_zone = args[:time_zone] if args.key?(:time_zone) @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule) @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule) end |