Class: Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An InstanceSchedulePolicy specifies when and how frequent certain operations are performed on the instance.
Instance Attribute Summary collapse
-
#expiration_time ⇒ String
The expiration time of the schedule.
-
#start_time ⇒ String
The start time of the schedule.
-
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
-
#vm_start_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
-
#vm_stop_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
constructor
A new instance of ResourcePolicyInstanceSchedulePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyInstanceSchedulePolicy
Returns a new instance of ResourcePolicyInstanceSchedulePolicy.
52560 52561 52562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52560 def initialize(**args) update!(**args) end |
Instance Attribute Details
#expiration_time ⇒ String
The expiration time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property expirationTime
52536 52537 52538 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52536 def expiration_time @expiration_time end |
#start_time ⇒ String
The start time of the schedule. The timestamp is an RFC3339 string.
Corresponds to the JSON property startTime
52541 52542 52543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52541 def start_time @start_time end |
#time_zone ⇒ String
Specifies the time zone to be used in interpreting Schedule.schedule.
The value of this field must be a time zone name from the tz database:
https://wikipedia.org/wiki/Tz_database.
Corresponds to the JSON property timeZone
52548 52549 52550 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52548 def time_zone @time_zone end |
#vm_start_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStartSchedule
52553 52554 52555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52553 def vm_start_schedule @vm_start_schedule end |
#vm_stop_schedule ⇒ Google::Apis::ComputeBeta::ResourcePolicyInstanceSchedulePolicySchedule
Schedule for an instance operation.
Corresponds to the JSON property vmStopSchedule
52558 52559 52560 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52558 def vm_stop_schedule @vm_stop_schedule end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52565 52566 52567 52568 52569 52570 52571 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52565 def update!(**args) @expiration_time = args[:expiration_time] if args.key?(:expiration_time) @start_time = args[:start_time] if args.key?(:start_time) @time_zone = args[:time_zone] if args.key?(:time_zone) @vm_start_schedule = args[:vm_start_schedule] if args.key?(:vm_start_schedule) @vm_stop_schedule = args[:vm_stop_schedule] if args.key?(:vm_stop_schedule) end |