Class: Google::Apis::ComputeBeta::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



54662
54663
54664
# File 'lib/google/apis/compute_beta/classes.rb', line 54662

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54623
54624
54625
# File 'lib/google/apis/compute_beta/classes.rb', line 54623

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54629
54630
54631
# File 'lib/google/apis/compute_beta/classes.rb', line 54629

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



54634
54635
54636
# File 'lib/google/apis/compute_beta/classes.rb', line 54634

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


54640
54641
54642
# File 'lib/google/apis/compute_beta/classes.rb', line 54640

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54650
54651
54652
# File 'lib/google/apis/compute_beta/classes.rb', line 54650

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54655
54656
54657
# File 'lib/google/apis/compute_beta/classes.rb', line 54655

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54660
54661
54662
# File 'lib/google/apis/compute_beta/classes.rb', line 54660

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54667
54668
54669
54670
54671
54672
54673
54674
54675
# File 'lib/google/apis/compute_beta/classes.rb', line 54667

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end