Class: Google::Apis::ComputeBeta::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



54612
54613
54614
# File 'lib/google/apis/compute_beta/classes.rb', line 54612

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54573
54574
54575
# File 'lib/google/apis/compute_beta/classes.rb', line 54573

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54579
54580
54581
# File 'lib/google/apis/compute_beta/classes.rb', line 54579

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



54584
54585
54586
# File 'lib/google/apis/compute_beta/classes.rb', line 54584

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


54590
54591
54592
# File 'lib/google/apis/compute_beta/classes.rb', line 54590

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54600
54601
54602
# File 'lib/google/apis/compute_beta/classes.rb', line 54600

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54605
54606
54607
# File 'lib/google/apis/compute_beta/classes.rb', line 54605

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54610
54611
54612
# File 'lib/google/apis/compute_beta/classes.rb', line 54610

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54617
54618
54619
54620
54621
54622
54623
54624
54625
# File 'lib/google/apis/compute_beta/classes.rb', line 54617

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end