Class: Google::Apis::ComputeBeta::ResourcePolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyList

Returns a new instance of ResourcePolicyList.



54253
54254
54255
# File 'lib/google/apis/compute_beta/classes.rb', line 54253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54214
54215
54216
# File 'lib/google/apis/compute_beta/classes.rb', line 54214

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54220
54221
54222
# File 'lib/google/apis/compute_beta/classes.rb', line 54220

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ResourcePolicy>

[Output Only] A list of ResourcePolicy resources. Corresponds to the JSON property items



54225
54226
54227
# File 'lib/google/apis/compute_beta/classes.rb', line 54225

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList for listsof resourcePolicies Corresponds to the JSON property kind

Returns:

  • (String)


54231
54232
54233
# File 'lib/google/apis/compute_beta/classes.rb', line 54231

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54241
54242
54243
# File 'lib/google/apis/compute_beta/classes.rb', line 54241

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54246
54247
54248
# File 'lib/google/apis/compute_beta/classes.rb', line 54246

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ResourcePolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54251
54252
54253
# File 'lib/google/apis/compute_beta/classes.rb', line 54251

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54258
54259
54260
54261
54262
54263
54264
54265
54266
# File 'lib/google/apis/compute_beta/classes.rb', line 54258

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end