Class: Google::Apis::ComputeBeta::ResourcePolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyList
constructor
A new instance of ResourcePolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyList
Returns a new instance of ResourcePolicyList.
54231 54232 54233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54231 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54192 54193 54194 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54192 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54198 54199 54200 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54198 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
Corresponds to the JSON property items
54203 54204 54205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54203 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList
for listsof resourcePolicies
Corresponds to the JSON property kind
54209 54210 54211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54209 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54219 54220 54221 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54219 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54224 54225 54226 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54224 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54229 54230 54231 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54229 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54236 54237 54238 54239 54240 54241 54242 54243 54244 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54236 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |