Class: Google::Apis::ComputeBeta::ResourcePolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyList
constructor
A new instance of ResourcePolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyList
Returns a new instance of ResourcePolicyList.
53451 53452 53453 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53451 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53412 53413 53414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53412 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
53418 53419 53420 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53418 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
Corresponds to the JSON property items
53423 53424 53425 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53423 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList
for listsof resourcePolicies
Corresponds to the JSON property kind
53429 53430 53431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53429 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53439 53440 53441 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53439 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53444 53445 53446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53444 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53449 53450 53451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53449 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53456 53457 53458 53459 53460 53461 53462 53463 53464 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53456 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |