Class: Google::Apis::ComputeBeta::ResourcePolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyList
constructor
A new instance of ResourcePolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyList
Returns a new instance of ResourcePolicyList.
52639 52640 52641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52639 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
52600 52601 52602 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52600 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
52606 52607 52608 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52606 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ResourcePolicy>
[Output Only] A list of ResourcePolicy resources.
Corresponds to the JSON property items
52611 52612 52613 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52611 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource.Alwayscompute#resourcePoliciesList
for listsof resourcePolicies
Corresponds to the JSON property kind
52617 52618 52619 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52617 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52627 52628 52629 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52627 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52632 52633 52634 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52632 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ResourcePolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52637 52638 52639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52637 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52644 52645 52646 52647 52648 52649 52650 52651 52652 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52644 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |