Class: Google::Apis::ComputeBeta::ResourcePolicyResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains output only fields. Use this sub-message for all output fields set on ResourcePolicy. The internal structure of this "status" field should mimic the structure of ResourcePolicy proto specification.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyResourceStatus

Returns a new instance of ResourcePolicyResourceStatus.



53610
53611
53612
# File 'lib/google/apis/compute_beta/classes.rb', line 53610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#instance_schedule_policyGoogle::Apis::ComputeBeta::ResourcePolicyResourceStatusInstanceSchedulePolicyStatus

Output only. [Output Only] Specifies a set of output values reffering to the instance_schedule_policy system status. This field should have the same name as corresponding policy field. Corresponds to the JSON property instanceSchedulePolicy



53608
53609
53610
# File 'lib/google/apis/compute_beta/classes.rb', line 53608

def instance_schedule_policy
  @instance_schedule_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53615
53616
53617
# File 'lib/google/apis/compute_beta/classes.rb', line 53615

def update!(**args)
  @instance_schedule_policy = args[:instance_schedule_policy] if args.key?(:instance_schedule_policy)
end