Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A snapshot schedule policy specifies when and how frequently snapshots are to be created for the target disk. Also specifies how many and how long these scheduled snapshots should be retained.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicy

Returns a new instance of ResourcePolicySnapshotSchedulePolicy.



54822
54823
54824
# File 'lib/google/apis/compute_beta/classes.rb', line 54822

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#retention_policyGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Policy for retention of scheduled snapshots. Corresponds to the JSON property retentionPolicy



54809
54810
54811
# File 'lib/google/apis/compute_beta/classes.rb', line 54809

def retention_policy
  @retention_policy
end

#scheduleGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySchedule

A schedule for disks where the schedueled operations are performed. Corresponds to the JSON property schedule



54814
54815
54816
# File 'lib/google/apis/compute_beta/classes.rb', line 54814

def schedule
  @schedule
end

#snapshot_propertiesGoogle::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Specified snapshot properties for scheduled snapshots created by this policy. Corresponds to the JSON property snapshotProperties



54820
54821
54822
# File 'lib/google/apis/compute_beta/classes.rb', line 54820

def snapshot_properties
  @snapshot_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54827
54828
54829
54830
54831
# File 'lib/google/apis/compute_beta/classes.rb', line 54827

def update!(**args)
  @retention_policy = args[:retention_policy] if args.key?(:retention_policy)
  @schedule = args[:schedule] if args.key?(:schedule)
  @snapshot_properties = args[:snapshot_properties] if args.key?(:snapshot_properties)
end