Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Policy for retention of scheduled snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Returns a new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.



54440
54441
54442
# File 'lib/google/apis/compute_beta/classes.rb', line 54440

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_retention_daysFixnum

Maximum age of the snapshot that is allowed to be kept. Corresponds to the JSON property maxRetentionDays

Returns:

  • (Fixnum)


54432
54433
54434
# File 'lib/google/apis/compute_beta/classes.rb', line 54432

def max_retention_days
  @max_retention_days
end

#on_source_disk_deleteString

Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Corresponds to the JSON property onSourceDiskDelete

Returns:

  • (String)


54438
54439
54440
# File 'lib/google/apis/compute_beta/classes.rb', line 54438

def on_source_disk_delete
  @on_source_disk_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54445
54446
54447
54448
# File 'lib/google/apis/compute_beta/classes.rb', line 54445

def update!(**args)
  @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days)
  @on_source_disk_delete = args[:on_source_disk_delete] if args.key?(:on_source_disk_delete)
end