Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Policy for retention of scheduled snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicyRetentionPolicy

Returns a new instance of ResourcePolicySnapshotSchedulePolicyRetentionPolicy.



52826
52827
52828
# File 'lib/google/apis/compute_beta/classes.rb', line 52826

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_retention_daysFixnum

Maximum age of the snapshot that is allowed to be kept. Corresponds to the JSON property maxRetentionDays

Returns:

  • (Fixnum)


52818
52819
52820
# File 'lib/google/apis/compute_beta/classes.rb', line 52818

def max_retention_days
  @max_retention_days
end

#on_source_disk_deleteString

Specifies the behavior to apply to scheduled snapshots when the source disk is deleted. Corresponds to the JSON property onSourceDiskDelete

Returns:

  • (String)


52824
52825
52826
# File 'lib/google/apis/compute_beta/classes.rb', line 52824

def on_source_disk_delete
  @on_source_disk_delete
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52831
52832
52833
52834
# File 'lib/google/apis/compute_beta/classes.rb', line 52831

def update!(**args)
  @max_retention_days = args[:max_retention_days] if args.key?(:max_retention_days)
  @on_source_disk_delete = args[:on_source_disk_delete] if args.key?(:on_source_disk_delete)
end