Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySnapshotProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specified snapshot properties for scheduled snapshots created by this policy.
Instance Attribute Summary collapse
-
#chain_name ⇒ String
Chain name that the snapshot is created in.
-
#guest_flush ⇒ Boolean
(also: #guest_flush?)
Indication to perform a 'guest aware' snapshot.
-
#labels ⇒ Hash<String,String>
Labels to apply to scheduled snapshots.
-
#region ⇒ String
Region where the snapshot is scoped to.
-
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional).
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties
constructor
A new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties
Returns a new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.
54493 54494 54495 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54493 def initialize(**args) update!(**args) end |
Instance Attribute Details
#chain_name ⇒ String
Chain name that the snapshot is created in.
Corresponds to the JSON property chainName
54468 54469 54470 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54468 def chain_name @chain_name end |
#guest_flush ⇒ Boolean Also known as: guest_flush?
Indication to perform a 'guest aware' snapshot.
Corresponds to the JSON property guestFlush
54473 54474 54475 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54473 def guest_flush @guest_flush end |
#labels ⇒ Hash<String,String>
Labels to apply to scheduled snapshots. These can be later modified
by the setLabels method. Label values may be empty.
Corresponds to the JSON property labels
54480 54481 54482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54480 def labels @labels end |
#region ⇒ String
Region where the snapshot is scoped to.
Corresponds to the JSON property region
54485 54486 54487 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54485 def region @region end |
#storage_locations ⇒ Array<String>
Cloud Storage bucket storage location of the auto snapshot (regional or
multi-regional).
Corresponds to the JSON property storageLocations
54491 54492 54493 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54491 def storage_locations @storage_locations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54498 54499 54500 54501 54502 54503 54504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54498 def update!(**args) @chain_name = args[:chain_name] if args.key?(:chain_name) @guest_flush = args[:guest_flush] if args.key?(:guest_flush) @labels = args[:labels] if args.key?(:labels) @region = args[:region] if args.key?(:region) @storage_locations = args[:storage_locations] if args.key?(:storage_locations) end |