Class: Google::Apis::ComputeBeta::ResourcePolicySnapshotSchedulePolicySnapshotProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specified snapshot properties for scheduled snapshots created by this policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicySnapshotSchedulePolicySnapshotProperties

Returns a new instance of ResourcePolicySnapshotSchedulePolicySnapshotProperties.



53772
53773
53774
# File 'lib/google/apis/compute_beta/classes.rb', line 53772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#chain_nameString

Chain name that the snapshot is created in. Corresponds to the JSON property chainName

Returns:

  • (String)


53747
53748
53749
# File 'lib/google/apis/compute_beta/classes.rb', line 53747

def chain_name
  @chain_name
end

#guest_flushBoolean Also known as: guest_flush?

Indication to perform a 'guest aware' snapshot. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


53752
53753
53754
# File 'lib/google/apis/compute_beta/classes.rb', line 53752

def guest_flush
  @guest_flush
end

#labelsHash<String,String>

Labels to apply to scheduled snapshots. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


53759
53760
53761
# File 'lib/google/apis/compute_beta/classes.rb', line 53759

def labels
  @labels
end

#regionString

Region where the snapshot is scoped to. Corresponds to the JSON property region

Returns:

  • (String)


53764
53765
53766
# File 'lib/google/apis/compute_beta/classes.rb', line 53764

def region
  @region
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the auto snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


53770
53771
53772
# File 'lib/google/apis/compute_beta/classes.rb', line 53770

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53777
53778
53779
53780
53781
53782
53783
# File 'lib/google/apis/compute_beta/classes.rb', line 53777

def update!(**args)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @labels = args[:labels] if args.key?(:labels)
  @region = args[:region] if args.key?(:region)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end