Class: Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents the workload policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy

Returns a new instance of ResourcePolicyWorkloadPolicy.



54610
54611
54612
# File 'lib/google/apis/compute_beta/classes.rb', line 54610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Specifies the topology required to create a partition for VMs that have interconnected GPUs. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


54592
54593
54594
# File 'lib/google/apis/compute_beta/classes.rb', line 54592

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


54598
54599
54600
# File 'lib/google/apis/compute_beta/classes.rb', line 54598

def accelerator_topology_mode
  @accelerator_topology_mode
end

#max_topology_distanceString

Specifies the maximum distance between instances. Corresponds to the JSON property maxTopologyDistance

Returns:

  • (String)


54603
54604
54605
# File 'lib/google/apis/compute_beta/classes.rb', line 54603

def max_topology_distance
  @max_topology_distance
end

#typeString

Specifies the intent of the instance placement in the MIG. Corresponds to the JSON property type

Returns:

  • (String)


54608
54609
54610
# File 'lib/google/apis/compute_beta/classes.rb', line 54608

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54615
54616
54617
54618
54619
54620
# File 'lib/google/apis/compute_beta/classes.rb', line 54615

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance)
  @type = args[:type] if args.key?(:type)
end