Class: Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents the workload policy.
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology.
-
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
-
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
constructor
A new instance of ResourcePolicyWorkloadPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
Returns a new instance of ResourcePolicyWorkloadPolicy.
52996 52997 52998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52996 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have
interconnected GPUs.
Corresponds to the JSON property acceleratorTopology
52978 52979 52980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52978 def accelerator_topology @accelerator_topology end |
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Corresponds to the JSON property acceleratorTopologyMode
52984 52985 52986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52984 def accelerator_topology_mode @accelerator_topology_mode end |
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
Corresponds to the JSON property maxTopologyDistance
52989 52990 52991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52989 def max_topology_distance @max_topology_distance end |
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Corresponds to the JSON property type
52994 52995 52996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52994 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53001 53002 53003 53004 53005 53006 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53001 def update!(**args) @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology) @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode) @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance) @type = args[:type] if args.key?(:type) end |