Class: Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents the workload policy.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy

Returns a new instance of ResourcePolicyWorkloadPolicy.



51839
51840
51841
# File 'lib/google/apis/compute_beta/classes.rb', line 51839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#accelerator_topologyString

Specifies the topology required to create a partition for VMs that have interconnected GPUs. Corresponds to the JSON property acceleratorTopology

Returns:

  • (String)


51821
51822
51823
# File 'lib/google/apis/compute_beta/classes.rb', line 51821

def accelerator_topology
  @accelerator_topology
end

#accelerator_topology_modeString

Specifies the connection mode for the accelerator topology. If not specified, the default is AUTO_CONNECT. Corresponds to the JSON property acceleratorTopologyMode

Returns:

  • (String)


51827
51828
51829
# File 'lib/google/apis/compute_beta/classes.rb', line 51827

def accelerator_topology_mode
  @accelerator_topology_mode
end

#max_topology_distanceString

Specifies the maximum distance between instances. Corresponds to the JSON property maxTopologyDistance

Returns:

  • (String)


51832
51833
51834
# File 'lib/google/apis/compute_beta/classes.rb', line 51832

def max_topology_distance
  @max_topology_distance
end

#typeString

Specifies the intent of the instance placement in the MIG. Corresponds to the JSON property type

Returns:

  • (String)


51837
51838
51839
# File 'lib/google/apis/compute_beta/classes.rb', line 51837

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51844
51845
51846
51847
51848
51849
# File 'lib/google/apis/compute_beta/classes.rb', line 51844

def update!(**args)
  @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology)
  @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode)
  @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance)
  @type = args[:type] if args.key?(:type)
end