Class: Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourcePolicyWorkloadPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents the workload policy.
Instance Attribute Summary collapse
-
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have interconnected GPUs.
-
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology.
-
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
-
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
constructor
A new instance of ResourcePolicyWorkloadPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourcePolicyWorkloadPolicy
Returns a new instance of ResourcePolicyWorkloadPolicy.
50115 50116 50117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#accelerator_topology ⇒ String
Specifies the topology required to create a partition for VMs that have
interconnected GPUs.
Corresponds to the JSON property acceleratorTopology
50097 50098 50099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50097 def accelerator_topology @accelerator_topology end |
#accelerator_topology_mode ⇒ String
Specifies the connection mode for the accelerator topology. If not
specified, the default is AUTO_CONNECT.
Corresponds to the JSON property acceleratorTopologyMode
50103 50104 50105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50103 def accelerator_topology_mode @accelerator_topology_mode end |
#max_topology_distance ⇒ String
Specifies the maximum distance between instances.
Corresponds to the JSON property maxTopologyDistance
50108 50109 50110 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50108 def max_topology_distance @max_topology_distance end |
#type ⇒ String
Specifies the intent of the instance placement in the MIG.
Corresponds to the JSON property type
50113 50114 50115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50113 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50120 50121 50122 50123 50124 50125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50120 def update!(**args) @accelerator_topology = args[:accelerator_topology] if args.key?(:accelerator_topology) @accelerator_topology_mode = args[:accelerator_topology_mode] if args.key?(:accelerator_topology_mode) @max_topology_distance = args[:max_topology_distance] if args.key?(:max_topology_distance) @type = args[:type] if args.key?(:type) end |