Class: Google::Apis::ComputeBeta::ResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatus

Returns a new instance of ResourceStatus.



53926
53927
53928
# File 'lib/google/apis/compute_beta/classes.rb', line 53926

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#effective_instance_metadataGoogle::Apis::ComputeBeta::ResourceStatusEffectiveInstanceMetadata

Effective values of predefined metadata keys for an instance. Corresponds to the JSON property effectiveInstanceMetadata



53889
53890
53891
# File 'lib/google/apis/compute_beta/classes.rb', line 53889

def 
  @effective_instance_metadata
end

#physical_hostString

Output only. [Output Only] The precise location of your instance within the zone's data center, including the block, sub-block, and host. The field is formatted as follows: blockId/subBlockId/hostId. Corresponds to the JSON property physicalHost

Returns:

  • (String)


53897
53898
53899
# File 'lib/google/apis/compute_beta/classes.rb', line 53897

def physical_host
  @physical_host
end

#physical_host_topologyGoogle::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology

Represents the physical host topology of the host on which the VM is running. Corresponds to the JSON property physicalHostTopology



53903
53904
53905
# File 'lib/google/apis/compute_beta/classes.rb', line 53903

def physical_host_topology
  @physical_host_topology
end

#reservation_consumption_infoGoogle::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo

Reservation consumption information that the instance is consuming from. Corresponds to the JSON property reservationConsumptionInfo



53908
53909
53910
# File 'lib/google/apis/compute_beta/classes.rb', line 53908

def reservation_consumption_info
  @reservation_consumption_info
end

#schedulingGoogle::Apis::ComputeBeta::ResourceStatusScheduling

Corresponds to the JSON property scheduling



53913
53914
53915
# File 'lib/google/apis/compute_beta/classes.rb', line 53913

def scheduling
  @scheduling
end

#shutdown_detailsGoogle::Apis::ComputeBeta::ResourceStatusShutdownDetails

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled. Corresponds to the JSON property shutdownDetails



53919
53920
53921
# File 'lib/google/apis/compute_beta/classes.rb', line 53919

def shutdown_details
  @shutdown_details
end

#upcoming_maintenanceGoogle::Apis::ComputeBeta::UpcomingMaintenance

Upcoming Maintenance notification information. Corresponds to the JSON property upcomingMaintenance



53924
53925
53926
# File 'lib/google/apis/compute_beta/classes.rb', line 53924

def upcoming_maintenance
  @upcoming_maintenance
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53931
53932
53933
53934
53935
53936
53937
53938
53939
# File 'lib/google/apis/compute_beta/classes.rb', line 53931

def update!(**args)
  @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata)
  @physical_host = args[:physical_host] if args.key?(:physical_host)
  @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology)
  @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details)
  @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance)
end