Class: Google::Apis::ComputeBeta::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Instance Attribute Summary collapse
-
#effective_instance_metadata ⇒ Google::Apis::ComputeBeta::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
-
#physical_host ⇒ String
Output only.
-
#physical_host_topology ⇒ Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is running.
-
#reservation_consumption_info ⇒ Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
-
#scheduling ⇒ Google::Apis::ComputeBeta::ResourceStatusScheduling
Corresponds to the JSON property
scheduling. -
#shutdown_details ⇒ Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
Specifies if the instance is in
PENDING_STOPstate or there is a programmed stop scheduled. -
#upcoming_maintenance ⇒ Google::Apis::ComputeBeta::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatus
constructor
A new instance of ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatus
Returns a new instance of ResourceStatus.
53867 53868 53869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53867 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_instance_metadata ⇒ Google::Apis::ComputeBeta::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
Corresponds to the JSON property effectiveInstanceMetadata
53830 53831 53832 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53830 def @effective_instance_metadata end |
#physical_host ⇒ String
Output only. [Output Only] The precise location of your instance within the
zone's data
center, including the block, sub-block, and host. The field is formatted as
follows: blockId/subBlockId/hostId.
Corresponds to the JSON property physicalHost
53838 53839 53840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53838 def physical_host @physical_host end |
#physical_host_topology ⇒ Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is
running.
Corresponds to the JSON property physicalHostTopology
53844 53845 53846 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53844 def physical_host_topology @physical_host_topology end |
#reservation_consumption_info ⇒ Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
Corresponds to the JSON property reservationConsumptionInfo
53849 53850 53851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53849 def reservation_consumption_info @reservation_consumption_info end |
#scheduling ⇒ Google::Apis::ComputeBeta::ResourceStatusScheduling
Corresponds to the JSON property scheduling
53854 53855 53856 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53854 def scheduling @scheduling end |
#shutdown_details ⇒ Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
53860 53861 53862 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53860 def shutdown_details @shutdown_details end |
#upcoming_maintenance ⇒ Google::Apis::ComputeBeta::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
53865 53866 53867 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53865 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53872 53873 53874 53875 53876 53877 53878 53879 53880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53872 def update!(**args) @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata) @physical_host = args[:physical_host] if args.key?(:physical_host) @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology) @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info) @scheduling = args[:scheduling] if args.key?(:scheduling) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |