Class: Google::Apis::ComputeBeta::ResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains output only fields. Use this sub-message for actual values set on Instance attributes as compared to the value requested by the user (intent) in their instance CRUD calls.
Instance Attribute Summary collapse
-
#effective_instance_metadata ⇒ Google::Apis::ComputeBeta::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
-
#physical_host ⇒ String
Output only.
-
#physical_host_topology ⇒ Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is running.
-
#reservation_consumption_info ⇒ Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
-
#scheduling ⇒ Google::Apis::ComputeBeta::ResourceStatusScheduling
Corresponds to the JSON property
scheduling. -
#shutdown_details ⇒ Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
Specifies if the instance is in
PENDING_STOPstate or there is a programmed stop scheduled. -
#upcoming_maintenance ⇒ Google::Apis::ComputeBeta::UpcomingMaintenance
Upcoming Maintenance notification information.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatus
constructor
A new instance of ResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatus
Returns a new instance of ResourceStatus.
50174 50175 50176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#effective_instance_metadata ⇒ Google::Apis::ComputeBeta::ResourceStatusEffectiveInstanceMetadata
Effective values of predefined metadata keys for an instance.
Corresponds to the JSON property effectiveInstanceMetadata
50137 50138 50139 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50137 def @effective_instance_metadata end |
#physical_host ⇒ String
Output only. [Output Only] The precise location of your instance within the
zone's data
center, including the block, sub-block, and host. The field is formatted as
follows: blockId/subBlockId/hostId.
Corresponds to the JSON property physicalHost
50145 50146 50147 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50145 def physical_host @physical_host end |
#physical_host_topology ⇒ Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
Represents the physical host topology of the host on which the VM is
running.
Corresponds to the JSON property physicalHostTopology
50151 50152 50153 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50151 def physical_host_topology @physical_host_topology end |
#reservation_consumption_info ⇒ Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo
Reservation consumption information that the instance is consuming from.
Corresponds to the JSON property reservationConsumptionInfo
50156 50157 50158 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50156 def reservation_consumption_info @reservation_consumption_info end |
#scheduling ⇒ Google::Apis::ComputeBeta::ResourceStatusScheduling
Corresponds to the JSON property scheduling
50161 50162 50163 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50161 def scheduling @scheduling end |
#shutdown_details ⇒ Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Corresponds to the JSON property shutdownDetails
50167 50168 50169 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50167 def shutdown_details @shutdown_details end |
#upcoming_maintenance ⇒ Google::Apis::ComputeBeta::UpcomingMaintenance
Upcoming Maintenance notification information.
Corresponds to the JSON property upcomingMaintenance
50172 50173 50174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50172 def upcoming_maintenance @upcoming_maintenance end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50179 50180 50181 50182 50183 50184 50185 50186 50187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50179 def update!(**args) @effective_instance_metadata = args[:effective_instance_metadata] if args.key?(:effective_instance_metadata) @physical_host = args[:physical_host] if args.key?(:physical_host) @physical_host_topology = args[:physical_host_topology] if args.key?(:physical_host_topology) @reservation_consumption_info = args[:reservation_consumption_info] if args.key?(:reservation_consumption_info) @scheduling = args[:scheduling] if args.key?(:scheduling) @shutdown_details = args[:shutdown_details] if args.key?(:shutdown_details) @upcoming_maintenance = args[:upcoming_maintenance] if args.key?(:upcoming_maintenance) end |