Class: Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents the physical host topology of the host on which the VM is running.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Additional location information of the running instance.
-
#block ⇒ String
[Output Only] The ID of the block in which the running instance is located.
-
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the running instance is located.
-
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
-
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
constructor
A new instance of ResourceStatusPhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
Returns a new instance of ResourceStatusPhysicalHostTopology.
55205 55206 55207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55205 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_attributes ⇒ Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopologyAdditionalAttributes
Additional location information of the running instance.
Corresponds to the JSON property additionalAttributes
55177 55178 55179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55177 def additional_attributes @additional_attributes end |
#block ⇒ String
[Output Only] The ID of the block in which the running instance is
located. Instances within the same block experience low network latency.
Corresponds to the JSON property block
55183 55184 55185 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55183 def block @block end |
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the
running instance is located.
Corresponds to the JSON property cluster
55189 55190 55191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55189 def cluster @cluster end |
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
Corresponds to the JSON property host
55196 55197 55198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55196 def host @host end |
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is
located. Instances in the same sub-block experience lower network latency
than instances in the same block.
Corresponds to the JSON property subblock
55203 55204 55205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55203 def subblock @subblock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55210 55211 55212 55213 55214 55215 55216 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55210 def update!(**args) @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @subblock = args[:subblock] if args.key?(:subblock) end |