Class: Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



55155
55156
55157
# File 'lib/google/apis/compute_beta/classes.rb', line 55155

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesGoogle::Apis::ComputeBeta::ResourceStatusPhysicalHostTopologyAdditionalAttributes

Additional location information of the running instance. Corresponds to the JSON property additionalAttributes



55127
55128
55129
# File 'lib/google/apis/compute_beta/classes.rb', line 55127

def additional_attributes
  @additional_attributes
end

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


55133
55134
55135
# File 'lib/google/apis/compute_beta/classes.rb', line 55133

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


55139
55140
55141
# File 'lib/google/apis/compute_beta/classes.rb', line 55139

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


55146
55147
55148
# File 'lib/google/apis/compute_beta/classes.rb', line 55146

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


55153
55154
55155
# File 'lib/google/apis/compute_beta/classes.rb', line 55153

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55160
55161
55162
55163
55164
55165
55166
# File 'lib/google/apis/compute_beta/classes.rb', line 55160

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end