Class: Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents the physical host topology of the host on which the VM is running.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology

Returns a new instance of ResourceStatusPhysicalHostTopology.



54774
54775
54776
# File 'lib/google/apis/compute_beta/classes.rb', line 54774

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#additional_attributesGoogle::Apis::ComputeBeta::ResourceStatusPhysicalHostTopologyAdditionalAttributes

Additional location information of the running instance. Corresponds to the JSON property additionalAttributes



54746
54747
54748
# File 'lib/google/apis/compute_beta/classes.rb', line 54746

def additional_attributes
  @additional_attributes
end

#blockString

[Output Only] The ID of the block in which the running instance is located. Instances within the same block experience low network latency. Corresponds to the JSON property block

Returns:

  • (String)


54752
54753
54754
# File 'lib/google/apis/compute_beta/classes.rb', line 54752

def block
  @block
end

#clusterString

[Output Only] The global name of the Compute Engine cluster where the running instance is located. Corresponds to the JSON property cluster

Returns:

  • (String)


54758
54759
54760
# File 'lib/google/apis/compute_beta/classes.rb', line 54758

def cluster
  @cluster
end

#hostString

[Output Only] The ID of the host on which the running instance is located. Instances on the same host experience the lowest possible network latency. Corresponds to the JSON property host

Returns:

  • (String)


54765
54766
54767
# File 'lib/google/apis/compute_beta/classes.rb', line 54765

def host
  @host
end

#subblockString

[Output Only] The ID of the sub-block in which the running instance is located. Instances in the same sub-block experience lower network latency than instances in the same block. Corresponds to the JSON property subblock

Returns:

  • (String)


54772
54773
54774
# File 'lib/google/apis/compute_beta/classes.rb', line 54772

def subblock
  @subblock
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54779
54780
54781
54782
54783
54784
54785
# File 'lib/google/apis/compute_beta/classes.rb', line 54779

def update!(**args)
  @additional_attributes = args[:additional_attributes] if args.key?(:additional_attributes)
  @block = args[:block] if args.key?(:block)
  @cluster = args[:cluster] if args.key?(:cluster)
  @host = args[:host] if args.key?(:host)
  @subblock = args[:subblock] if args.key?(:subblock)
end