Class: Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents the physical host topology of the host on which the VM is running.
Instance Attribute Summary collapse
-
#block ⇒ String
[Output Only] The ID of the block in which the running instance is located.
-
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the running instance is located.
-
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
-
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
constructor
A new instance of ResourceStatusPhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
Returns a new instance of ResourceStatusPhysicalHostTopology.
53177 53178 53179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53177 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
[Output Only] The ID of the block in which the running instance is
located. Instances within the same block experience low network latency.
Corresponds to the JSON property block
53155 53156 53157 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53155 def block @block end |
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the
running instance is located.
Corresponds to the JSON property cluster
53161 53162 53163 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53161 def cluster @cluster end |
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
Corresponds to the JSON property host
53168 53169 53170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53168 def host @host end |
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is
located. Instances in the same sub-block experience lower network latency
than instances in the same block.
Corresponds to the JSON property subblock
53175 53176 53177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53175 def subblock @subblock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53182 53183 53184 53185 53186 53187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53182 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @subblock = args[:subblock] if args.key?(:subblock) end |