Class: Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatusPhysicalHostTopology
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents the physical host topology of the host on which the VM is running.
Instance Attribute Summary collapse
-
#block ⇒ String
[Output Only] The ID of the block in which the running instance is located.
-
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the running instance is located.
-
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
-
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is located.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
constructor
A new instance of ResourceStatusPhysicalHostTopology.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusPhysicalHostTopology
Returns a new instance of ResourceStatusPhysicalHostTopology.
50289 50290 50291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50289 def initialize(**args) update!(**args) end |
Instance Attribute Details
#block ⇒ String
[Output Only] The ID of the block in which the running instance is
located. Instances within the same block experience low network latency.
Corresponds to the JSON property block
50267 50268 50269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50267 def block @block end |
#cluster ⇒ String
[Output Only] The global name of the Compute Engine cluster where the
running instance is located.
Corresponds to the JSON property cluster
50273 50274 50275 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50273 def cluster @cluster end |
#host ⇒ String
[Output Only] The ID of the host on which the running instance is located.
Instances on the same host experience the lowest possible network
latency.
Corresponds to the JSON property host
50280 50281 50282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50280 def host @host end |
#subblock ⇒ String
[Output Only] The ID of the sub-block in which the running instance is
located. Instances in the same sub-block experience lower network latency
than instances in the same block.
Corresponds to the JSON property subblock
50287 50288 50289 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50287 def subblock @subblock end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
50294 50295 50296 50297 50298 50299 |
# File 'lib/google/apis/compute_beta/classes.rb', line 50294 def update!(**args) @block = args[:block] if args.key?(:block) @cluster = args[:cluster] if args.key?(:cluster) @host = args[:host] if args.key?(:host) @subblock = args[:subblock] if args.key?(:subblock) end |