Class: Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo

Returns a new instance of ResourceStatusReservationConsumptionInfo.



55184
55185
55186
# File 'lib/google/apis/compute_beta/classes.rb', line 55184

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


55168
55169
55170
# File 'lib/google/apis/compute_beta/classes.rb', line 55168

def consumed_reservation
  @consumed_reservation
end

#consumed_reservation_blockString

Output only. [Output Only] The full resource name of the reservation block that this instance is consuming from. Corresponds to the JSON property consumedReservationBlock

Returns:

  • (String)


55175
55176
55177
# File 'lib/google/apis/compute_beta/classes.rb', line 55175

def consumed_reservation_block
  @consumed_reservation_block
end

#consumed_reservation_sub_blockString

Output only. [Output Only] The full resource name of the reservation sub-block that this instance is consuming from. Corresponds to the JSON property consumedReservationSubBlock

Returns:

  • (String)


55182
55183
55184
# File 'lib/google/apis/compute_beta/classes.rb', line 55182

def consumed_reservation_sub_block
  @consumed_reservation_sub_block
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55189
55190
55191
55192
55193
# File 'lib/google/apis/compute_beta/classes.rb', line 55189

def update!(**args)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
  @consumed_reservation_block = args[:consumed_reservation_block] if args.key?(:consumed_reservation_block)
  @consumed_reservation_sub_block = args[:consumed_reservation_sub_block] if args.key?(:consumed_reservation_sub_block)
end