Class: Google::Apis::ComputeBeta::ResourceStatusReservationConsumptionInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Reservation consumption information that the instance is consuming from.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusReservationConsumptionInfo

Returns a new instance of ResourceStatusReservationConsumptionInfo.



50312
50313
50314
# File 'lib/google/apis/compute_beta/classes.rb', line 50312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumed_reservationString

Output only. [Output Only] The full resource name of the reservation that this instance is consuming from. Corresponds to the JSON property consumedReservation

Returns:

  • (String)


50310
50311
50312
# File 'lib/google/apis/compute_beta/classes.rb', line 50310

def consumed_reservation
  @consumed_reservation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50317
50318
50319
# File 'lib/google/apis/compute_beta/classes.rb', line 50317

def update!(**args)
  @consumed_reservation = args[:consumed_reservation] if args.key?(:consumed_reservation)
end