Class: Google::Apis::ComputeBeta::ResourceStatusScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusScheduling

Returns a new instance of ResourceStatusScheduling.



55310
55311
55312
# File 'lib/google/apis/compute_beta/classes.rb', line 55310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


55296
55297
55298
# File 'lib/google/apis/compute_beta/classes.rb', line 55296

def availability_domain
  @availability_domain
end

#graceful_shutdown_timestampString

Output only. Specifies the timestamp, when the instance will start graceful shutdown process, in RFC3339 text format. Corresponds to the JSON property gracefulShutdownTimestamp

Returns:

  • (String)


55303
55304
55305
# File 'lib/google/apis/compute_beta/classes.rb', line 55303

def graceful_shutdown_timestamp
  @graceful_shutdown_timestamp
end

#termination_timestampString

Time in future when the instance will be terminated inRFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


55308
55309
55310
# File 'lib/google/apis/compute_beta/classes.rb', line 55308

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55315
55316
55317
55318
55319
# File 'lib/google/apis/compute_beta/classes.rb', line 55315

def update!(**args)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
  @graceful_shutdown_timestamp = args[:graceful_shutdown_timestamp] if args.key?(:graceful_shutdown_timestamp)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end