Class: Google::Apis::ComputeBeta::ResourceStatusScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusScheduling

Returns a new instance of ResourceStatusScheduling.



54863
54864
54865
# File 'lib/google/apis/compute_beta/classes.rb', line 54863

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


54856
54857
54858
# File 'lib/google/apis/compute_beta/classes.rb', line 54856

def availability_domain
  @availability_domain
end

#termination_timestampString

Time in future when the instance will be terminated inRFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


54861
54862
54863
# File 'lib/google/apis/compute_beta/classes.rb', line 54861

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54868
54869
54870
54871
# File 'lib/google/apis/compute_beta/classes.rb', line 54868

def update!(**args)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end