Class: Google::Apis::ComputeBeta::ResourceStatusScheduling
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatusScheduling
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in.
-
#termination_timestamp ⇒ String
Time in future when the instance will be terminated inRFC3339 text format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusScheduling
constructor
A new instance of ResourceStatusScheduling.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusScheduling
Returns a new instance of ResourceStatusScheduling.
53226 53227 53228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53226 def initialize(**args) update!(**args) end |
Instance Attribute Details
#availability_domain ⇒ Fixnum
Specifies the availability domain to place the instance in. The value
must be a number between 1 and the number of availability domains
specified in the spread placement policy attached to the instance.
Corresponds to the JSON property availabilityDomain
53219 53220 53221 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53219 def availability_domain @availability_domain end |
#termination_timestamp ⇒ String
Time in future when the instance will be terminated inRFC3339 text format.
Corresponds to the JSON property terminationTimestamp
53224 53225 53226 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53224 def @termination_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53231 53232 53233 53234 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53231 def update!(**args) @availability_domain = args[:availability_domain] if args.key?(:availability_domain) @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp) end |