Class: Google::Apis::ComputeBeta::ResourceStatusScheduling

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusScheduling

Returns a new instance of ResourceStatusScheduling.



50338
50339
50340
# File 'lib/google/apis/compute_beta/classes.rb', line 50338

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availability_domainFixnum

Specifies the availability domain to place the instance in. The value must be a number between 1 and the number of availability domains specified in the spread placement policy attached to the instance. Corresponds to the JSON property availabilityDomain

Returns:

  • (Fixnum)


50331
50332
50333
# File 'lib/google/apis/compute_beta/classes.rb', line 50331

def availability_domain
  @availability_domain
end

#termination_timestampString

Time in future when the instance will be terminated inRFC3339 text format. Corresponds to the JSON property terminationTimestamp

Returns:

  • (String)


50336
50337
50338
# File 'lib/google/apis/compute_beta/classes.rb', line 50336

def termination_timestamp
  @termination_timestamp
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50343
50344
50345
50346
# File 'lib/google/apis/compute_beta/classes.rb', line 50343

def update!(**args)
  @availability_domain = args[:availability_domain] if args.key?(:availability_domain)
  @termination_timestamp = args[:termination_timestamp] if args.key?(:termination_timestamp)
end