Class: Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current
stopStatein RFC3339 text format. -
#stop_state ⇒ String
Current stopping state of the instance.
-
#target_state ⇒ String
Target instance state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusShutdownDetails
constructor
A new instance of ResourceStatusShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusShutdownDetails
Returns a new instance of ResourceStatusShutdownDetails.
55284 55285 55286 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
55266 55267 55268 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55266 def max_duration @max_duration end |
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current stopState in RFC3339 text
format.
Corresponds to the JSON property requestTimestamp
55272 55273 55274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55272 def @request_timestamp end |
#stop_state ⇒ String
Current stopping state of the instance.
Corresponds to the JSON property stopState
55277 55278 55279 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55277 def stop_state @stop_state end |
#target_state ⇒ String
Target instance state.
Corresponds to the JSON property targetState
55282 55283 55284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55282 def target_state @target_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55289 55290 55291 55292 55293 55294 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55289 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) @stop_state = args[:stop_state] if args.key?(:stop_state) @target_state = args[:target_state] if args.key?(:target_state) end |