Class: Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ResourceStatusShutdownDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifies if the instance is in PENDING_STOP state or there is a
programmed stop scheduled.
Instance Attribute Summary collapse
-
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
-
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current
stopStatein RFC3339 text format. -
#stop_state ⇒ String
Current stopping state of the instance.
-
#target_state ⇒ String
Target instance state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ResourceStatusShutdownDetails
constructor
A new instance of ResourceStatusShutdownDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ResourceStatusShutdownDetails
Returns a new instance of ResourceStatusShutdownDetails.
54078 54079 54080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54078 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
54060 54061 54062 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54060 def max_duration @max_duration end |
#request_timestamp ⇒ String
Past timestamp indicating the beginning of current stopState in RFC3339 text
format.
Corresponds to the JSON property requestTimestamp
54066 54067 54068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54066 def @request_timestamp end |
#stop_state ⇒ String
Current stopping state of the instance.
Corresponds to the JSON property stopState
54071 54072 54073 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54071 def stop_state @stop_state end |
#target_state ⇒ String
Target instance state.
Corresponds to the JSON property targetState
54076 54077 54078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54076 def target_state @target_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54083 54084 54085 54086 54087 54088 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54083 def update!(**args) @max_duration = args[:max_duration] if args.key?(:max_duration) @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp) @stop_state = args[:stop_state] if args.key?(:stop_state) @target_state = args[:target_state] if args.key?(:target_state) end |