Class: Google::Apis::ComputeBeta::ResourceStatusShutdownDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Specifies if the instance is in PENDING_STOP state or there is a programmed stop scheduled.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ResourceStatusShutdownDetails

Returns a new instance of ResourceStatusShutdownDetails.



53266
53267
53268
# File 'lib/google/apis/compute_beta/classes.rb', line 53266

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#max_durationGoogle::Apis::ComputeBeta::Duration

A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution. It is independent of any calendar and concepts like "day" or "month". Range is approximately 10,000 years. Corresponds to the JSON property maxDuration



53248
53249
53250
# File 'lib/google/apis/compute_beta/classes.rb', line 53248

def max_duration
  @max_duration
end

#request_timestampString

Past timestamp indicating the beginning of current stopState in RFC3339 text format. Corresponds to the JSON property requestTimestamp

Returns:

  • (String)


53254
53255
53256
# File 'lib/google/apis/compute_beta/classes.rb', line 53254

def request_timestamp
  @request_timestamp
end

#stop_stateString

Current stopping state of the instance. Corresponds to the JSON property stopState

Returns:

  • (String)


53259
53260
53261
# File 'lib/google/apis/compute_beta/classes.rb', line 53259

def stop_state
  @stop_state
end

#target_stateString

Target instance state. Corresponds to the JSON property targetState

Returns:

  • (String)


53264
53265
53266
# File 'lib/google/apis/compute_beta/classes.rb', line 53264

def target_state
  @target_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53271
53272
53273
53274
53275
53276
# File 'lib/google/apis/compute_beta/classes.rb', line 53271

def update!(**args)
  @max_duration = args[:max_duration] if args.key?(:max_duration)
  @request_timestamp = args[:request_timestamp] if args.key?(:request_timestamp)
  @stop_state = args[:stop_state] if args.key?(:stop_state)
  @target_state = args[:target_state] if args.key?(:target_state)
end