Class: Google::Apis::ComputeBeta::RiskDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Detailed insights and metrics about a detected reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetails

Returns a new instance of RiskDetails.



55393
55394
55395
# File 'lib/google/apis/compute_beta/classes.rb', line 55393

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The duration of the risk since it was detected. Corresponds to the JSON property duration

Returns:

  • (String)


55371
55372
55373
# File 'lib/google/apis/compute_beta/classes.rb', line 55371

def duration
  @duration
end

#global_dns_insightGoogle::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight

Detailed insights for a global DNS reliability risk. Corresponds to the JSON property globalDnsInsight



55376
55377
55378
# File 'lib/google/apis/compute_beta/classes.rb', line 55376

def global_dns_insight
  @global_dns_insight
end

#last_update_timestampString

The last time the risk was updated. Corresponds to the JSON property lastUpdateTimestamp

Returns:

  • (String)


55381
55382
55383
# File 'lib/google/apis/compute_beta/classes.rb', line 55381

def last_update_timestamp
  @last_update_timestamp
end

#severityString

The severity of the risk. Corresponds to the JSON property severity

Returns:

  • (String)


55386
55387
55388
# File 'lib/google/apis/compute_beta/classes.rb', line 55386

def severity
  @severity
end

#typeString

The type of risk. Corresponds to the JSON property type

Returns:

  • (String)


55391
55392
55393
# File 'lib/google/apis/compute_beta/classes.rb', line 55391

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55398
55399
55400
55401
55402
55403
55404
# File 'lib/google/apis/compute_beta/classes.rb', line 55398

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight)
  @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
  @severity = args[:severity] if args.key?(:severity)
  @type = args[:type] if args.key?(:type)
end