Class: Google::Apis::ComputeBeta::RiskDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Detailed insights and metrics about a detected reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetails

Returns a new instance of RiskDetails.



55326
55327
55328
# File 'lib/google/apis/compute_beta/classes.rb', line 55326

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The duration of the risk since it was detected. Corresponds to the JSON property duration

Returns:

  • (String)


55304
55305
55306
# File 'lib/google/apis/compute_beta/classes.rb', line 55304

def duration
  @duration
end

#global_dns_insightGoogle::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight

Detailed insights for a global DNS reliability risk. Corresponds to the JSON property globalDnsInsight



55309
55310
55311
# File 'lib/google/apis/compute_beta/classes.rb', line 55309

def global_dns_insight
  @global_dns_insight
end

#last_update_timestampString

The last time the risk was updated. Corresponds to the JSON property lastUpdateTimestamp

Returns:

  • (String)


55314
55315
55316
# File 'lib/google/apis/compute_beta/classes.rb', line 55314

def last_update_timestamp
  @last_update_timestamp
end

#severityString

The severity of the risk. Corresponds to the JSON property severity

Returns:

  • (String)


55319
55320
55321
# File 'lib/google/apis/compute_beta/classes.rb', line 55319

def severity
  @severity
end

#typeString

The type of risk. Corresponds to the JSON property type

Returns:

  • (String)


55324
55325
55326
# File 'lib/google/apis/compute_beta/classes.rb', line 55324

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55331
55332
55333
55334
55335
55336
55337
# File 'lib/google/apis/compute_beta/classes.rb', line 55331

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight)
  @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
  @severity = args[:severity] if args.key?(:severity)
  @type = args[:type] if args.key?(:type)
end