Class: Google::Apis::ComputeBeta::RiskDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Detailed insights and metrics about a detected reliability risk.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RiskDetails

Returns a new instance of RiskDetails.



55294
55295
55296
# File 'lib/google/apis/compute_beta/classes.rb', line 55294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#durationString

The duration of the risk since it was detected. Corresponds to the JSON property duration

Returns:

  • (String)


55272
55273
55274
# File 'lib/google/apis/compute_beta/classes.rb', line 55272

def duration
  @duration
end

#global_dns_insightGoogle::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight

Detailed insights for a global DNS reliability risk. Corresponds to the JSON property globalDnsInsight



55277
55278
55279
# File 'lib/google/apis/compute_beta/classes.rb', line 55277

def global_dns_insight
  @global_dns_insight
end

#last_update_timestampString

The last time the risk was updated. Corresponds to the JSON property lastUpdateTimestamp

Returns:

  • (String)


55282
55283
55284
# File 'lib/google/apis/compute_beta/classes.rb', line 55282

def last_update_timestamp
  @last_update_timestamp
end

#severityString

The severity of the risk. Corresponds to the JSON property severity

Returns:

  • (String)


55287
55288
55289
# File 'lib/google/apis/compute_beta/classes.rb', line 55287

def severity
  @severity
end

#typeString

The type of risk. Corresponds to the JSON property type

Returns:

  • (String)


55292
55293
55294
# File 'lib/google/apis/compute_beta/classes.rb', line 55292

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55299
55300
55301
55302
55303
55304
55305
# File 'lib/google/apis/compute_beta/classes.rb', line 55299

def update!(**args)
  @duration = args[:duration] if args.key?(:duration)
  @global_dns_insight = args[:global_dns_insight] if args.key?(:global_dns_insight)
  @last_update_timestamp = args[:last_update_timestamp] if args.key?(:last_update_timestamp)
  @severity = args[:severity] if args.key?(:severity)
  @type = args[:type] if args.key?(:type)
end