Class: Google::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RiskDetailsGlobalDnsInsight
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Detailed insights for a global DNS reliability risk.
Instance Attribute Summary collapse
-
#project_default_is_global_dns ⇒ Boolean
(also: #project_default_is_global_dns?)
Indicates whether the project's default DNS setting is global DNS.
-
#query_observation_window ⇒ String
The observation window for the query counts.
-
#risky_query_count ⇒ Fixnum
The number of queries that are risky.
-
#total_query_count ⇒ Fixnum
The total number of queries in the observation window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RiskDetailsGlobalDnsInsight
constructor
A new instance of RiskDetailsGlobalDnsInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RiskDetailsGlobalDnsInsight
Returns a new instance of RiskDetailsGlobalDnsInsight.
55334 55335 55336 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55334 def initialize(**args) update!(**args) end |
Instance Attribute Details
#project_default_is_global_dns ⇒ Boolean Also known as: project_default_is_global_dns?
Indicates whether the project's default DNS setting is global DNS.
Corresponds to the JSON property projectDefaultIsGlobalDns
55315 55316 55317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55315 def project_default_is_global_dns @project_default_is_global_dns end |
#query_observation_window ⇒ String
The observation window for the query counts.
Corresponds to the JSON property queryObservationWindow
55321 55322 55323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55321 def query_observation_window @query_observation_window end |
#risky_query_count ⇒ Fixnum
The number of queries that are risky. This is always less than or
equal to total_query_count.
Corresponds to the JSON property riskyQueryCount
55327 55328 55329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55327 def risky_query_count @risky_query_count end |
#total_query_count ⇒ Fixnum
The total number of queries in the observation window.
Corresponds to the JSON property totalQueryCount
55332 55333 55334 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55332 def total_query_count @total_query_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55339 55340 55341 55342 55343 55344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55339 def update!(**args) @project_default_is_global_dns = args[:project_default_is_global_dns] if args.key?(:project_default_is_global_dns) @query_observation_window = args[:query_observation_window] if args.key?(:query_observation_window) @risky_query_count = args[:risky_query_count] if args.key?(:risky_query_count) @total_query_count = args[:total_query_count] if args.key?(:total_query_count) end |