Class: Google::Apis::ComputeBeta::Rollout

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Rollout resource. A Rollout is a specific instance of a RolloutPlan. It represents a single execution of a strategy to roll out a specific resource. It also provides APIs to interact with the rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Rollout

Returns a new instance of Rollout.



55479
55480
55481
# File 'lib/google/apis/compute_beta/classes.rb', line 55479

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cancellation_timeString

Output only. The timestamp at which the Rollout was cancelled. Corresponds to the JSON property cancellationTime

Returns:

  • (String)


55382
55383
55384
# File 'lib/google/apis/compute_beta/classes.rb', line 55382

def cancellation_time
  @cancellation_time
end

#completion_timeString

Output only. The timestamp at which the Rollout was completed. Corresponds to the JSON property completionTime

Returns:

  • (String)


55387
55388
55389
# File 'lib/google/apis/compute_beta/classes.rb', line 55387

def completion_time
  @completion_time
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


55393
55394
55395
# File 'lib/google/apis/compute_beta/classes.rb', line 55393

def creation_timestamp
  @creation_timestamp
end

#current_wave_numberFixnum

Output only. The number of the currently running wave. Ex. 1 Corresponds to the JSON property currentWaveNumber

Returns:

  • (Fixnum)


55399
55400
55401
# File 'lib/google/apis/compute_beta/classes.rb', line 55399

def current_wave_number
  @current_wave_number
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


55405
55406
55407
# File 'lib/google/apis/compute_beta/classes.rb', line 55405

def description
  @description
end

#etagString

Output only. etag of the Rollout Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


55411
55412
55413
# File 'lib/google/apis/compute_beta/classes.rb', line 55411

def etag
  @etag
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


55418
55419
55420
# File 'lib/google/apis/compute_beta/classes.rb', line 55418

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#rollout for rollouts. Corresponds to the JSON property kind

Returns:

  • (String)


55424
55425
55426
# File 'lib/google/apis/compute_beta/classes.rb', line 55424

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


55435
55436
55437
# File 'lib/google/apis/compute_beta/classes.rb', line 55435

def name
  @name
end

#pause_timeString

Output only. The timestamp at which the Rollout was paused. Corresponds to the JSON property pauseTime

Returns:

  • (String)


55440
55441
55442
# File 'lib/google/apis/compute_beta/classes.rb', line 55440

def pause_time
  @pause_time
end

#resume_timeString

Output only. The timestamp at which the Rollout was resumed. Corresponds to the JSON property resumeTime

Returns:

  • (String)


55445
55446
55447
# File 'lib/google/apis/compute_beta/classes.rb', line 55445

def resume_time
  @resume_time
end

#rollout_entityGoogle::Apis::ComputeBeta::RolloutRolloutEntity

Specifications of the resource to roll out. Corresponds to the JSON property rolloutEntity



55450
55451
55452
# File 'lib/google/apis/compute_beta/classes.rb', line 55450

def rollout_entity
  @rollout_entity
end

#rollout_planString

Required. Rollout Plan used to model the Rollout. Ex. compute.googleapis.com/v1/projects/1234/rolloutPlans/rp1 Corresponds to the JSON property rolloutPlan

Returns:

  • (String)


55456
55457
55458
# File 'lib/google/apis/compute_beta/classes.rb', line 55456

def rollout_plan
  @rollout_plan
end

Output only. [Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55462
55463
55464
# File 'lib/google/apis/compute_beta/classes.rb', line 55462

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


55467
55468
55469
# File 'lib/google/apis/compute_beta/classes.rb', line 55467

def self_link_with_id
  @self_link_with_id
end

#stateString

Output only. The current state of the Rollout. Corresponds to the JSON property state

Returns:

  • (String)


55472
55473
55474
# File 'lib/google/apis/compute_beta/classes.rb', line 55472

def state
  @state
end

#wave_detailsArray<Google::Apis::ComputeBeta::RolloutWaveDetails>

Output only. Details about each wave of the rollout. Corresponds to the JSON property waveDetails



55477
55478
55479
# File 'lib/google/apis/compute_beta/classes.rb', line 55477

def wave_details
  @wave_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55484
55485
55486
55487
55488
55489
55490
55491
55492
55493
55494
55495
55496
55497
55498
55499
55500
55501
55502
# File 'lib/google/apis/compute_beta/classes.rb', line 55484

def update!(**args)
  @cancellation_time = args[:cancellation_time] if args.key?(:cancellation_time)
  @completion_time = args[:completion_time] if args.key?(:completion_time)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @current_wave_number = args[:current_wave_number] if args.key?(:current_wave_number)
  @description = args[:description] if args.key?(:description)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @pause_time = args[:pause_time] if args.key?(:pause_time)
  @resume_time = args[:resume_time] if args.key?(:resume_time)
  @rollout_entity = args[:rollout_entity] if args.key?(:rollout_entity)
  @rollout_plan = args[:rollout_plan] if args.key?(:rollout_plan)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @state = args[:state] if args.key?(:state)
  @wave_details = args[:wave_details] if args.key?(:wave_details)
end