Class: Google::Apis::ComputeBeta::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



54389
54390
54391
# File 'lib/google/apis/compute_beta/classes.rb', line 54389

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


54362
54363
54364
# File 'lib/google/apis/compute_beta/classes.rb', line 54362

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


54367
54368
54369
# File 'lib/google/apis/compute_beta/classes.rb', line 54367

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



54374
54375
54376
# File 'lib/google/apis/compute_beta/classes.rb', line 54374

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeBeta::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



54382
54383
54384
# File 'lib/google/apis/compute_beta/classes.rb', line 54382

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeBeta::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



54387
54388
54389
# File 'lib/google/apis/compute_beta/classes.rb', line 54387

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54394
54395
54396
54397
54398
54399
54400
# File 'lib/google/apis/compute_beta/classes.rb', line 54394

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end