Class: Google::Apis::ComputeBeta::RolloutPlanWave

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A single wave in a rollout plan.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWave

Returns a new instance of RolloutPlanWave.



54330
54331
54332
# File 'lib/google/apis/compute_beta/classes.rb', line 54330

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#display_nameString

Optional. The display name of this wave of the rollout plan. Corresponds to the JSON property displayName

Returns:

  • (String)


54303
54304
54305
# File 'lib/google/apis/compute_beta/classes.rb', line 54303

def display_name
  @display_name
end

#numberFixnum

Output only. The wave number. Corresponds to the JSON property number

Returns:

  • (Fixnum)


54308
54309
54310
# File 'lib/google/apis/compute_beta/classes.rb', line 54308

def number
  @number
end

#orchestration_optionsGoogle::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern. Corresponds to the JSON property orchestrationOptions



54315
54316
54317
# File 'lib/google/apis/compute_beta/classes.rb', line 54315

def orchestration_options
  @orchestration_options
end

#selectorsArray<Google::Apis::ComputeBeta::RolloutPlanWaveSelector>

Required. The selectors for this wave. There is a logical AND between each selector defined in a wave, so a resource must satisfy the criteria of all the specified selectors to be in scope for the wave. Corresponds to the JSON property selectors



54323
54324
54325
# File 'lib/google/apis/compute_beta/classes.rb', line 54323

def selectors
  @selectors
end

#validationGoogle::Apis::ComputeBeta::RolloutPlanWaveValidation

The validation to be performed before progressing to the next wave. Corresponds to the JSON property validation



54328
54329
54330
# File 'lib/google/apis/compute_beta/classes.rb', line 54328

def validation
  @validation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54335
54336
54337
54338
54339
54340
54341
# File 'lib/google/apis/compute_beta/classes.rb', line 54335

def update!(**args)
  @display_name = args[:display_name] if args.key?(:display_name)
  @number = args[:number] if args.key?(:number)
  @orchestration_options = args[:orchestration_options] if args.key?(:orchestration_options)
  @selectors = args[:selectors] if args.key?(:selectors)
  @validation = args[:validation] if args.key?(:validation)
end