Class: Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.
Instance Attribute Summary collapse
-
#delays ⇒ Array<Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay>
Optional.
-
#max_concurrent_locations ⇒ Fixnum
Optional.
-
#max_concurrent_resources_per_location ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
constructor
A new instance of RolloutPlanWaveOrchestrationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
Returns a new instance of RolloutPlanWaveOrchestrationOptions.
55694 55695 55696 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55694 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delays ⇒ Array<Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay>
Optional. Delays, if any, to be added between batches of projects. We allow
multiple Delays to be specified, letting users set separate delays
between batches of projects corresponding to different locations and
batches of projects corresponding to the same location.
Corresponds to the JSON property delays
55681 55682 55683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55681 def delays @delays end |
#max_concurrent_locations ⇒ Fixnum
Optional. Maximum number of locations to be orchestrated in parallel.
Corresponds to the JSON property maxConcurrentLocations
55686 55687 55688 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55686 def max_concurrent_locations @max_concurrent_locations end |
#max_concurrent_resources_per_location ⇒ Fixnum
Optional. Maximum number of resources to be orchestrated per location in
parallel.
Corresponds to the JSON property maxConcurrentResourcesPerLocation
55692 55693 55694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55692 def max_concurrent_resources_per_location @max_concurrent_resources_per_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55699 55700 55701 55702 55703 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55699 def update!(**args) @delays = args[:delays] if args.key?(:delays) @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations) @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location) end |