Class: Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions

Returns a new instance of RolloutPlanWaveOrchestrationOptions.



55206
55207
55208
# File 'lib/google/apis/compute_beta/classes.rb', line 55206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delaysArray<Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay>

Optional. Delays, if any, to be added between batches of projects. We allow multiple Delays to be specified, letting users set separate delays between batches of projects corresponding to different locations and batches of projects corresponding to the same location. Corresponds to the JSON property delays



55193
55194
55195
# File 'lib/google/apis/compute_beta/classes.rb', line 55193

def delays
  @delays
end

#max_concurrent_locationsFixnum

Optional. Maximum number of locations to be orchestrated in parallel. Corresponds to the JSON property maxConcurrentLocations

Returns:

  • (Fixnum)


55198
55199
55200
# File 'lib/google/apis/compute_beta/classes.rb', line 55198

def max_concurrent_locations
  @max_concurrent_locations
end

#max_concurrent_resources_per_locationFixnum

Optional. Maximum number of resources to be orchestrated per location in parallel. Corresponds to the JSON property maxConcurrentResourcesPerLocation

Returns:

  • (Fixnum)


55204
55205
55206
# File 'lib/google/apis/compute_beta/classes.rb', line 55204

def max_concurrent_resources_per_location
  @max_concurrent_resources_per_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55211
55212
55213
55214
55215
# File 'lib/google/apis/compute_beta/classes.rb', line 55211

def update!(**args)
  @delays = args[:delays] if args.key?(:delays)
  @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations)
  @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location)
end