Class: Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Options to control the pace of orchestration of a wave. These options are required only if the resource being rolled out follows the Orchestrated pattern.
Instance Attribute Summary collapse
-
#delays ⇒ Array<Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay>
Optional.
-
#max_concurrent_locations ⇒ Fixnum
Optional.
-
#max_concurrent_resources_per_location ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
constructor
A new instance of RolloutPlanWaveOrchestrationOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptions
Returns a new instance of RolloutPlanWaveOrchestrationOptions.
54428 54429 54430 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54428 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delays ⇒ Array<Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay>
Optional. Delays, if any, to be added between batches of projects. We allow
multiple Delays to be specified, letting users set separate delays
between batches of projects corresponding to different locations and
batches of projects corresponding to the same location.
Corresponds to the JSON property delays
54415 54416 54417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54415 def delays @delays end |
#max_concurrent_locations ⇒ Fixnum
Optional. Maximum number of locations to be orchestrated in parallel.
Corresponds to the JSON property maxConcurrentLocations
54420 54421 54422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54420 def max_concurrent_locations @max_concurrent_locations end |
#max_concurrent_resources_per_location ⇒ Fixnum
Optional. Maximum number of resources to be orchestrated per location in
parallel.
Corresponds to the JSON property maxConcurrentResourcesPerLocation
54426 54427 54428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54426 def max_concurrent_resources_per_location @max_concurrent_resources_per_location end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54433 54434 54435 54436 54437 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54433 def update!(**args) @delays = args[:delays] if args.key?(:delays) @max_concurrent_locations = args[:max_concurrent_locations] if args.key?(:max_concurrent_locations) @max_concurrent_resources_per_location = args[:max_concurrent_resources_per_location] if args.key?(:max_concurrent_resources_per_location) end |