Class: Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Options to control the delay, if any, between batches of projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptionsDelay

Returns a new instance of RolloutPlanWaveOrchestrationOptionsDelay.



55700
55701
55702
# File 'lib/google/apis/compute_beta/classes.rb', line 55700

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location. Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Corresponds to the JSON property delimiter

Returns:

  • (String)


55684
55685
55686
# File 'lib/google/apis/compute_beta/classes.rb', line 55684

def delimiter
  @delimiter
end

#durationString

Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay. Corresponds to the JSON property duration

Returns:

  • (String)


55690
55691
55692
# File 'lib/google/apis/compute_beta/classes.rb', line 55690

def duration
  @duration
end

#typeString

Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration. Must be set to TYPE_UNSPECIFIED if no delay is to be added. Corresponds to the JSON property type

Returns:

  • (String)


55698
55699
55700
# File 'lib/google/apis/compute_beta/classes.rb', line 55698

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55705
55706
55707
55708
55709
# File 'lib/google/apis/compute_beta/classes.rb', line 55705

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @duration = args[:duration] if args.key?(:duration)
  @type = args[:type] if args.key?(:type)
end