Class: Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Options to control the delay, if any, between batches of projects.
Instance Attribute Summary collapse
-
#delimiter ⇒ String
Optional.
-
#duration ⇒ String
Optional.
-
#type ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptionsDelay
constructor
A new instance of RolloutPlanWaveOrchestrationOptionsDelay.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptionsDelay
Returns a new instance of RolloutPlanWaveOrchestrationOptionsDelay.
54466 54467 54468 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54466 def initialize(**args) update!(**args) end |
Instance Attribute Details
#delimiter ⇒ String
Optional. Controls whether the delay should only be added between batches of
projects corresponding to different locations, or also between
batches of projects corresponding to the same location.
Must be set to DELIMITER_UNSPECIFIED if no delay is to be added.
Corresponds to the JSON property delimiter
54450 54451 54452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54450 def delimiter @delimiter end |
#duration ⇒ String
Optional. The duration of the delay, if any, to be added between batches of
projects. A zero duration corresponds to no delay.
Corresponds to the JSON property duration
54456 54457 54458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54456 def duration @duration end |
#type ⇒ String
Optional. Controls whether the specified duration is to be added at the end of
each batch, or if the total processing time for each batch will be
padded if needed to meet the specified duration.
Must be set to TYPE_UNSPECIFIED if no delay is to be added.
Corresponds to the JSON property type
54464 54465 54466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54464 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54471 54472 54473 54474 54475 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54471 def update!(**args) @delimiter = args[:delimiter] if args.key?(:delimiter) @duration = args[:duration] if args.key?(:duration) @type = args[:type] if args.key?(:type) end |