Class: Google::Apis::ComputeBeta::RolloutPlanWaveOrchestrationOptionsDelay

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Options to control the delay, if any, between batches of projects.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveOrchestrationOptionsDelay

Returns a new instance of RolloutPlanWaveOrchestrationOptionsDelay.



53595
53596
53597
# File 'lib/google/apis/compute_beta/classes.rb', line 53595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#delimiterString

Optional. Controls whether the delay should only be added between batches of projects corresponding to different locations, or also between batches of projects corresponding to the same location. Must be set to DELIMITER_UNSPECIFIED if no delay is to be added. Corresponds to the JSON property delimiter

Returns:

  • (String)


53579
53580
53581
# File 'lib/google/apis/compute_beta/classes.rb', line 53579

def delimiter
  @delimiter
end

#durationString

Optional. The duration of the delay, if any, to be added between batches of projects. A zero duration corresponds to no delay. Corresponds to the JSON property duration

Returns:

  • (String)


53585
53586
53587
# File 'lib/google/apis/compute_beta/classes.rb', line 53585

def duration
  @duration
end

#typeString

Optional. Controls whether the specified duration is to be added at the end of each batch, or if the total processing time for each batch will be padded if needed to meet the specified duration. Must be set to TYPE_UNSPECIFIED if no delay is to be added. Corresponds to the JSON property type

Returns:

  • (String)


53593
53594
53595
# File 'lib/google/apis/compute_beta/classes.rb', line 53593

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53600
53601
53602
53603
53604
# File 'lib/google/apis/compute_beta/classes.rb', line 53600

def update!(**args)
  @delimiter = args[:delimiter] if args.key?(:delimiter)
  @duration = args[:duration] if args.key?(:duration)
  @type = args[:type] if args.key?(:type)
end