Class: Google::Apis::ComputeBeta::RolloutPlanWaveValidation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The validation to be performed before progressing to the next wave.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveValidation

Returns a new instance of RolloutPlanWaveValidation.



55811
55812
55813
# File 'lib/google/apis/compute_beta/classes.rb', line 55811

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#time_based_validation_metadataGoogle::Apis::ComputeBeta::RolloutPlanWaveValidationTimeBasedValidationMetadata

Metadata required if type = "time". Corresponds to the JSON property timeBasedValidationMetadata



55796
55797
55798
# File 'lib/google/apis/compute_beta/classes.rb', line 55796

def 
  @time_based_validation_metadata
end

#typeString

Required. The type of the validation. If a type of validation is associated with a metadata object, the appropriate metadata field mapping to the validation type must be provided in the validation message. Possible values are in quotes below alongside an explanation: "manual": The system waits for an end-user approval API before progressing to the next wave. "time": The system waits for a user specified duration before progressing to the next wave. TimeBasedValidation must be provided. Corresponds to the JSON property type

Returns:

  • (String)


55809
55810
55811
# File 'lib/google/apis/compute_beta/classes.rb', line 55809

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55816
55817
55818
55819
# File 'lib/google/apis/compute_beta/classes.rb', line 55816

def update!(**args)
  @time_based_validation_metadata = args[:time_based_validation_metadata] if args.key?(:time_based_validation_metadata)
  @type = args[:type] if args.key?(:type)
end