Class: Google::Apis::ComputeBeta::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlanWaveValidationTimeBasedValidationMetadata
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Metadata required if type = "time".
Instance Attribute Summary collapse
-
#wait_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata
constructor
A new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata
Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.
55399 55400 55401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#wait_duration ⇒ String
Optional. The duration that the system waits in between waves. This wait
starts
after all changes in the wave are rolled out.
Corresponds to the JSON property waitDuration
55397 55398 55399 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55397 def wait_duration @wait_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55404 55405 55406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55404 def update!(**args) @wait_duration = args[:wait_duration] if args.key?(:wait_duration) end |