Class: Google::Apis::ComputeBeta::RolloutPlanWaveValidationTimeBasedValidationMetadata

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Metadata required if type = "time".

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlanWaveValidationTimeBasedValidationMetadata

Returns a new instance of RolloutPlanWaveValidationTimeBasedValidationMetadata.



50840
50841
50842
# File 'lib/google/apis/compute_beta/classes.rb', line 50840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#wait_durationString

Optional. The duration that the system waits in between waves. This wait starts after all changes in the wave are rolled out. Corresponds to the JSON property waitDuration

Returns:

  • (String)


50838
50839
50840
# File 'lib/google/apis/compute_beta/classes.rb', line 50838

def wait_duration
  @wait_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50845
50846
50847
# File 'lib/google/apis/compute_beta/classes.rb', line 50845

def update!(**args)
  @wait_duration = args[:wait_duration] if args.key?(:wait_duration)
end