Class: Google::Apis::ComputeBeta::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
55920 55921 55922 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55920 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
55882 55883 55884 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55882 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55887 55888 55889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55887 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
55892 55893 55894 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55892 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55902 55903 55904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55902 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55907 55908 55909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55907 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
55913 55914 55915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55913 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55918 55919 55920 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55918 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55925 55926 55927 55928 55929 55930 55931 55932 55933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55925 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |