Class: Google::Apis::ComputeBeta::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
55888 55889 55890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
55850 55851 55852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55850 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55855 55856 55857 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55855 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
55860 55861 55862 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55860 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55870 55871 55872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55870 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55875 55876 55877 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55875 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
55881 55882 55883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55881 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55886 55887 55888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55886 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55893 55894 55895 55896 55897 55898 55899 55900 55901 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55893 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |