Class: Google::Apis::ComputeBeta::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
54654 54655 54656 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54654 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
54616 54617 54618 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54616 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54621 54622 54623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54621 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
54626 54627 54628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54626 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
54636 54637 54638 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54636 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
54641 54642 54643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54641 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
54647 54648 54649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54647 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
54652 54653 54654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54652 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54659 54660 54661 54662 54663 54664 54665 54666 54667 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54659 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |