Class: Google::Apis::ComputeBeta::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



54595
54596
54597
# File 'lib/google/apis/compute_beta/classes.rb', line 54595

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54557
54558
54559
# File 'lib/google/apis/compute_beta/classes.rb', line 54557

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54562
54563
54564
# File 'lib/google/apis/compute_beta/classes.rb', line 54562

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



54567
54568
54569
# File 'lib/google/apis/compute_beta/classes.rb', line 54567

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54577
54578
54579
# File 'lib/google/apis/compute_beta/classes.rb', line 54577

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54582
54583
54584
# File 'lib/google/apis/compute_beta/classes.rb', line 54582

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54588
54589
54590
# File 'lib/google/apis/compute_beta/classes.rb', line 54588

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54593
54594
54595
# File 'lib/google/apis/compute_beta/classes.rb', line 54593

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54600
54601
54602
54603
54604
54605
54606
54607
54608
# File 'lib/google/apis/compute_beta/classes.rb', line 54600

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end