Class: Google::Apis::ComputeBeta::RolloutPlansListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPlansListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of RolloutPlan resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPlansListResponse
constructor
A new instance of RolloutPlansListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPlansListResponse
Returns a new instance of RolloutPlansListResponse.
52626 52627 52628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52626 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
52588 52589 52590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52588 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
52593 52594 52595 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52593 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::RolloutPlan>
A list of RolloutPlan resources.
Corresponds to the JSON property items
52598 52599 52600 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52598 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
52608 52609 52610 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52608 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
52613 52614 52615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52613 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
52619 52620 52621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52619 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutPlansListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
52624 52625 52626 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52624 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
52631 52632 52633 52634 52635 52636 52637 52638 52639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 52631 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |