Class: Google::Apis::ComputeBeta::RolloutPlansListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of RolloutPlan resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutPlansListResponse

Returns a new instance of RolloutPlansListResponse.



50895
50896
50897
# File 'lib/google/apis/compute_beta/classes.rb', line 50895

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


50857
50858
50859
# File 'lib/google/apis/compute_beta/classes.rb', line 50857

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


50862
50863
50864
# File 'lib/google/apis/compute_beta/classes.rb', line 50862

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::RolloutPlan>

A list of RolloutPlan resources. Corresponds to the JSON property items



50867
50868
50869
# File 'lib/google/apis/compute_beta/classes.rb', line 50867

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


50877
50878
50879
# File 'lib/google/apis/compute_beta/classes.rb', line 50877

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


50882
50883
50884
# File 'lib/google/apis/compute_beta/classes.rb', line 50882

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


50888
50889
50890
# File 'lib/google/apis/compute_beta/classes.rb', line 50888

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RolloutPlansListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



50893
50894
50895
# File 'lib/google/apis/compute_beta/classes.rb', line 50893

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



50900
50901
50902
50903
50904
50905
50906
50907
50908
# File 'lib/google/apis/compute_beta/classes.rb', line 50900

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end