Class: Google::Apis::ComputeBeta::RolloutPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A rollout policy configuration.
Instance Attribute Summary collapse
-
#default_rollout_time ⇒ String
An optional RFC3339 timestamp on or after which the update is considered rolled out to any zone that is not explicitly stated.
-
#location_rollout_policies ⇒ Hash<String,String>
Location based rollout policies to apply to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPolicy
constructor
A new instance of RolloutPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPolicy
Returns a new instance of RolloutPolicy.
55537 55538 55539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55537 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_rollout_time ⇒ String
An optional RFC3339 timestamp on or after which the update is
considered rolled out to any zone that is not explicitly stated.
Corresponds to the JSON property defaultRolloutTime
55526 55527 55528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55526 def default_rollout_time @default_rollout_time end |
#location_rollout_policies ⇒ Hash<String,String>
Location based rollout policies to apply to the resource.
Currently only zone names are supported and must be represented
as valid URLs, like: zones/us-central1-a.
The value expects an RFC3339 timestamp on or after which the update is
considered rolled out to the specified location.
Corresponds to the JSON property locationRolloutPolicies
55535 55536 55537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55535 def location_rollout_policies @location_rollout_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55542 55543 55544 55545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55542 def update!(**args) @default_rollout_time = args[:default_rollout_time] if args.key?(:default_rollout_time) @location_rollout_policies = args[:location_rollout_policies] if args.key?(:location_rollout_policies) end |