Class: Google::Apis::ComputeBeta::RolloutPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A rollout policy configuration.
Instance Attribute Summary collapse
-
#default_rollout_time ⇒ String
An optional RFC3339 timestamp on or after which the update is considered rolled out to any zone that is not explicitly stated.
-
#location_rollout_policies ⇒ Hash<String,String>
Location based rollout policies to apply to the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutPolicy
constructor
A new instance of RolloutPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutPolicy
Returns a new instance of RolloutPolicy.
54759 54760 54761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54759 def initialize(**args) update!(**args) end |
Instance Attribute Details
#default_rollout_time ⇒ String
An optional RFC3339 timestamp on or after which the update is
considered rolled out to any zone that is not explicitly stated.
Corresponds to the JSON property defaultRolloutTime
54748 54749 54750 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54748 def default_rollout_time @default_rollout_time end |
#location_rollout_policies ⇒ Hash<String,String>
Location based rollout policies to apply to the resource.
Currently only zone names are supported and must be represented
as valid URLs, like: zones/us-central1-a.
The value expects an RFC3339 timestamp on or after which the update is
considered rolled out to the specified location.
Corresponds to the JSON property locationRolloutPolicies
54757 54758 54759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54757 def location_rollout_policies @location_rollout_policies end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54764 54765 54766 54767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54764 def update!(**args) @default_rollout_time = args[:default_rollout_time] if args.key?(:default_rollout_time) @location_rollout_policies = args[:location_rollout_policies] if args.key?(:location_rollout_policies) end |