Class: Google::Apis::ComputeBeta::RolloutRolloutEntity
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutRolloutEntity
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Specifications of the resource to roll out.
Instance Attribute Summary collapse
-
#orchestrated_entity ⇒ Google::Apis::ComputeBeta::RolloutRolloutEntityOrchestratedEntity
This message is used if the resource type follows the Orchestrated integration model with ProgressiveRollout.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutRolloutEntity
constructor
A new instance of RolloutRolloutEntity.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutRolloutEntity
Returns a new instance of RolloutRolloutEntity.
51021 51022 51023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#orchestrated_entity ⇒ Google::Apis::ComputeBeta::RolloutRolloutEntityOrchestratedEntity
This message is used if the resource type follows the Orchestrated
integration model with ProgressiveRollout.
Corresponds to the JSON property orchestratedEntity
51019 51020 51021 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51019 def orchestrated_entity @orchestrated_entity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51026 51027 51028 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51026 def update!(**args) @orchestrated_entity = args[:orchestrated_entity] if args.key?(:orchestrated_entity) end |