Class: Google::Apis::ComputeBeta::RolloutWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Additional metadata about the status of each wave provided by the server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetails

Returns a new instance of RolloutWaveDetails.



56095
56096
56097
# File 'lib/google/apis/compute_beta/classes.rb', line 56095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#orchestrated_wave_detailsGoogle::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetails

Details of the wave for products using the Orchestrated integration model. Corresponds to the JSON property orchestratedWaveDetails



56082
56083
56084
# File 'lib/google/apis/compute_beta/classes.rb', line 56082

def orchestrated_wave_details
  @orchestrated_wave_details
end

#wave_display_nameString

Output only. Wave name. Ex. wave1 Corresponds to the JSON property waveDisplayName

Returns:

  • (String)


56088
56089
56090
# File 'lib/google/apis/compute_beta/classes.rb', line 56088

def wave_display_name
  @wave_display_name
end

#wave_numberFixnum

Output only. System generated number for the wave. Corresponds to the JSON property waveNumber

Returns:

  • (Fixnum)


56093
56094
56095
# File 'lib/google/apis/compute_beta/classes.rb', line 56093

def wave_number
  @wave_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56100
56101
56102
56103
56104
# File 'lib/google/apis/compute_beta/classes.rb', line 56100

def update!(**args)
  @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details)
  @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name)
  @wave_number = args[:wave_number] if args.key?(:wave_number)
end