Class: Google::Apis::ComputeBeta::RolloutWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Additional metadata about the status of each wave provided by the server.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetails

Returns a new instance of RolloutWaveDetails.



51102
51103
51104
# File 'lib/google/apis/compute_beta/classes.rb', line 51102

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#orchestrated_wave_detailsGoogle::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetails

Details of the wave for products using the Orchestrated integration model. Corresponds to the JSON property orchestratedWaveDetails



51089
51090
51091
# File 'lib/google/apis/compute_beta/classes.rb', line 51089

def orchestrated_wave_details
  @orchestrated_wave_details
end

#wave_display_nameString

Output only. Wave name. Ex. wave1 Corresponds to the JSON property waveDisplayName

Returns:

  • (String)


51095
51096
51097
# File 'lib/google/apis/compute_beta/classes.rb', line 51095

def wave_display_name
  @wave_display_name
end

#wave_numberFixnum

Output only. System generated number for the wave. Corresponds to the JSON property waveNumber

Returns:

  • (Fixnum)


51100
51101
51102
# File 'lib/google/apis/compute_beta/classes.rb', line 51100

def wave_number
  @wave_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51107
51108
51109
51110
51111
# File 'lib/google/apis/compute_beta/classes.rb', line 51107

def update!(**args)
  @orchestrated_wave_details = args[:orchestrated_wave_details] if args.key?(:orchestrated_wave_details)
  @wave_display_name = args[:wave_display_name] if args.key?(:wave_display_name)
  @wave_number = args[:wave_number] if args.key?(:wave_number)
end