Class: Google::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetails
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetails
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Details of the wave for products using the Orchestrated integration model.
Instance Attribute Summary collapse
-
#completed_resources_count ⇒ Fixnum
Output only.
-
#estimated_completion_time ⇒ String
Output only.
-
#estimated_total_resources_count ⇒ Fixnum
Output only.
-
#failed_locations ⇒ Array<String>
Output only.
-
#failed_resources_count ⇒ Fixnum
Output only.
-
#location_status ⇒ Hash<String,Google::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
constructor
A new instance of RolloutWaveDetailsOrchestratedWaveDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails
Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.
55714 55715 55716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55714 def initialize(**args) update!(**args) end |
Instance Attribute Details
#completed_resources_count ⇒ Fixnum
Output only. Resource completed so far.
Corresponds to the JSON property completedResourcesCount
55681 55682 55683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55681 def completed_resources_count @completed_resources_count end |
#estimated_completion_time ⇒ String
Output only. Estimated timestamp at which the wave will complete. Extrapolated
from
current progress.
Corresponds to the JSON property estimatedCompletionTime
55688 55689 55690 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55688 def estimated_completion_time @estimated_completion_time end |
#estimated_total_resources_count ⇒ Fixnum
Output only. Estimated total count of resources.
Corresponds to the JSON property estimatedTotalResourcesCount
55693 55694 55695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55693 def estimated_total_resources_count @estimated_total_resources_count end |
#failed_locations ⇒ Array<String>
Output only. Locations that failed during orchestration, and
ProgressiveRollout
stopped retrying. There may be some successful resources rolled out in
the wave as the location may have failed later in the Rollout.
Corresponds to the JSON property failedLocations
55701 55702 55703 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55701 def failed_locations @failed_locations end |
#failed_resources_count ⇒ Fixnum
Output only. Resources failed.
Corresponds to the JSON property failedResourcesCount
55706 55707 55708 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55706 def failed_resources_count @failed_resources_count end |
#location_status ⇒ Hash<String,Google::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>
Output only. Status of each location in the wave. Map keys (locations) must be
specified like "us-east1" or "asia-west1-a".
Corresponds to the JSON property locationStatus
55712 55713 55714 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55712 def location_status @location_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55719 55720 55721 55722 55723 55724 55725 55726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55719 def update!(**args) @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count) @estimated_completion_time = args[:estimated_completion_time] if args.key?(:estimated_completion_time) @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count) @failed_locations = args[:failed_locations] if args.key?(:failed_locations) @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count) @location_status = args[:location_status] if args.key?(:location_status) end |