Class: Google::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetails

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Details of the wave for products using the Orchestrated integration model.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutWaveDetailsOrchestratedWaveDetails

Returns a new instance of RolloutWaveDetailsOrchestratedWaveDetails.



54036
54037
54038
# File 'lib/google/apis/compute_beta/classes.rb', line 54036

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#completed_resources_countFixnum

Output only. Resource completed so far. Corresponds to the JSON property completedResourcesCount

Returns:

  • (Fixnum)


54010
54011
54012
# File 'lib/google/apis/compute_beta/classes.rb', line 54010

def completed_resources_count
  @completed_resources_count
end

#estimated_total_resources_countFixnum

Output only. Estimated total count of resources. Corresponds to the JSON property estimatedTotalResourcesCount

Returns:

  • (Fixnum)


54015
54016
54017
# File 'lib/google/apis/compute_beta/classes.rb', line 54015

def estimated_total_resources_count
  @estimated_total_resources_count
end

#failed_locationsArray<String>

Output only. Locations that failed during orchestration, and ProgressiveRollout stopped retrying. There may be some successful resources rolled out in the wave as the location may have failed later in the Rollout. Corresponds to the JSON property failedLocations

Returns:

  • (Array<String>)


54023
54024
54025
# File 'lib/google/apis/compute_beta/classes.rb', line 54023

def failed_locations
  @failed_locations
end

#failed_resources_countFixnum

Output only. Resources failed. Corresponds to the JSON property failedResourcesCount

Returns:

  • (Fixnum)


54028
54029
54030
# File 'lib/google/apis/compute_beta/classes.rb', line 54028

def failed_resources_count
  @failed_resources_count
end

#location_statusHash<String,Google::Apis::ComputeBeta::RolloutWaveDetailsOrchestratedWaveDetailsLocationStatus>

Output only. Status of each location in the wave. Map keys (locations) must be specified like "us-east1" or "asia-west1-a". Corresponds to the JSON property locationStatus



54034
54035
54036
# File 'lib/google/apis/compute_beta/classes.rb', line 54034

def location_status
  @location_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54041
54042
54043
54044
54045
54046
54047
# File 'lib/google/apis/compute_beta/classes.rb', line 54041

def update!(**args)
  @completed_resources_count = args[:completed_resources_count] if args.key?(:completed_resources_count)
  @estimated_total_resources_count = args[:estimated_total_resources_count] if args.key?(:estimated_total_resources_count)
  @failed_locations = args[:failed_locations] if args.key?(:failed_locations)
  @failed_resources_count = args[:failed_resources_count] if args.key?(:failed_resources_count)
  @location_status = args[:location_status] if args.key?(:location_status)
end