Class: Google::Apis::ComputeBeta::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



56259
56260
56261
# File 'lib/google/apis/compute_beta/classes.rb', line 56259

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


56221
56222
56223
# File 'lib/google/apis/compute_beta/classes.rb', line 56221

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56226
56227
56228
# File 'lib/google/apis/compute_beta/classes.rb', line 56226

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



56231
56232
56233
# File 'lib/google/apis/compute_beta/classes.rb', line 56231

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56241
56242
56243
# File 'lib/google/apis/compute_beta/classes.rb', line 56241

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56246
56247
56248
# File 'lib/google/apis/compute_beta/classes.rb', line 56246

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56252
56253
56254
# File 'lib/google/apis/compute_beta/classes.rb', line 56252

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56257
56258
56259
# File 'lib/google/apis/compute_beta/classes.rb', line 56257

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56264
56265
56266
56267
56268
56269
56270
56271
56272
# File 'lib/google/apis/compute_beta/classes.rb', line 56264

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end