Class: Google::Apis::ComputeBeta::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
56227 56228 56229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
56189 56190 56191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56189 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56194 56195 56196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56194 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
56199 56200 56201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56199 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56209 56210 56211 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56209 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56214 56215 56216 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56214 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
56220 56221 56222 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56220 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56225 56226 56227 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56225 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56232 56233 56234 56235 56236 56237 56238 56239 56240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56232 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |