Class: Google::Apis::ComputeBeta::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



55793
55794
55795
# File 'lib/google/apis/compute_beta/classes.rb', line 55793

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


55755
55756
55757
# File 'lib/google/apis/compute_beta/classes.rb', line 55755

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55760
55761
55762
# File 'lib/google/apis/compute_beta/classes.rb', line 55760

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



55765
55766
55767
# File 'lib/google/apis/compute_beta/classes.rb', line 55765

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55775
55776
55777
# File 'lib/google/apis/compute_beta/classes.rb', line 55775

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55780
55781
55782
# File 'lib/google/apis/compute_beta/classes.rb', line 55780

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55786
55787
55788
# File 'lib/google/apis/compute_beta/classes.rb', line 55786

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55791
55792
55793
# File 'lib/google/apis/compute_beta/classes.rb', line 55791

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55798
55799
55800
55801
55802
55803
55804
55805
55806
# File 'lib/google/apis/compute_beta/classes.rb', line 55798

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end