Class: Google::Apis::ComputeBeta::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
55771 55772 55773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55771 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
55733 55734 55735 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55733 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55738 55739 55740 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55738 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
55743 55744 55745 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55743 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55753 55754 55755 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55753 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55758 55759 55760 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55758 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
55764 55765 55766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55764 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55769 55770 55771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55769 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55776 55777 55778 55779 55780 55781 55782 55783 55784 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55776 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |