Class: Google::Apis::ComputeBeta::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



54934
54935
54936
# File 'lib/google/apis/compute_beta/classes.rb', line 54934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54896
54897
54898
# File 'lib/google/apis/compute_beta/classes.rb', line 54896

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54901
54902
54903
# File 'lib/google/apis/compute_beta/classes.rb', line 54901

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



54906
54907
54908
# File 'lib/google/apis/compute_beta/classes.rb', line 54906

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54916
54917
54918
# File 'lib/google/apis/compute_beta/classes.rb', line 54916

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54921
54922
54923
# File 'lib/google/apis/compute_beta/classes.rb', line 54921

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54927
54928
54929
# File 'lib/google/apis/compute_beta/classes.rb', line 54927

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54932
54933
54934
# File 'lib/google/apis/compute_beta/classes.rb', line 54932

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54939
54940
54941
54942
54943
54944
54945
54946
54947
# File 'lib/google/apis/compute_beta/classes.rb', line 54939

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end