Class: Google::Apis::ComputeBeta::RolloutsListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutsListResponse

Returns a new instance of RolloutsListResponse.



54114
54115
54116
# File 'lib/google/apis/compute_beta/classes.rb', line 54114

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54076
54077
54078
# File 'lib/google/apis/compute_beta/classes.rb', line 54076

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54081
54082
54083
# File 'lib/google/apis/compute_beta/classes.rb', line 54081

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Rollout>

A list of Rollout resources. Corresponds to the JSON property items



54086
54087
54088
# File 'lib/google/apis/compute_beta/classes.rb', line 54086

def items
  @items
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54096
54097
54098
# File 'lib/google/apis/compute_beta/classes.rb', line 54096

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54101
54102
54103
# File 'lib/google/apis/compute_beta/classes.rb', line 54101

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54107
54108
54109
# File 'lib/google/apis/compute_beta/classes.rb', line 54107

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RolloutsListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54112
54113
54114
# File 'lib/google/apis/compute_beta/classes.rb', line 54112

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54119
54120
54121
54122
54123
54124
54125
54126
54127
# File 'lib/google/apis/compute_beta/classes.rb', line 54119

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end