Class: Google::Apis::ComputeBeta::RolloutsListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RolloutsListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutsListResponse
constructor
A new instance of RolloutsListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutsListResponse
Returns a new instance of RolloutsListResponse.
51200 51201 51202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51200 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
51162 51163 51164 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51162 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
51167 51168 51169 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51167 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Rollout>
A list of Rollout resources.
Corresponds to the JSON property items
51172 51173 51174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51172 def items @items end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
51182 51183 51184 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51182 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
51187 51188 51189 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51187 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
51193 51194 51195 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51193 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RolloutsListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
51198 51199 51200 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51198 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
51205 51206 51207 51208 51209 51210 51211 51212 51213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 51205 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |