Class: Google::Apis::ComputeBeta::Route
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Route
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read theRoutes overview.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#as_paths ⇒ Array<Google::Apis::ComputeBeta::RouteAsPath>
Output only.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#dest_range ⇒ String
The destination range of outgoing packets that this route applies to.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#network ⇒ String
Fully-qualified URL of the network that this route applies to.
-
#next_hop_gateway ⇒ String
The URL to a gateway that should handle matching packets.
-
#next_hop_hub ⇒ String
Output only.
-
#next_hop_ilb ⇒ String
The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule.
-
#next_hop_instance ⇒ String
The URL to an instance that should handle matching packets.
-
#next_hop_inter_region_cost ⇒ Fixnum
Output only.
-
#next_hop_interconnect_attachment ⇒ String
Output only.
-
#next_hop_ip ⇒ String
The network IP address of an instance that should handle matching packets.
-
#next_hop_med ⇒ Fixnum
Output only.
-
#next_hop_network ⇒ String
The URL of the local network if it should handle matching packets.
-
#next_hop_origin ⇒ String
Output only.
-
#next_hop_peering ⇒ String
Output only.
-
#next_hop_vpn_tunnel ⇒ String
The URL to a VpnTunnel that should handle matching packets.
-
#params ⇒ Google::Apis::ComputeBeta::RouteParams
Additional route parameters.
-
#priority ⇒ Fixnum
The priority of this route.
-
#route_status ⇒ String
[Output only] The status of the route.
-
#route_type ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined fully-qualified URL for this resource.
-
#tags ⇒ Array<String>
A list of instance tags to which this route applies.
-
#warnings ⇒ Array<Google::Apis::ComputeBeta::Route::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Route
constructor
A new instance of Route.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Route
Returns a new instance of Route.
56096 56097 56098 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56096 def initialize(**args) update!(**args) end |
Instance Attribute Details
#as_paths ⇒ Array<Google::Apis::ComputeBeta::RouteAsPath>
Output only. [Output Only] AS path.
Corresponds to the JSON property asPaths
55889 55890 55891 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55889 def as_paths @as_paths end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
55895 55896 55897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55895 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this field when you
create the resource.
Corresponds to the JSON property description
55901 55902 55903 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55901 def description @description end |
#dest_range ⇒ String
The destination range of outgoing packets that this route applies to. Both
IPv4 and IPv6 are supported.
Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291
format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952
compressed format.
Corresponds to the JSON property destRange
55910 55911 55912 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55910 def dest_range @dest_range end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
55917 55918 55919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55917 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of this resource. Always compute#routes for
Route resources.
Corresponds to the JSON property kind
55923 55924 55925 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55923 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a
lowercase letter, and all following characters (except for the last
character) must be a dash, lowercase letter, or digit. The last character
must be a lowercase letter or digit.
Corresponds to the JSON property name
55934 55935 55936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55934 def name @name end |
#network ⇒ String
Fully-qualified URL of the network that this route applies to.
Corresponds to the JSON property network
55939 55940 55941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55939 def network @network end |
#next_hop_gateway ⇒ String
The URL to a gateway that should handle matching packets.
You can only specify the internet gateway using a full or
partial valid URL: projects/project/global/gateways/default-internet-gateway
Corresponds to the JSON property nextHopGateway
55946 55947 55948 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55946 def next_hop_gateway @next_hop_gateway end |
#next_hop_hub ⇒ String
Output only. [Output Only] The full resource name of the Network Connectivity
Center hub
that will handle matching packets.
Corresponds to the JSON property nextHopHub
55953 55954 55955 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55953 def next_hop_hub @next_hop_hub end |
#next_hop_ilb ⇒ String
The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/regions/region/ forwardingRules/forwardingRule
regions/region/forwardingRules/forwardingRule If an IP address is provided, must specify an IPv4 address in dot-decimal notation or an IPv6 address in RFC 4291 format. For example, the following are all valid IP addresses:
10.128.0.56
2001:db8::2d9:51:0:0
2001:db8:0:0:2d9:51:0:0 IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property
nextHopIlb
55976 55977 55978 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55976 def next_hop_ilb @next_hop_ilb end |
#next_hop_instance ⇒ String
The URL to an instance that should handle matching packets. You can specify
this as a full or partial URL.
For example:
https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/
Corresponds to the JSON property nextHopInstance
55984 55985 55986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55984 def next_hop_instance @next_hop_instance end |
#next_hop_inter_region_cost ⇒ Fixnum
Output only. [Output only] Internal fixed region-to-region cost that Google
Cloud
calculates based on factors such as network performance, distance, and
available bandwidth between regions.
Corresponds to the JSON property nextHopInterRegionCost
55992 55993 55994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55992 def next_hop_inter_region_cost @next_hop_inter_region_cost end |
#next_hop_interconnect_attachment ⇒ String
Output only. [Output Only] The URL to an InterconnectAttachment which is the
next hop
for the route.
This field will only be populated for dynamic routes generated by
Cloud Router with a linked interconnectAttachment or the static route
generated by each L2 Interconnect Attachment.
Corresponds to the JSON property nextHopInterconnectAttachment
56002 56003 56004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56002 def @next_hop_interconnect_attachment end |
#next_hop_ip ⇒ String
The network IP address of an instance that should handle matching packets.
Both IPv6 address and IPv4 addresses are supported.
Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or
an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or
2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952
compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an
IPv4-mapped IPv6 address.
Corresponds to the JSON property nextHopIp
56013 56014 56015 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56013 def next_hop_ip @next_hop_ip end |
#next_hop_med ⇒ Fixnum
Output only. [Output Only] Multi-Exit Discriminator, a BGP route metric that
indicates
the desirability of a particular route in a network.
Corresponds to the JSON property nextHopMed
56020 56021 56022 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56020 def next_hop_med @next_hop_med end |
#next_hop_network ⇒ String
The URL of the local network if it should handle matching packets.
Corresponds to the JSON property nextHopNetwork
56025 56026 56027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56025 def next_hop_network @next_hop_network end |
#next_hop_origin ⇒ String
Output only. [Output Only] Indicates the origin of the route. Can be IGP
(Interior Gateway Protocol), EGP (Exterior Gateway Protocol),
or INCOMPLETE.
Corresponds to the JSON property nextHopOrigin
56032 56033 56034 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56032 def next_hop_origin @next_hop_origin end |
#next_hop_peering ⇒ String
Output only. [Output Only] The network peering name that should handle
matching packets,
which should conform to RFC1035.
Corresponds to the JSON property nextHopPeering
56039 56040 56041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56039 def next_hop_peering @next_hop_peering end |
#next_hop_vpn_tunnel ⇒ String
The URL to a VpnTunnel that should handle matching packets.
Corresponds to the JSON property nextHopVpnTunnel
56044 56045 56046 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56044 def next_hop_vpn_tunnel @next_hop_vpn_tunnel end |
#params ⇒ Google::Apis::ComputeBeta::RouteParams
Additional route parameters.
Corresponds to the JSON property params
56049 56050 56051 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56049 def params @params end |
#priority ⇒ Fixnum
The priority of this route. Priority is used to break ties in cases
where there is more than one matching route of equal prefix length. In
cases where multiple routes have equal prefix length, the one with the
lowest-numbered priority value wins. The default value is 1000. The
priority value must be from 0 to 65535, inclusive.
Corresponds to the JSON property priority
56058 56059 56060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56058 def priority @priority end |
#route_status ⇒ String
[Output only] The status of the route. This status applies to
dynamic routes learned by Cloud Routers. It is also applicable to routes
undergoing migration.
Corresponds to the JSON property routeStatus
56065 56066 56067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56065 def route_status @route_status end |
#route_type ⇒ String
Output only. [Output Only] The type of this route, which can be one of the following values:
- 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers
- 'SUBNET' for a route from a subnet of the VPC
- 'BGP' for a route learned from a BGP peer of this router
- 'STATIC' for a static route
Corresponds to the JSON property
routeType
56077 56078 56079 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56077 def route_type @route_type end |
#self_link ⇒ String
[Output Only] Server-defined fully-qualified URL for this resource.
Corresponds to the JSON property selfLink
56082 56083 56084 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56082 def self_link @self_link end |
#tags ⇒ Array<String>
A list of instance tags to which this route applies.
Corresponds to the JSON property tags
56087 56088 56089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56087 def @tags end |
#warnings ⇒ Array<Google::Apis::ComputeBeta::Route::Warning>
Output only. [Output Only] If potential misconfigurations are detected for
this
route, this field will be populated with warning messages.
Corresponds to the JSON property warnings
56094 56095 56096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56094 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56101 56102 56103 56104 56105 56106 56107 56108 56109 56110 56111 56112 56113 56114 56115 56116 56117 56118 56119 56120 56121 56122 56123 56124 56125 56126 56127 56128 56129 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56101 def update!(**args) @as_paths = args[:as_paths] if args.key?(:as_paths) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @dest_range = args[:dest_range] if args.key?(:dest_range) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway) @next_hop_hub = args[:next_hop_hub] if args.key?(:next_hop_hub) @next_hop_ilb = args[:next_hop_ilb] if args.key?(:next_hop_ilb) @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance) @next_hop_inter_region_cost = args[:next_hop_inter_region_cost] if args.key?(:next_hop_inter_region_cost) @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment) @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip) @next_hop_med = args[:next_hop_med] if args.key?(:next_hop_med) @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network) @next_hop_origin = args[:next_hop_origin] if args.key?(:next_hop_origin) @next_hop_peering = args[:next_hop_peering] if args.key?(:next_hop_peering) @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel) @params = args[:params] if args.key?(:params) @priority = args[:priority] if args.key?(:priority) @route_status = args[:route_status] if args.key?(:route_status) @route_type = args[:route_type] if args.key?(:route_type) @self_link = args[:self_link] if args.key?(:self_link) @tags = args[:tags] if args.key?(:tags) @warnings = args[:warnings] if args.key?(:warnings) end |