Class: Google::Apis::ComputeBeta::Route

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Route resource. A route defines a path from VM instances in the VPC network to a specific destination. This destination can be inside or outside the VPC network. For more information, read theRoutes overview.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Route

Returns a new instance of Route.



54417
54418
54419
# File 'lib/google/apis/compute_beta/classes.rb', line 54417

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#as_pathsArray<Google::Apis::ComputeBeta::RouteAsPath>

Output only. [Output Only] AS path. Corresponds to the JSON property asPaths



54210
54211
54212
# File 'lib/google/apis/compute_beta/classes.rb', line 54210

def as_paths
  @as_paths
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


54216
54217
54218
# File 'lib/google/apis/compute_beta/classes.rb', line 54216

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this field when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


54222
54223
54224
# File 'lib/google/apis/compute_beta/classes.rb', line 54222

def description
  @description
end

#dest_rangeString

The destination range of outgoing packets that this route applies to. Both IPv4 and IPv6 are supported. Must specify an IPv4 range (e.g. 192.0.2.0/24) or an IPv6 range in RFC 4291 format (e.g. 2001:db8::/32). IPv6 range will be displayed using RFC 5952 compressed format. Corresponds to the JSON property destRange

Returns:

  • (String)


54231
54232
54233
# File 'lib/google/apis/compute_beta/classes.rb', line 54231

def dest_range
  @dest_range
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


54238
54239
54240
# File 'lib/google/apis/compute_beta/classes.rb', line 54238

def id
  @id
end

#kindString

Output only. [Output Only] Type of this resource. Always compute#routes for Route resources. Corresponds to the JSON property kind

Returns:

  • (String)


54244
54245
54246
# File 'lib/google/apis/compute_beta/classes.rb', line 54244

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])?. The first character must be a lowercase letter, and all following characters (except for the last character) must be a dash, lowercase letter, or digit. The last character must be a lowercase letter or digit. Corresponds to the JSON property name

Returns:

  • (String)


54255
54256
54257
# File 'lib/google/apis/compute_beta/classes.rb', line 54255

def name
  @name
end

#networkString

Fully-qualified URL of the network that this route applies to. Corresponds to the JSON property network

Returns:

  • (String)


54260
54261
54262
# File 'lib/google/apis/compute_beta/classes.rb', line 54260

def network
  @network
end

#next_hop_gatewayString

The URL to a gateway that should handle matching packets. You can only specify the internet gateway using a full or partial valid URL: projects/project/global/gateways/default-internet-gateway Corresponds to the JSON property nextHopGateway

Returns:

  • (String)


54267
54268
54269
# File 'lib/google/apis/compute_beta/classes.rb', line 54267

def next_hop_gateway
  @next_hop_gateway
end

#next_hop_hubString

Output only. [Output Only] The full resource name of the Network Connectivity Center hub that will handle matching packets. Corresponds to the JSON property nextHopHub

Returns:

  • (String)


54274
54275
54276
# File 'lib/google/apis/compute_beta/classes.rb', line 54274

def next_hop_hub
  @next_hop_hub
end

#next_hop_ilbString

The URL to a forwarding rule of typeloadBalancingScheme=INTERNAL that should handle matching packets or the IP address of the forwarding Rule. For example, the following are all valid URLs:

  • https://www.googleapis.com/compute/v1/projects/project/regions/region/ forwardingRules/forwardingRule
  • regions/region/forwardingRules/forwardingRule If an IP address is provided, must specify an IPv4 address in dot-decimal notation or an IPv6 address in RFC 4291 format. For example, the following are all valid IP addresses:

  • 10.128.0.56

  • 2001:db8::2d9:51:0:0

  • 2001:db8:0:0:2d9:51:0:0 IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property nextHopIlb

Returns:

  • (String)


54297
54298
54299
# File 'lib/google/apis/compute_beta/classes.rb', line 54297

def next_hop_ilb
  @next_hop_ilb
end

#next_hop_instanceString

The URL to an instance that should handle matching packets. You can specify this as a full or partial URL. For example: https://www.googleapis.com/compute/v1/projects/project/zones/zone/instances/ Corresponds to the JSON property nextHopInstance

Returns:

  • (String)


54305
54306
54307
# File 'lib/google/apis/compute_beta/classes.rb', line 54305

def next_hop_instance
  @next_hop_instance
end

#next_hop_inter_region_costFixnum

Output only. [Output only] Internal fixed region-to-region cost that Google Cloud calculates based on factors such as network performance, distance, and available bandwidth between regions. Corresponds to the JSON property nextHopInterRegionCost

Returns:

  • (Fixnum)


54313
54314
54315
# File 'lib/google/apis/compute_beta/classes.rb', line 54313

def next_hop_inter_region_cost
  @next_hop_inter_region_cost
end

#next_hop_interconnect_attachmentString

Output only. [Output Only] The URL to an InterconnectAttachment which is the next hop for the route. This field will only be populated for dynamic routes generated by Cloud Router with a linked interconnectAttachment or the static route generated by each L2 Interconnect Attachment. Corresponds to the JSON property nextHopInterconnectAttachment

Returns:

  • (String)


54323
54324
54325
# File 'lib/google/apis/compute_beta/classes.rb', line 54323

def next_hop_interconnect_attachment
  @next_hop_interconnect_attachment
end

#next_hop_ipString

The network IP address of an instance that should handle matching packets. Both IPv6 address and IPv4 addresses are supported. Must specify an IPv4 address in dot-decimal notation (e.g. 192.0.2.99) or an IPv6 address in RFC 4291 format (e.g. 2001:db8::2d9:51:0:0 or 2001:db8:0:0:2d9:51:0:0). IPv6 addresses will be displayed using RFC 5952 compressed format (e.g. 2001:db8::2d9:51:0:0). Should never be an IPv4-mapped IPv6 address. Corresponds to the JSON property nextHopIp

Returns:

  • (String)


54334
54335
54336
# File 'lib/google/apis/compute_beta/classes.rb', line 54334

def next_hop_ip
  @next_hop_ip
end

#next_hop_medFixnum

Output only. [Output Only] Multi-Exit Discriminator, a BGP route metric that indicates the desirability of a particular route in a network. Corresponds to the JSON property nextHopMed

Returns:

  • (Fixnum)


54341
54342
54343
# File 'lib/google/apis/compute_beta/classes.rb', line 54341

def next_hop_med
  @next_hop_med
end

#next_hop_networkString

The URL of the local network if it should handle matching packets. Corresponds to the JSON property nextHopNetwork

Returns:

  • (String)


54346
54347
54348
# File 'lib/google/apis/compute_beta/classes.rb', line 54346

def next_hop_network
  @next_hop_network
end

#next_hop_originString

Output only. [Output Only] Indicates the origin of the route. Can be IGP (Interior Gateway Protocol), EGP (Exterior Gateway Protocol), or INCOMPLETE. Corresponds to the JSON property nextHopOrigin

Returns:

  • (String)


54353
54354
54355
# File 'lib/google/apis/compute_beta/classes.rb', line 54353

def next_hop_origin
  @next_hop_origin
end

#next_hop_peeringString

Output only. [Output Only] The network peering name that should handle matching packets, which should conform to RFC1035. Corresponds to the JSON property nextHopPeering

Returns:

  • (String)


54360
54361
54362
# File 'lib/google/apis/compute_beta/classes.rb', line 54360

def next_hop_peering
  @next_hop_peering
end

#next_hop_vpn_tunnelString

The URL to a VpnTunnel that should handle matching packets. Corresponds to the JSON property nextHopVpnTunnel

Returns:

  • (String)


54365
54366
54367
# File 'lib/google/apis/compute_beta/classes.rb', line 54365

def next_hop_vpn_tunnel
  @next_hop_vpn_tunnel
end

#paramsGoogle::Apis::ComputeBeta::RouteParams

Additional route parameters. Corresponds to the JSON property params



54370
54371
54372
# File 'lib/google/apis/compute_beta/classes.rb', line 54370

def params
  @params
end

#priorityFixnum

The priority of this route. Priority is used to break ties in cases where there is more than one matching route of equal prefix length. In cases where multiple routes have equal prefix length, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 0 to 65535, inclusive. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


54379
54380
54381
# File 'lib/google/apis/compute_beta/classes.rb', line 54379

def priority
  @priority
end

#route_statusString

[Output only] The status of the route. This status applies to dynamic routes learned by Cloud Routers. It is also applicable to routes undergoing migration. Corresponds to the JSON property routeStatus

Returns:

  • (String)


54386
54387
54388
# File 'lib/google/apis/compute_beta/classes.rb', line 54386

def route_status
  @route_status
end

#route_typeString

Output only. [Output Only] The type of this route, which can be one of the following values:

  • 'TRANSIT' for a transit route that this router learned from another Cloud Router and will readvertise to one of its BGP peers
  • 'SUBNET' for a route from a subnet of the VPC
  • 'BGP' for a route learned from a BGP peer of this router
  • 'STATIC' for a static route Corresponds to the JSON property routeType

Returns:

  • (String)


54398
54399
54400
# File 'lib/google/apis/compute_beta/classes.rb', line 54398

def route_type
  @route_type
end

[Output Only] Server-defined fully-qualified URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54403
54404
54405
# File 'lib/google/apis/compute_beta/classes.rb', line 54403

def self_link
  @self_link
end

#tagsArray<String>

A list of instance tags to which this route applies. Corresponds to the JSON property tags

Returns:

  • (Array<String>)


54408
54409
54410
# File 'lib/google/apis/compute_beta/classes.rb', line 54408

def tags
  @tags
end

#warningsArray<Google::Apis::ComputeBeta::Route::Warning>

Output only. [Output Only] If potential misconfigurations are detected for this route, this field will be populated with warning messages. Corresponds to the JSON property warnings



54415
54416
54417
# File 'lib/google/apis/compute_beta/classes.rb', line 54415

def warnings
  @warnings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54422
54423
54424
54425
54426
54427
54428
54429
54430
54431
54432
54433
54434
54435
54436
54437
54438
54439
54440
54441
54442
54443
54444
54445
54446
54447
54448
54449
54450
# File 'lib/google/apis/compute_beta/classes.rb', line 54422

def update!(**args)
  @as_paths = args[:as_paths] if args.key?(:as_paths)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @dest_range = args[:dest_range] if args.key?(:dest_range)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @next_hop_gateway = args[:next_hop_gateway] if args.key?(:next_hop_gateway)
  @next_hop_hub = args[:next_hop_hub] if args.key?(:next_hop_hub)
  @next_hop_ilb = args[:next_hop_ilb] if args.key?(:next_hop_ilb)
  @next_hop_instance = args[:next_hop_instance] if args.key?(:next_hop_instance)
  @next_hop_inter_region_cost = args[:next_hop_inter_region_cost] if args.key?(:next_hop_inter_region_cost)
  @next_hop_interconnect_attachment = args[:next_hop_interconnect_attachment] if args.key?(:next_hop_interconnect_attachment)
  @next_hop_ip = args[:next_hop_ip] if args.key?(:next_hop_ip)
  @next_hop_med = args[:next_hop_med] if args.key?(:next_hop_med)
  @next_hop_network = args[:next_hop_network] if args.key?(:next_hop_network)
  @next_hop_origin = args[:next_hop_origin] if args.key?(:next_hop_origin)
  @next_hop_peering = args[:next_hop_peering] if args.key?(:next_hop_peering)
  @next_hop_vpn_tunnel = args[:next_hop_vpn_tunnel] if args.key?(:next_hop_vpn_tunnel)
  @params = args[:params] if args.key?(:params)
  @priority = args[:priority] if args.key?(:priority)
  @route_status = args[:route_status] if args.key?(:route_status)
  @route_type = args[:route_type] if args.key?(:route_type)
  @self_link = args[:self_link] if args.key?(:self_link)
  @tags = args[:tags] if args.key?(:tags)
  @warnings = args[:warnings] if args.key?(:warnings)
end