Class: Google::Apis::ComputeBeta::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouteList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Route resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of Route resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouteList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
56810 56811 56812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56810 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56778 56779 56780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56778 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of Route resources.
Corresponds to the JSON property items
56783 56784 56785 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56783 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
56788 56789 56790 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56788 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56798 56799 56800 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56798 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56803 56804 56805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56803 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RouteList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56808 56809 56810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56808 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56815 56816 56817 56818 56819 56820 56821 56822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56815 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |