Class: Google::Apis::ComputeBeta::RouteList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouteList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Route resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of Route resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouteList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouteList
constructor
A new instance of RouteList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouteList
Returns a new instance of RouteList.
56711 56712 56713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56711 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56679 56680 56681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56679 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of Route resources.
Corresponds to the JSON property items
56684 56685 56686 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56684 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
56689 56690 56691 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56689 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56699 56700 56701 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56699 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56704 56705 56706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56704 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RouteList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56709 56710 56711 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56709 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56716 56717 56718 56719 56720 56721 56722 56723 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56716 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |