Class: Google::Apis::ComputeBeta::RouteList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Route resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteList

Returns a new instance of RouteList.



54598
54599
54600
# File 'lib/google/apis/compute_beta/classes.rb', line 54598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54566
54567
54568
# File 'lib/google/apis/compute_beta/classes.rb', line 54566

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Route>

A list of Route resources. Corresponds to the JSON property items



54571
54572
54573
# File 'lib/google/apis/compute_beta/classes.rb', line 54571

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


54576
54577
54578
# File 'lib/google/apis/compute_beta/classes.rb', line 54576

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54586
54587
54588
# File 'lib/google/apis/compute_beta/classes.rb', line 54586

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54591
54592
54593
# File 'lib/google/apis/compute_beta/classes.rb', line 54591

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RouteList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54596
54597
54598
# File 'lib/google/apis/compute_beta/classes.rb', line 54596

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54603
54604
54605
54606
54607
54608
54609
54610
# File 'lib/google/apis/compute_beta/classes.rb', line 54603

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end