Class: Google::Apis::ComputeBeta::RouteList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Route resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouteList

Returns a new instance of RouteList.



51684
51685
51686
# File 'lib/google/apis/compute_beta/classes.rb', line 51684

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


51652
51653
51654
# File 'lib/google/apis/compute_beta/classes.rb', line 51652

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Route>

A list of Route resources. Corresponds to the JSON property items



51657
51658
51659
# File 'lib/google/apis/compute_beta/classes.rb', line 51657

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


51662
51663
51664
# File 'lib/google/apis/compute_beta/classes.rb', line 51662

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


51672
51673
51674
# File 'lib/google/apis/compute_beta/classes.rb', line 51672

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


51677
51678
51679
# File 'lib/google/apis/compute_beta/classes.rb', line 51677

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RouteList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



51682
51683
51684
# File 'lib/google/apis/compute_beta/classes.rb', line 51682

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



51689
51690
51691
51692
51693
51694
51695
51696
# File 'lib/google/apis/compute_beta/classes.rb', line 51689

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end