Class: Google::Apis::ComputeBeta::RoutePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutePolicy

Returns a new instance of RoutePolicy.



56866
56867
56868
# File 'lib/google/apis/compute_beta/classes.rb', line 56866

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of route policy. Corresponds to the JSON property description

Returns:

  • (String)


56833
56834
56835
# File 'lib/google/apis/compute_beta/classes.rb', line 56833

def description
  @description
end

#fingerprintString

A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


56846
56847
56848
# File 'lib/google/apis/compute_beta/classes.rb', line 56846

def fingerprint
  @fingerprint
end

#nameString

Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


56852
56853
56854
# File 'lib/google/apis/compute_beta/classes.rb', line 56852

def name
  @name
end

#termsArray<Google::Apis::ComputeBeta::RoutePolicyPolicyTerm>

List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later. Corresponds to the JSON property terms



56859
56860
56861
# File 'lib/google/apis/compute_beta/classes.rb', line 56859

def terms
  @terms
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


56864
56865
56866
# File 'lib/google/apis/compute_beta/classes.rb', line 56864

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56871
56872
56873
56874
56875
56876
56877
# File 'lib/google/apis/compute_beta/classes.rb', line 56871

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @terms = args[:terms] if args.key?(:terms)
  @type = args[:type] if args.key?(:type)
end