Class: Google::Apis::ComputeBeta::RoutePolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutePolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
An optional description of route policy.
-
#fingerprint ⇒ String
A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking.
-
#name ⇒ String
Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies.
-
#terms ⇒ Array<Google::Apis::ComputeBeta::RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated in order of priority).
-
#type ⇒ String
Corresponds to the JSON property
type.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutePolicy
constructor
A new instance of RoutePolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutePolicy
Returns a new instance of RoutePolicy.
56432 56433 56434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56432 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
An optional description of route policy.
Corresponds to the JSON property description
56399 56400 56401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56399 def description @description end |
#fingerprint ⇒ String
A fingerprint for the Route Policy being applied to this Router, which is
essentially a hash of the Route Policy used for optimistic locking.
The fingerprint is initially generated by Compute Engine and changes
after every request to modify or update Route Policy. You must always
provide an up-to-date fingerprint hash in order to update or change
labels.
To see the latest fingerprint, make a getRoutePolicy() request
to retrieve a Route Policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
56412 56413 56414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56412 def fingerprint @fingerprint end |
#name ⇒ String
Route Policy name, which must be a resource ID segment and unique
within all the router's Route Policies. Name should conform to RFC1035.
Corresponds to the JSON property name
56418 56419 56420 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56418 def name @name end |
#terms ⇒ Array<Google::Apis::ComputeBeta::RoutePolicyPolicyTerm>
List of terms (the order in the list is not important, they are evaluated
in order of priority). Order of policies is not retained and might change
when getting policy later.
Corresponds to the JSON property terms
56425 56426 56427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56425 def terms @terms end |
#type ⇒ String
Corresponds to the JSON property type
56430 56431 56432 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56430 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56437 56438 56439 56440 56441 56442 56443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56437 def update!(**args) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @name = args[:name] if args.key?(:name) @terms = args[:terms] if args.key?(:terms) @type = args[:type] if args.key?(:type) end |