Class: Google::Apis::ComputeBeta::RoutePolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutePolicy

Returns a new instance of RoutePolicy.



54753
54754
54755
# File 'lib/google/apis/compute_beta/classes.rb', line 54753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

An optional description of route policy. Corresponds to the JSON property description

Returns:

  • (String)


54720
54721
54722
# File 'lib/google/apis/compute_beta/classes.rb', line 54720

def description
  @description
end

#fingerprintString

A fingerprint for the Route Policy being applied to this Router, which is essentially a hash of the Route Policy used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update Route Policy. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make a getRoutePolicy() request to retrieve a Route Policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


54733
54734
54735
# File 'lib/google/apis/compute_beta/classes.rb', line 54733

def fingerprint
  @fingerprint
end

#nameString

Route Policy name, which must be a resource ID segment and unique within all the router's Route Policies. Name should conform to RFC1035. Corresponds to the JSON property name

Returns:

  • (String)


54739
54740
54741
# File 'lib/google/apis/compute_beta/classes.rb', line 54739

def name
  @name
end

#termsArray<Google::Apis::ComputeBeta::RoutePolicyPolicyTerm>

List of terms (the order in the list is not important, they are evaluated in order of priority). Order of policies is not retained and might change when getting policy later. Corresponds to the JSON property terms



54746
54747
54748
# File 'lib/google/apis/compute_beta/classes.rb', line 54746

def terms
  @terms
end

#typeString

Corresponds to the JSON property type

Returns:

  • (String)


54751
54752
54753
# File 'lib/google/apis/compute_beta/classes.rb', line 54751

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54758
54759
54760
54761
54762
54763
54764
# File 'lib/google/apis/compute_beta/classes.rb', line 54758

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @name = args[:name] if args.key?(:name)
  @terms = args[:terms] if args.key?(:terms)
  @type = args[:type] if args.key?(:type)
end