Class: Google::Apis::ComputeBeta::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeBeta::RouterNat>
A list of NAT services created in this router.
-
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeBeta::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
56610 56611 56612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56610 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
56508 56509 56510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56508 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
56516 56517 56518 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56516 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
56522 56523 56524 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56522 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
56528 56529 56530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56528 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
56534 56535 56536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56534 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
56541 56542 56543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56541 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
56554 56555 56556 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56554 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
56560 56561 56562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56560 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
56565 56566 56567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56565 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
56576 56577 56578 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56576 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeBeta::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
56581 56582 56583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56581 def nats @nats end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
56586 56587 56588 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56586 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
56591 56592 56593 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56591 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::RouterParams
Additional router parameters.
Corresponds to the JSON property params
56596 56597 56598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56596 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
56603 56604 56605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56603 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
56608 56609 56610 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56608 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56615 56616 56617 56618 56619 56620 56621 56622 56623 56624 56625 56626 56627 56628 56629 56630 56631 56632 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56615 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |