Class: Google::Apis::ComputeBeta::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



55751
55752
55753
# File 'lib/google/apis/compute_beta/classes.rb', line 55751

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeBeta::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



55649
55650
55651
# File 'lib/google/apis/compute_beta/classes.rb', line 55649

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeBeta::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



55657
55658
55659
# File 'lib/google/apis/compute_beta/classes.rb', line 55657

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


55663
55664
55665
# File 'lib/google/apis/compute_beta/classes.rb', line 55663

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


55669
55670
55671
# File 'lib/google/apis/compute_beta/classes.rb', line 55669

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


55675
55676
55677
# File 'lib/google/apis/compute_beta/classes.rb', line 55675

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


55682
55683
55684
# File 'lib/google/apis/compute_beta/classes.rb', line 55682

def id
  @id
end

#interfacesArray<Google::Apis::ComputeBeta::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


55695
55696
55697
# File 'lib/google/apis/compute_beta/classes.rb', line 55695

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


55701
55702
55703
# File 'lib/google/apis/compute_beta/classes.rb', line 55701

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



55706
55707
55708
# File 'lib/google/apis/compute_beta/classes.rb', line 55706

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


55717
55718
55719
# File 'lib/google/apis/compute_beta/classes.rb', line 55717

def name
  @name
end

#natsArray<Google::Apis::ComputeBeta::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



55722
55723
55724
# File 'lib/google/apis/compute_beta/classes.rb', line 55722

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


55727
55728
55729
# File 'lib/google/apis/compute_beta/classes.rb', line 55727

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


55732
55733
55734
# File 'lib/google/apis/compute_beta/classes.rb', line 55732

def network
  @network
end

#paramsGoogle::Apis::ComputeBeta::RouterParams

Additional router parameters. Corresponds to the JSON property params



55737
55738
55739
# File 'lib/google/apis/compute_beta/classes.rb', line 55737

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


55744
55745
55746
# File 'lib/google/apis/compute_beta/classes.rb', line 55744

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55749
55750
55751
# File 'lib/google/apis/compute_beta/classes.rb', line 55749

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55756
55757
55758
55759
55760
55761
55762
55763
55764
55765
55766
55767
55768
55769
55770
55771
55772
55773
# File 'lib/google/apis/compute_beta/classes.rb', line 55756

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end