Class: Google::Apis::ComputeBeta::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeBeta::RouterNat>
A list of NAT services created in this router.
-
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeBeta::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
54931 54932 54933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
54829 54830 54831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54829 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
54837 54838 54839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54837 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
54843 54844 54845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54843 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
54849 54850 54851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54849 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
54855 54856 54857 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54855 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
54862 54863 54864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54862 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
54875 54876 54877 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54875 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
54881 54882 54883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54881 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
54886 54887 54888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54886 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
54897 54898 54899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54897 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeBeta::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
54902 54903 54904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54902 def nats @nats end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
54907 54908 54909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54907 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
54912 54913 54914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54912 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::RouterParams
Additional router parameters.
Corresponds to the JSON property params
54917 54918 54919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54917 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
54924 54925 54926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54924 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
54929 54930 54931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54929 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54936 54937 54938 54939 54940 54941 54942 54943 54944 54945 54946 54947 54948 54949 54950 54951 54952 54953 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54936 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |