Class: Google::Apis::ComputeBeta::Router
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Router
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.
Instance Attribute Summary collapse
-
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
-
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that must be configured into the routing stack to establish BGP peering.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#encrypted_interconnect_router ⇒ Boolean
(also: #encrypted_interconnect_router?)
Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces.
-
#kind ⇒ String
Output only.
-
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
-
#name ⇒ String
Name of the resource.
-
#nats ⇒ Array<Google::Apis::ComputeBeta::RouterNat>
A list of NAT services created in this router.
-
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
-
#params ⇒ Google::Apis::ComputeBeta::RouterParams
Additional router parameters.
-
#region ⇒ String
[Output Only] URI of the region where the router resides.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Router
constructor
A new instance of Router.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Router
Returns a new instance of Router.
53748 53749 53750 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53748 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bgp ⇒ Google::Apis::ComputeBeta::RouterBgp
BGP information specific to this router.
Corresponds to the JSON property bgp
53646 53647 53648 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53646 def bgp @bgp end |
#bgp_peers ⇒ Array<Google::Apis::ComputeBeta::RouterBgpPeer>
BGP information that must be configured into the routing stack to
establish BGP peering. This information must specify the peer ASN and
either the interface name, IP address, or peer IP address. Please refer
toRFC4273.
Corresponds to the JSON property bgpPeers
53654 53655 53656 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53654 def bgp_peers @bgp_peers end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
53660 53661 53662 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53660 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
53666 53667 53668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53666 def description @description end |
#encrypted_interconnect_router ⇒ Boolean Also known as: encrypted_interconnect_router?
Indicates if a router is dedicated for use with encrypted VLAN
attachments (interconnectAttachments).
Corresponds to the JSON property encryptedInterconnectRouter
53672 53673 53674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53672 def encrypted_interconnect_router @encrypted_interconnect_router end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
53679 53680 53681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53679 def id @id end |
#interfaces ⇒ Array<Google::Apis::ComputeBeta::RouterInterface>
Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:
- linkedVpnTunnel
- linkedInterconnectAttachment
- subnetwork
You can create a router interface without any of these fields specified.
However, you cannot create a BGP peer that uses that interface.
Corresponds to the JSON property
interfaces
53692 53693 53694 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53692 def interfaces @interfaces end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
53698 53699 53700 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53698 def kind @kind end |
#md5_authentication_keys ⇒ Array<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>
Keys used for MD5 authentication.
Corresponds to the JSON property md5AuthenticationKeys
53703 53704 53705 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53703 def md5_authentication_keys @md5_authentication_keys end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
53714 53715 53716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53714 def name @name end |
#nats ⇒ Array<Google::Apis::ComputeBeta::RouterNat>
A list of NAT services created in this router.
Corresponds to the JSON property nats
53719 53720 53721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53719 def nats @nats end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
53724 53725 53726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53724 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
53729 53730 53731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53729 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::RouterParams
Additional router parameters.
Corresponds to the JSON property params
53734 53735 53736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53734 def params @params end |
#region ⇒ String
[Output Only] URI of the region where the router resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
53741 53742 53743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53741 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
53746 53747 53748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53746 def self_link @self_link end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53753 53754 53755 53756 53757 53758 53759 53760 53761 53762 53763 53764 53765 53766 53767 53768 53769 53770 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53753 def update!(**args) @bgp = args[:bgp] if args.key?(:bgp) @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router) @id = args[:id] if args.key?(:id) @interfaces = args[:interfaces] if args.key?(:interfaces) @kind = args[:kind] if args.key?(:kind) @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys) @name = args[:name] if args.key?(:name) @nats = args[:nats] if args.key?(:nats) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) end |