Class: Google::Apis::ComputeBeta::Router

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Cloud Router resource. For more information about Cloud Router, read theCloud Router overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Router

Returns a new instance of Router.



52017
52018
52019
# File 'lib/google/apis/compute_beta/classes.rb', line 52017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bgpGoogle::Apis::ComputeBeta::RouterBgp

BGP information specific to this router. Corresponds to the JSON property bgp



51915
51916
51917
# File 'lib/google/apis/compute_beta/classes.rb', line 51915

def bgp
  @bgp
end

#bgp_peersArray<Google::Apis::ComputeBeta::RouterBgpPeer>

BGP information that must be configured into the routing stack to establish BGP peering. This information must specify the peer ASN and either the interface name, IP address, or peer IP address. Please refer toRFC4273. Corresponds to the JSON property bgpPeers



51923
51924
51925
# File 'lib/google/apis/compute_beta/classes.rb', line 51923

def bgp_peers
  @bgp_peers
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


51929
51930
51931
# File 'lib/google/apis/compute_beta/classes.rb', line 51929

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


51935
51936
51937
# File 'lib/google/apis/compute_beta/classes.rb', line 51935

def description
  @description
end

#encrypted_interconnect_routerBoolean Also known as: encrypted_interconnect_router?

Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments). Corresponds to the JSON property encryptedInterconnectRouter

Returns:

  • (Boolean)


51941
51942
51943
# File 'lib/google/apis/compute_beta/classes.rb', line 51941

def encrypted_interconnect_router
  @encrypted_interconnect_router
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


51948
51949
51950
# File 'lib/google/apis/compute_beta/classes.rb', line 51948

def id
  @id
end

#interfacesArray<Google::Apis::ComputeBeta::RouterInterface>

Router interfaces. To create a BGP peer that uses a router interface, the interface must have one of the following fields specified:

  • linkedVpnTunnel
  • linkedInterconnectAttachment
  • subnetwork You can create a router interface without any of these fields specified. However, you cannot create a BGP peer that uses that interface. Corresponds to the JSON property interfaces


51961
51962
51963
# File 'lib/google/apis/compute_beta/classes.rb', line 51961

def interfaces
  @interfaces
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


51967
51968
51969
# File 'lib/google/apis/compute_beta/classes.rb', line 51967

def kind
  @kind
end

#md5_authentication_keysArray<Google::Apis::ComputeBeta::RouterMd5AuthenticationKey>

Keys used for MD5 authentication. Corresponds to the JSON property md5AuthenticationKeys



51972
51973
51974
# File 'lib/google/apis/compute_beta/classes.rb', line 51972

def md5_authentication_keys
  @md5_authentication_keys
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


51983
51984
51985
# File 'lib/google/apis/compute_beta/classes.rb', line 51983

def name
  @name
end

#natsArray<Google::Apis::ComputeBeta::RouterNat>

A list of NAT services created in this router. Corresponds to the JSON property nats



51988
51989
51990
# File 'lib/google/apis/compute_beta/classes.rb', line 51988

def nats
  @nats
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


51993
51994
51995
# File 'lib/google/apis/compute_beta/classes.rb', line 51993

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


51998
51999
52000
# File 'lib/google/apis/compute_beta/classes.rb', line 51998

def network
  @network
end

#paramsGoogle::Apis::ComputeBeta::RouterParams

Additional router parameters. Corresponds to the JSON property params



52003
52004
52005
# File 'lib/google/apis/compute_beta/classes.rb', line 52003

def params
  @params
end

#regionString

[Output Only] URI of the region where the router resides. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


52010
52011
52012
# File 'lib/google/apis/compute_beta/classes.rb', line 52010

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


52015
52016
52017
# File 'lib/google/apis/compute_beta/classes.rb', line 52015

def self_link
  @self_link
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52022
52023
52024
52025
52026
52027
52028
52029
52030
52031
52032
52033
52034
52035
52036
52037
52038
52039
# File 'lib/google/apis/compute_beta/classes.rb', line 52022

def update!(**args)
  @bgp = args[:bgp] if args.key?(:bgp)
  @bgp_peers = args[:bgp_peers] if args.key?(:bgp_peers)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @encrypted_interconnect_router = args[:encrypted_interconnect_router] if args.key?(:encrypted_interconnect_router)
  @id = args[:id] if args.key?(:id)
  @interfaces = args[:interfaces] if args.key?(:interfaces)
  @kind = args[:kind] if args.key?(:kind)
  @md5_authentication_keys = args[:md5_authentication_keys] if args.key?(:md5_authentication_keys)
  @name = args[:name] if args.key?(:name)
  @nats = args[:nats] if args.key?(:nats)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
end