Class: Google::Apis::ComputeBeta::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
57237 57238 57239 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57237 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57200 57201 57202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57200 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
57205 57206 57207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57205 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
57210 57211 57212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57210 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57220 57221 57222 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57220 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57225 57226 57227 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57225 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
57230 57231 57232 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57230 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57235 57236 57237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57235 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57242 57243 57244 57245 57246 57247 57248 57249 57250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57242 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |