Class: Google::Apis::ComputeBeta::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



56704
56705
56706
# File 'lib/google/apis/compute_beta/classes.rb', line 56704

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56667
56668
56669
# File 'lib/google/apis/compute_beta/classes.rb', line 56667

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



56672
56673
56674
# File 'lib/google/apis/compute_beta/classes.rb', line 56672

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


56677
56678
56679
# File 'lib/google/apis/compute_beta/classes.rb', line 56677

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56687
56688
56689
# File 'lib/google/apis/compute_beta/classes.rb', line 56687

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56692
56693
56694
# File 'lib/google/apis/compute_beta/classes.rb', line 56692

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56697
56698
56699
# File 'lib/google/apis/compute_beta/classes.rb', line 56697

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56702
56703
56704
# File 'lib/google/apis/compute_beta/classes.rb', line 56702

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56709
56710
56711
56712
56713
56714
56715
56716
56717
# File 'lib/google/apis/compute_beta/classes.rb', line 56709

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end