Class: Google::Apis::ComputeBeta::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
56682 56683 56684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56682 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
56645 56646 56647 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56645 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
56650 56651 56652 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56650 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
56655 56656 56657 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56655 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56665 56666 56667 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56665 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56670 56671 56672 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56670 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
56675 56676 56677 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56675 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56680 56681 56682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56680 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56687 56688 56689 56690 56691 56692 56693 56694 56695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56687 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |