Class: Google::Apis::ComputeBeta::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
55904 55905 55906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55904 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
55867 55868 55869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55867 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
55872 55873 55874 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55872 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
55877 55878 55879 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55877 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55887 55888 55889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55887 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55892 55893 55894 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55892 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
55897 55898 55899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55897 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55902 55903 55904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55902 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55909 55910 55911 55912 55913 55914 55915 55916 55917 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55909 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |