Class: Google::Apis::ComputeBeta::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



55845
55846
55847
# File 'lib/google/apis/compute_beta/classes.rb', line 55845

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55808
55809
55810
# File 'lib/google/apis/compute_beta/classes.rb', line 55808

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



55813
55814
55815
# File 'lib/google/apis/compute_beta/classes.rb', line 55813

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


55818
55819
55820
# File 'lib/google/apis/compute_beta/classes.rb', line 55818

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55828
55829
55830
# File 'lib/google/apis/compute_beta/classes.rb', line 55828

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55833
55834
55835
# File 'lib/google/apis/compute_beta/classes.rb', line 55833

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


55838
55839
55840
# File 'lib/google/apis/compute_beta/classes.rb', line 55838

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55843
55844
55845
# File 'lib/google/apis/compute_beta/classes.rb', line 55843

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55850
55851
55852
55853
55854
55855
55856
55857
55858
# File 'lib/google/apis/compute_beta/classes.rb', line 55850

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end