Class: Google::Apis::ComputeBeta::RouterAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of routers.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterAggregatedList
constructor
A new instance of RouterAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterAggregatedList
Returns a new instance of RouterAggregatedList.
55025 55026 55027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55025 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
54988 54989 54990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54988 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::RoutersScopedList>
A list of Router resources.
Corresponds to the JSON property items
54993 54994 54995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54993 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
54998 54999 55000 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54998 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55008 55009 55010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55008 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55013 55014 55015 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55013 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
55018 55019 55020 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55018 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RouterAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55023 55024 55025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55023 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55030 55031 55032 55033 55034 55035 55036 55037 55038 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55030 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |