Class: Google::Apis::ComputeBeta::RouterAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of routers.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterAggregatedList

Returns a new instance of RouterAggregatedList.



53842
53843
53844
# File 'lib/google/apis/compute_beta/classes.rb', line 53842

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53805
53806
53807
# File 'lib/google/apis/compute_beta/classes.rb', line 53805

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::RoutersScopedList>

A list of Router resources. Corresponds to the JSON property items



53810
53811
53812
# File 'lib/google/apis/compute_beta/classes.rb', line 53810

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


53815
53816
53817
# File 'lib/google/apis/compute_beta/classes.rb', line 53815

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53825
53826
53827
# File 'lib/google/apis/compute_beta/classes.rb', line 53825

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53830
53831
53832
# File 'lib/google/apis/compute_beta/classes.rb', line 53830

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53835
53836
53837
# File 'lib/google/apis/compute_beta/classes.rb', line 53835

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RouterAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53840
53841
53842
# File 'lib/google/apis/compute_beta/classes.rb', line 53840

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53847
53848
53849
53850
53851
53852
53853
53854
53855
# File 'lib/google/apis/compute_beta/classes.rb', line 53847

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end