Class: Google::Apis::ComputeBeta::RouterBgpPeerBfd
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterBgpPeerBfd
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#min_receive_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets received from the peer router.
-
#min_transmit_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router.
-
#multiplier ⇒ Fixnum
The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.
-
#session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterBgpPeerBfd
constructor
A new instance of RouterBgpPeerBfd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterBgpPeerBfd
Returns a new instance of RouterBgpPeerBfd.
56256 56257 56258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56256 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_receive_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
received from the peer router. The actual value is negotiated between
the two routers and is equal to the greater of this value and the
transmit interval of the other router.
If set, this value must be between 1000 and 30000.
The default is 1000.
Corresponds to the JSON property minReceiveInterval
56227 56228 56229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56227 def min_receive_interval @min_receive_interval end |
#min_transmit_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
transmitted to the peer router. The actual value is negotiated between
the two routers and is equal to the greater of this value and the
corresponding receive interval of the other router.
If set, this value must be between 1000 and 30000.
The default is 1000.
Corresponds to the JSON property minTransmitInterval
56237 56238 56239 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56237 def min_transmit_interval @min_transmit_interval end |
#multiplier ⇒ Fixnum
The number of consecutive BFD packets that must be missed
before BFD declares that a peer is unavailable.
If set, the value must be a value between 5 and 16.
The default is 5.
Corresponds to the JSON property multiplier
56245 56246 56247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56245 def multiplier @multiplier end |
#session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
Corresponds to the JSON property sessionInitializationMode
56254 56255 56256 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56254 def session_initialization_mode @session_initialization_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56261 56262 56263 56264 56265 56266 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56261 def update!(**args) @min_receive_interval = args[:min_receive_interval] if args.key?(:min_receive_interval) @min_transmit_interval = args[:min_transmit_interval] if args.key?(:min_transmit_interval) @multiplier = args[:multiplier] if args.key?(:multiplier) @session_initialization_mode = args[:session_initialization_mode] if args.key?(:session_initialization_mode) end |