Class: Google::Apis::ComputeBeta::RouterBgpPeerBfd
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterBgpPeerBfd
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#min_receive_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets received from the peer router.
-
#min_transmit_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router.
-
#multiplier ⇒ Fixnum
The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable.
-
#session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterBgpPeerBfd
constructor
A new instance of RouterBgpPeerBfd.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterBgpPeerBfd
Returns a new instance of RouterBgpPeerBfd.
55436 55437 55438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#min_receive_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
received from the peer router. The actual value is negotiated between
the two routers and is equal to the greater of this value and the
transmit interval of the other router.
If set, this value must be between 1000 and 30000.
The default is 1000.
Corresponds to the JSON property minReceiveInterval
55407 55408 55409 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55407 def min_receive_interval @min_receive_interval end |
#min_transmit_interval ⇒ Fixnum
The minimum interval, in milliseconds, between BFD control packets
transmitted to the peer router. The actual value is negotiated between
the two routers and is equal to the greater of this value and the
corresponding receive interval of the other router.
If set, this value must be between 1000 and 30000.
The default is 1000.
Corresponds to the JSON property minTransmitInterval
55417 55418 55419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55417 def min_transmit_interval @min_transmit_interval end |
#multiplier ⇒ Fixnum
The number of consecutive BFD packets that must be missed
before BFD declares that a peer is unavailable.
If set, the value must be a value between 5 and 16.
The default is 5.
Corresponds to the JSON property multiplier
55425 55426 55427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55425 def multiplier @multiplier end |
#session_initialization_mode ⇒ String
The BFD session initialization mode for this BGP peer.
If set to ACTIVE, the Cloud Router will initiate the BFD session for
this BGP peer. If set to PASSIVE, the Cloud Router will wait for the
peer router to initiate the BFD session for this BGP peer. If set to
DISABLED, BFD is disabled for this BGP peer. The default is DISABLED.
Corresponds to the JSON property sessionInitializationMode
55434 55435 55436 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55434 def session_initialization_mode @session_initialization_mode end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55441 55442 55443 55444 55445 55446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55441 def update!(**args) @min_receive_interval = args[:min_receive_interval] if args.key?(:min_receive_interval) @min_transmit_interval = args[:min_transmit_interval] if args.key?(:min_transmit_interval) @multiplier = args[:multiplier] if args.key?(:multiplier) @session_initialization_mode = args[:session_initialization_mode] if args.key?(:session_initialization_mode) end |