Class: Google::Apis::ComputeBeta::RouterBgpPeerBfd

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterBgpPeerBfd

Returns a new instance of RouterBgpPeerBfd.



52522
52523
52524
# File 'lib/google/apis/compute_beta/classes.rb', line 52522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#min_receive_intervalFixnum

The minimum interval, in milliseconds, between BFD control packets received from the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the transmit interval of the other router. If set, this value must be between 1000 and 30000. The default is 1000. Corresponds to the JSON property minReceiveInterval

Returns:

  • (Fixnum)


52493
52494
52495
# File 'lib/google/apis/compute_beta/classes.rb', line 52493

def min_receive_interval
  @min_receive_interval
end

#min_transmit_intervalFixnum

The minimum interval, in milliseconds, between BFD control packets transmitted to the peer router. The actual value is negotiated between the two routers and is equal to the greater of this value and the corresponding receive interval of the other router. If set, this value must be between 1000 and 30000. The default is 1000. Corresponds to the JSON property minTransmitInterval

Returns:

  • (Fixnum)


52503
52504
52505
# File 'lib/google/apis/compute_beta/classes.rb', line 52503

def min_transmit_interval
  @min_transmit_interval
end

#multiplierFixnum

The number of consecutive BFD packets that must be missed before BFD declares that a peer is unavailable. If set, the value must be a value between 5 and 16. The default is 5. Corresponds to the JSON property multiplier

Returns:

  • (Fixnum)


52511
52512
52513
# File 'lib/google/apis/compute_beta/classes.rb', line 52511

def multiplier
  @multiplier
end

#session_initialization_modeString

The BFD session initialization mode for this BGP peer. If set to ACTIVE, the Cloud Router will initiate the BFD session for this BGP peer. If set to PASSIVE, the Cloud Router will wait for the peer router to initiate the BFD session for this BGP peer. If set to DISABLED, BFD is disabled for this BGP peer. The default is DISABLED. Corresponds to the JSON property sessionInitializationMode

Returns:

  • (String)


52520
52521
52522
# File 'lib/google/apis/compute_beta/classes.rb', line 52520

def session_initialization_mode
  @session_initialization_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



52527
52528
52529
52530
52531
52532
# File 'lib/google/apis/compute_beta/classes.rb', line 52527

def update!(**args)
  @min_receive_interval = args[:min_receive_interval] if args.key?(:min_receive_interval)
  @min_transmit_interval = args[:min_transmit_interval] if args.key?(:min_transmit_interval)
  @multiplier = args[:multiplier] if args.key?(:multiplier)
  @session_initialization_mode = args[:session_initialization_mode] if args.key?(:session_initialization_mode)
end