Class: Google::Apis::ComputeBeta::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



57771
57772
57773
# File 'lib/google/apis/compute_beta/classes.rb', line 57771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57738
57739
57740
# File 'lib/google/apis/compute_beta/classes.rb', line 57738

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Router>

A list of Router resources. Corresponds to the JSON property items



57743
57744
57745
# File 'lib/google/apis/compute_beta/classes.rb', line 57743

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


57749
57750
57751
# File 'lib/google/apis/compute_beta/classes.rb', line 57749

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57759
57760
57761
# File 'lib/google/apis/compute_beta/classes.rb', line 57759

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57764
57765
57766
# File 'lib/google/apis/compute_beta/classes.rb', line 57764

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57769
57770
57771
# File 'lib/google/apis/compute_beta/classes.rb', line 57769

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57776
57777
57778
57779
57780
57781
57782
57783
# File 'lib/google/apis/compute_beta/classes.rb', line 57776

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end