Class: Google::Apis::ComputeBeta::RouterList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Router resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of Router resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RouterList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterList
constructor
A new instance of RouterList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterList
Returns a new instance of RouterList.
57739 57740 57741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57739 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
57706 57707 57708 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57706 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of Router resources.
Corresponds to the JSON property items
57711 57712 57713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57711 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#router for
routers.
Corresponds to the JSON property kind
57717 57718 57719 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57717 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57727 57728 57729 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57727 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57732 57733 57734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57732 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::RouterList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57737 57738 57739 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57737 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57744 57745 57746 57747 57748 57749 57750 57751 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57744 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |