Class: Google::Apis::ComputeBeta::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



56446
56447
56448
# File 'lib/google/apis/compute_beta/classes.rb', line 56446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56413
56414
56415
# File 'lib/google/apis/compute_beta/classes.rb', line 56413

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Router>

A list of Router resources. Corresponds to the JSON property items



56418
56419
56420
# File 'lib/google/apis/compute_beta/classes.rb', line 56418

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


56424
56425
56426
# File 'lib/google/apis/compute_beta/classes.rb', line 56424

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56434
56435
56436
# File 'lib/google/apis/compute_beta/classes.rb', line 56434

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56439
56440
56441
# File 'lib/google/apis/compute_beta/classes.rb', line 56439

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56444
56445
56446
# File 'lib/google/apis/compute_beta/classes.rb', line 56444

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56451
56452
56453
56454
56455
56456
56457
56458
# File 'lib/google/apis/compute_beta/classes.rb', line 56451

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end