Class: Google::Apis::ComputeBeta::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



55626
55627
55628
# File 'lib/google/apis/compute_beta/classes.rb', line 55626

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55593
55594
55595
# File 'lib/google/apis/compute_beta/classes.rb', line 55593

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Router>

A list of Router resources. Corresponds to the JSON property items



55598
55599
55600
# File 'lib/google/apis/compute_beta/classes.rb', line 55598

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


55604
55605
55606
# File 'lib/google/apis/compute_beta/classes.rb', line 55604

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55614
55615
55616
# File 'lib/google/apis/compute_beta/classes.rb', line 55614

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


55619
55620
55621
# File 'lib/google/apis/compute_beta/classes.rb', line 55619

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55624
55625
55626
# File 'lib/google/apis/compute_beta/classes.rb', line 55624

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55631
55632
55633
55634
55635
55636
55637
55638
# File 'lib/google/apis/compute_beta/classes.rb', line 55631

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end