Class: Google::Apis::ComputeBeta::RouterList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Router resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterList

Returns a new instance of RouterList.



54443
54444
54445
# File 'lib/google/apis/compute_beta/classes.rb', line 54443

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54410
54411
54412
# File 'lib/google/apis/compute_beta/classes.rb', line 54410

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Router>

A list of Router resources. Corresponds to the JSON property items



54415
54416
54417
# File 'lib/google/apis/compute_beta/classes.rb', line 54415

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#router for routers. Corresponds to the JSON property kind

Returns:

  • (String)


54421
54422
54423
# File 'lib/google/apis/compute_beta/classes.rb', line 54421

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54431
54432
54433
# File 'lib/google/apis/compute_beta/classes.rb', line 54431

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54436
54437
54438
# File 'lib/google/apis/compute_beta/classes.rb', line 54436

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::RouterList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54441
54442
54443
# File 'lib/google/apis/compute_beta/classes.rb', line 54441

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54448
54449
54450
54451
54452
54453
54454
54455
# File 'lib/google/apis/compute_beta/classes.rb', line 54448

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end