Class: Google::Apis::ComputeBeta::RouterMd5AuthenticationKey
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterMd5AuthenticationKey
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#key ⇒ String
[Input only] Value of the key.
-
#name ⇒ String
Name used to identify the key.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterMd5AuthenticationKey
constructor
A new instance of RouterMd5AuthenticationKey.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterMd5AuthenticationKey
Returns a new instance of RouterMd5AuthenticationKey.
57943 57944 57945 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57943 def initialize(**args) update!(**args) end |
Instance Attribute Details
#key ⇒ String
[Input only] Value of the key.
For patch and update calls, it can be skipped to
copy the value from the previous configuration. This is allowed if the
key with the same name existed before the operation. Maximum length is 80
characters. Can only contain printable ASCII characters.
Corresponds to the JSON property key
57934 57935 57936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57934 def key @key end |
#name ⇒ String
Name used to identify the key.
Must be unique within a router. Must be referenced by exactly
one bgpPeer. Must comply withRFC1035.
Corresponds to the JSON property name
57941 57942 57943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57941 def name @name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57948 57949 57950 57951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57948 def update!(**args) @key = args[:key] if args.key?(:key) @name = args[:name] if args.key?(:name) end |