Class: Google::Apis::ComputeBeta::RouterMd5AuthenticationKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterMd5AuthenticationKey

Returns a new instance of RouterMd5AuthenticationKey.



57410
57411
57412
# File 'lib/google/apis/compute_beta/classes.rb', line 57410

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

[Input only] Value of the key. For patch and update calls, it can be skipped to copy the value from the previous configuration. This is allowed if the key with the same name existed before the operation. Maximum length is 80 characters. Can only contain printable ASCII characters. Corresponds to the JSON property key

Returns:

  • (String)


57401
57402
57403
# File 'lib/google/apis/compute_beta/classes.rb', line 57401

def key
  @key
end

#nameString

Name used to identify the key. Must be unique within a router. Must be referenced by exactly one bgpPeer. Must comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


57408
57409
57410
# File 'lib/google/apis/compute_beta/classes.rb', line 57408

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57415
57416
57417
57418
# File 'lib/google/apis/compute_beta/classes.rb', line 57415

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @name = args[:name] if args.key?(:name)
end