Class: Google::Apis::ComputeBeta::RouterMd5AuthenticationKey

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterMd5AuthenticationKey

Returns a new instance of RouterMd5AuthenticationKey.



56551
56552
56553
# File 'lib/google/apis/compute_beta/classes.rb', line 56551

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

[Input only] Value of the key. For patch and update calls, it can be skipped to copy the value from the previous configuration. This is allowed if the key with the same name existed before the operation. Maximum length is 80 characters. Can only contain printable ASCII characters. Corresponds to the JSON property key

Returns:

  • (String)


56542
56543
56544
# File 'lib/google/apis/compute_beta/classes.rb', line 56542

def key
  @key
end

#nameString

Name used to identify the key. Must be unique within a router. Must be referenced by exactly one bgpPeer. Must comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


56549
56550
56551
# File 'lib/google/apis/compute_beta/classes.rb', line 56549

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56556
56557
56558
56559
# File 'lib/google/apis/compute_beta/classes.rb', line 56556

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @name = args[:name] if args.key?(:name)
end