Class: Google::Apis::ComputeBeta::RouterNat

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Nat resource. It enables the VMs within the specified subnetworks to access Internet without external IP addresses. It specifies a list of subnetworks (and the ranges within) that want to use NAT. Customers can also provide the external IPs that would be used for NAT. GCP would auto-allocate ephemeral IPs if no external IPs are provided.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNat

Returns a new instance of RouterNat.



53016
53017
53018
# File 'lib/google/apis/compute_beta/classes.rb', line 53016

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_network_tierString

The network tier to use when automatically reserving NAT IP addresses. Must be one of: PREMIUM, STANDARD. If not specified, then the current project-level default tier is used. Corresponds to the JSON property autoNetworkTier

Returns:

  • (String)


52842
52843
52844
# File 'lib/google/apis/compute_beta/classes.rb', line 52842

def auto_network_tier
  @auto_network_tier
end

#drain_nat_ipsArray<String>

A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT only. Corresponds to the JSON property drainNatIps

Returns:

  • (Array<String>)


52849
52850
52851
# File 'lib/google/apis/compute_beta/classes.rb', line 52849

def drain_nat_ips
  @drain_nat_ips
end

#enable_dynamic_port_allocationBoolean Also known as: enable_dynamic_port_allocation?

Enable Dynamic Port Allocation. If not specified, it is disabled by default. If set to true,

  • Dynamic Port Allocation will be enabled on this NAT config.
  • enableEndpointIndependentMapping cannot be set to true.
  • If minPorts is set, minPortsPerVm must be set to a power of two greater than or equal to 32. If minPortsPerVm is not set, a minimum of 32 ports will be allocated to a VM from this NAT config. Corresponds to the JSON property enableDynamicPortAllocation

Returns:

  • (Boolean)


52864
52865
52866
# File 'lib/google/apis/compute_beta/classes.rb', line 52864

def enable_dynamic_port_allocation
  @enable_dynamic_port_allocation
end

#enable_endpoint_independent_mappingBoolean Also known as: enable_endpoint_independent_mapping?

Corresponds to the JSON property enableEndpointIndependentMapping

Returns:

  • (Boolean)


52870
52871
52872
# File 'lib/google/apis/compute_beta/classes.rb', line 52870

def enable_endpoint_independent_mapping
  @enable_endpoint_independent_mapping
end

#endpoint_typesArray<String>

List of NAT-ted endpoint types supported by the Nat Gateway. If the list is empty, then it will be equivalent to include ENDPOINT_TYPE_VM Corresponds to the JSON property endpointTypes

Returns:

  • (Array<String>)


52877
52878
52879
# File 'lib/google/apis/compute_beta/classes.rb', line 52877

def endpoint_types
  @endpoint_types
end

#icmp_idle_timeout_secFixnum

Timeout (in seconds) for ICMP connections. Defaults to 30s if not set. Corresponds to the JSON property icmpIdleTimeoutSec

Returns:

  • (Fixnum)


52882
52883
52884
# File 'lib/google/apis/compute_beta/classes.rb', line 52882

def icmp_idle_timeout_sec
  @icmp_idle_timeout_sec
end

#log_configGoogle::Apis::ComputeBeta::RouterNatLogConfig

Configuration of logging on a NAT. Corresponds to the JSON property logConfig



52887
52888
52889
# File 'lib/google/apis/compute_beta/classes.rb', line 52887

def log_config
  @log_config
end

#max_ports_per_vmFixnum

Maximum number of ports allocated to a VM from this NAT config when Dynamic Port Allocation is enabled. If Dynamic Port Allocation is not enabled, this field has no effect. If Dynamic Port Allocation is enabled, and this field is set, it must be set to a power of two greater than minPortsPerVm, or 64 if minPortsPerVm is not set. If Dynamic Port Allocation is enabled and this field is not set, a maximum of 65536 ports will be allocated to a VM from this NAT config. Corresponds to the JSON property maxPortsPerVm

Returns:

  • (Fixnum)


52900
52901
52902
# File 'lib/google/apis/compute_beta/classes.rb', line 52900

def max_ports_per_vm
  @max_ports_per_vm
end

#min_ports_per_vmFixnum

Minimum number of ports allocated to a VM from this NAT config. If not set, a default number of ports is allocated to a VM. This is rounded up to the nearest power of 2. For example, if the value of this field is 50, at least 64 ports are allocated to a VM. Corresponds to the JSON property minPortsPerVm

Returns:

  • (Fixnum)


52908
52909
52910
# File 'lib/google/apis/compute_beta/classes.rb', line 52908

def min_ports_per_vm
  @min_ports_per_vm
end

#nameString

Unique name of this Nat service. The name must be 1-63 characters long and comply withRFC1035. Corresponds to the JSON property name

Returns:

  • (String)


52914
52915
52916
# File 'lib/google/apis/compute_beta/classes.rb', line 52914

def name
  @name
end

#nat64_subnetworksArray<Google::Apis::ComputeBeta::RouterNatSubnetworkToNat64>

List of Subnetwork resources whose traffic should be translated by NAT64 Gateway. It is used only when LIST_OF_IPV6_SUBNETWORKS is selected for the SubnetworkIpRangeToNat64Option above. Corresponds to the JSON property nat64Subnetworks



52921
52922
52923
# File 'lib/google/apis/compute_beta/classes.rb', line 52921

def nat64_subnetworks
  @nat64_subnetworks
end

#nat_ip_allocate_optionString

Specify the NatIpAllocateOption, which can take one of the following values:

  • MANUAL_ONLY: Uses only Nat IP addresses provided by customers. When there are not enough specified Nat IPs, the Nat service fails for new VMs.
  • AUTO_ONLY: Nat IPs are allocated by Google Cloud Platform; customers can't specify any Nat IPs. When choosing AUTO_ONLY, then nat_ip should be empty. Corresponds to the JSON property natIpAllocateOption

Returns:

  • (String)


52934
52935
52936
# File 'lib/google/apis/compute_beta/classes.rb', line 52934

def nat_ip_allocate_option
  @nat_ip_allocate_option
end

#nat_ipsArray<String>

A list of URLs of the IP resources used for this Nat service. These IP addresses must be valid static external IP addresses assigned to the project. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


52941
52942
52943
# File 'lib/google/apis/compute_beta/classes.rb', line 52941

def nat_ips
  @nat_ips
end

#rulesArray<Google::Apis::ComputeBeta::RouterNatRule>

A list of rules associated with this NAT. Corresponds to the JSON property rules



52946
52947
52948
# File 'lib/google/apis/compute_beta/classes.rb', line 52946

def rules
  @rules
end

#source_subnetwork_ip_ranges_to_natString

Specify the Nat option, which can take one of the following values:

  • ALL_SUBNETWORKS_ALL_IP_RANGES: All of the IP ranges in every Subnetwork are allowed to Nat.
  • ALL_SUBNETWORKS_ALL_PRIMARY_IP_RANGES: All of the primary IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field subnetwork below) The default is SUBNETWORK_IP_RANGE_TO_NAT_OPTION_UNSPECIFIED. Note that if this field contains ALL_SUBNETWORKS_ALL_IP_RANGES then there should not be any other Router.Nat section in any Router for this network in this region. Corresponds to the JSON property sourceSubnetworkIpRangesToNat

Returns:

  • (String)


52962
52963
52964
# File 'lib/google/apis/compute_beta/classes.rb', line 52962

def source_subnetwork_ip_ranges_to_nat
  @source_subnetwork_ip_ranges_to_nat
end

#source_subnetwork_ip_ranges_to_nat64String

Specify the Nat option for NAT64, which can take one of the following values:

  • ALL_IPV6_SUBNETWORKS: All of the IP ranges in every Subnetwork are allowed to Nat.
  • LIST_OF_IPV6_SUBNETWORKS: A list of Subnetworks are allowed to Nat (specified in the field nat64_subnetwork below) The default is NAT64_OPTION_UNSPECIFIED. Note that if this field contains NAT64_ALL_V6_SUBNETWORKS no other Router.Nat section in this region can also enable NAT64 for any Subnetworks in this network. Other Router.Nat sections can still be present to enable NAT44 only. Corresponds to the JSON property sourceSubnetworkIpRangesToNat64

Returns:

  • (String)


52978
52979
52980
# File 'lib/google/apis/compute_beta/classes.rb', line 52978

def source_subnetwork_ip_ranges_to_nat64
  @source_subnetwork_ip_ranges_to_nat64
end

#subnetworksArray<Google::Apis::ComputeBeta::RouterNatSubnetworkToNat>

A list of Subnetwork resources whose traffic should be translated by NAT Gateway. It is used only when LIST_OF_SUBNETWORKS is selected for the SubnetworkIpRangeToNatOption above. Corresponds to the JSON property subnetworks



52985
52986
52987
# File 'lib/google/apis/compute_beta/classes.rb', line 52985

def subnetworks
  @subnetworks
end

#tcp_established_idle_timeout_secFixnum

Timeout (in seconds) for TCP established connections. Defaults to 1200s if not set. Corresponds to the JSON property tcpEstablishedIdleTimeoutSec

Returns:

  • (Fixnum)


52991
52992
52993
# File 'lib/google/apis/compute_beta/classes.rb', line 52991

def tcp_established_idle_timeout_sec
  @tcp_established_idle_timeout_sec
end

#tcp_time_wait_timeout_secFixnum

Timeout (in seconds) for TCP connections that are in TIME_WAIT state. Defaults to 120s if not set. Corresponds to the JSON property tcpTimeWaitTimeoutSec

Returns:

  • (Fixnum)


52997
52998
52999
# File 'lib/google/apis/compute_beta/classes.rb', line 52997

def tcp_time_wait_timeout_sec
  @tcp_time_wait_timeout_sec
end

#tcp_transitory_idle_timeout_secFixnum

Timeout (in seconds) for TCP transitory connections. Defaults to 30s if not set. Corresponds to the JSON property tcpTransitoryIdleTimeoutSec

Returns:

  • (Fixnum)


53003
53004
53005
# File 'lib/google/apis/compute_beta/classes.rb', line 53003

def tcp_transitory_idle_timeout_sec
  @tcp_transitory_idle_timeout_sec
end

#typeString

Indicates whether this NAT is used for public or private IP translation. If unspecified, it defaults to PUBLIC. Corresponds to the JSON property type

Returns:

  • (String)


53009
53010
53011
# File 'lib/google/apis/compute_beta/classes.rb', line 53009

def type
  @type
end

#udp_idle_timeout_secFixnum

Timeout (in seconds) for UDP connections. Defaults to 30s if not set. Corresponds to the JSON property udpIdleTimeoutSec

Returns:

  • (Fixnum)


53014
53015
53016
# File 'lib/google/apis/compute_beta/classes.rb', line 53014

def udp_idle_timeout_sec
  @udp_idle_timeout_sec
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53021
53022
53023
53024
53025
53026
53027
53028
53029
53030
53031
53032
53033
53034
53035
53036
53037
53038
53039
53040
53041
53042
53043
53044
# File 'lib/google/apis/compute_beta/classes.rb', line 53021

def update!(**args)
  @auto_network_tier = args[:auto_network_tier] if args.key?(:auto_network_tier)
  @drain_nat_ips = args[:drain_nat_ips] if args.key?(:drain_nat_ips)
  @enable_dynamic_port_allocation = args[:enable_dynamic_port_allocation] if args.key?(:enable_dynamic_port_allocation)
  @enable_endpoint_independent_mapping = args[:enable_endpoint_independent_mapping] if args.key?(:enable_endpoint_independent_mapping)
  @endpoint_types = args[:endpoint_types] if args.key?(:endpoint_types)
  @icmp_idle_timeout_sec = args[:icmp_idle_timeout_sec] if args.key?(:icmp_idle_timeout_sec)
  @log_config = args[:log_config] if args.key?(:log_config)
  @max_ports_per_vm = args[:max_ports_per_vm] if args.key?(:max_ports_per_vm)
  @min_ports_per_vm = args[:min_ports_per_vm] if args.key?(:min_ports_per_vm)
  @name = args[:name] if args.key?(:name)
  @nat64_subnetworks = args[:nat64_subnetworks] if args.key?(:nat64_subnetworks)
  @nat_ip_allocate_option = args[:nat_ip_allocate_option] if args.key?(:nat_ip_allocate_option)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @rules = args[:rules] if args.key?(:rules)
  @source_subnetwork_ip_ranges_to_nat = args[:source_subnetwork_ip_ranges_to_nat] if args.key?(:source_subnetwork_ip_ranges_to_nat)
  @source_subnetwork_ip_ranges_to_nat64 = args[:source_subnetwork_ip_ranges_to_nat64] if args.key?(:source_subnetwork_ip_ranges_to_nat64)
  @subnetworks = args[:subnetworks] if args.key?(:subnetworks)
  @tcp_established_idle_timeout_sec = args[:tcp_established_idle_timeout_sec] if args.key?(:tcp_established_idle_timeout_sec)
  @tcp_time_wait_timeout_sec = args[:tcp_time_wait_timeout_sec] if args.key?(:tcp_time_wait_timeout_sec)
  @tcp_transitory_idle_timeout_sec = args[:tcp_transitory_idle_timeout_sec] if args.key?(:tcp_transitory_idle_timeout_sec)
  @type = args[:type] if args.key?(:type)
  @udp_idle_timeout_sec = args[:udp_idle_timeout_sec] if args.key?(:udp_idle_timeout_sec)
end