Class: Google::Apis::ComputeBeta::RouterNatLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterNatLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration of logging on a NAT.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
Indicates whether or not to export logs.
-
#filter ⇒ String
Specify the desired filtering of logs on this NAT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatLogConfig
constructor
A new instance of RouterNatLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatLogConfig
Returns a new instance of RouterNatLogConfig.
58605 58606 58607 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58605 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
Indicates whether or not to export logs. This is false by default.
Corresponds to the JSON property enable
58589 58590 58591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58589 def enable @enable end |
#filter ⇒ String
Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:
- ERRORS_ONLY: Export logs only for connection failures.
- TRANSLATIONS_ONLY: Export logs only for successful connections.
- ALL: Export logs for all connections, successful and
unsuccessful.
Corresponds to the JSON property
filter
58603 58604 58605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58603 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58610 58611 58612 58613 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58610 def update!(**args) @enable = args[:enable] if args.key?(:enable) @filter = args[:filter] if args.key?(:filter) end |