Class: Google::Apis::ComputeBeta::RouterNatLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration of logging on a NAT.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatLogConfig

Returns a new instance of RouterNatLogConfig.



58107
58108
58109
# File 'lib/google/apis/compute_beta/classes.rb', line 58107

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Indicates whether or not to export logs. This is false by default. Corresponds to the JSON property enable

Returns:

  • (Boolean)


58091
58092
58093
# File 'lib/google/apis/compute_beta/classes.rb', line 58091

def enable
  @enable
end

#filterString

Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

  • ERRORS_ONLY: Export logs only for connection failures.
  • TRANSLATIONS_ONLY: Export logs only for successful connections.
  • ALL: Export logs for all connections, successful and unsuccessful. Corresponds to the JSON property filter

Returns:

  • (String)


58105
58106
58107
# File 'lib/google/apis/compute_beta/classes.rb', line 58105

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58112
58113
58114
58115
# File 'lib/google/apis/compute_beta/classes.rb', line 58112

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @filter = args[:filter] if args.key?(:filter)
end