Class: Google::Apis::ComputeBeta::RouterNatLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration of logging on a NAT.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatLogConfig

Returns a new instance of RouterNatLogConfig.



57650
57651
57652
# File 'lib/google/apis/compute_beta/classes.rb', line 57650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enableBoolean Also known as: enable?

Indicates whether or not to export logs. This is false by default. Corresponds to the JSON property enable

Returns:

  • (Boolean)


57634
57635
57636
# File 'lib/google/apis/compute_beta/classes.rb', line 57634

def enable
  @enable
end

#filterString

Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:

  • ERRORS_ONLY: Export logs only for connection failures.
  • TRANSLATIONS_ONLY: Export logs only for successful connections.
  • ALL: Export logs for all connections, successful and unsuccessful. Corresponds to the JSON property filter

Returns:

  • (String)


57648
57649
57650
# File 'lib/google/apis/compute_beta/classes.rb', line 57648

def filter
  @filter
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57655
57656
57657
57658
# File 'lib/google/apis/compute_beta/classes.rb', line 57655

def update!(**args)
  @enable = args[:enable] if args.key?(:enable)
  @filter = args[:filter] if args.key?(:filter)
end