Class: Google::Apis::ComputeBeta::RouterNatLogConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterNatLogConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration of logging on a NAT.
Instance Attribute Summary collapse
-
#enable ⇒ Boolean
(also: #enable?)
Indicates whether or not to export logs.
-
#filter ⇒ String
Specify the desired filtering of logs on this NAT.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatLogConfig
constructor
A new instance of RouterNatLogConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatLogConfig
Returns a new instance of RouterNatLogConfig.
54801 54802 54803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54801 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable ⇒ Boolean Also known as: enable?
Indicates whether or not to export logs. This is false by default.
Corresponds to the JSON property enable
54785 54786 54787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54785 def enable @enable end |
#filter ⇒ String
Specify the desired filtering of logs on this NAT. If unspecified, logs are exported for all connections handled by this NAT. This option can take one of the following values:
- ERRORS_ONLY: Export logs only for connection failures.
- TRANSLATIONS_ONLY: Export logs only for successful connections.
- ALL: Export logs for all connections, successful and
unsuccessful.
Corresponds to the JSON property
filter
54799 54800 54801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54799 def filter @filter end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54806 54807 54808 54809 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54806 def update!(**args) @enable = args[:enable] if args.key?(:enable) @filter = args[:filter] if args.key?(:filter) end |