Class: Google::Apis::ComputeBeta::RouterNatRuleAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterNatRuleAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#source_nat_active_ips ⇒ Array<String>
A list of URLs of the IP resources used for this NAT rule.
-
#source_nat_active_ranges ⇒ Array<String>
A list of URLs of the subnetworks used as source ranges for this NAT Rule.
-
#source_nat_drain_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained.
-
#source_nat_drain_ranges ⇒ Array<String>
A list of URLs of subnetworks representing source ranges to be drained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatRuleAction
constructor
A new instance of RouterNatRuleAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatRuleAction
Returns a new instance of RouterNatRuleAction.
58203 58204 58205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_nat_active_ips ⇒ Array<String>
A list of URLs of the IP resources used for this NAT rule. These IP
addresses must be valid static external IP addresses assigned to the
project.
This field is used for public NAT.
Corresponds to the JSON property sourceNatActiveIps
58177 58178 58179 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58177 def source_nat_active_ips @source_nat_active_ips end |
#source_nat_active_ranges ⇒ Array<String>
A list of URLs of the subnetworks used as source ranges for this
NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT.
This field is used for private NAT.
Corresponds to the JSON property sourceNatActiveRanges
58184 58185 58186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58184 def source_nat_active_ranges @source_nat_active_ranges end |
#source_nat_drain_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained. These IPs
must be valid static external IPs that have been assigned to the NAT.
These IPs should be used for updating/patching a NAT rule only.
This field is used for public NAT.
Corresponds to the JSON property sourceNatDrainIps
58192 58193 58194 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58192 def source_nat_drain_ips @source_nat_drain_ips end |
#source_nat_drain_ranges ⇒ Array<String>
A list of URLs of subnetworks representing source ranges to be
drained. This is only supported on patch/update, and these
subnetworks must have previously been used as active ranges in this
NAT Rule.
This field is used for private NAT.
Corresponds to the JSON property sourceNatDrainRanges
58201 58202 58203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58201 def source_nat_drain_ranges @source_nat_drain_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58208 58209 58210 58211 58212 58213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58208 def update!(**args) @source_nat_active_ips = args[:source_nat_active_ips] if args.key?(:source_nat_active_ips) @source_nat_active_ranges = args[:source_nat_active_ranges] if args.key?(:source_nat_active_ranges) @source_nat_drain_ips = args[:source_nat_drain_ips] if args.key?(:source_nat_drain_ips) @source_nat_drain_ranges = args[:source_nat_drain_ranges] if args.key?(:source_nat_drain_ranges) end |