Class: Google::Apis::ComputeBeta::RouterNatRuleAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterNatRuleAction

Returns a new instance of RouterNatRuleAction.



57769
57770
57771
# File 'lib/google/apis/compute_beta/classes.rb', line 57769

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#source_nat_active_ipsArray<String>

A list of URLs of the IP resources used for this NAT rule. These IP addresses must be valid static external IP addresses assigned to the project. This field is used for public NAT. Corresponds to the JSON property sourceNatActiveIps

Returns:

  • (Array<String>)


57743
57744
57745
# File 'lib/google/apis/compute_beta/classes.rb', line 57743

def source_nat_active_ips
  @source_nat_active_ips
end

#source_nat_active_rangesArray<String>

A list of URLs of the subnetworks used as source ranges for this NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT. This field is used for private NAT. Corresponds to the JSON property sourceNatActiveRanges

Returns:

  • (Array<String>)


57750
57751
57752
# File 'lib/google/apis/compute_beta/classes.rb', line 57750

def source_nat_active_ranges
  @source_nat_active_ranges
end

#source_nat_drain_ipsArray<String>

A list of URLs of the IP resources to be drained. These IPs must be valid static external IPs that have been assigned to the NAT. These IPs should be used for updating/patching a NAT rule only. This field is used for public NAT. Corresponds to the JSON property sourceNatDrainIps

Returns:

  • (Array<String>)


57758
57759
57760
# File 'lib/google/apis/compute_beta/classes.rb', line 57758

def source_nat_drain_ips
  @source_nat_drain_ips
end

#source_nat_drain_rangesArray<String>

A list of URLs of subnetworks representing source ranges to be drained. This is only supported on patch/update, and these subnetworks must have previously been used as active ranges in this NAT Rule. This field is used for private NAT. Corresponds to the JSON property sourceNatDrainRanges

Returns:

  • (Array<String>)


57767
57768
57769
# File 'lib/google/apis/compute_beta/classes.rb', line 57767

def source_nat_drain_ranges
  @source_nat_drain_ranges
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57774
57775
57776
57777
57778
57779
# File 'lib/google/apis/compute_beta/classes.rb', line 57774

def update!(**args)
  @source_nat_active_ips = args[:source_nat_active_ips] if args.key?(:source_nat_active_ips)
  @source_nat_active_ranges = args[:source_nat_active_ranges] if args.key?(:source_nat_active_ranges)
  @source_nat_drain_ips = args[:source_nat_drain_ips] if args.key?(:source_nat_drain_ips)
  @source_nat_drain_ranges = args[:source_nat_drain_ranges] if args.key?(:source_nat_drain_ranges)
end