Class: Google::Apis::ComputeBeta::RouterNatRuleAction
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterNatRuleAction
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#source_nat_active_ips ⇒ Array<String>
A list of URLs of the IP resources used for this NAT rule.
-
#source_nat_active_ranges ⇒ Array<String>
A list of URLs of the subnetworks used as source ranges for this NAT Rule.
-
#source_nat_drain_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained.
-
#source_nat_drain_ranges ⇒ Array<String>
A list of URLs of subnetworks representing source ranges to be drained.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterNatRuleAction
constructor
A new instance of RouterNatRuleAction.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterNatRuleAction
Returns a new instance of RouterNatRuleAction.
54897 54898 54899 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54897 def initialize(**args) update!(**args) end |
Instance Attribute Details
#source_nat_active_ips ⇒ Array<String>
A list of URLs of the IP resources used for this NAT rule. These IP
addresses must be valid static external IP addresses assigned to the
project.
This field is used for public NAT.
Corresponds to the JSON property sourceNatActiveIps
54871 54872 54873 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54871 def source_nat_active_ips @source_nat_active_ips end |
#source_nat_active_ranges ⇒ Array<String>
A list of URLs of the subnetworks used as source ranges for this
NAT Rule. These subnetworks must have purpose set to PRIVATE_NAT.
This field is used for private NAT.
Corresponds to the JSON property sourceNatActiveRanges
54878 54879 54880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54878 def source_nat_active_ranges @source_nat_active_ranges end |
#source_nat_drain_ips ⇒ Array<String>
A list of URLs of the IP resources to be drained. These IPs
must be valid static external IPs that have been assigned to the NAT.
These IPs should be used for updating/patching a NAT rule only.
This field is used for public NAT.
Corresponds to the JSON property sourceNatDrainIps
54886 54887 54888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54886 def source_nat_drain_ips @source_nat_drain_ips end |
#source_nat_drain_ranges ⇒ Array<String>
A list of URLs of subnetworks representing source ranges to be
drained. This is only supported on patch/update, and these
subnetworks must have previously been used as active ranges in this
NAT Rule.
This field is used for private NAT.
Corresponds to the JSON property sourceNatDrainRanges
54895 54896 54897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54895 def source_nat_drain_ranges @source_nat_drain_ranges end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54902 54903 54904 54905 54906 54907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54902 def update!(**args) @source_nat_active_ips = args[:source_nat_active_ips] if args.key?(:source_nat_active_ips) @source_nat_active_ranges = args[:source_nat_active_ranges] if args.key?(:source_nat_active_ranges) @source_nat_drain_ips = args[:source_nat_drain_ips] if args.key?(:source_nat_drain_ips) @source_nat_drain_ranges = args[:source_nat_drain_ranges] if args.key?(:source_nat_drain_ranges) end |