Class: Google::Apis::ComputeBeta::RouterStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatus

Returns a new instance of RouterStatus.



58347
58348
58349
# File 'lib/google/apis/compute_beta/classes.rb', line 58347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_routesArray<Google::Apis::ComputeBeta::Route>

A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router. Lists all of the best routes per prefix that are programmed into this region's VPC data plane. When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions. Corresponds to the JSON property bestRoutes



58317
58318
58319
# File 'lib/google/apis/compute_beta/classes.rb', line 58317

def best_routes
  @best_routes
end

#best_routes_for_routerArray<Google::Apis::ComputeBeta::Route>

A list of the best BGP routes learned by this Cloud Router. It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router. Corresponds to the JSON property bestRoutesForRouter



58325
58326
58327
# File 'lib/google/apis/compute_beta/classes.rb', line 58325

def best_routes_for_router
  @best_routes_for_router
end

#bgp_peer_statusArray<Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus>

Corresponds to the JSON property bgpPeerStatus



58330
58331
58332
# File 'lib/google/apis/compute_beta/classes.rb', line 58330

def bgp_peer_status
  @bgp_peer_status
end

#nat_statusArray<Google::Apis::ComputeBeta::RouterStatusNatStatus>

Corresponds to the JSON property natStatus



58335
58336
58337
# File 'lib/google/apis/compute_beta/classes.rb', line 58335

def nat_status
  @nat_status
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


58340
58341
58342
# File 'lib/google/apis/compute_beta/classes.rb', line 58340

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


58345
58346
58347
# File 'lib/google/apis/compute_beta/classes.rb', line 58345

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58352
58353
58354
58355
58356
58357
58358
58359
# File 'lib/google/apis/compute_beta/classes.rb', line 58352

def update!(**args)
  @best_routes = args[:best_routes] if args.key?(:best_routes)
  @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router)
  @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status)
  @nat_status = args[:nat_status] if args.key?(:nat_status)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
end