Class: Google::Apis::ComputeBeta::RouterStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#best_routes ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router.
-
#best_routes_for_router ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of the best BGP routes learned by this Cloud Router.
-
#bgp_peer_status ⇒ Array<Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus>
Corresponds to the JSON property
bgpPeerStatus. -
#nat_status ⇒ Array<Google::Apis::ComputeBeta::RouterStatusNatStatus>
Corresponds to the JSON property
natStatus. -
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
-
#network ⇒ String
URI of the network to which this router belongs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatus
constructor
A new instance of RouterStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatus
Returns a new instance of RouterStatus.
57890 57891 57892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57890 def initialize(**args) update!(**args) end |
Instance Attribute Details
#best_routes ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of the best dynamic routes for this Cloud Router's Virtual Private
Cloud (VPC) network in the same region as this Cloud Router.
Lists all of the best routes per prefix that are programmed into this
region's VPC data plane.
When global dynamic routing mode is turned on in the VPC network, this list
can include cross-region dynamic routes from Cloud Routers in other
regions.
Corresponds to the JSON property bestRoutes
57860 57861 57862 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57860 def best_routes @best_routes end |
#best_routes_for_router ⇒ Array<Google::Apis::ComputeBeta::Route>
A list of the best BGP routes learned by this Cloud Router.
It is possible that routes listed might not be programmed into the data
plane, if the Google Cloud control plane finds a more optimal route for a
prefix than a route learned by this Cloud Router.
Corresponds to the JSON property bestRoutesForRouter
57868 57869 57870 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57868 def best_routes_for_router @best_routes_for_router end |
#bgp_peer_status ⇒ Array<Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus>
Corresponds to the JSON property bgpPeerStatus
57873 57874 57875 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57873 def bgp_peer_status @bgp_peer_status end |
#nat_status ⇒ Array<Google::Apis::ComputeBeta::RouterStatusNatStatus>
Corresponds to the JSON property natStatus
57878 57879 57880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57878 def nat_status @nat_status end |
#ncc_gateway ⇒ String
URI of the ncc_gateway to which this router associated.
Corresponds to the JSON property nccGateway
57883 57884 57885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57883 def ncc_gateway @ncc_gateway end |
#network ⇒ String
URI of the network to which this router belongs.
Corresponds to the JSON property network
57888 57889 57890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57888 def network @network end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57895 57896 57897 57898 57899 57900 57901 57902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57895 def update!(**args) @best_routes = args[:best_routes] if args.key?(:best_routes) @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router) @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status) @nat_status = args[:nat_status] if args.key?(:nat_status) @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway) @network = args[:network] if args.key?(:network) end |