Class: Google::Apis::ComputeBeta::RouterStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatus

Returns a new instance of RouterStatus.



57044
57045
57046
# File 'lib/google/apis/compute_beta/classes.rb', line 57044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_routesArray<Google::Apis::ComputeBeta::Route>

A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router. Lists all of the best routes per prefix that are programmed into this region's VPC data plane. When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions. Corresponds to the JSON property bestRoutes



57014
57015
57016
# File 'lib/google/apis/compute_beta/classes.rb', line 57014

def best_routes
  @best_routes
end

#best_routes_for_routerArray<Google::Apis::ComputeBeta::Route>

A list of the best BGP routes learned by this Cloud Router. It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router. Corresponds to the JSON property bestRoutesForRouter



57022
57023
57024
# File 'lib/google/apis/compute_beta/classes.rb', line 57022

def best_routes_for_router
  @best_routes_for_router
end

#bgp_peer_statusArray<Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus>

Corresponds to the JSON property bgpPeerStatus



57027
57028
57029
# File 'lib/google/apis/compute_beta/classes.rb', line 57027

def bgp_peer_status
  @bgp_peer_status
end

#nat_statusArray<Google::Apis::ComputeBeta::RouterStatusNatStatus>

Corresponds to the JSON property natStatus



57032
57033
57034
# File 'lib/google/apis/compute_beta/classes.rb', line 57032

def nat_status
  @nat_status
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


57037
57038
57039
# File 'lib/google/apis/compute_beta/classes.rb', line 57037

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


57042
57043
57044
# File 'lib/google/apis/compute_beta/classes.rb', line 57042

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57049
57050
57051
57052
57053
57054
57055
57056
# File 'lib/google/apis/compute_beta/classes.rb', line 57049

def update!(**args)
  @best_routes = args[:best_routes] if args.key?(:best_routes)
  @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router)
  @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status)
  @nat_status = args[:nat_status] if args.key?(:nat_status)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
end