Class: Google::Apis::ComputeBeta::RouterStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatus

Returns a new instance of RouterStatus.



56224
56225
56226
# File 'lib/google/apis/compute_beta/classes.rb', line 56224

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_routesArray<Google::Apis::ComputeBeta::Route>

A list of the best dynamic routes for this Cloud Router's Virtual Private Cloud (VPC) network in the same region as this Cloud Router. Lists all of the best routes per prefix that are programmed into this region's VPC data plane. When global dynamic routing mode is turned on in the VPC network, this list can include cross-region dynamic routes from Cloud Routers in other regions. Corresponds to the JSON property bestRoutes



56194
56195
56196
# File 'lib/google/apis/compute_beta/classes.rb', line 56194

def best_routes
  @best_routes
end

#best_routes_for_routerArray<Google::Apis::ComputeBeta::Route>

A list of the best BGP routes learned by this Cloud Router. It is possible that routes listed might not be programmed into the data plane, if the Google Cloud control plane finds a more optimal route for a prefix than a route learned by this Cloud Router. Corresponds to the JSON property bestRoutesForRouter



56202
56203
56204
# File 'lib/google/apis/compute_beta/classes.rb', line 56202

def best_routes_for_router
  @best_routes_for_router
end

#bgp_peer_statusArray<Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus>

Corresponds to the JSON property bgpPeerStatus



56207
56208
56209
# File 'lib/google/apis/compute_beta/classes.rb', line 56207

def bgp_peer_status
  @bgp_peer_status
end

#nat_statusArray<Google::Apis::ComputeBeta::RouterStatusNatStatus>

Corresponds to the JSON property natStatus



56212
56213
56214
# File 'lib/google/apis/compute_beta/classes.rb', line 56212

def nat_status
  @nat_status
end

#ncc_gatewayString

URI of the ncc_gateway to which this router associated. Corresponds to the JSON property nccGateway

Returns:

  • (String)


56217
56218
56219
# File 'lib/google/apis/compute_beta/classes.rb', line 56217

def ncc_gateway
  @ncc_gateway
end

#networkString

URI of the network to which this router belongs. Corresponds to the JSON property network

Returns:

  • (String)


56222
56223
56224
# File 'lib/google/apis/compute_beta/classes.rb', line 56222

def network
  @network
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56229
56230
56231
56232
56233
56234
56235
56236
# File 'lib/google/apis/compute_beta/classes.rb', line 56229

def update!(**args)
  @best_routes = args[:best_routes] if args.key?(:best_routes)
  @best_routes_for_router = args[:best_routes_for_router] if args.key?(:best_routes_for_router)
  @bgp_peer_status = args[:bgp_peer_status] if args.key?(:bgp_peer_status)
  @nat_status = args[:nat_status] if args.key?(:nat_status)
  @ncc_gateway = args[:ncc_gateway] if args.key?(:ncc_gateway)
  @network = args[:network] if args.key?(:network)
end