Class: Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RouterStatusBgpPeerStatus

Returns a new instance of RouterStatusBgpPeerStatus.



58481
58482
58483
# File 'lib/google/apis/compute_beta/classes.rb', line 58481

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertised_routesArray<Google::Apis::ComputeBeta::Route>

Routes that were advertised to the remote BGP peer Corresponds to the JSON property advertisedRoutes



58369
58370
58371
# File 'lib/google/apis/compute_beta/classes.rb', line 58369

def advertised_routes
  @advertised_routes
end

#bfd_statusGoogle::Apis::ComputeBeta::BfdStatus

Next free: 15 Corresponds to the JSON property bfdStatus



58374
58375
58376
# File 'lib/google/apis/compute_beta/classes.rb', line 58374

def bfd_status
  @bfd_status
end

#enable_ipv4Boolean Also known as: enable_ipv4?

Output only. Enable IPv4 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 4. Corresponds to the JSON property enableIpv4

Returns:

  • (Boolean)


58380
58381
58382
# File 'lib/google/apis/compute_beta/classes.rb', line 58380

def enable_ipv4
  @enable_ipv4
end

#enable_ipv6Boolean Also known as: enable_ipv6?

Output only. Enable IPv6 traffic over BGP Peer. It is enabled by default if the peerIpAddress is version 6. Corresponds to the JSON property enableIpv6

Returns:

  • (Boolean)


58387
58388
58389
# File 'lib/google/apis/compute_beta/classes.rb', line 58387

def enable_ipv6
  @enable_ipv6
end

#ip_addressString

Output only. IP address of the local BGP interface. Corresponds to the JSON property ipAddress

Returns:

  • (String)


58393
58394
58395
# File 'lib/google/apis/compute_beta/classes.rb', line 58393

def ip_address
  @ip_address
end

#ipv4_nexthop_addressString

Output only. IPv4 address of the local BGP interface. Corresponds to the JSON property ipv4NexthopAddress

Returns:

  • (String)


58398
58399
58400
# File 'lib/google/apis/compute_beta/classes.rb', line 58398

def ipv4_nexthop_address
  @ipv4_nexthop_address
end

#ipv6_nexthop_addressString

Output only. IPv6 address of the local BGP interface. Corresponds to the JSON property ipv6NexthopAddress

Returns:

  • (String)


58403
58404
58405
# File 'lib/google/apis/compute_beta/classes.rb', line 58403

def ipv6_nexthop_address
  @ipv6_nexthop_address
end

#linked_vpn_tunnelString

Output only. URL of the VPN tunnel that this BGP peer controls. Corresponds to the JSON property linkedVpnTunnel

Returns:

  • (String)


58408
58409
58410
# File 'lib/google/apis/compute_beta/classes.rb', line 58408

def linked_vpn_tunnel
  @linked_vpn_tunnel
end

#md5_auth_enabledBoolean Also known as: md5_auth_enabled?

Informs whether MD5 authentication is enabled on this BGP peer. Corresponds to the JSON property md5AuthEnabled

Returns:

  • (Boolean)


58413
58414
58415
# File 'lib/google/apis/compute_beta/classes.rb', line 58413

def md5_auth_enabled
  @md5_auth_enabled
end

#nameString

Output only. Name of this BGP peer. Unique within the Routers resource. Corresponds to the JSON property name

Returns:

  • (String)


58419
58420
58421
# File 'lib/google/apis/compute_beta/classes.rb', line 58419

def name
  @name
end

#num_learned_routesFixnum

Output only. Number of routes learned from the remote BGP Peer. Corresponds to the JSON property numLearnedRoutes

Returns:

  • (Fixnum)


58424
58425
58426
# File 'lib/google/apis/compute_beta/classes.rb', line 58424

def num_learned_routes
  @num_learned_routes
end

#peer_ip_addressString

Output only. IP address of the remote BGP interface. Corresponds to the JSON property peerIpAddress

Returns:

  • (String)


58429
58430
58431
# File 'lib/google/apis/compute_beta/classes.rb', line 58429

def peer_ip_address
  @peer_ip_address
end

#peer_ipv4_nexthop_addressString

Output only. IPv4 address of the remote BGP interface. Corresponds to the JSON property peerIpv4NexthopAddress

Returns:

  • (String)


58434
58435
58436
# File 'lib/google/apis/compute_beta/classes.rb', line 58434

def peer_ipv4_nexthop_address
  @peer_ipv4_nexthop_address
end

#peer_ipv6_nexthop_addressString

Output only. IPv6 address of the remote BGP interface. Corresponds to the JSON property peerIpv6NexthopAddress

Returns:

  • (String)


58439
58440
58441
# File 'lib/google/apis/compute_beta/classes.rb', line 58439

def peer_ipv6_nexthop_address
  @peer_ipv6_nexthop_address
end

#router_appliance_instanceString

Output only. [Output only] URI of the VM instance that is used as third-party router appliances such as Next Gen Firewalls, Virtual Routers, or Router Appliances. The VM instance is the peer side of the BGP session. Corresponds to the JSON property routerApplianceInstance

Returns:

  • (String)


58448
58449
58450
# File 'lib/google/apis/compute_beta/classes.rb', line 58448

def router_appliance_instance
  @router_appliance_instance
end

#stateString

Output only. The state of the BGP session. For a list of possible values for this field, seeBGP session states. Corresponds to the JSON property state

Returns:

  • (String)


58455
58456
58457
# File 'lib/google/apis/compute_beta/classes.rb', line 58455

def state
  @state
end

#statusString

Output only. Status of the BGP peer: UP, DOWN Corresponds to the JSON property status

Returns:

  • (String)


58460
58461
58462
# File 'lib/google/apis/compute_beta/classes.rb', line 58460

def status
  @status
end

#status_reasonString

Indicates why particular status was returned. Corresponds to the JSON property statusReason

Returns:

  • (String)


58465
58466
58467
# File 'lib/google/apis/compute_beta/classes.rb', line 58465

def status_reason
  @status_reason
end

#uptimeString

Output only. Time this session has been up. Format: 14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds Corresponds to the JSON property uptime

Returns:

  • (String)


58472
58473
58474
# File 'lib/google/apis/compute_beta/classes.rb', line 58472

def uptime
  @uptime
end

#uptime_secondsString

Output only. Time this session has been up, in seconds. Format: 145 Corresponds to the JSON property uptimeSeconds

Returns:

  • (String)


58479
58480
58481
# File 'lib/google/apis/compute_beta/classes.rb', line 58479

def uptime_seconds
  @uptime_seconds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58486
58487
58488
58489
58490
58491
58492
58493
58494
58495
58496
58497
58498
58499
58500
58501
58502
58503
58504
58505
58506
58507
# File 'lib/google/apis/compute_beta/classes.rb', line 58486

def update!(**args)
  @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes)
  @bfd_status = args[:bfd_status] if args.key?(:bfd_status)
  @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4)
  @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6)
  @ip_address = args[:ip_address] if args.key?(:ip_address)
  @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address)
  @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address)
  @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel)
  @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled)
  @name = args[:name] if args.key?(:name)
  @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes)
  @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address)
  @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address)
  @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address)
  @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance)
  @state = args[:state] if args.key?(:state)
  @status = args[:status] if args.key?(:status)
  @status_reason = args[:status_reason] if args.key?(:status_reason)
  @uptime = args[:uptime] if args.key?(:uptime)
  @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds)
end