Class: Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RouterStatusBgpPeerStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#advertised_routes ⇒ Array<Google::Apis::ComputeBeta::Route>
Routes that were advertised to the remote BGP peer Corresponds to the JSON property
advertisedRoutes. -
#bfd_status ⇒ Google::Apis::ComputeBeta::BfdStatus
Next free: 15 Corresponds to the JSON property
bfdStatus. -
#enable_ipv4 ⇒ Boolean
(also: #enable_ipv4?)
Output only.
-
#enable_ipv6 ⇒ Boolean
(also: #enable_ipv6?)
Output only.
-
#ip_address ⇒ String
Output only.
-
#ipv4_nexthop_address ⇒ String
Output only.
-
#ipv6_nexthop_address ⇒ String
Output only.
-
#linked_vpn_tunnel ⇒ String
Output only.
-
#md5_auth_enabled ⇒ Boolean
(also: #md5_auth_enabled?)
Informs whether MD5 authentication is enabled on this BGP peer.
-
#name ⇒ String
Output only.
-
#num_learned_routes ⇒ Fixnum
Output only.
-
#peer_ip_address ⇒ String
Output only.
-
#peer_ipv4_nexthop_address ⇒ String
Output only.
-
#peer_ipv6_nexthop_address ⇒ String
Output only.
-
#router_appliance_instance ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#status ⇒ String
Output only.
-
#status_reason ⇒ String
Indicates why particular status was returned.
-
#uptime ⇒ String
Output only.
-
#uptime_seconds ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
constructor
A new instance of RouterStatusBgpPeerStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RouterStatusBgpPeerStatus
Returns a new instance of RouterStatusBgpPeerStatus.
55175 55176 55177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55175 def initialize(**args) update!(**args) end |
Instance Attribute Details
#advertised_routes ⇒ Array<Google::Apis::ComputeBeta::Route>
Routes that were advertised to the remote BGP peer
Corresponds to the JSON property advertisedRoutes
55063 55064 55065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55063 def advertised_routes @advertised_routes end |
#bfd_status ⇒ Google::Apis::ComputeBeta::BfdStatus
Next free: 15
Corresponds to the JSON property bfdStatus
55068 55069 55070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55068 def bfd_status @bfd_status end |
#enable_ipv4 ⇒ Boolean Also known as: enable_ipv4?
Output only. Enable IPv4 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 4.
Corresponds to the JSON property enableIpv4
55074 55075 55076 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55074 def enable_ipv4 @enable_ipv4 end |
#enable_ipv6 ⇒ Boolean Also known as: enable_ipv6?
Output only. Enable IPv6 traffic over BGP Peer.
It is enabled by default if the peerIpAddress is version 6.
Corresponds to the JSON property enableIpv6
55081 55082 55083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55081 def enable_ipv6 @enable_ipv6 end |
#ip_address ⇒ String
Output only. IP address of the local BGP interface.
Corresponds to the JSON property ipAddress
55087 55088 55089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55087 def ip_address @ip_address end |
#ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the local BGP interface.
Corresponds to the JSON property ipv4NexthopAddress
55092 55093 55094 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55092 def ipv4_nexthop_address @ipv4_nexthop_address end |
#ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the local BGP interface.
Corresponds to the JSON property ipv6NexthopAddress
55097 55098 55099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55097 def ipv6_nexthop_address @ipv6_nexthop_address end |
#linked_vpn_tunnel ⇒ String
Output only. URL of the VPN tunnel that this BGP peer controls.
Corresponds to the JSON property linkedVpnTunnel
55102 55103 55104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55102 def linked_vpn_tunnel @linked_vpn_tunnel end |
#md5_auth_enabled ⇒ Boolean Also known as: md5_auth_enabled?
Informs whether MD5 authentication is enabled on this BGP peer.
Corresponds to the JSON property md5AuthEnabled
55107 55108 55109 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55107 def md5_auth_enabled @md5_auth_enabled end |
#name ⇒ String
Output only. Name of this BGP peer. Unique within the Routers resource.
Corresponds to the JSON property name
55113 55114 55115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55113 def name @name end |
#num_learned_routes ⇒ Fixnum
Output only. Number of routes learned from the remote BGP Peer.
Corresponds to the JSON property numLearnedRoutes
55118 55119 55120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55118 def num_learned_routes @num_learned_routes end |
#peer_ip_address ⇒ String
Output only. IP address of the remote BGP interface.
Corresponds to the JSON property peerIpAddress
55123 55124 55125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55123 def peer_ip_address @peer_ip_address end |
#peer_ipv4_nexthop_address ⇒ String
Output only. IPv4 address of the remote BGP interface.
Corresponds to the JSON property peerIpv4NexthopAddress
55128 55129 55130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55128 def peer_ipv4_nexthop_address @peer_ipv4_nexthop_address end |
#peer_ipv6_nexthop_address ⇒ String
Output only. IPv6 address of the remote BGP interface.
Corresponds to the JSON property peerIpv6NexthopAddress
55133 55134 55135 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55133 def peer_ipv6_nexthop_address @peer_ipv6_nexthop_address end |
#router_appliance_instance ⇒ String
Output only. [Output only] URI of the VM instance that is used as third-party
router
appliances such as Next Gen Firewalls, Virtual Routers, or Router
Appliances.
The VM instance is the peer side of the BGP session.
Corresponds to the JSON property routerApplianceInstance
55142 55143 55144 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55142 def router_appliance_instance @router_appliance_instance end |
#state ⇒ String
Output only. The state of the BGP session. For a list of possible values for
this
field, seeBGP session states.
Corresponds to the JSON property state
55149 55150 55151 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55149 def state @state end |
#status ⇒ String
Output only. Status of the BGP peer: UP, DOWN
Corresponds to the JSON property status
55154 55155 55156 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55154 def status @status end |
#status_reason ⇒ String
Indicates why particular status was returned.
Corresponds to the JSON property statusReason
55159 55160 55161 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55159 def status_reason @status_reason end |
#uptime ⇒ String
Output only. Time this session has been up.
Format:
14 years, 51 weeks, 6 days, 23 hours, 59 minutes, 59 seconds
Corresponds to the JSON property uptime
55166 55167 55168 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55166 def uptime @uptime end |
#uptime_seconds ⇒ String
Output only. Time this session has been up, in seconds.
Format:
145
Corresponds to the JSON property uptimeSeconds
55173 55174 55175 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55173 def uptime_seconds @uptime_seconds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55180 55181 55182 55183 55184 55185 55186 55187 55188 55189 55190 55191 55192 55193 55194 55195 55196 55197 55198 55199 55200 55201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55180 def update!(**args) @advertised_routes = args[:advertised_routes] if args.key?(:advertised_routes) @bfd_status = args[:bfd_status] if args.key?(:bfd_status) @enable_ipv4 = args[:enable_ipv4] if args.key?(:enable_ipv4) @enable_ipv6 = args[:enable_ipv6] if args.key?(:enable_ipv6) @ip_address = args[:ip_address] if args.key?(:ip_address) @ipv4_nexthop_address = args[:ipv4_nexthop_address] if args.key?(:ipv4_nexthop_address) @ipv6_nexthop_address = args[:ipv6_nexthop_address] if args.key?(:ipv6_nexthop_address) @linked_vpn_tunnel = args[:linked_vpn_tunnel] if args.key?(:linked_vpn_tunnel) @md5_auth_enabled = args[:md5_auth_enabled] if args.key?(:md5_auth_enabled) @name = args[:name] if args.key?(:name) @num_learned_routes = args[:num_learned_routes] if args.key?(:num_learned_routes) @peer_ip_address = args[:peer_ip_address] if args.key?(:peer_ip_address) @peer_ipv4_nexthop_address = args[:peer_ipv4_nexthop_address] if args.key?(:peer_ipv4_nexthop_address) @peer_ipv6_nexthop_address = args[:peer_ipv6_nexthop_address] if args.key?(:peer_ipv6_nexthop_address) @router_appliance_instance = args[:router_appliance_instance] if args.key?(:router_appliance_instance) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @status_reason = args[:status_reason] if args.key?(:status_reason) @uptime = args[:uptime] if args.key?(:uptime) @uptime_seconds = args[:uptime_seconds] if args.key?(:uptime_seconds) end |