Class: Google::Apis::ComputeBeta::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
58787 58788 58789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58787 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
58743 58744 58745 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58743 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58749 58750 58751 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58749 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
58755 58756 58757 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58755 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58765 58766 58767 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58765 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
58770 58771 58772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58770 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58775 58776 58777 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58775 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58780 58781 58782 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58780 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58785 58786 58787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58785 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58792 58793 58794 58795 58796 58797 58798 58799 58800 58801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58792 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |