Class: Google::Apis::ComputeBeta::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



58321
58322
58323
# File 'lib/google/apis/compute_beta/classes.rb', line 58321

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58277
58278
58279
# File 'lib/google/apis/compute_beta/classes.rb', line 58277

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58283
58284
58285
# File 'lib/google/apis/compute_beta/classes.rb', line 58283

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


58289
58290
58291
# File 'lib/google/apis/compute_beta/classes.rb', line 58289

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58299
58300
58301
# File 'lib/google/apis/compute_beta/classes.rb', line 58299

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



58304
58305
58306
# File 'lib/google/apis/compute_beta/classes.rb', line 58304

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58309
58310
58311
# File 'lib/google/apis/compute_beta/classes.rb', line 58309

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58314
58315
58316
# File 'lib/google/apis/compute_beta/classes.rb', line 58314

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58319
58320
58321
# File 'lib/google/apis/compute_beta/classes.rb', line 58319

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58326
58327
58328
58329
58330
58331
58332
58333
58334
58335
# File 'lib/google/apis/compute_beta/classes.rb', line 58326

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end