Class: Google::Apis::ComputeBeta::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



57511
57512
57513
# File 'lib/google/apis/compute_beta/classes.rb', line 57511

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


57467
57468
57469
# File 'lib/google/apis/compute_beta/classes.rb', line 57467

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57473
57474
57475
# File 'lib/google/apis/compute_beta/classes.rb', line 57473

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


57479
57480
57481
# File 'lib/google/apis/compute_beta/classes.rb', line 57479

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57489
57490
57491
# File 'lib/google/apis/compute_beta/classes.rb', line 57489

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



57494
57495
57496
# File 'lib/google/apis/compute_beta/classes.rb', line 57494

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57499
57500
57501
# File 'lib/google/apis/compute_beta/classes.rb', line 57499

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


57504
57505
57506
# File 'lib/google/apis/compute_beta/classes.rb', line 57504

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57509
57510
57511
# File 'lib/google/apis/compute_beta/classes.rb', line 57509

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57516
57517
57518
57519
57520
57521
57522
57523
57524
57525
# File 'lib/google/apis/compute_beta/classes.rb', line 57516

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end