Class: Google::Apis::ComputeBeta::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
57452 57453 57454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57452 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
57408 57409 57410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57408 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
57414 57415 57416 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57414 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
57420 57421 57422 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57420 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
57430 57431 57432 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57430 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
57435 57436 57437 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57435 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
57440 57441 57442 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57440 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
57445 57446 57447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57445 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
57450 57451 57452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57450 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57457 57458 57459 57460 57461 57462 57463 57464 57465 57466 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57457 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |