Class: Google::Apis::ComputeBeta::RoutersListBgpRoutes
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListBgpRoutes
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::BgpRoute>
[Output Only] A list of bgp routes.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListBgpRoutes
constructor
A new instance of RoutersListBgpRoutes.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListBgpRoutes
Returns a new instance of RoutersListBgpRoutes.
56632 56633 56634 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56632 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
56588 56589 56590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56588 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
56594 56595 56596 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56594 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListBgpRoutes for lists of bgp routes.
Corresponds to the JSON property kind
56600 56601 56602 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56600 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
56610 56611 56612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56610 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::BgpRoute>
[Output Only] A list of bgp routes.
Corresponds to the JSON property result
56615 56616 56617 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56615 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
56620 56621 56622 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56620 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
56625 56626 56627 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56625 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListBgpRoutes::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
56630 56631 56632 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56630 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56637 56638 56639 56640 56641 56642 56643 56644 56645 56646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56637 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |