Class: Google::Apis::ComputeBeta::RoutersListBgpRoutes

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListBgpRoutes

Returns a new instance of RoutersListBgpRoutes.



53693
53694
53695
# File 'lib/google/apis/compute_beta/classes.rb', line 53693

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


53649
53650
53651
# File 'lib/google/apis/compute_beta/classes.rb', line 53649

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


53655
53656
53657
# File 'lib/google/apis/compute_beta/classes.rb', line 53655

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListBgpRoutes for lists of bgp routes. Corresponds to the JSON property kind

Returns:

  • (String)


53661
53662
53663
# File 'lib/google/apis/compute_beta/classes.rb', line 53661

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


53671
53672
53673
# File 'lib/google/apis/compute_beta/classes.rb', line 53671

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::BgpRoute>

[Output Only] A list of bgp routes. Corresponds to the JSON property result



53676
53677
53678
# File 'lib/google/apis/compute_beta/classes.rb', line 53676

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


53681
53682
53683
# File 'lib/google/apis/compute_beta/classes.rb', line 53681

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


53686
53687
53688
# File 'lib/google/apis/compute_beta/classes.rb', line 53686

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListBgpRoutes::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



53691
53692
53693
# File 'lib/google/apis/compute_beta/classes.rb', line 53691

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



53698
53699
53700
53701
53702
53703
53704
53705
53706
53707
# File 'lib/google/apis/compute_beta/classes.rb', line 53698

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end