Class: Google::Apis::ComputeBeta::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
59399 59400 59401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59399 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
59355 59356 59357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59355 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
59361 59362 59363 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59361 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
59367 59368 59369 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59367 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59377 59378 59379 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59377 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
59382 59383 59384 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59382 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59387 59388 59389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59387 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59392 59393 59394 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59392 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59397 59398 59399 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59397 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59404 59405 59406 59407 59408 59409 59410 59411 59412 59413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59404 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |