Class: Google::Apis::ComputeBeta::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
59000 59001 59002 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59000 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
58956 58957 58958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58956 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58962 58963 58964 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58962 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
58968 58969 58970 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58968 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58978 58979 58980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58978 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
58983 58984 58985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58983 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58988 58989 58990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58988 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58993 58994 58995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58993 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58998 58999 59000 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58998 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59005 59006 59007 59008 59009 59010 59011 59012 59013 59014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59005 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |