Class: Google::Apis::ComputeBeta::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



58893
58894
58895
# File 'lib/google/apis/compute_beta/classes.rb', line 58893

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58849
58850
58851
# File 'lib/google/apis/compute_beta/classes.rb', line 58849

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58855
58856
58857
# File 'lib/google/apis/compute_beta/classes.rb', line 58855

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


58861
58862
58863
# File 'lib/google/apis/compute_beta/classes.rb', line 58861

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58871
58872
58873
# File 'lib/google/apis/compute_beta/classes.rb', line 58871

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



58876
58877
58878
# File 'lib/google/apis/compute_beta/classes.rb', line 58876

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58881
58882
58883
# File 'lib/google/apis/compute_beta/classes.rb', line 58881

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58886
58887
58888
# File 'lib/google/apis/compute_beta/classes.rb', line 58886

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58891
58892
58893
# File 'lib/google/apis/compute_beta/classes.rb', line 58891

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58898
58899
58900
58901
58902
58903
58904
58905
58906
58907
# File 'lib/google/apis/compute_beta/classes.rb', line 58898

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end