Class: Google::Apis::ComputeBeta::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
58459 58460 58461 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
58415 58416 58417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58415 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58421 58422 58423 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58421 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
58427 58428 58429 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58427 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58437 58438 58439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58437 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
58442 58443 58444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58442 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58447 58448 58449 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58447 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58452 58453 58454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58452 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58457 58458 58459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58457 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58464 58465 58466 58467 58468 58469 58470 58471 58472 58473 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58464 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |