Class: Google::Apis::ComputeBeta::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
58436 58437 58438 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58436 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
58392 58393 58394 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58392 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58398 58399 58400 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58398 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
58404 58405 58406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58404 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
58414 58415 58416 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58414 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
58419 58420 58421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58419 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
58424 58425 58426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58424 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
58429 58430 58431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58429 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
58434 58435 58436 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58434 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58441 58442 58443 58444 58445 58446 58447 58448 58449 58450 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58441 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |