Class: Google::Apis::ComputeBeta::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



57649
57650
57651
# File 'lib/google/apis/compute_beta/classes.rb', line 57649

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


57605
57606
57607
# File 'lib/google/apis/compute_beta/classes.rb', line 57605

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57611
57612
57613
# File 'lib/google/apis/compute_beta/classes.rb', line 57611

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


57617
57618
57619
# File 'lib/google/apis/compute_beta/classes.rb', line 57617

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57627
57628
57629
# File 'lib/google/apis/compute_beta/classes.rb', line 57627

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



57632
57633
57634
# File 'lib/google/apis/compute_beta/classes.rb', line 57632

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57637
57638
57639
# File 'lib/google/apis/compute_beta/classes.rb', line 57637

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


57642
57643
57644
# File 'lib/google/apis/compute_beta/classes.rb', line 57642

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57647
57648
57649
# File 'lib/google/apis/compute_beta/classes.rb', line 57647

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57654
57655
57656
57657
57658
57659
57660
57661
57662
57663
# File 'lib/google/apis/compute_beta/classes.rb', line 57654

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end