Class: Google::Apis::ComputeBeta::RoutersListNamedSets

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListNamedSets

Returns a new instance of RoutersListNamedSets.



56770
56771
56772
# File 'lib/google/apis/compute_beta/classes.rb', line 56770

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


56726
56727
56728
# File 'lib/google/apis/compute_beta/classes.rb', line 56726

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


56732
56733
56734
# File 'lib/google/apis/compute_beta/classes.rb', line 56732

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListNamedSets for lists of named sets. Corresponds to the JSON property kind

Returns:

  • (String)


56738
56739
56740
# File 'lib/google/apis/compute_beta/classes.rb', line 56738

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


56748
56749
56750
# File 'lib/google/apis/compute_beta/classes.rb', line 56748

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::NamedSet>

[Output Only] A list of named sets. Corresponds to the JSON property result



56753
56754
56755
# File 'lib/google/apis/compute_beta/classes.rb', line 56753

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56758
56759
56760
# File 'lib/google/apis/compute_beta/classes.rb', line 56758

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


56763
56764
56765
# File 'lib/google/apis/compute_beta/classes.rb', line 56763

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListNamedSets::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



56768
56769
56770
# File 'lib/google/apis/compute_beta/classes.rb', line 56768

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56775
56776
56777
56778
56779
56780
56781
56782
56783
56784
# File 'lib/google/apis/compute_beta/classes.rb', line 56775

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end