Class: Google::Apis::ComputeBeta::RoutersListNamedSets
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListNamedSets
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListNamedSets
constructor
A new instance of RoutersListNamedSets.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListNamedSets
Returns a new instance of RoutersListNamedSets.
55587 55588 55589 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55587 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
55543 55544 55545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55543 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
55549 55550 55551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55549 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListNamedSets for lists of named sets.
Corresponds to the JSON property kind
55555 55556 55557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55555 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55565 55566 55567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55565 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::NamedSet>
[Output Only] A list of named sets.
Corresponds to the JSON property result
55570 55571 55572 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55570 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55575 55576 55577 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55575 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
55580 55581 55582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55580 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListNamedSets::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55585 55586 55587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55585 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55592 55593 55594 55595 55596 55597 55598 55599 55600 55601 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55592 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |