Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



59063
59064
59065
# File 'lib/google/apis/compute_beta/classes.rb', line 59063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


59019
59020
59021
# File 'lib/google/apis/compute_beta/classes.rb', line 59019

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59025
59026
59027
# File 'lib/google/apis/compute_beta/classes.rb', line 59025

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


59031
59032
59033
# File 'lib/google/apis/compute_beta/classes.rb', line 59031

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59041
59042
59043
# File 'lib/google/apis/compute_beta/classes.rb', line 59041

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



59046
59047
59048
# File 'lib/google/apis/compute_beta/classes.rb', line 59046

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59051
59052
59053
# File 'lib/google/apis/compute_beta/classes.rb', line 59051

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59056
59057
59058
# File 'lib/google/apis/compute_beta/classes.rb', line 59056

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59061
59062
59063
# File 'lib/google/apis/compute_beta/classes.rb', line 59061

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59068
59069
59070
59071
59072
59073
59074
59075
59076
59077
# File 'lib/google/apis/compute_beta/classes.rb', line 59068

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end