Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
59031 59032 59033 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59031 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
58987 58988 58989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58987 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
58993 58994 58995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58993 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
58999 59000 59001 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58999 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59009 59010 59011 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59009 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
59014 59015 59016 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59014 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59019 59020 59021 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59019 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59024 59025 59026 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59024 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59029 59030 59031 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59029 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59036 59037 59038 59039 59040 59041 59042 59043 59044 59045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59036 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |