Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



58597
58598
58599
# File 'lib/google/apis/compute_beta/classes.rb', line 58597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58553
58554
58555
# File 'lib/google/apis/compute_beta/classes.rb', line 58553

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58559
58560
58561
# File 'lib/google/apis/compute_beta/classes.rb', line 58559

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


58565
58566
58567
# File 'lib/google/apis/compute_beta/classes.rb', line 58565

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58575
58576
58577
# File 'lib/google/apis/compute_beta/classes.rb', line 58575

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



58580
58581
58582
# File 'lib/google/apis/compute_beta/classes.rb', line 58580

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58585
58586
58587
# File 'lib/google/apis/compute_beta/classes.rb', line 58585

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58590
58591
58592
# File 'lib/google/apis/compute_beta/classes.rb', line 58590

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58595
58596
58597
# File 'lib/google/apis/compute_beta/classes.rb', line 58595

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58602
58603
58604
58605
58606
58607
58608
58609
58610
58611
# File 'lib/google/apis/compute_beta/classes.rb', line 58602

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end