Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



58574
58575
58576
# File 'lib/google/apis/compute_beta/classes.rb', line 58574

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58530
58531
58532
# File 'lib/google/apis/compute_beta/classes.rb', line 58530

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58536
58537
58538
# File 'lib/google/apis/compute_beta/classes.rb', line 58536

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


58542
58543
58544
# File 'lib/google/apis/compute_beta/classes.rb', line 58542

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58552
58553
58554
# File 'lib/google/apis/compute_beta/classes.rb', line 58552

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



58557
58558
58559
# File 'lib/google/apis/compute_beta/classes.rb', line 58557

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58562
58563
58564
# File 'lib/google/apis/compute_beta/classes.rb', line 58562

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58567
58568
58569
# File 'lib/google/apis/compute_beta/classes.rb', line 58567

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58572
58573
58574
# File 'lib/google/apis/compute_beta/classes.rb', line 58572

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58579
58580
58581
58582
58583
58584
58585
58586
58587
58588
# File 'lib/google/apis/compute_beta/classes.rb', line 58579

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end