Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RoutersListRoutePolicies

Returns a new instance of RoutersListRoutePolicies.



57787
57788
57789
# File 'lib/google/apis/compute_beta/classes.rb', line 57787

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


57743
57744
57745
# File 'lib/google/apis/compute_beta/classes.rb', line 57743

def etag
  @etag
end

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57749
57750
57751
# File 'lib/google/apis/compute_beta/classes.rb', line 57749

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# routersListRoutePolicies for lists of route policies. Corresponds to the JSON property kind

Returns:

  • (String)


57755
57756
57757
# File 'lib/google/apis/compute_beta/classes.rb', line 57755

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57765
57766
57767
# File 'lib/google/apis/compute_beta/classes.rb', line 57765

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::RoutePolicy>

[Output Only] A list of route policies. Corresponds to the JSON property result



57770
57771
57772
# File 'lib/google/apis/compute_beta/classes.rb', line 57770

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57775
57776
57777
# File 'lib/google/apis/compute_beta/classes.rb', line 57775

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


57780
57781
57782
# File 'lib/google/apis/compute_beta/classes.rb', line 57780

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::RoutersListRoutePolicies::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57785
57786
57787
# File 'lib/google/apis/compute_beta/classes.rb', line 57785

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57792
57793
57794
57795
57796
57797
57798
57799
57800
57801
# File 'lib/google/apis/compute_beta/classes.rb', line 57792

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end