Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
55725 55726 55727 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55725 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
55681 55682 55683 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55681 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
55687 55688 55689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55687 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
55693 55694 55695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55693 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
55703 55704 55705 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55703 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
55708 55709 55710 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55708 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
55713 55714 55715 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55713 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
55718 55719 55720 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55718 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
55723 55724 55725 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55723 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55730 55731 55732 55733 55734 55735 55736 55737 55738 55739 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55730 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |