Class: Google::Apis::ComputeBeta::RoutersListRoutePolicies
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersListRoutePolicies
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::RoutePolicy>
[Output Only] A list of route policies.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersListRoutePolicies
constructor
A new instance of RoutersListRoutePolicies.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersListRoutePolicies
Returns a new instance of RoutersListRoutePolicies.
53831 53832 53833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53831 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
53787 53788 53789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53787 def etag @etag end |
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
53793 53794 53795 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53793 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
routersListRoutePolicies for lists of route policies.
Corresponds to the JSON property kind
53799 53800 53801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53799 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
53809 53810 53811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53809 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::RoutePolicy>
[Output Only] A list of route policies.
Corresponds to the JSON property result
53814 53815 53816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53814 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
53819 53820 53821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53819 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
53824 53825 53826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53824 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersListRoutePolicies::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
53829 53830 53831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53829 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
53836 53837 53838 53839 53840 53841 53842 53843 53844 53845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 53836 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |