Class: Google::Apis::ComputeBeta::RoutersScopedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::RoutersScopedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#routers ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of routers contained in this scope.
-
#warning ⇒ Google::Apis::ComputeBeta::RoutersScopedList::Warning
Informational warning which replaces the list of routers when the list is empty.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RoutersScopedList
constructor
A new instance of RoutersScopedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RoutersScopedList
Returns a new instance of RoutersScopedList.
57851 57852 57853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57851 def initialize(**args) update!(**args) end |
Instance Attribute Details
#routers ⇒ Array<Google::Apis::ComputeBeta::Router>
A list of routers contained in this scope.
Corresponds to the JSON property routers
57843 57844 57845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57843 def routers @routers end |
#warning ⇒ Google::Apis::ComputeBeta::RoutersScopedList::Warning
Informational warning which replaces the list of routers when
the list is empty.
Corresponds to the JSON property warning
57849 57850 57851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57849 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57856 57857 57858 57859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57856 def update!(**args) @routers = args[:routers] if args.key?(:routers) @warning = args[:warning] if args.key?(:warning) end |