Class: Google::Apis::ComputeBeta::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedAttachedDisk

Returns a new instance of SavedAttachedDisk.



59422
59423
59424
# File 'lib/google/apis/compute_beta/classes.rb', line 59422

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


59326
59327
59328
# File 'lib/google/apis/compute_beta/classes.rb', line 59326

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


59333
59334
59335
# File 'lib/google/apis/compute_beta/classes.rb', line 59333

def boot
  @boot
end

#device_nameString

Specifies the name of the disk attached to the source instance. Corresponds to the JSON property deviceName

Returns:

  • (String)


59339
59340
59341
# File 'lib/google/apis/compute_beta/classes.rb', line 59339

def device_name
  @device_name
end

#disk_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

The encryption key for the disk. Corresponds to the JSON property diskEncryptionKey



59344
59345
59346
# File 'lib/google/apis/compute_beta/classes.rb', line 59344

def disk_encryption_key
  @disk_encryption_key
end

#disk_size_gbFixnum

The size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


59349
59350
59351
# File 'lib/google/apis/compute_beta/classes.rb', line 59349

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Output only. [Output Only] URL of the disk type resource. For example:projects/ project/zones/zone/diskTypes/pd-standard or pd-ssd Corresponds to the JSON property diskType

Returns:

  • (String)


59356
59357
59358
# File 'lib/google/apis/compute_beta/classes.rb', line 59356

def disk_type
  @disk_type
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



59364
59365
59366
# File 'lib/google/apis/compute_beta/classes.rb', line 59364

def guest_os_features
  @guest_os_features
end

#indexFixnum

Output only. Specifies zero-based index of the disk that is attached to the source instance. Corresponds to the JSON property index

Returns:

  • (Fixnum)


59371
59372
59373
# File 'lib/google/apis/compute_beta/classes.rb', line 59371

def index
  @index
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Corresponds to the JSON property interface

Returns:

  • (String)


59377
59378
59379
# File 'lib/google/apis/compute_beta/classes.rb', line 59377

def interface
  @interface
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


59383
59384
59385
# File 'lib/google/apis/compute_beta/classes.rb', line 59383

def kind
  @kind
end

#licensesArray<String>

Output only. [Output Only] Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


59388
59389
59390
# File 'lib/google/apis/compute_beta/classes.rb', line 59388

def licenses
  @licenses
end

#modeString

The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Corresponds to the JSON property mode

Returns:

  • (String)


59394
59395
59396
# File 'lib/google/apis/compute_beta/classes.rb', line 59394

def mode
  @mode
end

#sourceString

Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property source

Returns:

  • (String)


59399
59400
59401
# File 'lib/google/apis/compute_beta/classes.rb', line 59399

def source
  @source
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


59406
59407
59408
# File 'lib/google/apis/compute_beta/classes.rb', line 59406

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


59415
59416
59417
# File 'lib/google/apis/compute_beta/classes.rb', line 59415

def storage_bytes_status
  @storage_bytes_status
end

#typeString

Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Corresponds to the JSON property type

Returns:

  • (String)


59420
59421
59422
# File 'lib/google/apis/compute_beta/classes.rb', line 59420

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59427
59428
59429
59430
59431
59432
59433
59434
59435
59436
59437
59438
59439
59440
59441
59442
59443
59444
# File 'lib/google/apis/compute_beta/classes.rb', line 59427

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @type = args[:type] if args.key?(:type)
end