Class: Google::Apis::ComputeBeta::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedAttachedDisk

Returns a new instance of SavedAttachedDisk.



58988
58989
58990
# File 'lib/google/apis/compute_beta/classes.rb', line 58988

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


58892
58893
58894
# File 'lib/google/apis/compute_beta/classes.rb', line 58892

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


58899
58900
58901
# File 'lib/google/apis/compute_beta/classes.rb', line 58899

def boot
  @boot
end

#device_nameString

Specifies the name of the disk attached to the source instance. Corresponds to the JSON property deviceName

Returns:

  • (String)


58905
58906
58907
# File 'lib/google/apis/compute_beta/classes.rb', line 58905

def device_name
  @device_name
end

#disk_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

The encryption key for the disk. Corresponds to the JSON property diskEncryptionKey



58910
58911
58912
# File 'lib/google/apis/compute_beta/classes.rb', line 58910

def disk_encryption_key
  @disk_encryption_key
end

#disk_size_gbFixnum

The size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


58915
58916
58917
# File 'lib/google/apis/compute_beta/classes.rb', line 58915

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Output only. [Output Only] URL of the disk type resource. For example:projects/ project/zones/zone/diskTypes/pd-standard or pd-ssd Corresponds to the JSON property diskType

Returns:

  • (String)


58922
58923
58924
# File 'lib/google/apis/compute_beta/classes.rb', line 58922

def disk_type
  @disk_type
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



58930
58931
58932
# File 'lib/google/apis/compute_beta/classes.rb', line 58930

def guest_os_features
  @guest_os_features
end

#indexFixnum

Output only. Specifies zero-based index of the disk that is attached to the source instance. Corresponds to the JSON property index

Returns:

  • (Fixnum)


58937
58938
58939
# File 'lib/google/apis/compute_beta/classes.rb', line 58937

def index
  @index
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Corresponds to the JSON property interface

Returns:

  • (String)


58943
58944
58945
# File 'lib/google/apis/compute_beta/classes.rb', line 58943

def interface
  @interface
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


58949
58950
58951
# File 'lib/google/apis/compute_beta/classes.rb', line 58949

def kind
  @kind
end

#licensesArray<String>

Output only. [Output Only] Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


58954
58955
58956
# File 'lib/google/apis/compute_beta/classes.rb', line 58954

def licenses
  @licenses
end

#modeString

The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Corresponds to the JSON property mode

Returns:

  • (String)


58960
58961
58962
# File 'lib/google/apis/compute_beta/classes.rb', line 58960

def mode
  @mode
end

#sourceString

Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property source

Returns:

  • (String)


58965
58966
58967
# File 'lib/google/apis/compute_beta/classes.rb', line 58965

def source
  @source
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


58972
58973
58974
# File 'lib/google/apis/compute_beta/classes.rb', line 58972

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


58981
58982
58983
# File 'lib/google/apis/compute_beta/classes.rb', line 58981

def storage_bytes_status
  @storage_bytes_status
end

#typeString

Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Corresponds to the JSON property type

Returns:

  • (String)


58986
58987
58988
# File 'lib/google/apis/compute_beta/classes.rb', line 58986

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58993
58994
58995
58996
58997
58998
58999
59000
59001
59002
59003
59004
59005
59006
59007
59008
59009
59010
# File 'lib/google/apis/compute_beta/classes.rb', line 58993

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @type = args[:type] if args.key?(:type)
end