Class: Google::Apis::ComputeBeta::SavedAttachedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

DEPRECATED: Please use compute#savedDisk instead. An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedAttachedDisk

Returns a new instance of SavedAttachedDisk.



57299
57300
57301
# File 'lib/google/apis/compute_beta/classes.rb', line 57299

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deleteBoolean Also known as: auto_delete?

Specifies whether the disk will be auto-deleted when the instance is deleted (but not when the disk is detached from the instance). Corresponds to the JSON property autoDelete

Returns:

  • (Boolean)


57203
57204
57205
# File 'lib/google/apis/compute_beta/classes.rb', line 57203

def auto_delete
  @auto_delete
end

#bootBoolean Also known as: boot?

Indicates that this is a boot disk. The virtual machine will use the first partition of the disk for its root filesystem. Corresponds to the JSON property boot

Returns:

  • (Boolean)


57210
57211
57212
# File 'lib/google/apis/compute_beta/classes.rb', line 57210

def boot
  @boot
end

#device_nameString

Specifies the name of the disk attached to the source instance. Corresponds to the JSON property deviceName

Returns:

  • (String)


57216
57217
57218
# File 'lib/google/apis/compute_beta/classes.rb', line 57216

def device_name
  @device_name
end

#disk_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

The encryption key for the disk. Corresponds to the JSON property diskEncryptionKey



57221
57222
57223
# File 'lib/google/apis/compute_beta/classes.rb', line 57221

def disk_encryption_key
  @disk_encryption_key
end

#disk_size_gbFixnum

The size of the disk in base-2 GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


57226
57227
57228
# File 'lib/google/apis/compute_beta/classes.rb', line 57226

def disk_size_gb
  @disk_size_gb
end

#disk_typeString

Output only. [Output Only] URL of the disk type resource. For example:projects/ project/zones/zone/diskTypes/pd-standard or pd-ssd Corresponds to the JSON property diskType

Returns:

  • (String)


57233
57234
57235
# File 'lib/google/apis/compute_beta/classes.rb', line 57233

def disk_type
  @disk_type
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



57241
57242
57243
# File 'lib/google/apis/compute_beta/classes.rb', line 57241

def guest_os_features
  @guest_os_features
end

#indexFixnum

Output only. Specifies zero-based index of the disk that is attached to the source instance. Corresponds to the JSON property index

Returns:

  • (Fixnum)


57248
57249
57250
# File 'lib/google/apis/compute_beta/classes.rb', line 57248

def index
  @index
end

#interfaceString

Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME. Corresponds to the JSON property interface

Returns:

  • (String)


57254
57255
57256
# File 'lib/google/apis/compute_beta/classes.rb', line 57254

def interface
  @interface
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#attachedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


57260
57261
57262
# File 'lib/google/apis/compute_beta/classes.rb', line 57260

def kind
  @kind
end

#licensesArray<String>

Output only. [Output Only] Any valid publicly visible licenses. Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


57265
57266
57267
# File 'lib/google/apis/compute_beta/classes.rb', line 57265

def licenses
  @licenses
end

#modeString

The mode in which this disk is attached to the source instance, eitherREAD_WRITE or READ_ONLY. Corresponds to the JSON property mode

Returns:

  • (String)


57271
57272
57273
# File 'lib/google/apis/compute_beta/classes.rb', line 57271

def mode
  @mode
end

#sourceString

Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property source

Returns:

  • (String)


57276
57277
57278
# File 'lib/google/apis/compute_beta/classes.rb', line 57276

def source
  @source
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the disk's snapshot by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


57283
57284
57285
# File 'lib/google/apis/compute_beta/classes.rb', line 57283

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


57292
57293
57294
# File 'lib/google/apis/compute_beta/classes.rb', line 57292

def storage_bytes_status
  @storage_bytes_status
end

#typeString

Specifies the type of the attached disk, either SCRATCH orPERSISTENT. Corresponds to the JSON property type

Returns:

  • (String)


57297
57298
57299
# File 'lib/google/apis/compute_beta/classes.rb', line 57297

def type
  @type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57304
57305
57306
57307
57308
57309
57310
57311
57312
57313
57314
57315
57316
57317
57318
57319
57320
57321
# File 'lib/google/apis/compute_beta/classes.rb', line 57304

def update!(**args)
  @auto_delete = args[:auto_delete] if args.key?(:auto_delete)
  @boot = args[:boot] if args.key?(:boot)
  @device_name = args[:device_name] if args.key?(:device_name)
  @disk_encryption_key = args[:disk_encryption_key] if args.key?(:disk_encryption_key)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @disk_type = args[:disk_type] if args.key?(:disk_type)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @index = args[:index] if args.key?(:index)
  @interface = args[:interface] if args.key?(:interface)
  @kind = args[:kind] if args.key?(:kind)
  @licenses = args[:licenses] if args.key?(:licenses)
  @mode = args[:mode] if args.key?(:mode)
  @source = args[:source] if args.key?(:source)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @type = args[:type] if args.key?(:type)
end