Class: Google::Apis::ComputeBeta::SavedDisk

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

An instance-attached disk resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SavedDisk

Returns a new instance of SavedDisk.



58180
58181
58182
# File 'lib/google/apis/compute_beta/classes.rb', line 58180

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the attached disk. Corresponds to the JSON property architecture

Returns:

  • (String)


58151
58152
58153
# File 'lib/google/apis/compute_beta/classes.rb', line 58151

def architecture
  @architecture
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#savedDisk for attached disks. Corresponds to the JSON property kind

Returns:

  • (String)


58157
58158
58159
# File 'lib/google/apis/compute_beta/classes.rb', line 58157

def kind
  @kind
end

#source_diskString

Output only. Specifies a URL of the disk attached to the source instance. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


58162
58163
58164
# File 'lib/google/apis/compute_beta/classes.rb', line 58162

def source_disk
  @source_disk
end

#storage_bytesFixnum

Output only. [Output Only] Size of the individual disk snapshot used by this machine image. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


58169
58170
58171
# File 'lib/google/apis/compute_beta/classes.rb', line 58169

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


58178
58179
58180
# File 'lib/google/apis/compute_beta/classes.rb', line 58178

def storage_bytes_status
  @storage_bytes_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58185
58186
58187
58188
58189
58190
58191
# File 'lib/google/apis/compute_beta/classes.rb', line 58185

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @kind = args[:kind] if args.key?(:kind)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
end