Class: Google::Apis::ComputeBeta::SavedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SavedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#source_disk ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedDisk
constructor
A new instance of SavedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedDisk
Returns a new instance of SavedDisk.
57360 57361 57362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57360 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the attached disk.
Corresponds to the JSON property architecture
57331 57332 57333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57331 def architecture @architecture end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#savedDisk
for attached disks.
Corresponds to the JSON property kind
57337 57338 57339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57337 def kind @kind end |
#source_disk ⇒ String
Output only. Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property sourceDisk
57342 57343 57344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57342 def source_disk @source_disk end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] Size of the individual disk snapshot used by this
machine
image.
Corresponds to the JSON property storageBytes
57349 57350 57351 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57349 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
57358 57359 57360 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57358 def storage_bytes_status @storage_bytes_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
57365 57366 57367 57368 57369 57370 57371 |
# File 'lib/google/apis/compute_beta/classes.rb', line 57365 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @kind = args[:kind] if args.key?(:kind) @source_disk = args[:source_disk] if args.key?(:source_disk) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) end |