Class: Google::Apis::ComputeBeta::SavedDisk
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SavedDisk
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An instance-attached disk resource.
Instance Attribute Summary collapse
-
#architecture ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#source_disk ⇒ String
Output only.
-
#storage_bytes ⇒ Fixnum
Output only.
-
#storage_bytes_status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SavedDisk
constructor
A new instance of SavedDisk.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SavedDisk
Returns a new instance of SavedDisk.
54283 54284 54285 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54283 def initialize(**args) update!(**args) end |
Instance Attribute Details
#architecture ⇒ String
Output only. [Output Only] The architecture of the attached disk.
Corresponds to the JSON property architecture
54254 54255 54256 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54254 def architecture @architecture end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#savedDisk
for attached disks.
Corresponds to the JSON property kind
54260 54261 54262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54260 def kind @kind end |
#source_disk ⇒ String
Output only. Specifies a URL of the disk attached to the source instance.
Corresponds to the JSON property sourceDisk
54265 54266 54267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54265 def source_disk @source_disk end |
#storage_bytes ⇒ Fixnum
Output only. [Output Only] Size of the individual disk snapshot used by this
machine
image.
Corresponds to the JSON property storageBytes
54272 54273 54274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54272 def storage_bytes @storage_bytes end |
#storage_bytes_status ⇒ String
Output only. [Output Only] An indicator whether storageBytes is in a
stable state or it is being adjusted as a result of shared storage
reallocation. This status can either be UPDATING, meaning
the size of the snapshot is being updated, or UP_TO_DATE,
meaning the size of the snapshot is up-to-date.
Corresponds to the JSON property storageBytesStatus
54281 54282 54283 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54281 def storage_bytes_status @storage_bytes_status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
54288 54289 54290 54291 54292 54293 54294 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54288 def update!(**args) @architecture = args[:architecture] if args.key?(:architecture) @kind = args[:kind] if args.key?(:kind) @source_disk = args[:source_disk] if args.key?(:source_disk) @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes) @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status) end |