Class: Google::Apis::ComputeBeta::SchedulingGracefulShutdown
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SchedulingGracefulShutdown
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The configuration for gracefully shutting down the instance.
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean
(also: #enabled?)
Opts-in for graceful shutdown.
-
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented as a count of seconds and fractions of seconds at nanosecond resolution.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SchedulingGracefulShutdown
constructor
A new instance of SchedulingGracefulShutdown.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SchedulingGracefulShutdown
Returns a new instance of SchedulingGracefulShutdown.
58419 58420 58421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58419 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enabled ⇒ Boolean Also known as: enabled?
Opts-in for graceful shutdown.
Corresponds to the JSON property enabled
58408 58409 58410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58408 def enabled @enabled end |
#max_duration ⇒ Google::Apis::ComputeBeta::Duration
A Duration represents a fixed-length span of time represented
as a count of seconds and fractions of seconds at nanosecond
resolution. It is independent of any calendar and concepts like "day"
or "month". Range is approximately 10,000 years.
Corresponds to the JSON property maxDuration
58417 58418 58419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58417 def max_duration @max_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58424 58425 58426 58427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58424 def update!(**args) @enabled = args[:enabled] if args.key?(:enabled) @max_duration = args[:max_duration] if args.key?(:max_duration) end |