Class: Google::Apis::ComputeBeta::SchedulingOnInstanceStopAction

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Defines the behaviour for instances with the instance_termination_actionSTOP.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SchedulingOnInstanceStopAction

Returns a new instance of SchedulingOnInstanceStopAction.



57655
57656
57657
# File 'lib/google/apis/compute_beta/classes.rb', line 57655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discard_local_ssdBoolean Also known as: discard_local_ssd?

If true, the contents of any attached Local SSD disks will be discarded else, the Local SSD data will be preserved when the instance is stopped at the end of the run duration/termination time. Corresponds to the JSON property discardLocalSsd

Returns:

  • (Boolean)


57652
57653
57654
# File 'lib/google/apis/compute_beta/classes.rb', line 57652

def discard_local_ssd
  @discard_local_ssd
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57660
57661
57662
# File 'lib/google/apis/compute_beta/classes.rb', line 57660

def update!(**args)
  @discard_local_ssd = args[:discard_local_ssd] if args.key?(:discard_local_ssd)
end