Class: Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SecurityPoliciesScopedList>
A list of SecurityPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPoliciesAggregatedList
constructor
A new instance of SecurityPoliciesAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPoliciesAggregatedList
Returns a new instance of SecurityPoliciesAggregatedList.
59972 59973 59974 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59972 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
59928 59929 59930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59928 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59933 59934 59935 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59933 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SecurityPoliciesScopedList>
A list of SecurityPoliciesScopedList resources.
Corresponds to the JSON property items
59938 59939 59940 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59938 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
securityPolicyAggregatedList for lists of Security
Policies.
Corresponds to the JSON property kind
59945 59946 59947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59945 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59955 59956 59957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59955 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
59960 59961 59962 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59960 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
59965 59966 59967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59965 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59970 59971 59972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59970 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59977 59978 59979 59980 59981 59982 59983 59984 59985 59986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59977 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |