Class: Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



58621
58622
58623
# File 'lib/google/apis/compute_beta/classes.rb', line 58621

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58577
58578
58579
# File 'lib/google/apis/compute_beta/classes.rb', line 58577

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58582
58583
58584
# File 'lib/google/apis/compute_beta/classes.rb', line 58582

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



58587
58588
58589
# File 'lib/google/apis/compute_beta/classes.rb', line 58587

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


58594
58595
58596
# File 'lib/google/apis/compute_beta/classes.rb', line 58594

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58604
58605
58606
# File 'lib/google/apis/compute_beta/classes.rb', line 58604

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58609
58610
58611
# File 'lib/google/apis/compute_beta/classes.rb', line 58609

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58614
58615
58616
# File 'lib/google/apis/compute_beta/classes.rb', line 58614

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58619
58620
58621
# File 'lib/google/apis/compute_beta/classes.rb', line 58619

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58626
58627
58628
58629
58630
58631
58632
58633
58634
58635
# File 'lib/google/apis/compute_beta/classes.rb', line 58626

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end