Class: Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



58562
58563
58564
# File 'lib/google/apis/compute_beta/classes.rb', line 58562

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


58518
58519
58520
# File 'lib/google/apis/compute_beta/classes.rb', line 58518

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58523
58524
58525
# File 'lib/google/apis/compute_beta/classes.rb', line 58523

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



58528
58529
58530
# File 'lib/google/apis/compute_beta/classes.rb', line 58528

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


58535
58536
58537
# File 'lib/google/apis/compute_beta/classes.rb', line 58535

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58545
58546
58547
# File 'lib/google/apis/compute_beta/classes.rb', line 58545

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58550
58551
58552
# File 'lib/google/apis/compute_beta/classes.rb', line 58550

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


58555
58556
58557
# File 'lib/google/apis/compute_beta/classes.rb', line 58555

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58560
58561
58562
# File 'lib/google/apis/compute_beta/classes.rb', line 58560

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58567
58568
58569
58570
58571
58572
58573
58574
58575
58576
# File 'lib/google/apis/compute_beta/classes.rb', line 58567

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end