Class: Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



57742
57743
57744
# File 'lib/google/apis/compute_beta/classes.rb', line 57742

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


57698
57699
57700
# File 'lib/google/apis/compute_beta/classes.rb', line 57698

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


57703
57704
57705
# File 'lib/google/apis/compute_beta/classes.rb', line 57703

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



57708
57709
57710
# File 'lib/google/apis/compute_beta/classes.rb', line 57708

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


57715
57716
57717
# File 'lib/google/apis/compute_beta/classes.rb', line 57715

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


57725
57726
57727
# File 'lib/google/apis/compute_beta/classes.rb', line 57725

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


57730
57731
57732
# File 'lib/google/apis/compute_beta/classes.rb', line 57730

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


57735
57736
57737
# File 'lib/google/apis/compute_beta/classes.rb', line 57735

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



57740
57741
57742
# File 'lib/google/apis/compute_beta/classes.rb', line 57740

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57747
57748
57749
57750
57751
57752
57753
57754
57755
57756
# File 'lib/google/apis/compute_beta/classes.rb', line 57747

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end