Class: Google::Apis::ComputeBeta::SecurityPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPoliciesAggregatedList

Returns a new instance of SecurityPoliciesAggregatedList.



54656
54657
54658
# File 'lib/google/apis/compute_beta/classes.rb', line 54656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


54612
54613
54614
# File 'lib/google/apis/compute_beta/classes.rb', line 54612

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


54617
54618
54619
# File 'lib/google/apis/compute_beta/classes.rb', line 54617

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SecurityPoliciesScopedList>

A list of SecurityPoliciesScopedList resources. Corresponds to the JSON property items



54622
54623
54624
# File 'lib/google/apis/compute_beta/classes.rb', line 54622

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# securityPolicyAggregatedList for lists of Security Policies. Corresponds to the JSON property kind

Returns:

  • (String)


54629
54630
54631
# File 'lib/google/apis/compute_beta/classes.rb', line 54629

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


54639
54640
54641
# File 'lib/google/apis/compute_beta/classes.rb', line 54639

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


54644
54645
54646
# File 'lib/google/apis/compute_beta/classes.rb', line 54644

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


54649
54650
54651
# File 'lib/google/apis/compute_beta/classes.rb', line 54649

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SecurityPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



54654
54655
54656
# File 'lib/google/apis/compute_beta/classes.rb', line 54654

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



54661
54662
54663
54664
54665
54666
54667
54668
54669
54670
# File 'lib/google/apis/compute_beta/classes.rb', line 54661

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end