Class: Google::Apis::ComputeBeta::SecurityPolicy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Google Cloud Armor security policy resource. Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicy

Returns a new instance of SecurityPolicy.



59049
59050
59051
# File 'lib/google/apis/compute_beta/classes.rb', line 59049

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#adaptive_protection_configGoogle::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfig

Configuration options for Cloud Armor Adaptive Protection (CAAP). Corresponds to the JSON property adaptiveProtectionConfig



58853
58854
58855
# File 'lib/google/apis/compute_beta/classes.rb', line 58853

def adaptive_protection_config
  @adaptive_protection_config
end

#advanced_options_configGoogle::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfig

Corresponds to the JSON property advancedOptionsConfig



58858
58859
58860
# File 'lib/google/apis/compute_beta/classes.rb', line 58858

def advanced_options_config
  @advanced_options_config
end

#associationsArray<Google::Apis::ComputeBeta::SecurityPolicyAssociation>

A list of associations that belong to this policy. Corresponds to the JSON property associations



58863
58864
58865
# File 'lib/google/apis/compute_beta/classes.rb', line 58863

def associations
  @associations
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


58869
58870
58871
# File 'lib/google/apis/compute_beta/classes.rb', line 58869

def creation_timestamp
  @creation_timestamp
end

#ddos_protection_configGoogle::Apis::ComputeBeta::SecurityPolicyDdosProtectionConfig

Corresponds to the JSON property ddosProtectionConfig



58874
58875
58876
# File 'lib/google/apis/compute_beta/classes.rb', line 58874

def ddos_protection_config
  @ddos_protection_config
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


58880
58881
58882
# File 'lib/google/apis/compute_beta/classes.rb', line 58880

def description
  @description
end

#display_nameString

User-provided name of the organization security policy. The name should be unique in the organization in which the security policy is created. This should only be used when SecurityPolicyType is FIREWALL. The name must be 1-63 characters long, and comply with https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property displayName

Returns:

  • (String)


58893
58894
58895
# File 'lib/google/apis/compute_beta/classes.rb', line 58893

def display_name
  @display_name
end

#fingerprintString

Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update metadata. You must always provide an up-to-date fingerprint hash in order to update or change metadata, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make get() request to the security policy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


58906
58907
58908
# File 'lib/google/apis/compute_beta/classes.rb', line 58906

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


58913
58914
58915
# File 'lib/google/apis/compute_beta/classes.rb', line 58913

def id
  @id
end

#kindString

Output only. [Output only] Type of the resource. Alwayscompute# securityPolicyfor security policies Corresponds to the JSON property kind

Returns:

  • (String)


58919
58920
58921
# File 'lib/google/apis/compute_beta/classes.rb', line 58919

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. To see the latest fingerprint, make get() request to the security policy. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


58931
58932
58933
# File 'lib/google/apis/compute_beta/classes.rb', line 58931

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels for this resource. These can only be added or modified by thesetLabels method. Each label key/value pair must comply withRFC1035. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


58938
58939
58940
# File 'lib/google/apis/compute_beta/classes.rb', line 58938

def labels
  @labels
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


58949
58950
58951
# File 'lib/google/apis/compute_beta/classes.rb', line 58949

def name
  @name
end

#parentString

Output only. [Output Only] The parent of the security policy. Corresponds to the JSON property parent

Returns:

  • (String)


58954
58955
58956
# File 'lib/google/apis/compute_beta/classes.rb', line 58954

def parent
  @parent
end

#recaptcha_options_configGoogle::Apis::ComputeBeta::SecurityPolicyRecaptchaOptionsConfig

Corresponds to the JSON property recaptchaOptionsConfig



58959
58960
58961
# File 'lib/google/apis/compute_beta/classes.rb', line 58959

def recaptcha_options_config
  @recaptcha_options_config
end

#regionString

Output only. [Output Only] URL of the region where the regional security policy resides. This field is not applicable to global security policies. Corresponds to the JSON property region

Returns:

  • (String)


58966
58967
58968
# File 'lib/google/apis/compute_beta/classes.rb', line 58966

def region
  @region
end

#rule_tuple_countFixnum

Output only. [Output Only] Total count of all security policy rule tuples. A security policy can not exceed a set number of tuples. Corresponds to the JSON property ruleTupleCount

Returns:

  • (Fixnum)


58973
58974
58975
# File 'lib/google/apis/compute_beta/classes.rb', line 58973

def rule_tuple_count
  @rule_tuple_count
end

#rulesArray<Google::Apis::ComputeBeta::SecurityPolicyRule>

A list of rules that belong to this policy. There must always be a default rule which is a rule with priority 2147483647 and match all condition (for the match condition this means match "" for srcIpRanges and for the networkMatch condition every field must be either match "" or not set). If no rules are provided when creating a security policy, a default rule with action "allow" will be added. Corresponds to the JSON property rules



58984
58985
58986
# File 'lib/google/apis/compute_beta/classes.rb', line 58984

def rules
  @rules
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58989
58990
58991
# File 'lib/google/apis/compute_beta/classes.rb', line 58989

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource with the resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


58995
58996
58997
# File 'lib/google/apis/compute_beta/classes.rb', line 58995

def self_link_with_id
  @self_link_with_id
end

#short_nameString

User-provided name of the organization security policy. The name should be unique in the organization in which the security policy is created. This should only be used when SecurityPolicyType is CLOUD_ARMOR. The name must be 1-63 characters long, and comply with https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property shortName

Returns:

  • (String)


59008
59009
59010
# File 'lib/google/apis/compute_beta/classes.rb', line 59008

def short_name
  @short_name
end

#typeString

The type indicates the intended use of the security policy.

  • CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers.
  • CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache.
  • CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application.
  • CLOUD_ARMOR_NETWORK: Cloud Armor network policies can be configured to filter packets targeting network load balancing resources such as backend services, target pools, target instances, and instances with external IPs. They filter requests before the request is served from the application. This field can be set only at resource creation time. Corresponds to the JSON property type

Returns:

  • (String)


59031
59032
59033
# File 'lib/google/apis/compute_beta/classes.rb', line 59031

def type
  @type
end

#user_defined_fieldsArray<Google::Apis::ComputeBeta::SecurityPolicyUserDefinedField>

Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields. Example: userDefinedFields:

  • name: "ipv4_fragment_offset" base: IPV4 offset: 6 size: 2 mask: "0x1fff" Corresponds to the JSON property userDefinedFields


59047
59048
59049
# File 'lib/google/apis/compute_beta/classes.rb', line 59047

def user_defined_fields
  @user_defined_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59054
59055
59056
59057
59058
59059
59060
59061
59062
59063
59064
59065
59066
59067
59068
59069
59070
59071
59072
59073
59074
59075
59076
59077
59078
# File 'lib/google/apis/compute_beta/classes.rb', line 59054

def update!(**args)
  @adaptive_protection_config = args[:adaptive_protection_config] if args.key?(:adaptive_protection_config)
  @advanced_options_config = args[:advanced_options_config] if args.key?(:advanced_options_config)
  @associations = args[:associations] if args.key?(:associations)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @ddos_protection_config = args[:ddos_protection_config] if args.key?(:ddos_protection_config)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @parent = args[:parent] if args.key?(:parent)
  @recaptcha_options_config = args[:recaptcha_options_config] if args.key?(:recaptcha_options_config)
  @region = args[:region] if args.key?(:region)
  @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count)
  @rules = args[:rules] if args.key?(:rules)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @short_name = args[:short_name] if args.key?(:short_name)
  @type = args[:type] if args.key?(:type)
  @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields)
end