Class: Google::Apis::ComputeBeta::SecurityPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Google Cloud Armor security policy resource. Only external backend services that use load balancers can reference a security policy. For more information, see Google Cloud Armor security policy overview.
Instance Attribute Summary collapse
-
#adaptive_protection_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfig
Configuration options for Cloud Armor Adaptive Protection (CAAP).
-
#advanced_options_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfig
Corresponds to the JSON property
advancedOptionsConfig. -
#associations ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAssociation>
A list of associations that belong to this policy.
-
#creation_timestamp ⇒ String
Output only.
-
#ddos_protection_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyDdosProtectionConfig
Corresponds to the JSON property
ddosProtectionConfig. -
#description ⇒ String
An optional description of this resource.
-
#display_name ⇒ String
User-provided name of the organization security policy.
-
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of the metadata's contents and used for optimistic locking.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this security policy, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#name ⇒ String
Name of the resource.
-
#parent ⇒ String
Output only.
-
#recaptcha_options_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyRecaptchaOptionsConfig
Corresponds to the JSON property
recaptchaOptionsConfig. -
#region ⇒ String
Output only.
-
#rule_tuple_count ⇒ Fixnum
Output only.
-
#rules ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyRule>
A list of rules that belong to this policy.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#short_name ⇒ String
User-provided name of the organization security policy.
-
#type ⇒ String
The type indicates the intended use of the security policy.
-
#user_defined_fields ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyUserDefinedField>
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicy
constructor
A new instance of SecurityPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicy
Returns a new instance of SecurityPolicy.
55084 55085 55086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55084 def initialize(**args) update!(**args) end |
Instance Attribute Details
#adaptive_protection_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfig
Configuration options for Cloud Armor Adaptive Protection (CAAP).
Corresponds to the JSON property adaptiveProtectionConfig
54888 54889 54890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54888 def adaptive_protection_config @adaptive_protection_config end |
#advanced_options_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfig
Corresponds to the JSON property advancedOptionsConfig
54893 54894 54895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54893 def @advanced_options_config end |
#associations ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAssociation>
A list of associations that belong to this policy.
Corresponds to the JSON property associations
54898 54899 54900 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54898 def associations @associations end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
54904 54905 54906 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54904 def @creation_timestamp end |
#ddos_protection_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyDdosProtectionConfig
Corresponds to the JSON property ddosProtectionConfig
54909 54910 54911 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54909 def ddos_protection_config @ddos_protection_config end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
54915 54916 54917 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54915 def description @description end |
#display_name ⇒ String
User-provided name of the organization security policy. The name should be
unique in the organization in which the security policy is created. This
should only be used when SecurityPolicyType is FIREWALL.
The name must be 1-63 characters long, and comply with
https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
Corresponds to the JSON property displayName
54928 54929 54930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54928 def display_name @display_name end |
#fingerprint ⇒ String
Specifies a fingerprint for this resource, which is essentially a hash of
the metadata's contents and used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update metadata. You must always provide an
up-to-date fingerprint hash in order to update or change metadata,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make get() request to the
security policy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
54941 54942 54943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54941 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
54948 54949 54950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54948 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#
securityPolicyfor security policies
Corresponds to the JSON property kind
54954 54955 54956 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54954 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this security policy, which
is essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels.
To see the latest fingerprint, make get() request to the
security policy.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
54966 54967 54968 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54966 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
54973 54974 54975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54973 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
54984 54985 54986 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54984 def name @name end |
#parent ⇒ String
Output only. [Output Only] The parent of the security policy.
Corresponds to the JSON property parent
54989 54990 54991 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54989 def parent @parent end |
#recaptcha_options_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyRecaptchaOptionsConfig
Corresponds to the JSON property recaptchaOptionsConfig
54994 54995 54996 |
# File 'lib/google/apis/compute_beta/classes.rb', line 54994 def @recaptcha_options_config end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional security
policy
resides. This field is not applicable to global security policies.
Corresponds to the JSON property region
55001 55002 55003 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55001 def region @region end |
#rule_tuple_count ⇒ Fixnum
Output only. [Output Only] Total count of all security policy rule tuples. A
security
policy can not exceed a set number of tuples.
Corresponds to the JSON property ruleTupleCount
55008 55009 55010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55008 def rule_tuple_count @rule_tuple_count end |
#rules ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyRule>
A list of rules that belong to this policy.
There must always be a default rule which is a rule with priority
2147483647 and match all condition (for the match condition this means
match "" for srcIpRanges and for the networkMatch condition every field
must be either match "" or not set). If no rules are provided when
creating a security policy, a default rule with action "allow" will be
added.
Corresponds to the JSON property rules
55019 55020 55021 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55019 def rules @rules end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
55024 55025 55026 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55024 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource with the
resource id.
Corresponds to the JSON property selfLinkWithId
55030 55031 55032 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55030 def self_link_with_id @self_link_with_id end |
#short_name ⇒ String
User-provided name of the organization security policy. The name should be
unique in the organization in which the security policy is created. This
should only be used when SecurityPolicyType is CLOUD_ARMOR.
The name must be 1-63 characters long, and comply with
https://www.ietf.org/rfc/rfc1035.txt. Specifically, the name must be 1-63
characters long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a
lowercase letter, and all following characters must be a dash, lowercase
letter, or digit, except the last character, which cannot be a dash.
Corresponds to the JSON property shortName
55043 55044 55045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55043 def short_name @short_name end |
#type ⇒ String
The type indicates the intended use of the security policy.
- CLOUD_ARMOR: Cloud Armor backend security policies can be configured to filter incoming HTTP requests targeting backend services. They filter requests before they hit the origin servers.
- CLOUD_ARMOR_EDGE: Cloud Armor edge security policies can be configured to filter incoming HTTP requests targeting backend services (including Cloud CDN-enabled) as well as backend buckets (Cloud Storage). They filter requests before the request is served from Google's cache.
- CLOUD_ARMOR_INTERNAL_SERVICE (preview only): Cloud Armor internal service policies can be configured to filter HTTP requests targeting services managed by Traffic Director in a service mesh. They filter requests before the request is served from the application.
- CLOUD_ARMOR_NETWORK: Cloud Armor network policies
can be configured to filter packets targeting network load balancing
resources such as backend services, target pools, target instances, and
instances with external IPs. They filter requests before the request is
served from the application.
This field can be set only at resource creation time.
Corresponds to the JSON property
type
55066 55067 55068 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55066 def type @type end |
#user_defined_fields ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyUserDefinedField>
Definitions of user-defined fields for CLOUD_ARMOR_NETWORK policies. A user-defined field consists of up to 4 bytes extracted from a fixed offset in the packet, relative to the IPv4, IPv6, TCP, or UDP header, with an optional mask to select certain bits. Rules may then specify matching values for these fields. Example: userDefinedFields:
- name: "ipv4_fragment_offset"
base: IPV4
offset: 6
size: 2
mask: "0x1fff"
Corresponds to the JSON property
userDefinedFields
55082 55083 55084 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55082 def user_defined_fields @user_defined_fields end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55089 55090 55091 55092 55093 55094 55095 55096 55097 55098 55099 55100 55101 55102 55103 55104 55105 55106 55107 55108 55109 55110 55111 55112 55113 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55089 def update!(**args) @adaptive_protection_config = args[:adaptive_protection_config] if args.key?(:adaptive_protection_config) @advanced_options_config = args[:advanced_options_config] if args.key?(:advanced_options_config) @associations = args[:associations] if args.key?(:associations) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @ddos_protection_config = args[:ddos_protection_config] if args.key?(:ddos_protection_config) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @parent = args[:parent] if args.key?(:parent) @recaptcha_options_config = args[:recaptcha_options_config] if args.key?(:recaptcha_options_config) @region = args[:region] if args.key?(:region) @rule_tuple_count = args[:rule_tuple_count] if args.key?(:rule_tuple_count) @rules = args[:rules] if args.key?(:rules) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @short_name = args[:short_name] if args.key?(:short_name) @type = args[:type] if args.key?(:type) @user_defined_fields = args[:user_defined_fields] if args.key?(:user_defined_fields) end |