Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.



59237
59238
59239
# File 'lib/google/apis/compute_beta/classes.rb', line 59237

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deploy_confidence_thresholdFloat

Corresponds to the JSON property autoDeployConfidenceThreshold

Returns:

  • (Float)


59193
59194
59195
# File 'lib/google/apis/compute_beta/classes.rb', line 59193

def auto_deploy_confidence_threshold
  @auto_deploy_confidence_threshold
end

#auto_deploy_expiration_secFixnum

Corresponds to the JSON property autoDeployExpirationSec

Returns:

  • (Fixnum)


59198
59199
59200
# File 'lib/google/apis/compute_beta/classes.rb', line 59198

def auto_deploy_expiration_sec
  @auto_deploy_expiration_sec
end

#auto_deploy_impacted_baseline_thresholdFloat

Corresponds to the JSON property autoDeployImpactedBaselineThreshold

Returns:

  • (Float)


59203
59204
59205
# File 'lib/google/apis/compute_beta/classes.rb', line 59203

def auto_deploy_impacted_baseline_threshold
  @auto_deploy_impacted_baseline_threshold
end

#auto_deploy_load_thresholdFloat

Corresponds to the JSON property autoDeployLoadThreshold

Returns:

  • (Float)


59208
59209
59210
# File 'lib/google/apis/compute_beta/classes.rb', line 59208

def auto_deploy_load_threshold
  @auto_deploy_load_threshold
end

#detection_absolute_qpsFloat

Corresponds to the JSON property detectionAbsoluteQps

Returns:

  • (Float)


59213
59214
59215
# File 'lib/google/apis/compute_beta/classes.rb', line 59213

def detection_absolute_qps
  @detection_absolute_qps
end

#detection_load_thresholdFloat

Corresponds to the JSON property detectionLoadThreshold

Returns:

  • (Float)


59218
59219
59220
# File 'lib/google/apis/compute_beta/classes.rb', line 59218

def detection_load_threshold
  @detection_load_threshold
end

#detection_relative_to_baseline_qpsFloat

Corresponds to the JSON property detectionRelativeToBaselineQps

Returns:

  • (Float)


59223
59224
59225
# File 'lib/google/apis/compute_beta/classes.rb', line 59223

def detection_relative_to_baseline_qps
  @detection_relative_to_baseline_qps
end

#nameString

The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy. Corresponds to the JSON property name

Returns:

  • (String)


59229
59230
59231
# File 'lib/google/apis/compute_beta/classes.rb', line 59229

def name
  @name
end

#traffic_granularity_configsArray<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>

Configuration options for enabling Adaptive Protection to operate on specified granular traffic units. Corresponds to the JSON property trafficGranularityConfigs



59235
59236
59237
# File 'lib/google/apis/compute_beta/classes.rb', line 59235

def traffic_granularity_configs
  @traffic_granularity_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59242
59243
59244
59245
59246
59247
59248
59249
59250
59251
59252
# File 'lib/google/apis/compute_beta/classes.rb', line 59242

def update!(**args)
  @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold)
  @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec)
  @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold)
  @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold)
  @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps)
  @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold)
  @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps)
  @name = args[:name] if args.key?(:name)
  @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs)
end