Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property
autoDeployConfidenceThreshold. -
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property
autoDeployExpirationSec. -
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property
autoDeployImpactedBaselineThreshold. -
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property
autoDeployLoadThreshold. -
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property
detectionAbsoluteQps. -
#detection_load_threshold ⇒ Float
Corresponds to the JSON property
detectionLoadThreshold. -
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property
detectionRelativeToBaselineQps. -
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
-
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate on specified granular traffic units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
59178 59179 59180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property autoDeployConfidenceThreshold
59134 59135 59136 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59134 def auto_deploy_confidence_threshold @auto_deploy_confidence_threshold end |
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property autoDeployExpirationSec
59139 59140 59141 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59139 def auto_deploy_expiration_sec @auto_deploy_expiration_sec end |
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property autoDeployImpactedBaselineThreshold
59144 59145 59146 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59144 def auto_deploy_impacted_baseline_threshold @auto_deploy_impacted_baseline_threshold end |
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property autoDeployLoadThreshold
59149 59150 59151 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59149 def auto_deploy_load_threshold @auto_deploy_load_threshold end |
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property detectionAbsoluteQps
59154 59155 59156 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59154 def detection_absolute_qps @detection_absolute_qps end |
#detection_load_threshold ⇒ Float
Corresponds to the JSON property detectionLoadThreshold
59159 59160 59161 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59159 def detection_load_threshold @detection_load_threshold end |
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property detectionRelativeToBaselineQps
59164 59165 59166 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59164 def detection_relative_to_baseline_qps @detection_relative_to_baseline_qps end |
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the security policy.
Corresponds to the JSON property name
59170 59171 59172 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59170 def name @name end |
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate
on specified granular traffic units.
Corresponds to the JSON property trafficGranularityConfigs
59176 59177 59178 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59176 def traffic_granularity_configs @traffic_granularity_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59183 59184 59185 59186 59187 59188 59189 59190 59191 59192 59193 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59183 def update!(**args) @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold) @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec) @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold) @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold) @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps) @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold) @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps) @name = args[:name] if args.key?(:name) @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs) end |