Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.



57175
57176
57177
# File 'lib/google/apis/compute_beta/classes.rb', line 57175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_deploy_confidence_thresholdFloat

Corresponds to the JSON property autoDeployConfidenceThreshold

Returns:

  • (Float)


57131
57132
57133
# File 'lib/google/apis/compute_beta/classes.rb', line 57131

def auto_deploy_confidence_threshold
  @auto_deploy_confidence_threshold
end

#auto_deploy_expiration_secFixnum

Corresponds to the JSON property autoDeployExpirationSec

Returns:

  • (Fixnum)


57136
57137
57138
# File 'lib/google/apis/compute_beta/classes.rb', line 57136

def auto_deploy_expiration_sec
  @auto_deploy_expiration_sec
end

#auto_deploy_impacted_baseline_thresholdFloat

Corresponds to the JSON property autoDeployImpactedBaselineThreshold

Returns:

  • (Float)


57141
57142
57143
# File 'lib/google/apis/compute_beta/classes.rb', line 57141

def auto_deploy_impacted_baseline_threshold
  @auto_deploy_impacted_baseline_threshold
end

#auto_deploy_load_thresholdFloat

Corresponds to the JSON property autoDeployLoadThreshold

Returns:

  • (Float)


57146
57147
57148
# File 'lib/google/apis/compute_beta/classes.rb', line 57146

def auto_deploy_load_threshold
  @auto_deploy_load_threshold
end

#detection_absolute_qpsFloat

Corresponds to the JSON property detectionAbsoluteQps

Returns:

  • (Float)


57151
57152
57153
# File 'lib/google/apis/compute_beta/classes.rb', line 57151

def detection_absolute_qps
  @detection_absolute_qps
end

#detection_load_thresholdFloat

Corresponds to the JSON property detectionLoadThreshold

Returns:

  • (Float)


57156
57157
57158
# File 'lib/google/apis/compute_beta/classes.rb', line 57156

def detection_load_threshold
  @detection_load_threshold
end

#detection_relative_to_baseline_qpsFloat

Corresponds to the JSON property detectionRelativeToBaselineQps

Returns:

  • (Float)


57161
57162
57163
# File 'lib/google/apis/compute_beta/classes.rb', line 57161

def detection_relative_to_baseline_qps
  @detection_relative_to_baseline_qps
end

#nameString

The name must be 1-63 characters long, and comply withRFC1035. The name must be unique within the security policy. Corresponds to the JSON property name

Returns:

  • (String)


57167
57168
57169
# File 'lib/google/apis/compute_beta/classes.rb', line 57167

def name
  @name
end

#traffic_granularity_configsArray<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>

Configuration options for enabling Adaptive Protection to operate on specified granular traffic units. Corresponds to the JSON property trafficGranularityConfigs



57173
57174
57175
# File 'lib/google/apis/compute_beta/classes.rb', line 57173

def traffic_granularity_configs
  @traffic_granularity_configs
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57180
57181
57182
57183
57184
57185
57186
57187
57188
57189
57190
# File 'lib/google/apis/compute_beta/classes.rb', line 57180

def update!(**args)
  @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold)
  @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec)
  @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold)
  @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold)
  @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps)
  @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold)
  @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps)
  @name = args[:name] if args.key?(:name)
  @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs)
end