Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property
autoDeployConfidenceThreshold. -
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property
autoDeployExpirationSec. -
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property
autoDeployImpactedBaselineThreshold. -
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property
autoDeployLoadThreshold. -
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property
detectionAbsoluteQps. -
#detection_load_threshold ⇒ Float
Corresponds to the JSON property
detectionLoadThreshold. -
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property
detectionRelativeToBaselineQps. -
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
-
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate on specified granular traffic units.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfig.
55272 55273 55274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_deploy_confidence_threshold ⇒ Float
Corresponds to the JSON property autoDeployConfidenceThreshold
55228 55229 55230 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55228 def auto_deploy_confidence_threshold @auto_deploy_confidence_threshold end |
#auto_deploy_expiration_sec ⇒ Fixnum
Corresponds to the JSON property autoDeployExpirationSec
55233 55234 55235 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55233 def auto_deploy_expiration_sec @auto_deploy_expiration_sec end |
#auto_deploy_impacted_baseline_threshold ⇒ Float
Corresponds to the JSON property autoDeployImpactedBaselineThreshold
55238 55239 55240 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55238 def auto_deploy_impacted_baseline_threshold @auto_deploy_impacted_baseline_threshold end |
#auto_deploy_load_threshold ⇒ Float
Corresponds to the JSON property autoDeployLoadThreshold
55243 55244 55245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55243 def auto_deploy_load_threshold @auto_deploy_load_threshold end |
#detection_absolute_qps ⇒ Float
Corresponds to the JSON property detectionAbsoluteQps
55248 55249 55250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55248 def detection_absolute_qps @detection_absolute_qps end |
#detection_load_threshold ⇒ Float
Corresponds to the JSON property detectionLoadThreshold
55253 55254 55255 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55253 def detection_load_threshold @detection_load_threshold end |
#detection_relative_to_baseline_qps ⇒ Float
Corresponds to the JSON property detectionRelativeToBaselineQps
55258 55259 55260 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55258 def detection_relative_to_baseline_qps @detection_relative_to_baseline_qps end |
#name ⇒ String
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the security policy.
Corresponds to the JSON property name
55264 55265 55266 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55264 def name @name end |
#traffic_granularity_configs ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig>
Configuration options for enabling Adaptive Protection to operate
on specified granular traffic units.
Corresponds to the JSON property trafficGranularityConfigs
55270 55271 55272 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55270 def traffic_granularity_configs @traffic_granularity_configs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
55277 55278 55279 55280 55281 55282 55283 55284 55285 55286 55287 |
# File 'lib/google/apis/compute_beta/classes.rb', line 55277 def update!(**args) @auto_deploy_confidence_threshold = args[:auto_deploy_confidence_threshold] if args.key?(:auto_deploy_confidence_threshold) @auto_deploy_expiration_sec = args[:auto_deploy_expiration_sec] if args.key?(:auto_deploy_expiration_sec) @auto_deploy_impacted_baseline_threshold = args[:auto_deploy_impacted_baseline_threshold] if args.key?(:auto_deploy_impacted_baseline_threshold) @auto_deploy_load_threshold = args[:auto_deploy_load_threshold] if args.key?(:auto_deploy_load_threshold) @detection_absolute_qps = args[:detection_absolute_qps] if args.key?(:detection_absolute_qps) @detection_load_threshold = args[:detection_load_threshold] if args.key?(:detection_load_threshold) @detection_relative_to_baseline_qps = args[:detection_relative_to_baseline_qps] if args.key?(:detection_relative_to_baseline_qps) @name = args[:name] if args.key?(:name) @traffic_granularity_configs = args[:traffic_granularity_configs] if args.key?(:traffic_granularity_configs) end |