Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configurations to specifc granular traffic units processed by Adaptive Protection.
Instance Attribute Summary collapse
-
#enable_each_unique_value ⇒ Boolean
(also: #enable_each_unique_value?)
If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit.
-
#type ⇒ String
Type of this configuration.
-
#value ⇒ String
Requests that match this value constitute a granular traffic unit.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
constructor
A new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig
Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.
60629 60630 60631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#enable_each_unique_value ⇒ Boolean Also known as: enable_each_unique_value?
If enabled, traffic matching each unique value for the specified
type constitutes a separate traffic unit.
It can only be set to true if value is empty.
Corresponds to the JSON property enableEachUniqueValue
60616 60617 60618 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60616 def enable_each_unique_value @enable_each_unique_value end |
#type ⇒ String
Type of this configuration.
Corresponds to the JSON property type
60622 60623 60624 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60622 def type @type end |
#value ⇒ String
Requests that match this value constitute a granular traffic unit.
Corresponds to the JSON property value
60627 60628 60629 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60627 def value @value end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60634 60635 60636 60637 60638 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60634 def update!(**args) @enable_each_unique_value = args[:enable_each_unique_value] if args.key?(:enable_each_unique_value) @type = args[:type] if args.key?(:type) @value = args[:value] if args.key?(:value) end |