Class: Google::Apis::ComputeBeta::SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configurations to specifc granular traffic units processed by Adaptive Protection.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig

Returns a new instance of SecurityPolicyAdaptiveProtectionConfigLayer7DdosDefenseConfigThresholdConfigTrafficGranularityConfig.



60065
60066
60067
# File 'lib/google/apis/compute_beta/classes.rb', line 60065

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enable_each_unique_valueBoolean Also known as: enable_each_unique_value?

If enabled, traffic matching each unique value for the specified type constitutes a separate traffic unit. It can only be set to true if value is empty. Corresponds to the JSON property enableEachUniqueValue

Returns:

  • (Boolean)


60052
60053
60054
# File 'lib/google/apis/compute_beta/classes.rb', line 60052

def enable_each_unique_value
  @enable_each_unique_value
end

#typeString

Type of this configuration. Corresponds to the JSON property type

Returns:

  • (String)


60058
60059
60060
# File 'lib/google/apis/compute_beta/classes.rb', line 60058

def type
  @type
end

#valueString

Requests that match this value constitute a granular traffic unit. Corresponds to the JSON property value

Returns:

  • (String)


60063
60064
60065
# File 'lib/google/apis/compute_beta/classes.rb', line 60063

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60070
60071
60072
60073
60074
# File 'lib/google/apis/compute_beta/classes.rb', line 60070

def update!(**args)
  @enable_each_unique_value = args[:enable_each_unique_value] if args.key?(:enable_each_unique_value)
  @type = args[:type] if args.key?(:type)
  @value = args[:value] if args.key?(:value)
end