Class: Google::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#json_custom_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing.
-
#json_parsing ⇒ String
Corresponds to the JSON property
jsonParsing. -
#log_level ⇒ String
Corresponds to the JSON property
logLevel. -
#request_body_inspection_size ⇒ String
The maximum request size chosen by the customer with Waf enabled.
-
#user_ip_request_headers ⇒ Array<String>
An optional list of case-insensitive request header names to use for resolving the callers client IP address.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig
constructor
A new instance of SecurityPolicyAdvancedOptionsConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAdvancedOptionsConfig
Returns a new instance of SecurityPolicyAdvancedOptionsConfig.
60567 60568 60569 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60567 def initialize(**args) update!(**args) end |
Instance Attribute Details
#json_custom_config ⇒ Google::Apis::ComputeBeta::SecurityPolicyAdvancedOptionsConfigJsonCustomConfig
Custom configuration to apply the JSON parsing. Only applicable when
json_parsing is set to STANDARD.
Corresponds to the JSON property jsonCustomConfig
60542 60543 60544 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60542 def json_custom_config @json_custom_config end |
#json_parsing ⇒ String
Corresponds to the JSON property jsonParsing
60547 60548 60549 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60547 def json_parsing @json_parsing end |
#log_level ⇒ String
Corresponds to the JSON property logLevel
60552 60553 60554 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60552 def log_level @log_level end |
#request_body_inspection_size ⇒ String
The maximum request size chosen by the customer with Waf enabled.
Values supported are "8KB", "16KB, "32KB", "48KB" and "64KB".
Values are case insensitive.
Corresponds to the JSON property requestBodyInspectionSize
60559 60560 60561 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60559 def request_body_inspection_size @request_body_inspection_size end |
#user_ip_request_headers ⇒ Array<String>
An optional list of case-insensitive request header names to use for
resolving the callers client IP address.
Corresponds to the JSON property userIpRequestHeaders
60565 60566 60567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60565 def user_ip_request_headers @user_ip_request_headers end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60572 60573 60574 60575 60576 60577 60578 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60572 def update!(**args) @json_custom_config = args[:json_custom_config] if args.key?(:json_custom_config) @json_parsing = args[:json_parsing] if args.key?(:json_parsing) @log_level = args[:log_level] if args.key?(:log_level) @request_body_inspection_size = args[:request_body_inspection_size] if args.key?(:request_body_inspection_size) @user_ip_request_headers = args[:user_ip_request_headers] if args.key?(:user_ip_request_headers) end |