Class: Google::Apis::ComputeBeta::SecurityPolicyAssociation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyAssociation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#attachment_id ⇒ String
The resource that the security policy is attached to.
-
#display_name ⇒ String
Output only.
-
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
-
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
-
#name ⇒ String
The name for an association.
-
#security_policy_id ⇒ String
Output only.
-
#short_name ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyAssociation
constructor
A new instance of SecurityPolicyAssociation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyAssociation
Returns a new instance of SecurityPolicyAssociation.
60212 60213 60214 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60212 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attachment_id ⇒ String
The resource that the security policy is attached to.
Corresponds to the JSON property attachmentId
60178 60179 60180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60178 def @attachment_id end |
#display_name ⇒ String
Output only. [Output Only] The display name of the security policy of the
association.
Corresponds to the JSON property displayName
60184 60185 60186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60184 def display_name @display_name end |
#excluded_folders ⇒ Array<String>
A list of folders to exclude from the security policy.
Corresponds to the JSON property excludedFolders
60189 60190 60191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60189 def excluded_folders @excluded_folders end |
#excluded_projects ⇒ Array<String>
A list of projects to exclude from the security policy.
Corresponds to the JSON property excludedProjects
60194 60195 60196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60194 def excluded_projects @excluded_projects end |
#name ⇒ String
The name for an association.
Corresponds to the JSON property name
60199 60200 60201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60199 def name @name end |
#security_policy_id ⇒ String
Output only. [Output Only] The security policy ID of the association.
Corresponds to the JSON property securityPolicyId
60204 60205 60206 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60204 def security_policy_id @security_policy_id end |
#short_name ⇒ String
Output only. [Output Only] The short name of the security policy of the
association.
Corresponds to the JSON property shortName
60210 60211 60212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60210 def short_name @short_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60217 60218 60219 60220 60221 60222 60223 60224 60225 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60217 def update!(**args) @attachment_id = args[:attachment_id] if args.key?(:attachment_id) @display_name = args[:display_name] if args.key?(:display_name) @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders) @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects) @name = args[:name] if args.key?(:name) @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id) @short_name = args[:short_name] if args.key?(:short_name) end |