Class: Google::Apis::ComputeBeta::SecurityPolicyAssociation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyAssociation

Returns a new instance of SecurityPolicyAssociation.



59402
59403
59404
# File 'lib/google/apis/compute_beta/classes.rb', line 59402

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attachment_idString

The resource that the security policy is attached to. Corresponds to the JSON property attachmentId

Returns:

  • (String)


59368
59369
59370
# File 'lib/google/apis/compute_beta/classes.rb', line 59368

def attachment_id
  @attachment_id
end

#display_nameString

Output only. [Output Only] The display name of the security policy of the association. Corresponds to the JSON property displayName

Returns:

  • (String)


59374
59375
59376
# File 'lib/google/apis/compute_beta/classes.rb', line 59374

def display_name
  @display_name
end

#excluded_foldersArray<String>

A list of folders to exclude from the security policy. Corresponds to the JSON property excludedFolders

Returns:

  • (Array<String>)


59379
59380
59381
# File 'lib/google/apis/compute_beta/classes.rb', line 59379

def excluded_folders
  @excluded_folders
end

#excluded_projectsArray<String>

A list of projects to exclude from the security policy. Corresponds to the JSON property excludedProjects

Returns:

  • (Array<String>)


59384
59385
59386
# File 'lib/google/apis/compute_beta/classes.rb', line 59384

def excluded_projects
  @excluded_projects
end

#nameString

The name for an association. Corresponds to the JSON property name

Returns:

  • (String)


59389
59390
59391
# File 'lib/google/apis/compute_beta/classes.rb', line 59389

def name
  @name
end

#security_policy_idString

Output only. [Output Only] The security policy ID of the association. Corresponds to the JSON property securityPolicyId

Returns:

  • (String)


59394
59395
59396
# File 'lib/google/apis/compute_beta/classes.rb', line 59394

def security_policy_id
  @security_policy_id
end

#short_nameString

Output only. [Output Only] The short name of the security policy of the association. Corresponds to the JSON property shortName

Returns:

  • (String)


59400
59401
59402
# File 'lib/google/apis/compute_beta/classes.rb', line 59400

def short_name
  @short_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59407
59408
59409
59410
59411
59412
59413
59414
59415
# File 'lib/google/apis/compute_beta/classes.rb', line 59407

def update!(**args)
  @attachment_id = args[:attachment_id] if args.key?(:attachment_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @excluded_folders = args[:excluded_folders] if args.key?(:excluded_folders)
  @excluded_projects = args[:excluded_projects] if args.key?(:excluded_projects)
  @name = args[:name] if args.key?(:name)
  @security_policy_id = args[:security_policy_id] if args.key?(:security_policy_id)
  @short_name = args[:short_name] if args.key?(:short_name)
end