Class: Google::Apis::ComputeBeta::SecurityPolicyDdosProtectionConfig
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyDdosProtectionConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#ddos_adaptive_protection ⇒ String
Corresponds to the JSON property
ddosAdaptiveProtection. -
#ddos_impacted_baseline_threshold ⇒ Float
DDoS Protection for Network Load Balancers (and VMs with public IPs) builds DDoS mitigations that minimize collateral damage.
-
#ddos_protection ⇒ String
Corresponds to the JSON property
ddosProtection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyDdosProtectionConfig
constructor
A new instance of SecurityPolicyDdosProtectionConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyDdosProtectionConfig
Returns a new instance of SecurityPolicyDdosProtectionConfig.
60260 60261 60262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60260 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ddos_adaptive_protection ⇒ String
Corresponds to the JSON property ddosAdaptiveProtection
60235 60236 60237 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60235 def ddos_adaptive_protection @ddos_adaptive_protection end |
#ddos_impacted_baseline_threshold ⇒ Float
DDoS Protection for Network Load Balancers (and VMs with public IPs)
builds DDoS mitigations that minimize collateral damage. It quantifies
this as the fraction of a non-abuse baseline that's inadvertently
blocked.
Rules whose collateral damage exceeds ddosImpactedBaselineThreshold will
not be deployed. Using a lower value will prioritize keeping collateral
damage low, possibly at the cost of its effectiveness in rate limiting
some or all of the attack. It should typically be unset, so Advanced DDoS
(and Adaptive Protection) uses the best mitigation it can find. Setting
the threshold is advised if there are logs for false positive detections
with high collateral damage, and will cause Advanced DDoS to attempt to
find a less aggressive rule that satisfies the constraint. If a suitable
rule cannot be found, the system falls back to either no mitigation for
smaller attacks or broader network throttles for larger ones.
Corresponds to the JSON property ddosImpactedBaselineThreshold
60253 60254 60255 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60253 def ddos_impacted_baseline_threshold @ddos_impacted_baseline_threshold end |
#ddos_protection ⇒ String
Corresponds to the JSON property ddosProtection
60258 60259 60260 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60258 def ddos_protection @ddos_protection end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60265 60266 60267 60268 60269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60265 def update!(**args) @ddos_adaptive_protection = args[:ddos_adaptive_protection] if args.key?(:ddos_adaptive_protection) @ddos_impacted_baseline_threshold = args[:ddos_impacted_baseline_threshold] if args.key?(:ddos_impacted_baseline_threshold) @ddos_protection = args[:ddos_protection] if args.key?(:ddos_protection) end |