Class: Google::Apis::ComputeBeta::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
61247 61248 61249 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61247 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61219 61220 61221 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61219 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
61224 61225 61226 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61224 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
61230 61231 61232 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61230 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61240 61241 61242 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61240 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61245 61246 61247 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61245 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61252 61253 61254 61255 61256 61257 61258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61252 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |