Class: Google::Apis::ComputeBeta::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



60848
60849
60850
# File 'lib/google/apis/compute_beta/classes.rb', line 60848

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60820
60821
60822
# File 'lib/google/apis/compute_beta/classes.rb', line 60820

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



60825
60826
60827
# File 'lib/google/apis/compute_beta/classes.rb', line 60825

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


60831
60832
60833
# File 'lib/google/apis/compute_beta/classes.rb', line 60831

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60841
60842
60843
# File 'lib/google/apis/compute_beta/classes.rb', line 60841

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60846
60847
60848
# File 'lib/google/apis/compute_beta/classes.rb', line 60846

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60853
60854
60855
60856
60857
60858
60859
# File 'lib/google/apis/compute_beta/classes.rb', line 60853

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end