Class: Google::Apis::ComputeBeta::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
60773 60774 60775 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60773 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60745 60746 60747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60745 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
60750 60751 60752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60750 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
60756 60757 60758 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60756 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60766 60767 60768 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60766 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60771 60772 60773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60771 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60778 60779 60780 60781 60782 60783 60784 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60778 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |