Class: Google::Apis::ComputeBeta::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
60741 60742 60743 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60741 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60713 60714 60715 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60713 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
60718 60719 60720 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60718 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
60724 60725 60726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60724 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60734 60735 60736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60734 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60739 60740 60741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60739 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60746 60747 60748 60749 60750 60751 60752 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60746 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |