Class: Google::Apis::ComputeBeta::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
60284 60285 60286 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60284 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
60256 60257 60258 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60256 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
60261 60262 60263 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60261 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
60267 60268 60269 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60267 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
60277 60278 60279 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60277 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
60282 60283 60284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60282 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60289 60290 60291 60292 60293 60294 60295 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60289 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |