Class: Google::Apis::ComputeBeta::SecurityPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyList
constructor
A new instance of SecurityPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyList
Returns a new instance of SecurityPolicyList.
59497 59498 59499 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59497 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
59469 59470 59471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59469 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SecurityPolicy>
A list of SecurityPolicy resources.
Corresponds to the JSON property items
59474 59475 59476 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59474 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList
for listsof securityPolicies
Corresponds to the JSON property kind
59480 59481 59482 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59480 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
59490 59491 59492 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59490 def next_page_token @next_page_token end |
#warning ⇒ Google::Apis::ComputeBeta::SecurityPolicyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
59495 59496 59497 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59495 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59502 59503 59504 59505 59506 59507 59508 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59502 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @warning = args[:warning] if args.key?(:warning) end |