Class: Google::Apis::ComputeBeta::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



59438
59439
59440
# File 'lib/google/apis/compute_beta/classes.rb', line 59438

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59410
59411
59412
# File 'lib/google/apis/compute_beta/classes.rb', line 59410

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



59415
59416
59417
# File 'lib/google/apis/compute_beta/classes.rb', line 59415

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


59421
59422
59423
# File 'lib/google/apis/compute_beta/classes.rb', line 59421

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59431
59432
59433
# File 'lib/google/apis/compute_beta/classes.rb', line 59431

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59436
59437
59438
# File 'lib/google/apis/compute_beta/classes.rb', line 59436

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59443
59444
59445
59446
59447
59448
59449
# File 'lib/google/apis/compute_beta/classes.rb', line 59443

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end