Class: Google::Apis::ComputeBeta::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



58618
58619
58620
# File 'lib/google/apis/compute_beta/classes.rb', line 58618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58590
58591
58592
# File 'lib/google/apis/compute_beta/classes.rb', line 58590

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



58595
58596
58597
# File 'lib/google/apis/compute_beta/classes.rb', line 58595

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


58601
58602
58603
# File 'lib/google/apis/compute_beta/classes.rb', line 58601

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58611
58612
58613
# File 'lib/google/apis/compute_beta/classes.rb', line 58611

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58616
58617
58618
# File 'lib/google/apis/compute_beta/classes.rb', line 58616

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58623
58624
58625
58626
58627
58628
58629
# File 'lib/google/apis/compute_beta/classes.rb', line 58623

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end