Class: Google::Apis::ComputeBeta::SecurityPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyList

Returns a new instance of SecurityPolicyList.



55532
55533
55534
# File 'lib/google/apis/compute_beta/classes.rb', line 55532

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


55504
55505
55506
# File 'lib/google/apis/compute_beta/classes.rb', line 55504

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SecurityPolicy>

A list of SecurityPolicy resources. Corresponds to the JSON property items



55509
55510
55511
# File 'lib/google/apis/compute_beta/classes.rb', line 55509

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#securityPolicyList for listsof securityPolicies Corresponds to the JSON property kind

Returns:

  • (String)


55515
55516
55517
# File 'lib/google/apis/compute_beta/classes.rb', line 55515

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


55525
55526
55527
# File 'lib/google/apis/compute_beta/classes.rb', line 55525

def next_page_token
  @next_page_token
end

#warningGoogle::Apis::ComputeBeta::SecurityPolicyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



55530
55531
55532
# File 'lib/google/apis/compute_beta/classes.rb', line 55530

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



55537
55538
55539
55540
55541
55542
55543
# File 'lib/google/apis/compute_beta/classes.rb', line 55537

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @warning = args[:warning] if args.key?(:warning)
end