Class: Google::Apis::ComputeBeta::SecurityPolicyRecaptchaOptionsConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRecaptchaOptionsConfig

Returns a new instance of SecurityPolicyRecaptchaOptionsConfig.



58717
58718
58719
# File 'lib/google/apis/compute_beta/classes.rb', line 58717

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#redirect_site_keyString

An optional field to supply a reCAPTCHA site key to be used for all the rules using the redirect action with the type of GOOGLE_RECAPTCHA under the security policy. The specified site key needs to be created from the reCAPTCHA API. The user is responsible for the validity of the specified site key. If not specified, a Google-managed site key is used. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property redirectSiteKey

Returns:

  • (String)


58715
58716
58717
# File 'lib/google/apis/compute_beta/classes.rb', line 58715

def redirect_site_key
  @redirect_site_key
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58722
58723
58724
# File 'lib/google/apis/compute_beta/classes.rb', line 58722

def update!(**args)
  @redirect_site_key = args[:redirect_site_key] if args.key?(:redirect_site_key)
end