Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfigLayer4Config
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherConfigLayer4Config
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#ip_protocol ⇒ String
The IP protocol to which this rule applies.
-
#ports ⇒ Array<String>
An optional list of ports to which this rule applies.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfigLayer4Config
constructor
A new instance of SecurityPolicyRuleMatcherConfigLayer4Config.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherConfigLayer4Config
Returns a new instance of SecurityPolicyRuleMatcherConfigLayer4Config.
60753 60754 60755 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60753 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_protocol ⇒ String
The IP protocol to which this rule applies. The protocol type is
required when creating a firewall rule. This value can either be
one of the following well known protocol strings (tcp,udp, icmp, esp,ah, ipip,
sctp), or the IP
protocol number.
Corresponds to the JSON property ipProtocol
60740 60741 60742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60740 def ip_protocol @ip_protocol end |
#ports ⇒ Array<String>
An optional list of ports to which this rule applies. This field is
only applicable for UDP or TCP protocol. Each entry must be either
an integer or a range. If not specified, this rule applies to
connections through any port.
Example inputs include: ["22"],["80","443"], and ["12345-12349"].
This field may only be specified when versioned_expr is set to
FIREWALL.
Corresponds to the JSON property ports
60751 60752 60753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60751 def ports @ports end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60758 60759 60760 60761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60758 def update!(**args) @ip_protocol = args[:ip_protocol] if args.key?(:ip_protocol) @ports = args[:ports] if args.key?(:ports) end |