Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#recaptcha_options ⇒ Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptions.
61338 61339 61340 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61338 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recaptcha_options ⇒ Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule. If the
rule does not evaluate reCAPTCHA tokens, this field has no effect.
Corresponds to the JSON property recaptchaOptions
61336 61337 61338 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61336 def @recaptcha_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61343 61344 61345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61343 def update!(**args) @recaptcha_options = args[:recaptcha_options] if args.key?(:recaptcha_options) end |