Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptions
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptions
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#recaptcha_options ⇒ Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
constructor
A new instance of SecurityPolicyRuleMatcherExprOptions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptions
Returns a new instance of SecurityPolicyRuleMatcherExprOptions.
60774 60775 60776 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60774 def initialize(**args) update!(**args) end |
Instance Attribute Details
#recaptcha_options ⇒ Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions
reCAPTCHA configuration options to be applied for the rule. If the
rule does not evaluate reCAPTCHA tokens, this field has no effect.
Corresponds to the JSON property recaptchaOptions
60772 60773 60774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60772 def @recaptcha_options end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60779 60780 60781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60779 def update!(**args) @recaptcha_options = args[:recaptcha_options] if args.key?(:recaptcha_options) end |