Class: Google::Apis::ComputeBeta::SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions

Returns a new instance of SecurityPolicyRuleMatcherExprOptionsRecaptchaOptions.



57955
57956
57957
# File 'lib/google/apis/compute_beta/classes.rb', line 57955

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA action-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property actionTokenSiteKeys

Returns:

  • (Array<String>)


57945
57946
57947
# File 'lib/google/apis/compute_beta/classes.rb', line 57945

def action_token_site_keys
  @action_token_site_keys
end

#session_token_site_keysArray<String>

A list of site keys to be used during the validation of reCAPTCHA session-tokens. The provided site keys need to be created from reCAPTCHA API under the same project where the security policy is created. Corresponds to the JSON property sessionTokenSiteKeys

Returns:

  • (Array<String>)


57953
57954
57955
# File 'lib/google/apis/compute_beta/classes.rb', line 57953

def session_token_site_keys
  @session_token_site_keys
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57960
57961
57962
57963
# File 'lib/google/apis/compute_beta/classes.rb', line 57960

def update!(**args)
  @action_token_site_keys = args[:action_token_site_keys] if args.key?(:action_token_site_keys)
  @session_token_site_keys = args[:session_token_site_keys] if args.key?(:session_token_site_keys)
end