Class: Google::Apis::ComputeBeta::SecurityPolicyRulePreconfiguredWafConfigExclusion

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRulePreconfiguredWafConfigExclusion

Returns a new instance of SecurityPolicyRulePreconfiguredWafConfigExclusion.



60979
60980
60981
# File 'lib/google/apis/compute_beta/classes.rb', line 60979

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#request_bodies_to_excludeArray<Google::Apis::ComputeBeta::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request body fields to be excluded from inspection during preconfigured WAF evaluation. Corresponds to the JSON property requestBodiesToExclude



60939
60940
60941
# File 'lib/google/apis/compute_beta/classes.rb', line 60939

def request_bodies_to_exclude
  @request_bodies_to_exclude
end

#request_cookies_to_excludeArray<Google::Apis::ComputeBeta::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request cookie names whose value will be excluded from inspection during preconfigured WAF evaluation. Corresponds to the JSON property requestCookiesToExclude



60945
60946
60947
# File 'lib/google/apis/compute_beta/classes.rb', line 60945

def request_cookies_to_exclude
  @request_cookies_to_exclude
end

#request_headers_to_excludeArray<Google::Apis::ComputeBeta::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request header names whose value will be excluded from inspection during preconfigured WAF evaluation. Corresponds to the JSON property requestHeadersToExclude



60951
60952
60953
# File 'lib/google/apis/compute_beta/classes.rb', line 60951

def request_headers_to_exclude
  @request_headers_to_exclude
end

#request_query_params_to_excludeArray<Google::Apis::ComputeBeta::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request query parameter names whose value will be excluded from inspection during preconfigured WAF evaluation. Note that the parameter can be in the query string or in the POST body. Corresponds to the JSON property requestQueryParamsToExclude



60958
60959
60960
# File 'lib/google/apis/compute_beta/classes.rb', line 60958

def request_query_params_to_exclude
  @request_query_params_to_exclude
end

#request_uris_to_excludeArray<Google::Apis::ComputeBeta::SecurityPolicyRulePreconfiguredWafConfigExclusionFieldParams>

A list of request URIs from the request line to be excluded from inspection during preconfigured WAF evaluation. When specifying this field, the query or fragment part should be excluded. Corresponds to the JSON property requestUrisToExclude



60965
60966
60967
# File 'lib/google/apis/compute_beta/classes.rb', line 60965

def request_uris_to_exclude
  @request_uris_to_exclude
end

#target_rule_idsArray<String>

A list of target rule IDs under the WAF rule set to apply the preconfigured WAF exclusion. If omitted, it refers to all the rule IDs under the WAF rule set. Corresponds to the JSON property targetRuleIds

Returns:

  • (Array<String>)


60972
60973
60974
# File 'lib/google/apis/compute_beta/classes.rb', line 60972

def target_rule_ids
  @target_rule_ids
end

#target_rule_setString

Target WAF rule set to apply the preconfigured WAF exclusion. Corresponds to the JSON property targetRuleSet

Returns:

  • (String)


60977
60978
60979
# File 'lib/google/apis/compute_beta/classes.rb', line 60977

def target_rule_set
  @target_rule_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60984
60985
60986
60987
60988
60989
60990
60991
60992
# File 'lib/google/apis/compute_beta/classes.rb', line 60984

def update!(**args)
  @request_bodies_to_exclude = args[:request_bodies_to_exclude] if args.key?(:request_bodies_to_exclude)
  @request_cookies_to_exclude = args[:request_cookies_to_exclude] if args.key?(:request_cookies_to_exclude)
  @request_headers_to_exclude = args[:request_headers_to_exclude] if args.key?(:request_headers_to_exclude)
  @request_query_params_to_exclude = args[:request_query_params_to_exclude] if args.key?(:request_query_params_to_exclude)
  @request_uris_to_exclude = args[:request_uris_to_exclude] if args.key?(:request_uris_to_exclude)
  @target_rule_ids = args[:target_rule_ids] if args.key?(:target_rule_ids)
  @target_rule_set = args[:target_rule_set] if args.key?(:target_rule_set)
end