Class: Google::Apis::ComputeBeta::SecurityPolicyRuleRateLimitOptions

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SecurityPolicyRuleRateLimitOptions

Returns a new instance of SecurityPolicyRuleRateLimitOptions.



60289
60290
60291
# File 'lib/google/apis/compute_beta/classes.rb', line 60289

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ban_duration_secFixnum

Can only be specified if the action for the rule is "rate_based_ban". If specified, determines the time (in seconds) the traffic will continue to be banned by the rate limit after the rate falls below the threshold. Corresponds to the JSON property banDurationSec

Returns:

  • (Fixnum)


60184
60185
60186
# File 'lib/google/apis/compute_beta/classes.rb', line 60184

def ban_duration_sec
  @ban_duration_sec
end

#ban_thresholdGoogle::Apis::ComputeBeta::SecurityPolicyRuleRateLimitOptionsThreshold

Can only be specified if the action for the rule is "rate_based_ban". If specified, the key will be banned for the configured 'ban_duration_sec' when the number of requests that exceed the 'rate_limit_threshold' also exceed this 'ban_threshold'. Corresponds to the JSON property banThreshold



60192
60193
60194
# File 'lib/google/apis/compute_beta/classes.rb', line 60192

def ban_threshold
  @ban_threshold
end

#conform_actionString

Action to take for requests that are under the configured rate limit threshold. Valid option is "allow" only. Corresponds to the JSON property conformAction

Returns:

  • (String)


60198
60199
60200
# File 'lib/google/apis/compute_beta/classes.rb', line 60198

def conform_action
  @conform_action
end

#enforce_on_keyString

Determines the key to enforce the rate_limit_threshold on. Possible values are:

  • ALL: A single rate limit threshold is applied to all the requests matching this rule. This is the default value if "enforceOnKey" is not configured.
  • IP: The source IP address of the request is the key. Each IP has this limit enforced separately.
  • HTTP_HEADER: The value of the HTTP header whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the header value. If no such header is present in the request, the key type defaults toALL.
  • XFF_IP: The first IP address (i.e. the originating client IP address) specified in the list of IPs under X-Forwarded-For HTTP header. If no such header is present or the value is not a valid IP, the key defaults to the source IP address of the request i.e. key type IP.
  • HTTP_COOKIE: The value of the HTTP cookie whose name is configured under "enforceOnKeyName". The key value is truncated to the first 128 bytes of the cookie value. If no such cookie is present in the request, the key type defaults toALL.
  • HTTP_PATH: The URL path of the HTTP request. The key value is truncated to the first 128 bytes.
  • SNI: Server name indication in the TLS session of the HTTPS request. The key value is truncated to the first 128 bytes. The key type defaults to ALL on a HTTP session.
  • REGION_CODE: The country/region from which the request originates.
  • TLS_JA3_FINGERPRINT: JA3 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL.
  • USER_IP: The IP address of the originating client, which is resolved based on "userIpRequestHeaders" configured with the security policy. If there is no "userIpRequestHeaders" configuration or an IP address cannot be resolved from it, the key type defaults toIP.
  • TLS_JA4_FINGERPRINT: JA4 TLS/SSL fingerprint if the client connects using HTTPS, HTTP/2 or HTTP/3. If not available, the key type defaults to ALL. For "fairshare" action, this value is limited to ALL i.e. a single rate limit threshold is enforced for all the requests matching the rule. Corresponds to the JSON property enforceOnKey

Returns:

  • (String)


60243
60244
60245
# File 'lib/google/apis/compute_beta/classes.rb', line 60243

def enforce_on_key
  @enforce_on_key
end

#enforce_on_key_configsArray<Google::Apis::ComputeBeta::SecurityPolicyRuleRateLimitOptionsEnforceOnKeyConfig>

If specified, any combination of values of enforce_on_key_type/enforce_on_key_name is treated as the key on which ratelimit threshold/action is enforced. You can specify up to 3 enforce_on_key_configs. If enforce_on_key_configs is specified, enforce_on_key must not be specified. Corresponds to the JSON property enforceOnKeyConfigs



60252
60253
60254
# File 'lib/google/apis/compute_beta/classes.rb', line 60252

def enforce_on_key_configs
  @enforce_on_key_configs
end

#enforce_on_key_nameString

Rate limit key name applicable only for the following key types: HTTP_HEADER -- Name of the HTTP header whose value is taken as the key value. HTTP_COOKIE -- Name of the HTTP cookie whose value is taken as the key value. Corresponds to the JSON property enforceOnKeyName

Returns:

  • (String)


60261
60262
60263
# File 'lib/google/apis/compute_beta/classes.rb', line 60261

def enforce_on_key_name
  @enforce_on_key_name
end

#exceed_actionString

Action to take for requests that are above the configured rate limit threshold, to either deny with a specified HTTP response code, or redirect to a different endpoint. Valid options are deny(STATUS), where valid values for STATUS are 403, 404, 429, and 502, and redirect, where the redirect parameters come from exceedRedirectOptions below. The redirect action is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property exceedAction

Returns:

  • (String)


60274
60275
60276
# File 'lib/google/apis/compute_beta/classes.rb', line 60274

def exceed_action
  @exceed_action
end

#exceed_redirect_optionsGoogle::Apis::ComputeBeta::SecurityPolicyRuleRedirectOptions

Parameters defining the redirect action that is used as the exceed action. Cannot be specified if the exceed action is not redirect. This field is only supported in Global Security Policies of type CLOUD_ARMOR. Corresponds to the JSON property exceedRedirectOptions



60282
60283
60284
# File 'lib/google/apis/compute_beta/classes.rb', line 60282

def exceed_redirect_options
  @exceed_redirect_options
end

#rate_limit_thresholdGoogle::Apis::ComputeBeta::SecurityPolicyRuleRateLimitOptionsThreshold

Threshold at which to begin ratelimiting. Corresponds to the JSON property rateLimitThreshold



60287
60288
60289
# File 'lib/google/apis/compute_beta/classes.rb', line 60287

def rate_limit_threshold
  @rate_limit_threshold
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60294
60295
60296
60297
60298
60299
60300
60301
60302
60303
60304
# File 'lib/google/apis/compute_beta/classes.rb', line 60294

def update!(**args)
  @ban_duration_sec = args[:ban_duration_sec] if args.key?(:ban_duration_sec)
  @ban_threshold = args[:ban_threshold] if args.key?(:ban_threshold)
  @conform_action = args[:conform_action] if args.key?(:conform_action)
  @enforce_on_key = args[:enforce_on_key] if args.key?(:enforce_on_key)
  @enforce_on_key_configs = args[:enforce_on_key_configs] if args.key?(:enforce_on_key_configs)
  @enforce_on_key_name = args[:enforce_on_key_name] if args.key?(:enforce_on_key_name)
  @exceed_action = args[:exceed_action] if args.key?(:exceed_action)
  @exceed_redirect_options = args[:exceed_redirect_options] if args.key?(:exceed_redirect_options)
  @rate_limit_threshold = args[:rate_limit_threshold] if args.key?(:rate_limit_threshold)
end