Class: Google::Apis::ComputeBeta::SecurityPolicyUserDefinedField
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecurityPolicyUserDefinedField
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#base ⇒ String
The base relative to which 'offset' is measured.
-
#mask ⇒ String
If specified, apply this mask (bitwise AND) to the field to ignore bits before matching.
-
#name ⇒ String
The name of this field.
-
#offset ⇒ Fixnum
Offset of the first byte of the field (in network byte order) relative to 'base'.
-
#size ⇒ Fixnum
Size of the field in bytes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecurityPolicyUserDefinedField
constructor
A new instance of SecurityPolicyUserDefinedField.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecurityPolicyUserDefinedField
Returns a new instance of SecurityPolicyUserDefinedField.
56566 56567 56568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56566 def initialize(**args) update!(**args) end |
Instance Attribute Details
#base ⇒ String
The base relative to which 'offset' is measured. Possible values are:
- IPV4: Points to the beginning of the IPv4 header.
- IPV6: Points to the beginning of the IPv6 header.
- TCP: Points to the beginning of the TCP header, skipping over any IPv4 options or IPv6 extension headers. Not present for non-first fragments.
- UDP: Points to the beginning of the UDP header, skipping
over any IPv4 options or IPv6 extension headers. Not present for
non-first fragments.
required
Corresponds to the JSON property
base
56540 56541 56542 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56540 def base @base end |
#mask ⇒ String
If specified, apply this mask (bitwise AND) to the field to ignore bits
before matching. Encoded as a hexadecimal number (starting with "0x").
The last byte of the field (in network byte order) corresponds to the
least significant byte of the mask.
Corresponds to the JSON property mask
56548 56549 56550 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56548 def mask @mask end |
#name ⇒ String
The name of this field. Must be unique within the policy.
Corresponds to the JSON property name
56553 56554 56555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56553 def name @name end |
#offset ⇒ Fixnum
Offset of the first byte of the field (in network byte order) relative to
'base'.
Corresponds to the JSON property offset
56559 56560 56561 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56559 def offset @offset end |
#size ⇒ Fixnum
Size of the field in bytes. Valid values: 1-4.
Corresponds to the JSON property size
56564 56565 56566 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56564 def size @size end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56571 56572 56573 56574 56575 56576 56577 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56571 def update!(**args) @base = args[:base] if args.key?(:base) @mask = args[:mask] if args.key?(:mask) @name = args[:name] if args.key?(:name) @offset = args[:offset] if args.key?(:offset) @size = args[:size] if args.key?(:size) end |