Class: Google::Apis::ComputeBeta::SecuritySettings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SecuritySettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The authentication and authorization settings for a BackendService.
Instance Attribute Summary collapse
-
#authentication ⇒ String
[Deprecated] Use clientTlsPolicy instead.
-
#aws_v4_authentication ⇒ Google::Apis::ComputeBeta::Awsv4Signature
Contains the configurations necessary to generate a signature for access to private storage buckets that support Signature Version 4 for authentication.
-
#client_tls_policy ⇒ String
Optional.
-
#subject_alt_names ⇒ Array<String>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SecuritySettings
constructor
A new instance of SecuritySettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SecuritySettings
Returns a new instance of SecuritySettings.
56628 56629 56630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication ⇒ String
[Deprecated] Use clientTlsPolicy instead.
Corresponds to the JSON property authentication
56587 56588 56589 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56587 def authentication @authentication end |
#aws_v4_authentication ⇒ Google::Apis::ComputeBeta::Awsv4Signature
Contains the configurations necessary to generate a signature for access to
private storage buckets that support Signature Version 4 for authentication.
The service name for generating the authentication header will always default
to 's3'.
Corresponds to the JSON property awsV4Authentication
56595 56596 56597 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56595 def aws_v4_authentication @aws_v4_authentication end |
#client_tls_policy ⇒ String
Optional. A URL referring to a networksecurity.ClientTlsPolicy resource
that describes how clients should authenticate with this service's
backends.
clientTlsPolicy only applies to a globalBackendService with the
loadBalancingScheme set
to INTERNAL_SELF_MANAGED.
If left blank, communications are not encrypted.
Corresponds to the JSON property clientTlsPolicy
56606 56607 56608 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56606 def client_tls_policy @client_tls_policy end |
#subject_alt_names ⇒ Array<String>
Optional. A list of Subject Alternative Names (SANs) that the client
verifies during a mutual TLS handshake with an server/endpoint for
thisBackendService. When the server presents its X.509 certificate
to the client, the client inspects the certificate'ssubjectAltName field. If
the field contains one of the
specified values, the communication continues. Otherwise, it fails. This
additional check enables the client to verify that the server is authorized
to run the requested service.
Note that the contents of the server
certificate's subjectAltName field are configured by the
Public Key Infrastructure which provisions server identities.
Only applies to a global BackendService withloadBalancingScheme set to
INTERNAL_SELF_MANAGED.
Only applies when BackendService has an attachedclientTlsPolicy with
clientCertificate (mTLS
mode).
Corresponds to the JSON property subjectAltNames
56626 56627 56628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56626 def subject_alt_names @subject_alt_names end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
56633 56634 56635 56636 56637 56638 |
# File 'lib/google/apis/compute_beta/classes.rb', line 56633 def update!(**args) @authentication = args[:authentication] if args.key?(:authentication) @aws_v4_authentication = args[:aws_v4_authentication] if args.key?(:aws_v4_authentication) @client_tls_policy = args[:client_tls_policy] if args.key?(:client_tls_policy) @subject_alt_names = args[:subject_alt_names] if args.key?(:subject_alt_names) end |