Class: Google::Apis::ComputeBeta::SerialPortOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

An instance serial console output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SerialPortOutput

Returns a new instance of SerialPortOutput.



61888
61889
61890
# File 'lib/google/apis/compute_beta/classes.rb', line 61888

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

[Output Only] The contents of the console output. Corresponds to the JSON property contents

Returns:

  • (String)


61857
61858
61859
# File 'lib/google/apis/compute_beta/classes.rb', line 61857

def contents
  @contents
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serialPortOutput for serial port output. Corresponds to the JSON property kind

Returns:

  • (String)


61863
61864
61865
# File 'lib/google/apis/compute_beta/classes.rb', line 61863

def kind
  @kind
end

#nextFixnum

[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the contents property. Use this value in the next request as the start parameter. Corresponds to the JSON property next

Returns:

  • (Fixnum)


61871
61872
61873
# File 'lib/google/apis/compute_beta/classes.rb', line 61871

def next
  @next
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61876
61877
61878
# File 'lib/google/apis/compute_beta/classes.rb', line 61876

def self_link
  @self_link
end

#startFixnum

The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer (1 MB), older output is overwritten by newer content. The output start value will indicate the byte position of the output that was returned, which might be different than the start value that was specified in the request. Corresponds to the JSON property start

Returns:

  • (Fixnum)


61886
61887
61888
# File 'lib/google/apis/compute_beta/classes.rb', line 61886

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61893
61894
61895
61896
61897
61898
61899
# File 'lib/google/apis/compute_beta/classes.rb', line 61893

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @kind = args[:kind] if args.key?(:kind)
  @next = args[:next] if args.key?(:next)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start = args[:start] if args.key?(:start)
end