Class: Google::Apis::ComputeBeta::SerialPortOutput
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SerialPortOutput
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
An instance serial console output.
Instance Attribute Summary collapse
-
#contents ⇒ String
[Output Only] The contents of the console output.
-
#kind ⇒ String
Output only.
-
#next ⇒ Fixnum
[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the
contentsproperty. -
#self_link ⇒ String
Output only.
-
#start ⇒ Fixnum
The starting byte position of the output that was returned.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SerialPortOutput
constructor
A new instance of SerialPortOutput.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SerialPortOutput
Returns a new instance of SerialPortOutput.
60644 60645 60646 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60644 def initialize(**args) update!(**args) end |
Instance Attribute Details
#contents ⇒ String
[Output Only] The contents of the console output.
Corresponds to the JSON property contents
60613 60614 60615 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60613 def contents @contents end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serialPortOutput for serial port output.
Corresponds to the JSON property kind
60619 60620 60621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60619 def kind @kind end |
#next ⇒ Fixnum
[Output Only] The position of the next byte of content, regardless of
whether the content exists, following the output returned in the contents
property. Use this value in the next request as the start
parameter.
Corresponds to the JSON property next
60627 60628 60629 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60627 def next @next end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
60632 60633 60634 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60632 def self_link @self_link end |
#start ⇒ Fixnum
The starting byte position of the output that was returned.
This should match the start parameter sent with the request.
If the serial console output exceeds the size of the buffer (1 MB), older
output is overwritten by newer content. The output start value will
indicate the byte position of the output that was returned, which might be
different than the start value that was specified in the request.
Corresponds to the JSON property start
60642 60643 60644 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60642 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60649 60650 60651 60652 60653 60654 60655 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60649 def update!(**args) @contents = args[:contents] if args.key?(:contents) @kind = args[:kind] if args.key?(:kind) @next = args[:next] if args.key?(:next) @self_link = args[:self_link] if args.key?(:self_link) @start = args[:start] if args.key?(:start) end |