Class: Google::Apis::ComputeBeta::SerialPortOutput

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

An instance serial console output.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SerialPortOutput

Returns a new instance of SerialPortOutput.



56679
56680
56681
# File 'lib/google/apis/compute_beta/classes.rb', line 56679

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#contentsString

[Output Only] The contents of the console output. Corresponds to the JSON property contents

Returns:

  • (String)


56648
56649
56650
# File 'lib/google/apis/compute_beta/classes.rb', line 56648

def contents
  @contents
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serialPortOutput for serial port output. Corresponds to the JSON property kind

Returns:

  • (String)


56654
56655
56656
# File 'lib/google/apis/compute_beta/classes.rb', line 56654

def kind
  @kind
end

#nextFixnum

[Output Only] The position of the next byte of content, regardless of whether the content exists, following the output returned in the contents property. Use this value in the next request as the start parameter. Corresponds to the JSON property next

Returns:

  • (Fixnum)


56662
56663
56664
# File 'lib/google/apis/compute_beta/classes.rb', line 56662

def next
  @next
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


56667
56668
56669
# File 'lib/google/apis/compute_beta/classes.rb', line 56667

def self_link
  @self_link
end

#startFixnum

The starting byte position of the output that was returned. This should match the start parameter sent with the request. If the serial console output exceeds the size of the buffer (1 MB), older output is overwritten by newer content. The output start value will indicate the byte position of the output that was returned, which might be different than the start value that was specified in the request. Corresponds to the JSON property start

Returns:

  • (Fixnum)


56677
56678
56679
# File 'lib/google/apis/compute_beta/classes.rb', line 56677

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



56684
56685
56686
56687
56688
56689
56690
# File 'lib/google/apis/compute_beta/classes.rb', line 56684

def update!(**args)
  @contents = args[:contents] if args.key?(:contents)
  @kind = args[:kind] if args.key?(:kind)
  @next = args[:next] if args.key?(:next)
  @self_link = args[:self_link] if args.key?(:self_link)
  @start = args[:start] if args.key?(:start)
end