Class: Google::Apis::ComputeBeta::ServiceAttachment

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a ServiceAttachment resource. A service attachment represents a service that a producer has exposed. It encapsulates the load balancer which fronts the service runs and a list of NAT IP ranges that the producers uses to represent the consumers connecting to the service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachment

Returns a new instance of ServiceAttachment.



61708
61709
61710
# File 'lib/google/apis/compute_beta/classes.rb', line 61708

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connected_endpointsArray<Google::Apis::ComputeBeta::ServiceAttachmentConnectedEndpoint>

Output only. [Output Only] An array of connections for all the consumers connected to this service attachment. Corresponds to the JSON property connectedEndpoints



61525
61526
61527
# File 'lib/google/apis/compute_beta/classes.rb', line 61525

def connected_endpoints
  @connected_endpoints
end

#connection_preferenceString

The connection preference of service attachment. The value can be set to ACCEPT_AUTOMATIC. An ACCEPT_AUTOMATIC service attachment is one that always accepts the connection from consumer forwarding rules. Corresponds to the JSON property connectionPreference

Returns:

  • (String)


61533
61534
61535
# File 'lib/google/apis/compute_beta/classes.rb', line 61533

def connection_preference
  @connection_preference
end

#consumer_accept_listsArray<Google::Apis::ComputeBeta::ServiceAttachmentConsumerProjectLimit>

Specifies which consumer projects or networks are allowed to connect to the service attachment. Each project or network has a connection limit. A given service attachment can manage connections at either the project or network level. Therefore, both the accept and reject lists for a given service attachment must contain either only projects or only networks or only endpoints. Corresponds to the JSON property consumerAcceptLists



61543
61544
61545
# File 'lib/google/apis/compute_beta/classes.rb', line 61543

def consumer_accept_lists
  @consumer_accept_lists
end

#consumer_reject_listsArray<String>

Specifies a list of projects or networks that are not allowed to connect to this service attachment. The project can be specified using its project ID or project number and the network can be specified using its URL. A given service attachment can manage connections at either the project or network level. Therefore, both the reject and accept lists for a given service attachment must contain either only projects or only networks. Corresponds to the JSON property consumerRejectLists

Returns:

  • (Array<String>)


61553
61554
61555
# File 'lib/google/apis/compute_beta/classes.rb', line 61553

def consumer_reject_lists
  @consumer_reject_lists
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


61559
61560
61561
# File 'lib/google/apis/compute_beta/classes.rb', line 61559

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


61565
61566
61567
# File 'lib/google/apis/compute_beta/classes.rb', line 61565

def description
  @description
end

#domain_namesArray<String>

If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS. For example, this is a valid domain name: "p.mycompany.com.". Current max number of domain names supported is 1. Corresponds to the JSON property domainNames

Returns:

  • (Array<String>)


61573
61574
61575
# File 'lib/google/apis/compute_beta/classes.rb', line 61573

def domain_names
  @domain_names
end

#enable_proxy_protocolBoolean Also known as: enable_proxy_protocol?

If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers. Corresponds to the JSON property enableProxyProtocol

Returns:

  • (Boolean)


61580
61581
61582
# File 'lib/google/apis/compute_beta/classes.rb', line 61580

def enable_proxy_protocol
  @enable_proxy_protocol
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a ServiceAttachment. An up-to-date fingerprint must be provided in order to patch/update the ServiceAttachment; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the ServiceAttachment. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


61593
61594
61595
# File 'lib/google/apis/compute_beta/classes.rb', line 61593

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


61600
61601
61602
# File 'lib/google/apis/compute_beta/classes.rb', line 61600

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


61606
61607
61608
# File 'lib/google/apis/compute_beta/classes.rb', line 61606

def kind
  @kind
end

#metadataHash<String,String>

Metadata of the service attachment. Corresponds to the JSON property metadata

Returns:

  • (Hash<String,String>)


61611
61612
61613
# File 'lib/google/apis/compute_beta/classes.rb', line 61611

def 
  @metadata
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


61622
61623
61624
# File 'lib/google/apis/compute_beta/classes.rb', line 61622

def name
  @name
end

#nat_ips_per_endpointFixnum

The number of NAT IP addresses to be allocated per connected endpoint. If not specified, the default value is 1. Corresponds to the JSON property natIpsPerEndpoint

Returns:

  • (Fixnum)


61628
61629
61630
# File 'lib/google/apis/compute_beta/classes.rb', line 61628

def nat_ips_per_endpoint
  @nat_ips_per_endpoint
end

#nat_subnetsArray<String>

An array of URLs where each entry is the URL of a subnet provided by the service producer to use for NAT in this service attachment. Corresponds to the JSON property natSubnets

Returns:

  • (Array<String>)


61634
61635
61636
# File 'lib/google/apis/compute_beta/classes.rb', line 61634

def nat_subnets
  @nat_subnets
end

#producer_forwarding_ruleString

The URL of a forwarding rule with loadBalancingScheme INTERNAL* that is serving the endpoint identified by this service attachment. Corresponds to the JSON property producerForwardingRule

Returns:

  • (String)


61640
61641
61642
# File 'lib/google/apis/compute_beta/classes.rb', line 61640

def producer_forwarding_rule
  @producer_forwarding_rule
end

#propagated_connection_limitFixnum

The number of consumer spokes that connected Private Service Connect endpoints can be propagated to through Network Connectivity Center. This limit lets the service producer limit how many propagated Private Service Connect connections can be established to this service attachment from a single consumer. If the connection preference of the service attachment is ACCEPT_MANUAL, the limit applies to each project or network that is listed in the consumer accept list. If the connection preference of the service attachment is ACCEPT_AUTOMATIC, the limit applies to each project that contains a connected endpoint. If unspecified, the default propagated connection limit is 250. Corresponds to the JSON property propagatedConnectionLimit

Returns:

  • (Fixnum)


61655
61656
61657
# File 'lib/google/apis/compute_beta/classes.rb', line 61655

def propagated_connection_limit
  @propagated_connection_limit
end

#psc_service_attachment_idGoogle::Apis::ComputeBeta::Uint128

Output only. [Output Only] An 128-bit global unique ID of the PSC service attachment. Corresponds to the JSON property pscServiceAttachmentId



61661
61662
61663
# File 'lib/google/apis/compute_beta/classes.rb', line 61661

def psc_service_attachment_id
  @psc_service_attachment_id
end

#reconcile_connectionsBoolean Also known as: reconcile_connections?

This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.

  • If false, connection policy update will only affect existing PENDING PSC endpoints. Existing ACCEPTED/REJECTED endpoints will remain untouched regardless how the connection policy is modified .
  • If true, update will affect both PENDING and ACCEPTED/REJECTED PSC endpoints. For example, an ACCEPTED PSC endpoint will be moved to REJECTED if its project is added to the reject list. For newly created service attachment, this boolean defaults to false. Corresponds to the JSON property reconcileConnections

Returns:

  • (Boolean)


61677
61678
61679
# File 'lib/google/apis/compute_beta/classes.rb', line 61677

def reconcile_connections
  @reconcile_connections
end

#regionString

Output only. [Output Only] URL of the region where the service attachment resides. This field applies only to the region resource. You must specify this field as part of the HTTP request URL. It is not settable as a field in the request body. Corresponds to the JSON property region

Returns:

  • (String)


61687
61688
61689
# File 'lib/google/apis/compute_beta/classes.rb', line 61687

def region
  @region
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61692
61693
61694
# File 'lib/google/apis/compute_beta/classes.rb', line 61692

def self_link
  @self_link
end

#target_serviceString

The URL of a service serving the endpoint identified by this service attachment. Corresponds to the JSON property targetService

Returns:

  • (String)


61698
61699
61700
# File 'lib/google/apis/compute_beta/classes.rb', line 61698

def target_service
  @target_service
end

#tunneling_configGoogle::Apis::ComputeBeta::ServiceAttachmentTunnelingConfig

Use to configure this PSC connection in tunneling mode. In tunneling mode traffic from consumer to producer will be encapsulated as it crosses the VPC boundary and traffic from producer to consumer will be decapsulated in the same manner. Corresponds to the JSON property tunnelingConfig



61706
61707
61708
# File 'lib/google/apis/compute_beta/classes.rb', line 61706

def tunneling_config
  @tunneling_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61713
61714
61715
61716
61717
61718
61719
61720
61721
61722
61723
61724
61725
61726
61727
61728
61729
61730
61731
61732
61733
61734
61735
61736
61737
# File 'lib/google/apis/compute_beta/classes.rb', line 61713

def update!(**args)
  @connected_endpoints = args[:connected_endpoints] if args.key?(:connected_endpoints)
  @connection_preference = args[:connection_preference] if args.key?(:connection_preference)
  @consumer_accept_lists = args[:consumer_accept_lists] if args.key?(:consumer_accept_lists)
  @consumer_reject_lists = args[:consumer_reject_lists] if args.key?(:consumer_reject_lists)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @domain_names = args[:domain_names] if args.key?(:domain_names)
  @enable_proxy_protocol = args[:enable_proxy_protocol] if args.key?(:enable_proxy_protocol)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @metadata = args[:metadata] if args.key?(:metadata)
  @name = args[:name] if args.key?(:name)
  @nat_ips_per_endpoint = args[:nat_ips_per_endpoint] if args.key?(:nat_ips_per_endpoint)
  @nat_subnets = args[:nat_subnets] if args.key?(:nat_subnets)
  @producer_forwarding_rule = args[:producer_forwarding_rule] if args.key?(:producer_forwarding_rule)
  @propagated_connection_limit = args[:propagated_connection_limit] if args.key?(:propagated_connection_limit)
  @psc_service_attachment_id = args[:psc_service_attachment_id] if args.key?(:psc_service_attachment_id)
  @reconcile_connections = args[:reconcile_connections] if args.key?(:reconcile_connections)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @target_service = args[:target_service] if args.key?(:target_service)
  @tunneling_config = args[:tunneling_config] if args.key?(:tunneling_config)
end