Class: Google::Apis::ComputeBeta::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A connection connected to this service attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint

Returns a new instance of ServiceAttachmentConnectedEndpoint.



59032
59033
59034
# File 'lib/google/apis/compute_beta/classes.rb', line 59032

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

The url of the consumer network. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


58998
58999
59000
# File 'lib/google/apis/compute_beta/classes.rb', line 58998

def consumer_network
  @consumer_network
end

#endpointString

The url of a connected endpoint. Corresponds to the JSON property endpoint

Returns:

  • (String)


59003
59004
59005
# File 'lib/google/apis/compute_beta/classes.rb', line 59003

def endpoint
  @endpoint
end

#endpoint_with_idString

The url of a connected endpoint with resource id. Corresponds to the JSON property endpointWithId

Returns:

  • (String)


59008
59009
59010
# File 'lib/google/apis/compute_beta/classes.rb', line 59008

def endpoint_with_id
  @endpoint_with_id
end

#nat_ipsArray<String>

NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


59014
59015
59016
# File 'lib/google/apis/compute_beta/classes.rb', line 59014

def nat_ips
  @nat_ips
end

#propagated_connection_countFixnum

The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to. Corresponds to the JSON property propagatedConnectionCount

Returns:

  • (Fixnum)


59020
59021
59022
# File 'lib/google/apis/compute_beta/classes.rb', line 59020

def propagated_connection_count
  @propagated_connection_count
end

#psc_connection_idFixnum

The PSC connection id of the connected endpoint. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


59025
59026
59027
# File 'lib/google/apis/compute_beta/classes.rb', line 59025

def psc_connection_id
  @psc_connection_id
end

#statusString

The status of a connected endpoint to this service attachment. Corresponds to the JSON property status

Returns:

  • (String)


59030
59031
59032
# File 'lib/google/apis/compute_beta/classes.rb', line 59030

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59037
59038
59039
59040
59041
59042
59043
59044
59045
# File 'lib/google/apis/compute_beta/classes.rb', line 59037

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @status = args[:status] if args.key?(:status)
end