Class: Google::Apis::ComputeBeta::ServiceAttachmentConnectedEndpoint

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] A connection connected to this service attachment.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConnectedEndpoint

Returns a new instance of ServiceAttachmentConnectedEndpoint.



57129
57130
57131
# File 'lib/google/apis/compute_beta/classes.rb', line 57129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#consumer_networkString

The url of the consumer network. Corresponds to the JSON property consumerNetwork

Returns:

  • (String)


57095
57096
57097
# File 'lib/google/apis/compute_beta/classes.rb', line 57095

def consumer_network
  @consumer_network
end

#endpointString

The url of a connected endpoint. Corresponds to the JSON property endpoint

Returns:

  • (String)


57100
57101
57102
# File 'lib/google/apis/compute_beta/classes.rb', line 57100

def endpoint
  @endpoint
end

#endpoint_with_idString

The url of a connected endpoint with resource id. Corresponds to the JSON property endpointWithId

Returns:

  • (String)


57105
57106
57107
# File 'lib/google/apis/compute_beta/classes.rb', line 57105

def endpoint_with_id
  @endpoint_with_id
end

#nat_ipsArray<String>

NAT IPs of the connected PSC endpoint and those of other endpoints propagated from it. Corresponds to the JSON property natIps

Returns:

  • (Array<String>)


57111
57112
57113
# File 'lib/google/apis/compute_beta/classes.rb', line 57111

def nat_ips
  @nat_ips
end

#propagated_connection_countFixnum

The number of consumer Network Connectivity Center spokes that the connected Private Service Connect endpoint has propagated to. Corresponds to the JSON property propagatedConnectionCount

Returns:

  • (Fixnum)


57117
57118
57119
# File 'lib/google/apis/compute_beta/classes.rb', line 57117

def propagated_connection_count
  @propagated_connection_count
end

#psc_connection_idFixnum

The PSC connection id of the connected endpoint. Corresponds to the JSON property pscConnectionId

Returns:

  • (Fixnum)


57122
57123
57124
# File 'lib/google/apis/compute_beta/classes.rb', line 57122

def psc_connection_id
  @psc_connection_id
end

#statusString

The status of a connected endpoint to this service attachment. Corresponds to the JSON property status

Returns:

  • (String)


57127
57128
57129
# File 'lib/google/apis/compute_beta/classes.rb', line 57127

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



57134
57135
57136
57137
57138
57139
57140
57141
57142
# File 'lib/google/apis/compute_beta/classes.rb', line 57134

def update!(**args)
  @consumer_network = args[:consumer_network] if args.key?(:consumer_network)
  @endpoint = args[:endpoint] if args.key?(:endpoint)
  @endpoint_with_id = args[:endpoint_with_id] if args.key?(:endpoint_with_id)
  @nat_ips = args[:nat_ips] if args.key?(:nat_ips)
  @propagated_connection_count = args[:propagated_connection_count] if args.key?(:propagated_connection_count)
  @psc_connection_id = args[:psc_connection_id] if args.key?(:psc_connection_id)
  @status = args[:status] if args.key?(:status)
end