Class: Google::Apis::ComputeBeta::ServiceAttachmentConsumerProjectLimit

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit

Returns a new instance of ServiceAttachmentConsumerProjectLimit.



62497
62498
62499
# File 'lib/google/apis/compute_beta/classes.rb', line 62497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_limitFixnum

The value of the limit to set. For endpoint_url, the limit should be no more than 1. Corresponds to the JSON property connectionLimit

Returns:

  • (Fixnum)


62480
62481
62482
# File 'lib/google/apis/compute_beta/classes.rb', line 62480

def connection_limit
  @connection_limit
end

#endpoint_urlString

The URL for the PSC endpoint to accept Corresponds to the JSON property endpointUrl

Returns:

  • (String)


62485
62486
62487
# File 'lib/google/apis/compute_beta/classes.rb', line 62485

def endpoint_url
  @endpoint_url
end

#network_urlString

The network URL for the network to set the limit for. Corresponds to the JSON property networkUrl

Returns:

  • (String)


62490
62491
62492
# File 'lib/google/apis/compute_beta/classes.rb', line 62490

def network_url
  @network_url
end

#project_id_or_numString

The project id or number for the project to set the limit for. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


62495
62496
62497
# File 'lib/google/apis/compute_beta/classes.rb', line 62495

def project_id_or_num
  @project_id_or_num
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62502
62503
62504
62505
62506
62507
# File 'lib/google/apis/compute_beta/classes.rb', line 62502

def update!(**args)
  @connection_limit = args[:connection_limit] if args.key?(:connection_limit)
  @endpoint_url = args[:endpoint_url] if args.key?(:endpoint_url)
  @network_url = args[:network_url] if args.key?(:network_url)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
end