Class: Google::Apis::ComputeBeta::ServiceAttachmentConsumerProjectLimit

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentConsumerProjectLimit

Returns a new instance of ServiceAttachmentConsumerProjectLimit.



62386
62387
62388
# File 'lib/google/apis/compute_beta/classes.rb', line 62386

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connection_limitFixnum

The value of the limit to set. For endpoint_url, the limit should be no more than 1. Corresponds to the JSON property connectionLimit

Returns:

  • (Fixnum)


62369
62370
62371
# File 'lib/google/apis/compute_beta/classes.rb', line 62369

def connection_limit
  @connection_limit
end

#endpoint_urlString

The URL for the PSC endpoint to accept Corresponds to the JSON property endpointUrl

Returns:

  • (String)


62374
62375
62376
# File 'lib/google/apis/compute_beta/classes.rb', line 62374

def endpoint_url
  @endpoint_url
end

#network_urlString

The network URL for the network to set the limit for. Corresponds to the JSON property networkUrl

Returns:

  • (String)


62379
62380
62381
# File 'lib/google/apis/compute_beta/classes.rb', line 62379

def network_url
  @network_url
end

#project_id_or_numString

The project id or number for the project to set the limit for. Corresponds to the JSON property projectIdOrNum

Returns:

  • (String)


62384
62385
62386
# File 'lib/google/apis/compute_beta/classes.rb', line 62384

def project_id_or_num
  @project_id_or_num
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62391
62392
62393
62394
62395
62396
# File 'lib/google/apis/compute_beta/classes.rb', line 62391

def update!(**args)
  @connection_limit = args[:connection_limit] if args.key?(:connection_limit)
  @endpoint_url = args[:endpoint_url] if args.key?(:endpoint_url)
  @network_url = args[:network_url] if args.key?(:network_url)
  @project_id_or_num = args[:project_id_or_num] if args.key?(:project_id_or_num)
end