Class: Google::Apis::ComputeBeta::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
62949 62950 62951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62949 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62916 62917 62918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62916 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
62921 62922 62923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62921 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
62927 62928 62929 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62927 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62937 62938 62939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62937 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62942 62943 62944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62942 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62947 62948 62949 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62947 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62954 62955 62956 62957 62958 62959 62960 62961 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62954 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |