Class: Google::Apis::ComputeBeta::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



62471
62472
62473
# File 'lib/google/apis/compute_beta/classes.rb', line 62471

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62438
62439
62440
# File 'lib/google/apis/compute_beta/classes.rb', line 62438

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



62443
62444
62445
# File 'lib/google/apis/compute_beta/classes.rb', line 62443

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


62449
62450
62451
# File 'lib/google/apis/compute_beta/classes.rb', line 62449

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62459
62460
62461
# File 'lib/google/apis/compute_beta/classes.rb', line 62459

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62464
62465
62466
# File 'lib/google/apis/compute_beta/classes.rb', line 62464

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62469
62470
62471
# File 'lib/google/apis/compute_beta/classes.rb', line 62469

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62476
62477
62478
62479
62480
62481
62482
62483
# File 'lib/google/apis/compute_beta/classes.rb', line 62476

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end