Class: Google::Apis::ComputeBeta::ServiceAttachmentList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ServiceAttachmentList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::ServiceAttachment>
A list of ServiceAttachment resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceAttachmentList
constructor
A new instance of ServiceAttachmentList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceAttachmentList
Returns a new instance of ServiceAttachmentList.
62439 62440 62441 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62439 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62406 62407 62408 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62406 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::ServiceAttachment>
A list of ServiceAttachment resources.
Corresponds to the JSON property items
62411 62412 62413 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62411 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
serviceAttachment for service attachments.
Corresponds to the JSON property kind
62417 62418 62419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62417 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62427 62428 62429 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62427 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62432 62433 62434 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62432 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ServiceAttachmentList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62437 62438 62439 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62437 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62444 62445 62446 62447 62448 62449 62450 62451 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62444 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |