Class: Google::Apis::ComputeBeta::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



62005
62006
62007
# File 'lib/google/apis/compute_beta/classes.rb', line 62005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61972
61973
61974
# File 'lib/google/apis/compute_beta/classes.rb', line 61972

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



61977
61978
61979
# File 'lib/google/apis/compute_beta/classes.rb', line 61977

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


61983
61984
61985
# File 'lib/google/apis/compute_beta/classes.rb', line 61983

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61993
61994
61995
# File 'lib/google/apis/compute_beta/classes.rb', line 61993

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61998
61999
62000
# File 'lib/google/apis/compute_beta/classes.rb', line 61998

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62003
62004
62005
# File 'lib/google/apis/compute_beta/classes.rb', line 62003

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62010
62011
62012
62013
62014
62015
62016
62017
# File 'lib/google/apis/compute_beta/classes.rb', line 62010

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end