Class: Google::Apis::ComputeBeta::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



61129
61130
61131
# File 'lib/google/apis/compute_beta/classes.rb', line 61129

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61096
61097
61098
# File 'lib/google/apis/compute_beta/classes.rb', line 61096

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



61101
61102
61103
# File 'lib/google/apis/compute_beta/classes.rb', line 61101

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


61107
61108
61109
# File 'lib/google/apis/compute_beta/classes.rb', line 61107

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61117
61118
61119
# File 'lib/google/apis/compute_beta/classes.rb', line 61117

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61122
61123
61124
# File 'lib/google/apis/compute_beta/classes.rb', line 61122

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61127
61128
61129
# File 'lib/google/apis/compute_beta/classes.rb', line 61127

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61134
61135
61136
61137
61138
61139
61140
61141
# File 'lib/google/apis/compute_beta/classes.rb', line 61134

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end