Class: Google::Apis::ComputeBeta::ServiceAttachmentList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentList

Returns a new instance of ServiceAttachmentList.



60309
60310
60311
# File 'lib/google/apis/compute_beta/classes.rb', line 60309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


60276
60277
60278
# File 'lib/google/apis/compute_beta/classes.rb', line 60276

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::ServiceAttachment>

A list of ServiceAttachment resources. Corresponds to the JSON property items



60281
60282
60283
# File 'lib/google/apis/compute_beta/classes.rb', line 60281

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute# serviceAttachment for service attachments. Corresponds to the JSON property kind

Returns:

  • (String)


60287
60288
60289
# File 'lib/google/apis/compute_beta/classes.rb', line 60287

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


60297
60298
60299
# File 'lib/google/apis/compute_beta/classes.rb', line 60297

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


60302
60303
60304
# File 'lib/google/apis/compute_beta/classes.rb', line 60302

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ServiceAttachmentList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



60307
60308
60309
# File 'lib/google/apis/compute_beta/classes.rb', line 60307

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60314
60315
60316
60317
60318
60319
60320
60321
# File 'lib/google/apis/compute_beta/classes.rb', line 60314

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end