Class: Google::Apis::ComputeBeta::ServiceAttachmentTunnelingConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Use to configure this PSC connection in tunneling mode. In tunneling mode traffic from consumer to producer will be encapsulated as it crosses the VPC boundary and traffic from producer to consumer will be decapsulated in the same manner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceAttachmentTunnelingConfig

Returns a new instance of ServiceAttachmentTunnelingConfig.



60413
60414
60415
# File 'lib/google/apis/compute_beta/classes.rb', line 60413

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#encapsulation_profileString

Specify the encapsulation protocol and what metadata to include in incoming encapsulated packet headers. Corresponds to the JSON property encapsulationProfile

Returns:

  • (String)


60405
60406
60407
# File 'lib/google/apis/compute_beta/classes.rb', line 60405

def encapsulation_profile
  @encapsulation_profile
end

#routing_modeString

How this Service Attachment will treat traffic sent to the tunnel_ip, destined for the consumer network. Corresponds to the JSON property routingMode

Returns:

  • (String)


60411
60412
60413
# File 'lib/google/apis/compute_beta/classes.rb', line 60411

def routing_mode
  @routing_mode
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60418
60419
60420
60421
# File 'lib/google/apis/compute_beta/classes.rb', line 60418

def update!(**args)
  @encapsulation_profile = args[:encapsulation_profile] if args.key?(:encapsulation_profile)
  @routing_mode = args[:routing_mode] if args.key?(:routing_mode)
end