Class: Google::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo

Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.



62233
62234
62235
# File 'lib/google/apis/compute_beta/classes.rb', line 62233

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::ComputeBeta::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



62225
62226
62227
# File 'lib/google/apis/compute_beta/classes.rb', line 62225

def error
  @error
end

#stateString

[Output Only] Status of the action, which can be one of the following: PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE. Corresponds to the JSON property state

Returns:

  • (String)


62231
62232
62233
# File 'lib/google/apis/compute_beta/classes.rb', line 62231

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62238
62239
62240
62241
# File 'lib/google/apis/compute_beta/classes.rb', line 62238

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @state = args[:state] if args.key?(:state)
end