Class: Google::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::ComputeBeta::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING,PROPAGATED,ABANDONED,FAILED, orDONE.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
constructor
A new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo
Returns a new instance of SetCommonInstanceMetadataOperationMetadataPerLocationOperationInfo.
61446 61447 61448 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61446 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::ComputeBeta::Status
The Status type defines a logical error model that is suitable for
different programming environments, including REST APIs and RPC APIs. It is
used by gRPC. Each Status message contains
three pieces of data: error code, error message, and error details.
You can find out more about this error model and how to work with it in the
API Design Guide.
Corresponds to the JSON property error
61438 61439 61440 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61438 def error @error end |
#state ⇒ String
[Output Only] Status of the action, which can be one of the following:
PROPAGATING, PROPAGATED, ABANDONED, FAILED, or DONE.
Corresponds to the JSON property state
61444 61445 61446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61444 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61451 61452 61453 61454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61451 def update!(**args) @error = args[:error] if args.key?(:error) @state = args[:state] if args.key?(:state) end |