Class: Google::Apis::ComputeBeta::ShareSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The share setting for reservations and sole tenancy node groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ShareSettings

Returns a new instance of ShareSettings.



62274
62275
62276
# File 'lib/google/apis/compute_beta/classes.rb', line 62274

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#folder_mapHash<String,Google::Apis::ComputeBeta::ShareSettingsFolderConfig>

A map of folder id and folder config to specify consumer projects for this shared-reservation. This is only valid when share_type's value is DIRECT_PROJECTS_UNDER_SPECIFIC_FOLDERS. Folder id should be a string of number, and without "folders/" prefix. Corresponds to the JSON property folderMap



62254
62255
62256
# File 'lib/google/apis/compute_beta/classes.rb', line 62254

def folder_map
  @folder_map
end

#project_mapHash<String,Google::Apis::ComputeBeta::ShareSettingsProjectConfig>

A map of project id and project config. This is only valid when share_type's value is SPECIFIC_PROJECTS. Corresponds to the JSON property projectMap



62260
62261
62262
# File 'lib/google/apis/compute_beta/classes.rb', line 62260

def project_map
  @project_map
end

#projectsArray<String>

A List of Project names to specify consumer projects for this shared-reservation. This is only valid when share_type's value is SPECIFIC_PROJECTS. Corresponds to the JSON property projects

Returns:

  • (Array<String>)


62267
62268
62269
# File 'lib/google/apis/compute_beta/classes.rb', line 62267

def projects
  @projects
end

#share_typeString

Type of sharing for this shared-reservation Corresponds to the JSON property shareType

Returns:

  • (String)


62272
62273
62274
# File 'lib/google/apis/compute_beta/classes.rb', line 62272

def share_type
  @share_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62279
62280
62281
62282
62283
62284
# File 'lib/google/apis/compute_beta/classes.rb', line 62279

def update!(**args)
  @folder_map = args[:folder_map] if args.key?(:folder_map)
  @project_map = args[:project_map] if args.key?(:project_map)
  @projects = args[:projects] if args.key?(:projects)
  @share_type = args[:share_type] if args.key?(:share_type)
end