Class: Google::Apis::ComputeBeta::Snapshot

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Persistent Disk Snapshot resource. You can use snapshots to back up data on a regular interval. For more information, read Creating persistent disk snapshots.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Snapshot

Returns a new instance of Snapshot.



62034
62035
62036
# File 'lib/google/apis/compute_beta/classes.rb', line 62034

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#architectureString

Output only. [Output Only] The architecture of the snapshot. Valid values are ARM64 or X86_64. Corresponds to the JSON property architecture

Returns:

  • (String)


61736
61737
61738
# File 'lib/google/apis/compute_beta/classes.rb', line 61736

def architecture
  @architecture
end

#auto_createdBoolean Also known as: auto_created?

Output only. [Output Only] Set to true if snapshots are automatically created by applying resource policy on the target disk. Corresponds to the JSON property autoCreated

Returns:

  • (Boolean)


61743
61744
61745
# File 'lib/google/apis/compute_beta/classes.rb', line 61743

def auto_created
  @auto_created
end

#chain_nameString

Creates the new snapshot in the snapshot chain labeled with the specified name. The chain name must be 1-63 characters long and comply with RFC1035. This is an uncommon option only for advanced service owners who needs to create separate snapshot chains, for example, for chargeback tracking. When you describe your snapshot resource, this field is visible only if it has a non-empty value. Corresponds to the JSON property chainName

Returns:

  • (String)


61754
61755
61756
# File 'lib/google/apis/compute_beta/classes.rb', line 61754

def chain_name
  @chain_name
end

#creation_size_bytesFixnum

Output only. [Output Only] Size in bytes of the snapshot at creation time. Corresponds to the JSON property creationSizeBytes

Returns:

  • (Fixnum)


61759
61760
61761
# File 'lib/google/apis/compute_beta/classes.rb', line 61759

def creation_size_bytes
  @creation_size_bytes
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


61765
61766
61767
# File 'lib/google/apis/compute_beta/classes.rb', line 61765

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


61771
61772
61773
# File 'lib/google/apis/compute_beta/classes.rb', line 61771

def description
  @description
end

#disk_size_gbFixnum

Output only. [Output Only] Size of the source disk, specified in GB. Corresponds to the JSON property diskSizeGb

Returns:

  • (Fixnum)


61776
61777
61778
# File 'lib/google/apis/compute_beta/classes.rb', line 61776

def disk_size_gb
  @disk_size_gb
end

#download_bytesFixnum

Output only. [Output Only] Number of bytes downloaded to restore a snapshot to a disk. Corresponds to the JSON property downloadBytes

Returns:

  • (Fixnum)


61782
61783
61784
# File 'lib/google/apis/compute_beta/classes.rb', line 61782

def download_bytes
  @download_bytes
end

#enable_confidential_computeBoolean Also known as: enable_confidential_compute?

Output only. Whether this snapshot is created from a confidential compute mode disk. [Output Only]: This field is not set by user, but from source disk. Corresponds to the JSON property enableConfidentialCompute

Returns:

  • (Boolean)


61789
61790
61791
# File 'lib/google/apis/compute_beta/classes.rb', line 61789

def enable_confidential_compute
  @enable_confidential_compute
end

#guest_flushBoolean Also known as: guest_flush?

[Input Only] Whether to attempt an application consistent snapshot by informing the OS to prepare for the snapshot process. Corresponds to the JSON property guestFlush

Returns:

  • (Boolean)


61796
61797
61798
# File 'lib/google/apis/compute_beta/classes.rb', line 61796

def guest_flush
  @guest_flush
end

#guest_os_featuresArray<Google::Apis::ComputeBeta::GuestOsFeature>

Output only. [Output Only] A list of features to enable on the guest operating system. Applicable only for bootable images. Read Enabling guest operating system features to see a list of available options. Corresponds to the JSON property guestOsFeatures



61806
61807
61808
# File 'lib/google/apis/compute_beta/classes.rb', line 61806

def guest_os_features
  @guest_os_features
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


61813
61814
61815
# File 'lib/google/apis/compute_beta/classes.rb', line 61813

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#snapshot for Snapshot resources. Corresponds to the JSON property kind

Returns:

  • (String)


61819
61820
61821
# File 'lib/google/apis/compute_beta/classes.rb', line 61819

def kind
  @kind
end

#label_fingerprintString

A fingerprint for the labels being applied to this snapshot, which is essentially a hash of the labels set used for optimistic locking. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels, otherwise the request will fail with error412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a snapshot. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


61832
61833
61834
# File 'lib/google/apis/compute_beta/classes.rb', line 61832

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

Labels to apply to this snapshot. These can be later modified by the setLabels method. Label values may be empty. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


61839
61840
61841
# File 'lib/google/apis/compute_beta/classes.rb', line 61839

def labels
  @labels
end

#license_codesArray<Fixnum>

Output only. [Output Only] Integer license codes indicating which licenses are attached to this snapshot. Corresponds to the JSON property licenseCodes

Returns:

  • (Array<Fixnum>)


61846
61847
61848
# File 'lib/google/apis/compute_beta/classes.rb', line 61846

def license_codes
  @license_codes
end

#licensesArray<String>

Output only. [Output Only] A list of public visible licenses that apply to this snapshot. This can be because the original image had licenses attached (such as a Windows image). Corresponds to the JSON property licenses

Returns:

  • (Array<String>)


61854
61855
61856
# File 'lib/google/apis/compute_beta/classes.rb', line 61854

def licenses
  @licenses
end

#location_hintString

An opaque location hint used to place the snapshot close to other resources. This field is for use by internal tools that use the public API. Corresponds to the JSON property locationHint

Returns:

  • (String)


61861
61862
61863
# File 'lib/google/apis/compute_beta/classes.rb', line 61861

def location_hint
  @location_hint
end

#nameString

Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


61872
61873
61874
# File 'lib/google/apis/compute_beta/classes.rb', line 61872

def name
  @name
end

#paramsGoogle::Apis::ComputeBeta::SnapshotParams

Additional snapshot params. Corresponds to the JSON property params



61877
61878
61879
# File 'lib/google/apis/compute_beta/classes.rb', line 61877

def params
  @params
end

#regionString

Output only. [Output Only] URL of the region where the snapshot resides. Only applicable for regional snapshots. Corresponds to the JSON property region

Returns:

  • (String)


61884
61885
61886
# File 'lib/google/apis/compute_beta/classes.rb', line 61884

def region
  @region
end

#satisfies_pziBoolean Also known as: satisfies_pzi?

Output only. Reserved for future use. Corresponds to the JSON property satisfiesPzi

Returns:

  • (Boolean)


61889
61890
61891
# File 'lib/google/apis/compute_beta/classes.rb', line 61889

def satisfies_pzi
  @satisfies_pzi
end

#satisfies_pzsBoolean Also known as: satisfies_pzs?

Output only. [Output Only] Reserved for future use. Corresponds to the JSON property satisfiesPzs

Returns:

  • (Boolean)


61895
61896
61897
# File 'lib/google/apis/compute_beta/classes.rb', line 61895

def satisfies_pzs
  @satisfies_pzs
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61901
61902
61903
# File 'lib/google/apis/compute_beta/classes.rb', line 61901

def self_link
  @self_link
end

#snapshot_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Encrypts the snapshot using acustomer-supplied encryption key. After you encrypt a snapshot using a customer-supplied key, you must provide the same key if you use the snapshot later. For example, you must provide the encryption key when you create a disk from the encrypted snapshot in a future request. Customer-supplied encryption keys do not protect access to metadata of the snapshot. If you do not provide an encryption key when creating the snapshot, then the snapshot will be encrypted using an automatically generated key and you do not need to provide a key to use the snapshot later. Corresponds to the JSON property snapshotEncryptionKey



61916
61917
61918
# File 'lib/google/apis/compute_beta/classes.rb', line 61916

def snapshot_encryption_key
  @snapshot_encryption_key
end

#snapshot_group_idString

Output only. [Output Only] The unique ID of the snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted. Corresponds to the JSON property snapshotGroupId

Returns:

  • (String)


61923
61924
61925
# File 'lib/google/apis/compute_beta/classes.rb', line 61923

def snapshot_group_id
  @snapshot_group_id
end

#snapshot_group_nameString

Output only. [Output only] The snapshot group that this snapshot belongs to. The usage of snapshot group feature is restricted. Corresponds to the JSON property snapshotGroupName

Returns:

  • (String)


61930
61931
61932
# File 'lib/google/apis/compute_beta/classes.rb', line 61930

def snapshot_group_name
  @snapshot_group_name
end

#snapshot_typeString

Indicates the type of the snapshot. Corresponds to the JSON property snapshotType

Returns:

  • (String)


61935
61936
61937
# File 'lib/google/apis/compute_beta/classes.rb', line 61935

def snapshot_type
  @snapshot_type
end

#source_diskString

The source disk used to create this snapshot. Corresponds to the JSON property sourceDisk

Returns:

  • (String)


61940
61941
61942
# File 'lib/google/apis/compute_beta/classes.rb', line 61940

def source_disk
  @source_disk
end

#source_disk_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

The customer-supplied encryption key of the source disk. Required if the source disk is protected by a customer-supplied encryption key. Corresponds to the JSON property sourceDiskEncryptionKey



61947
61948
61949
# File 'lib/google/apis/compute_beta/classes.rb', line 61947

def source_disk_encryption_key
  @source_disk_encryption_key
end

#source_disk_for_recovery_checkpointString

The source disk whose recovery checkpoint will be used to create this snapshot. Corresponds to the JSON property sourceDiskForRecoveryCheckpoint

Returns:

  • (String)


61953
61954
61955
# File 'lib/google/apis/compute_beta/classes.rb', line 61953

def source_disk_for_recovery_checkpoint
  @source_disk_for_recovery_checkpoint
end

#source_disk_idString

Output only. [Output Only] The ID value of the disk used to create this snapshot. This value may be used to determine whether the snapshot was taken from the current or a previous instance of a given disk name. Corresponds to the JSON property sourceDiskId

Returns:

  • (String)


61961
61962
61963
# File 'lib/google/apis/compute_beta/classes.rb', line 61961

def source_disk_id
  @source_disk_id
end

#source_instant_snapshotString

The source instant snapshot used to create this snapshot. You can provide this as a partial or full URL to the resource. For example, the following are valid values:

Returns:

  • (String)


61974
61975
61976
# File 'lib/google/apis/compute_beta/classes.rb', line 61974

def source_instant_snapshot
  @source_instant_snapshot
end

#source_instant_snapshot_encryption_keyGoogle::Apis::ComputeBeta::CustomerEncryptionKey

Customer provided encryption key when creating Snapshot from Instant Snapshot. Corresponds to the JSON property sourceInstantSnapshotEncryptionKey



61980
61981
61982
# File 'lib/google/apis/compute_beta/classes.rb', line 61980

def source_instant_snapshot_encryption_key
  @source_instant_snapshot_encryption_key
end

#source_instant_snapshot_idString

Output only. [Output Only] The unique ID of the instant snapshot used to create this snapshot. This value identifies the exact instant snapshot that was used to create this snapshot. For example, if you created the snapshot from an instant snapshot that was later deleted and recreated under the same name, the source instant snapshot ID would identify the exact instant snapshot that was used. Corresponds to the JSON property sourceInstantSnapshotId

Returns:

  • (String)


61991
61992
61993
# File 'lib/google/apis/compute_beta/classes.rb', line 61991

def source_instant_snapshot_id
  @source_instant_snapshot_id
end

#source_snapshot_schedule_policyString

Output only. [Output Only] URL of the resource policy which created this scheduled snapshot. Corresponds to the JSON property sourceSnapshotSchedulePolicy

Returns:

  • (String)


61997
61998
61999
# File 'lib/google/apis/compute_beta/classes.rb', line 61997

def source_snapshot_schedule_policy
  @source_snapshot_schedule_policy
end

#source_snapshot_schedule_policy_idString

Output only. [Output Only] ID of the resource policy which created this scheduled snapshot. Corresponds to the JSON property sourceSnapshotSchedulePolicyId

Returns:

  • (String)


62003
62004
62005
# File 'lib/google/apis/compute_beta/classes.rb', line 62003

def source_snapshot_schedule_policy_id
  @source_snapshot_schedule_policy_id
end

#statusString

Output only. [Output Only] The status of the snapshot. This can beCREATING, DELETING, FAILED,READY, or UPLOADING. Corresponds to the JSON property status

Returns:

  • (String)


62009
62010
62011
# File 'lib/google/apis/compute_beta/classes.rb', line 62009

def status
  @status
end

#storage_bytesFixnum

Output only. [Output Only] A size of the storage used by the snapshot. As snapshots share storage, this number is expected to change with snapshot creation/deletion. Corresponds to the JSON property storageBytes

Returns:

  • (Fixnum)


62017
62018
62019
# File 'lib/google/apis/compute_beta/classes.rb', line 62017

def storage_bytes
  @storage_bytes
end

#storage_bytes_statusString

Output only. [Output Only] An indicator whether storageBytes is in a stable state or it is being adjusted as a result of shared storage reallocation. This status can either be UPDATING, meaning the size of the snapshot is being updated, or UP_TO_DATE, meaning the size of the snapshot is up-to-date. Corresponds to the JSON property storageBytesStatus

Returns:

  • (String)


62026
62027
62028
# File 'lib/google/apis/compute_beta/classes.rb', line 62026

def storage_bytes_status
  @storage_bytes_status
end

#storage_locationsArray<String>

Cloud Storage bucket storage location of the snapshot (regional or multi-regional). Corresponds to the JSON property storageLocations

Returns:

  • (Array<String>)


62032
62033
62034
# File 'lib/google/apis/compute_beta/classes.rb', line 62032

def storage_locations
  @storage_locations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62039
62040
62041
62042
62043
62044
62045
62046
62047
62048
62049
62050
62051
62052
62053
62054
62055
62056
62057
62058
62059
62060
62061
62062
62063
62064
62065
62066
62067
62068
62069
62070
62071
62072
62073
62074
62075
62076
62077
62078
62079
62080
62081
# File 'lib/google/apis/compute_beta/classes.rb', line 62039

def update!(**args)
  @architecture = args[:architecture] if args.key?(:architecture)
  @auto_created = args[:auto_created] if args.key?(:auto_created)
  @chain_name = args[:chain_name] if args.key?(:chain_name)
  @creation_size_bytes = args[:creation_size_bytes] if args.key?(:creation_size_bytes)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @disk_size_gb = args[:disk_size_gb] if args.key?(:disk_size_gb)
  @download_bytes = args[:download_bytes] if args.key?(:download_bytes)
  @enable_confidential_compute = args[:enable_confidential_compute] if args.key?(:enable_confidential_compute)
  @guest_flush = args[:guest_flush] if args.key?(:guest_flush)
  @guest_os_features = args[:guest_os_features] if args.key?(:guest_os_features)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
  @license_codes = args[:license_codes] if args.key?(:license_codes)
  @licenses = args[:licenses] if args.key?(:licenses)
  @location_hint = args[:location_hint] if args.key?(:location_hint)
  @name = args[:name] if args.key?(:name)
  @params = args[:params] if args.key?(:params)
  @region = args[:region] if args.key?(:region)
  @satisfies_pzi = args[:satisfies_pzi] if args.key?(:satisfies_pzi)
  @satisfies_pzs = args[:satisfies_pzs] if args.key?(:satisfies_pzs)
  @self_link = args[:self_link] if args.key?(:self_link)
  @snapshot_encryption_key = args[:snapshot_encryption_key] if args.key?(:snapshot_encryption_key)
  @snapshot_group_id = args[:snapshot_group_id] if args.key?(:snapshot_group_id)
  @snapshot_group_name = args[:snapshot_group_name] if args.key?(:snapshot_group_name)
  @snapshot_type = args[:snapshot_type] if args.key?(:snapshot_type)
  @source_disk = args[:source_disk] if args.key?(:source_disk)
  @source_disk_encryption_key = args[:source_disk_encryption_key] if args.key?(:source_disk_encryption_key)
  @source_disk_for_recovery_checkpoint = args[:source_disk_for_recovery_checkpoint] if args.key?(:source_disk_for_recovery_checkpoint)
  @source_disk_id = args[:source_disk_id] if args.key?(:source_disk_id)
  @source_instant_snapshot = args[:source_instant_snapshot] if args.key?(:source_instant_snapshot)
  @source_instant_snapshot_encryption_key = args[:source_instant_snapshot_encryption_key] if args.key?(:source_instant_snapshot_encryption_key)
  @source_instant_snapshot_id = args[:source_instant_snapshot_id] if args.key?(:source_instant_snapshot_id)
  @source_snapshot_schedule_policy = args[:source_snapshot_schedule_policy] if args.key?(:source_snapshot_schedule_policy)
  @source_snapshot_schedule_policy_id = args[:source_snapshot_schedule_policy_id] if args.key?(:source_snapshot_schedule_policy_id)
  @status = args[:status] if args.key?(:status)
  @storage_bytes = args[:storage_bytes] if args.key?(:storage_bytes)
  @storage_bytes_status = args[:storage_bytes_status] if args.key?(:storage_bytes_status)
  @storage_locations = args[:storage_locations] if args.key?(:storage_locations)
end