Class: Google::Apis::ComputeBeta::SnapshotGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a SnapshotGroup resource. A snapshot group is a set of snapshots that represents a point in time state of a consistency group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotGroup

Returns a new instance of SnapshotGroup.



63175
63176
63177
# File 'lib/google/apis/compute_beta/classes.rb', line 63175

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63110
63111
63112
# File 'lib/google/apis/compute_beta/classes.rb', line 63110

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


63117
63118
63119
# File 'lib/google/apis/compute_beta/classes.rb', line 63117

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63124
63125
63126
# File 'lib/google/apis/compute_beta/classes.rb', line 63124

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#snapshotGroup for SnapshotGroup resources. Corresponds to the JSON property kind

Returns:

  • (String)


63131
63132
63133
# File 'lib/google/apis/compute_beta/classes.rb', line 63131

def kind
  @kind
end

#nameString

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63143
63144
63145
# File 'lib/google/apis/compute_beta/classes.rb', line 63143

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63148
63149
63150
# File 'lib/google/apis/compute_beta/classes.rb', line 63148

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


63153
63154
63155
# File 'lib/google/apis/compute_beta/classes.rb', line 63153

def self_link_with_id
  @self_link_with_id
end

#source_infoGoogle::Apis::ComputeBeta::SnapshotGroupSourceInfo

Output only. [Output Only] Corresponds to the JSON property sourceInfo



63158
63159
63160
# File 'lib/google/apis/compute_beta/classes.rb', line 63158

def source_info
  @source_info
end

#source_instant_snapshot_groupString

Input field for the source instant snapshot group. Corresponds to the JSON property sourceInstantSnapshotGroup

Returns:

  • (String)


63163
63164
63165
# File 'lib/google/apis/compute_beta/classes.rb', line 63163

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

#source_instant_snapshot_group_infoGoogle::Apis::ComputeBeta::SnapshotGroupSourceInstantSnapshotGroupInfo

Output only. [Output Only] Corresponds to the JSON property sourceInstantSnapshotGroupInfo



63168
63169
63170
# File 'lib/google/apis/compute_beta/classes.rb', line 63168

def source_instant_snapshot_group_info
  @source_instant_snapshot_group_info
end

#statusString

Output only. [Output Only] Corresponds to the JSON property status

Returns:

  • (String)


63173
63174
63175
# File 'lib/google/apis/compute_beta/classes.rb', line 63173

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63180
63181
63182
63183
63184
63185
63186
63187
63188
63189
63190
63191
63192
# File 'lib/google/apis/compute_beta/classes.rb', line 63180

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_info = args[:source_info] if args.key?(:source_info)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
  @source_instant_snapshot_group_info = args[:source_instant_snapshot_group_info] if args.key?(:source_instant_snapshot_group_info)
  @status = args[:status] if args.key?(:status)
end