Class: Google::Apis::ComputeBeta::SnapshotGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a SnapshotGroup resource. A snapshot group is a set of snapshots that represents a point in time state of a consistency group.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotGroup

Returns a new instance of SnapshotGroup.



62356
62357
62358
# File 'lib/google/apis/compute_beta/classes.rb', line 62356

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


62291
62292
62293
# File 'lib/google/apis/compute_beta/classes.rb', line 62291

def creation_timestamp
  @creation_timestamp
end

#descriptionString

Optional. An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


62298
62299
62300
# File 'lib/google/apis/compute_beta/classes.rb', line 62298

def description
  @description
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


62305
62306
62307
# File 'lib/google/apis/compute_beta/classes.rb', line 62305

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#snapshotGroup for SnapshotGroup resources. Corresponds to the JSON property kind

Returns:

  • (String)


62312
62313
62314
# File 'lib/google/apis/compute_beta/classes.rb', line 62312

def kind
  @kind
end

#nameString

Identifier. Name of the resource; provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


62324
62325
62326
# File 'lib/google/apis/compute_beta/classes.rb', line 62324

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62329
62330
62331
# File 'lib/google/apis/compute_beta/classes.rb', line 62329

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL for this resource's resource id. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


62334
62335
62336
# File 'lib/google/apis/compute_beta/classes.rb', line 62334

def self_link_with_id
  @self_link_with_id
end

#source_infoGoogle::Apis::ComputeBeta::SnapshotGroupSourceInfo

Output only. [Output Only] Corresponds to the JSON property sourceInfo



62339
62340
62341
# File 'lib/google/apis/compute_beta/classes.rb', line 62339

def source_info
  @source_info
end

#source_instant_snapshot_groupString

Input field for the source instant snapshot group. Corresponds to the JSON property sourceInstantSnapshotGroup

Returns:

  • (String)


62344
62345
62346
# File 'lib/google/apis/compute_beta/classes.rb', line 62344

def source_instant_snapshot_group
  @source_instant_snapshot_group
end

#source_instant_snapshot_group_infoGoogle::Apis::ComputeBeta::SnapshotGroupSourceInstantSnapshotGroupInfo

Output only. [Output Only] Corresponds to the JSON property sourceInstantSnapshotGroupInfo



62349
62350
62351
# File 'lib/google/apis/compute_beta/classes.rb', line 62349

def source_instant_snapshot_group_info
  @source_instant_snapshot_group_info
end

#statusString

Output only. [Output Only] Corresponds to the JSON property status

Returns:

  • (String)


62354
62355
62356
# File 'lib/google/apis/compute_beta/classes.rb', line 62354

def status
  @status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62361
62362
62363
62364
62365
62366
62367
62368
62369
62370
62371
62372
62373
# File 'lib/google/apis/compute_beta/classes.rb', line 62361

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @source_info = args[:source_info] if args.key?(:source_info)
  @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group)
  @source_instant_snapshot_group_info = args[:source_instant_snapshot_group_info] if args.key?(:source_instant_snapshot_group_info)
  @status = args[:status] if args.key?(:status)
end