Class: Google::Apis::ComputeBeta::SnapshotGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a SnapshotGroup resource. A snapshot group is a set of snapshots that represents a point in time state of a consistency group.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInfo
Output only.
-
#source_instant_snapshot_group ⇒ String
Input field for the source instant snapshot group.
-
#source_instant_snapshot_group_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInstantSnapshotGroupInfo
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotGroup
constructor
A new instance of SnapshotGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotGroup
Returns a new instance of SnapshotGroup.
61477 61478 61479 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61477 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
61412 61413 61414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61412 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource. Provide this property when
you
create the resource.
Corresponds to the JSON property description
61419 61420 61421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61419 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
61426 61427 61428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61426 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#snapshotGroup
for SnapshotGroup
resources.
Corresponds to the JSON property kind
61433 61434 61435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61433 def kind @kind end |
#name ⇒ String
Identifier. Name of the resource; provided by the client when the resource is
created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
61445 61446 61447 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61445 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
61450 61451 61452 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61450 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
61455 61456 61457 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61455 def self_link_with_id @self_link_with_id end |
#source_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInfo
Output only. [Output Only]
Corresponds to the JSON property sourceInfo
61460 61461 61462 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61460 def source_info @source_info end |
#source_instant_snapshot_group ⇒ String
Input field for the source instant snapshot group.
Corresponds to the JSON property sourceInstantSnapshotGroup
61465 61466 61467 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61465 def source_instant_snapshot_group @source_instant_snapshot_group end |
#source_instant_snapshot_group_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInstantSnapshotGroupInfo
Output only. [Output Only]
Corresponds to the JSON property sourceInstantSnapshotGroupInfo
61470 61471 61472 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61470 def source_instant_snapshot_group_info @source_instant_snapshot_group_info end |
#status ⇒ String
Output only. [Output Only]
Corresponds to the JSON property status
61475 61476 61477 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61475 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61482 61483 61484 61485 61486 61487 61488 61489 61490 61491 61492 61493 61494 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61482 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_info = args[:source_info] if args.key?(:source_info) @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group) @source_instant_snapshot_group_info = args[:source_instant_snapshot_group_info] if args.key?(:source_instant_snapshot_group_info) @status = args[:status] if args.key?(:status) end |