Class: Google::Apis::ComputeBeta::SnapshotGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a SnapshotGroup resource. A snapshot group is a set of snapshots that represents a point in time state of a consistency group.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Identifier.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#source_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInfo
Output only.
-
#source_instant_snapshot_group ⇒ String
Input field for the source instant snapshot group.
-
#source_instant_snapshot_group_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInstantSnapshotGroupInfo
Output only.
-
#status ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotGroup
constructor
A new instance of SnapshotGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotGroup
Returns a new instance of SnapshotGroup.
60292 60293 60294 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60292 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
60227 60228 60229 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60227 def @creation_timestamp end |
#description ⇒ String
Optional. An optional description of this resource. Provide this property when
you
create the resource.
Corresponds to the JSON property description
60234 60235 60236 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60234 def description @description end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
60241 60242 60243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60241 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#snapshotGroup
for SnapshotGroup
resources.
Corresponds to the JSON property kind
60248 60249 60250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60248 def kind @kind end |
#name ⇒ String
Identifier. Name of the resource; provided by the client when the resource is
created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must be
a dash, lowercase letter, or digit, except the last character, which cannot
be a dash.
Corresponds to the JSON property name
60260 60261 60262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60260 def name @name end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
60265 60266 60267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60265 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
60270 60271 60272 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60270 def self_link_with_id @self_link_with_id end |
#source_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInfo
Output only. [Output Only]
Corresponds to the JSON property sourceInfo
60275 60276 60277 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60275 def source_info @source_info end |
#source_instant_snapshot_group ⇒ String
Input field for the source instant snapshot group.
Corresponds to the JSON property sourceInstantSnapshotGroup
60280 60281 60282 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60280 def source_instant_snapshot_group @source_instant_snapshot_group end |
#source_instant_snapshot_group_info ⇒ Google::Apis::ComputeBeta::SnapshotGroupSourceInstantSnapshotGroupInfo
Output only. [Output Only]
Corresponds to the JSON property sourceInstantSnapshotGroupInfo
60285 60286 60287 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60285 def source_instant_snapshot_group_info @source_instant_snapshot_group_info end |
#status ⇒ String
Output only. [Output Only]
Corresponds to the JSON property status
60290 60291 60292 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60290 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60297 60298 60299 60300 60301 60302 60303 60304 60305 60306 60307 60308 60309 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60297 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @source_info = args[:source_info] if args.key?(:source_info) @source_instant_snapshot_group = args[:source_instant_snapshot_group] if args.key?(:source_instant_snapshot_group) @source_instant_snapshot_group_info = args[:source_instant_snapshot_group_info] if args.key?(:source_instant_snapshot_group_info) @status = args[:status] if args.key?(:status) end |