Class: Google::Apis::ComputeBeta::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
64301 64302 64303 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64301 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64269 64270 64271 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64269 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
64274 64275 64276 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64274 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64279 64280 64281 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64279 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64289 64290 64291 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64289 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64294 64295 64296 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64294 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64299 64300 64301 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64299 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64306 64307 64308 64309 64310 64311 64312 64313 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64306 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |