Class: Google::Apis::ComputeBeta::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



63791
63792
63793
# File 'lib/google/apis/compute_beta/classes.rb', line 63791

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63759
63760
63761
# File 'lib/google/apis/compute_beta/classes.rb', line 63759

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



63764
63765
63766
# File 'lib/google/apis/compute_beta/classes.rb', line 63764

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63769
63770
63771
# File 'lib/google/apis/compute_beta/classes.rb', line 63769

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63779
63780
63781
# File 'lib/google/apis/compute_beta/classes.rb', line 63779

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63784
63785
63786
# File 'lib/google/apis/compute_beta/classes.rb', line 63784

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63789
63790
63791
# File 'lib/google/apis/compute_beta/classes.rb', line 63789

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63796
63797
63798
63799
63800
63801
63802
63803
# File 'lib/google/apis/compute_beta/classes.rb', line 63796

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end