Class: Google::Apis::ComputeBeta::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
63327 63328 63329 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63327 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
63295 63296 63297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63295 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
63300 63301 63302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63300 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
63305 63306 63307 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63305 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
63315 63316 63317 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63315 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
63320 63321 63322 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63320 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
63325 63326 63327 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63325 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63332 63333 63334 63335 63336 63337 63338 63339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63332 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |