Class: Google::Apis::ComputeBeta::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
62508 62509 62510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62508 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62476 62477 62478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62476 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
62481 62482 62483 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62481 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
62486 62487 62488 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62486 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62496 62497 62498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62496 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62501 62502 62503 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62501 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62506 62507 62508 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62506 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62513 62514 62515 62516 62517 62518 62519 62520 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62513 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |