Class: Google::Apis::ComputeBeta::SnapshotList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Snapshot resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotList
constructor
A new instance of SnapshotList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotList
Returns a new instance of SnapshotList.
61629 61630 61631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61629 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
61597 61598 61599 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61597 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Snapshot>
A list of Snapshot resources.
Corresponds to the JSON property items
61602 61603 61604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61602 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
61607 61608 61609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61607 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
61617 61618 61619 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61617 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
61622 61623 61624 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61622 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SnapshotList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
61627 61628 61629 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61627 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
61634 61635 61636 61637 61638 61639 61640 61641 |
# File 'lib/google/apis/compute_beta/classes.rb', line 61634 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |