Class: Google::Apis::ComputeBeta::SnapshotList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Snapshot resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotList

Returns a new instance of SnapshotList.



58346
58347
58348
# File 'lib/google/apis/compute_beta/classes.rb', line 58346

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


58314
58315
58316
# File 'lib/google/apis/compute_beta/classes.rb', line 58314

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Snapshot>

A list of Snapshot resources. Corresponds to the JSON property items



58319
58320
58321
# File 'lib/google/apis/compute_beta/classes.rb', line 58319

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


58324
58325
58326
# File 'lib/google/apis/compute_beta/classes.rb', line 58324

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


58334
58335
58336
# File 'lib/google/apis/compute_beta/classes.rb', line 58334

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


58339
58340
58341
# File 'lib/google/apis/compute_beta/classes.rb', line 58339

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SnapshotList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



58344
58345
58346
# File 'lib/google/apis/compute_beta/classes.rb', line 58344

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



58351
58352
58353
58354
58355
58356
58357
58358
# File 'lib/google/apis/compute_beta/classes.rb', line 58351

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end