Class: Google::Apis::ComputeBeta::SnapshotSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettings

Returns a new instance of SnapshotSettings.



63918
63919
63920
# File 'lib/google/apis/compute_beta/classes.rb', line 63918

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_locationGoogle::Apis::ComputeBeta::SnapshotSettingsAccessLocation

(Regional snapshots use only)Policy of which location is allowed to access snapshot. Corresponds to the JSON property accessLocation



63910
63911
63912
# File 'lib/google/apis/compute_beta/classes.rb', line 63910

def access_location
  @access_location
end

#storage_locationGoogle::Apis::ComputeBeta::SnapshotSettingsStorageLocationSettings

Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out. Corresponds to the JSON property storageLocation



63916
63917
63918
# File 'lib/google/apis/compute_beta/classes.rb', line 63916

def storage_location
  @storage_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63923
63924
63925
63926
# File 'lib/google/apis/compute_beta/classes.rb', line 63923

def update!(**args)
  @access_location = args[:access_location] if args.key?(:access_location)
  @storage_location = args[:storage_location] if args.key?(:storage_location)
end