Class: Google::Apis::ComputeBeta::SnapshotSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettings

Returns a new instance of SnapshotSettings.



63484
63485
63486
# File 'lib/google/apis/compute_beta/classes.rb', line 63484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#access_locationGoogle::Apis::ComputeBeta::SnapshotSettingsAccessLocation

(Regional snapshots use only)Policy of which location is allowed to access snapshot. Corresponds to the JSON property accessLocation



63476
63477
63478
# File 'lib/google/apis/compute_beta/classes.rb', line 63476

def access_location
  @access_location
end

#storage_locationGoogle::Apis::ComputeBeta::SnapshotSettingsStorageLocationSettings

Policy of which storage location is going to be resolved, and additional data that particularizes how the policy is going to be carried out. Corresponds to the JSON property storageLocation



63482
63483
63484
# File 'lib/google/apis/compute_beta/classes.rb', line 63482

def storage_location
  @storage_location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63489
63490
63491
63492
# File 'lib/google/apis/compute_beta/classes.rb', line 63489

def update!(**args)
  @access_location = args[:access_location] if args.key?(:access_location)
  @storage_location = args[:storage_location] if args.key?(:storage_location)
end