Class: Google::Apis::ComputeBeta::SnapshotSettingsAccessLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettingsAccessLocation

Returns a new instance of SnapshotSettingsAccessLocation.



61782
61783
61784
# File 'lib/google/apis/compute_beta/classes.rb', line 61782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationsHash<String,Google::Apis::ComputeBeta::SnapshotSettingsAccessLocationAccessLocationPreference>

List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property locations



61775
61776
61777
# File 'lib/google/apis/compute_beta/classes.rb', line 61775

def locations
  @locations
end

#policyString

Policy of which location is allowed to access snapshot. Corresponds to the JSON property policy

Returns:

  • (String)


61780
61781
61782
# File 'lib/google/apis/compute_beta/classes.rb', line 61780

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61787
61788
61789
61790
# File 'lib/google/apis/compute_beta/classes.rb', line 61787

def update!(**args)
  @locations = args[:locations] if args.key?(:locations)
  @policy = args[:policy] if args.key?(:policy)
end