Class: Google::Apis::ComputeBeta::SnapshotSettingsAccessLocation

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotSettingsAccessLocation

Returns a new instance of SnapshotSettingsAccessLocation.



60597
60598
60599
# File 'lib/google/apis/compute_beta/classes.rb', line 60597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#locationsHash<String,Google::Apis::ComputeBeta::SnapshotSettingsAccessLocationAccessLocationPreference>

List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property locations



60590
60591
60592
# File 'lib/google/apis/compute_beta/classes.rb', line 60590

def locations
  @locations
end

#policyString

Policy of which location is allowed to access snapshot. Corresponds to the JSON property policy

Returns:

  • (String)


60595
60596
60597
# File 'lib/google/apis/compute_beta/classes.rb', line 60595

def policy
  @policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



60602
60603
60604
60605
# File 'lib/google/apis/compute_beta/classes.rb', line 60602

def update!(**args)
  @locations = args[:locations] if args.key?(:locations)
  @policy = args[:policy] if args.key?(:policy)
end