Class: Google::Apis::ComputeBeta::SnapshotSettingsAccessLocation
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SnapshotSettingsAccessLocation
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#locations ⇒ Hash<String,Google::Apis::ComputeBeta::SnapshotSettingsAccessLocationAccessLocationPreference>
List of regions that can restore a regional snapshot from the current region Corresponds to the JSON property
locations. -
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SnapshotSettingsAccessLocation
constructor
A new instance of SnapshotSettingsAccessLocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SnapshotSettingsAccessLocation
Returns a new instance of SnapshotSettingsAccessLocation.
58498 58499 58500 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58498 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Hash<String,Google::Apis::ComputeBeta::SnapshotSettingsAccessLocationAccessLocationPreference>
List of regions that can restore a regional
snapshot from the current region
Corresponds to the JSON property locations
58491 58492 58493 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58491 def locations @locations end |
#policy ⇒ String
Policy of which location is allowed to access snapshot.
Corresponds to the JSON property policy
58496 58497 58498 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58496 def policy @policy end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
58503 58504 58505 58506 |
# File 'lib/google/apis/compute_beta/classes.rb', line 58503 def update!(**args) @locations = args[:locations] if args.key?(:locations) @policy = args[:policy] if args.key?(:policy) end |