Class: Google::Apis::ComputeBeta::SnapshotUpdateKmsKeyRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SnapshotUpdateKmsKeyRequest

Returns a new instance of SnapshotUpdateKmsKeyRequest.



61875
61876
61877
# File 'lib/google/apis/compute_beta/classes.rb', line 61875

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kms_key_nameString

Optional. The new KMS key to replace the current one on the snapshot. If empty, the snapshot will be re-encrypted using the primary version of the snapshot's current KMS key. The KMS key can be provided in the following formats:

  • projects/project_id/locations/region/keyRings/key_ring/cryptoKeys/key Corresponds to the JSON property kmsKeyName

Returns:

  • (String)


61873
61874
61875
# File 'lib/google/apis/compute_beta/classes.rb', line 61873

def kms_key_name
  @kms_key_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61880
61881
61882
# File 'lib/google/apis/compute_beta/classes.rb', line 61880

def update!(**args)
  @kms_key_name = args[:kms_key_name] if args.key?(:kms_key_name)
end