Class: Google::Apis::ComputeBeta::SourceInstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceInstanceProperties

Returns a new instance of SourceInstanceProperties.



64304
64305
64306
# File 'lib/google/apis/compute_beta/classes.rb', line 64304

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


64215
64216
64217
# File 'lib/google/apis/compute_beta/classes.rb', line 64215

def can_ip_forward
  @can_ip_forward
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the instance created from this machine image should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


64222
64223
64224
# File 'lib/google/apis/compute_beta/classes.rb', line 64222

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional text description for the instances that are created from this machine image. Corresponds to the JSON property description

Returns:

  • (String)


64229
64230
64231
# File 'lib/google/apis/compute_beta/classes.rb', line 64229

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::SavedAttachedDisk>

An array of disks that are associated with the instances that are created from this machine image. Corresponds to the JSON property disks



64235
64236
64237
# File 'lib/google/apis/compute_beta/classes.rb', line 64235

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeBeta::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from this machine image. Corresponds to the JSON property guestAccelerators



64241
64242
64243
# File 'lib/google/apis/compute_beta/classes.rb', line 64241

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


64247
64248
64249
# File 'lib/google/apis/compute_beta/classes.rb', line 64247

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from this machine image. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


64252
64253
64254
# File 'lib/google/apis/compute_beta/classes.rb', line 64252

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from this machine image. Corresponds to the JSON property machineType

Returns:

  • (String)


64258
64259
64260
# File 'lib/google/apis/compute_beta/classes.rb', line 64258

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



64263
64264
64265
# File 'lib/google/apis/compute_beta/classes.rb', line 64263

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


64274
64275
64276
# File 'lib/google/apis/compute_beta/classes.rb', line 64274

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeBeta::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



64279
64280
64281
# File 'lib/google/apis/compute_beta/classes.rb', line 64279

def network_interfaces
  @network_interfaces
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


64284
64285
64286
# File 'lib/google/apis/compute_beta/classes.rb', line 64284

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#schedulingGoogle::Apis::ComputeBeta::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



64289
64290
64291
# File 'lib/google/apis/compute_beta/classes.rb', line 64289

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeBeta::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



64297
64298
64299
# File 'lib/google/apis/compute_beta/classes.rb', line 64297

def service_accounts
  @service_accounts
end

#tagsGoogle::Apis::ComputeBeta::Tags

A set of instance tags. Corresponds to the JSON property tags



64302
64303
64304
# File 'lib/google/apis/compute_beta/classes.rb', line 64302

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64309
64310
64311
64312
64313
64314
64315
64316
64317
64318
64319
64320
64321
64322
64323
64324
64325
# File 'lib/google/apis/compute_beta/classes.rb', line 64309

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @tags = args[:tags] if args.key?(:tags)
end