Class: Google::Apis::ComputeBeta::SourceInstanceProperties

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SourceInstanceProperties

Returns a new instance of SourceInstanceProperties.



63840
63841
63842
# File 'lib/google/apis/compute_beta/classes.rb', line 63840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_ip_forwardBoolean Also known as: can_ip_forward?

Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own. If these instances will be used as an IP gateway or it will be set as the next-hop in a Route resource, specify true. If unsure, leave this set tofalse. See theEnable IP forwarding documentation for more information. Corresponds to the JSON property canIpForward

Returns:

  • (Boolean)


63751
63752
63753
# File 'lib/google/apis/compute_beta/classes.rb', line 63751

def can_ip_forward
  @can_ip_forward
end

#deletion_protectionBoolean Also known as: deletion_protection?

Whether the instance created from this machine image should be protected against deletion. Corresponds to the JSON property deletionProtection

Returns:

  • (Boolean)


63758
63759
63760
# File 'lib/google/apis/compute_beta/classes.rb', line 63758

def deletion_protection
  @deletion_protection
end

#descriptionString

An optional text description for the instances that are created from this machine image. Corresponds to the JSON property description

Returns:

  • (String)


63765
63766
63767
# File 'lib/google/apis/compute_beta/classes.rb', line 63765

def description
  @description
end

#disksArray<Google::Apis::ComputeBeta::SavedAttachedDisk>

An array of disks that are associated with the instances that are created from this machine image. Corresponds to the JSON property disks



63771
63772
63773
# File 'lib/google/apis/compute_beta/classes.rb', line 63771

def disks
  @disks
end

#guest_acceleratorsArray<Google::Apis::ComputeBeta::AcceleratorConfig>

A list of guest accelerator cards' type and count to use for instances created from this machine image. Corresponds to the JSON property guestAccelerators



63777
63778
63779
# File 'lib/google/apis/compute_beta/classes.rb', line 63777

def guest_accelerators
  @guest_accelerators
end

#key_revocation_action_typeString

KeyRevocationActionType of the instance. Supported options are "STOP" and "NONE". The default value is "NONE" if it is not specified. Corresponds to the JSON property keyRevocationActionType

Returns:

  • (String)


63783
63784
63785
# File 'lib/google/apis/compute_beta/classes.rb', line 63783

def key_revocation_action_type
  @key_revocation_action_type
end

#labelsHash<String,String>

Labels to apply to instances that are created from this machine image. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


63788
63789
63790
# File 'lib/google/apis/compute_beta/classes.rb', line 63788

def labels
  @labels
end

#machine_typeString

The machine type to use for instances that are created from this machine image. Corresponds to the JSON property machineType

Returns:

  • (String)


63794
63795
63796
# File 'lib/google/apis/compute_beta/classes.rb', line 63794

def machine_type
  @machine_type
end

#metadataGoogle::Apis::ComputeBeta::Metadata

A metadata key/value entry. Corresponds to the JSON property metadata



63799
63800
63801
# File 'lib/google/apis/compute_beta/classes.rb', line 63799

def 
  @metadata
end

#min_cpu_platformString

Minimum cpu/platform to be used by instances created from this machine image. The instance may be scheduled on the specified or newer cpu/platform. Applicable values are the friendly names of CPU platforms, such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge". For more information, read Specifying a Minimum CPU Platform. Corresponds to the JSON property minCpuPlatform

Returns:

  • (String)


63810
63811
63812
# File 'lib/google/apis/compute_beta/classes.rb', line 63810

def min_cpu_platform
  @min_cpu_platform
end

#network_interfacesArray<Google::Apis::ComputeBeta::NetworkInterface>

An array of network access configurations for this interface. Corresponds to the JSON property networkInterfaces



63815
63816
63817
# File 'lib/google/apis/compute_beta/classes.rb', line 63815

def network_interfaces
  @network_interfaces
end

#post_key_revocation_action_typeString

PostKeyRevocationActionType of the instance. Corresponds to the JSON property postKeyRevocationActionType

Returns:

  • (String)


63820
63821
63822
# File 'lib/google/apis/compute_beta/classes.rb', line 63820

def post_key_revocation_action_type
  @post_key_revocation_action_type
end

#schedulingGoogle::Apis::ComputeBeta::Scheduling

Sets the scheduling options for an Instance. Corresponds to the JSON property scheduling



63825
63826
63827
# File 'lib/google/apis/compute_beta/classes.rb', line 63825

def scheduling
  @scheduling
end

#service_accountsArray<Google::Apis::ComputeBeta::ServiceAccount>

A list of service accounts with specified scopes. Access tokens for these service accounts are available to the instances that are created from this machine image. Use metadata queries to obtain the access tokens for these instances. Corresponds to the JSON property serviceAccounts



63833
63834
63835
# File 'lib/google/apis/compute_beta/classes.rb', line 63833

def service_accounts
  @service_accounts
end

#tagsGoogle::Apis::ComputeBeta::Tags

A set of instance tags. Corresponds to the JSON property tags



63838
63839
63840
# File 'lib/google/apis/compute_beta/classes.rb', line 63838

def tags
  @tags
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63845
63846
63847
63848
63849
63850
63851
63852
63853
63854
63855
63856
63857
63858
63859
63860
63861
# File 'lib/google/apis/compute_beta/classes.rb', line 63845

def update!(**args)
  @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward)
  @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection)
  @description = args[:description] if args.key?(:description)
  @disks = args[:disks] if args.key?(:disks)
  @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators)
  @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type)
  @labels = args[:labels] if args.key?(:labels)
  @machine_type = args[:machine_type] if args.key?(:machine_type)
  @metadata = args[:metadata] if args.key?(:metadata)
  @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform)
  @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces)
  @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type)
  @scheduling = args[:scheduling] if args.key?(:scheduling)
  @service_accounts = args[:service_accounts] if args.key?(:service_accounts)
  @tags = args[:tags] if args.key?(:tags)
end