Class: Google::Apis::ComputeBeta::SourceInstanceProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SourceInstanceProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
DEPRECATED: Please use compute#instanceProperties instead. New properties will not be added to this field.
Instance Attribute Summary collapse
-
#can_ip_forward ⇒ Boolean
(also: #can_ip_forward?)
Enables instances created based on this machine image to send packets with source IP addresses other than their own and receive packets with destination IP addresses other than their own.
-
#deletion_protection ⇒ Boolean
(also: #deletion_protection?)
Whether the instance created from this machine image should be protected against deletion.
-
#description ⇒ String
An optional text description for the instances that are created from this machine image.
-
#disks ⇒ Array<Google::Apis::ComputeBeta::SavedAttachedDisk>
An array of disks that are associated with the instances that are created from this machine image.
-
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances created from this machine image.
-
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance.
-
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from this machine image.
-
#machine_type ⇒ String
The machine type to use for instances that are created from this machine image.
-
#metadata ⇒ Google::Apis::ComputeBeta::Metadata
A metadata key/value entry.
-
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances created from this machine image.
-
#network_interfaces ⇒ Array<Google::Apis::ComputeBeta::NetworkInterface>
An array of network access configurations for this interface.
-
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
-
#scheduling ⇒ Google::Apis::ComputeBeta::Scheduling
Sets the scheduling options for an Instance.
-
#service_accounts ⇒ Array<Google::Apis::ComputeBeta::ServiceAccount>
A list of service accounts with specified scopes.
-
#tags ⇒ Google::Apis::ComputeBeta::Tags
A set of instance tags.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SourceInstanceProperties
constructor
A new instance of SourceInstanceProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SourceInstanceProperties
Returns a new instance of SourceInstanceProperties.
60931 60932 60933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_ip_forward ⇒ Boolean Also known as: can_ip_forward?
Enables instances created based on this machine image to send packets with
source IP addresses other than their own and receive packets with
destination IP addresses other than their own. If these instances will be
used as an IP gateway or it will be set as the next-hop in a Route
resource, specify true. If unsure, leave this set tofalse. See theEnable IP
forwarding
documentation for more information.
Corresponds to the JSON property canIpForward
60842 60843 60844 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60842 def can_ip_forward @can_ip_forward end |
#deletion_protection ⇒ Boolean Also known as: deletion_protection?
Whether the instance created from this machine image should be protected
against deletion.
Corresponds to the JSON property deletionProtection
60849 60850 60851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60849 def deletion_protection @deletion_protection end |
#description ⇒ String
An optional text description for the instances that are created from this
machine image.
Corresponds to the JSON property description
60856 60857 60858 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60856 def description @description end |
#disks ⇒ Array<Google::Apis::ComputeBeta::SavedAttachedDisk>
An array of disks that are associated with the instances that are created
from this machine image.
Corresponds to the JSON property disks
60862 60863 60864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60862 def disks @disks end |
#guest_accelerators ⇒ Array<Google::Apis::ComputeBeta::AcceleratorConfig>
A list of guest accelerator cards' type and count to use for instances
created from this machine image.
Corresponds to the JSON property guestAccelerators
60868 60869 60870 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60868 def guest_accelerators @guest_accelerators end |
#key_revocation_action_type ⇒ String
KeyRevocationActionType of the instance. Supported options are "STOP" and
"NONE". The default value is "NONE" if it is not specified.
Corresponds to the JSON property keyRevocationActionType
60874 60875 60876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60874 def key_revocation_action_type @key_revocation_action_type end |
#labels ⇒ Hash<String,String>
Labels to apply to instances that are created from this machine image.
Corresponds to the JSON property labels
60879 60880 60881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60879 def labels @labels end |
#machine_type ⇒ String
The machine type to use for instances that are created from this machine
image.
Corresponds to the JSON property machineType
60885 60886 60887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60885 def machine_type @machine_type end |
#metadata ⇒ Google::Apis::ComputeBeta::Metadata
A metadata key/value entry.
Corresponds to the JSON property metadata
60890 60891 60892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60890 def @metadata end |
#min_cpu_platform ⇒ String
Minimum cpu/platform to be used by instances created from this machine
image. The instance may be scheduled on the specified or newer
cpu/platform. Applicable values are the friendly names of CPU platforms,
such as minCpuPlatform: "Intel Haswell" orminCpuPlatform: "Intel Sandy Bridge".
For more
information, read Specifying a
Minimum CPU Platform.
Corresponds to the JSON property minCpuPlatform
60901 60902 60903 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60901 def min_cpu_platform @min_cpu_platform end |
#network_interfaces ⇒ Array<Google::Apis::ComputeBeta::NetworkInterface>
An array of network access configurations for this interface.
Corresponds to the JSON property networkInterfaces
60906 60907 60908 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60906 def network_interfaces @network_interfaces end |
#post_key_revocation_action_type ⇒ String
PostKeyRevocationActionType of the instance.
Corresponds to the JSON property postKeyRevocationActionType
60911 60912 60913 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60911 def post_key_revocation_action_type @post_key_revocation_action_type end |
#scheduling ⇒ Google::Apis::ComputeBeta::Scheduling
Sets the scheduling options for an Instance.
Corresponds to the JSON property scheduling
60916 60917 60918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60916 def scheduling @scheduling end |
#service_accounts ⇒ Array<Google::Apis::ComputeBeta::ServiceAccount>
A list of service accounts with specified scopes. Access tokens for these
service accounts are available to the instances that are created from this
machine image. Use metadata queries to obtain the access tokens for these
instances.
Corresponds to the JSON property serviceAccounts
60924 60925 60926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60924 def service_accounts @service_accounts end |
#tags ⇒ Google::Apis::ComputeBeta::Tags
A set of instance tags.
Corresponds to the JSON property tags
60929 60930 60931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60929 def @tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
60936 60937 60938 60939 60940 60941 60942 60943 60944 60945 60946 60947 60948 60949 60950 60951 60952 |
# File 'lib/google/apis/compute_beta/classes.rb', line 60936 def update!(**args) @can_ip_forward = args[:can_ip_forward] if args.key?(:can_ip_forward) @deletion_protection = args[:deletion_protection] if args.key?(:deletion_protection) @description = args[:description] if args.key?(:description) @disks = args[:disks] if args.key?(:disks) @guest_accelerators = args[:guest_accelerators] if args.key?(:guest_accelerators) @key_revocation_action_type = args[:key_revocation_action_type] if args.key?(:key_revocation_action_type) @labels = args[:labels] if args.key?(:labels) @machine_type = args[:machine_type] if args.key?(:machine_type) @metadata = args[:metadata] if args.key?(:metadata) @min_cpu_platform = args[:min_cpu_platform] if args.key?(:min_cpu_platform) @network_interfaces = args[:network_interfaces] if args.key?(:network_interfaces) @post_key_revocation_action_type = args[:post_key_revocation_action_type] if args.key?(:post_key_revocation_action_type) @scheduling = args[:scheduling] if args.key?(:scheduling) @service_accounts = args[:service_accounts] if args.key?(:service_accounts) @tags = args[:tags] if args.key?(:tags) end |