Class: Google::Apis::ComputeBeta::SslCertificateAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslCertificateAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateAggregatedList
constructor
A new instance of SslCertificateAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateAggregatedList
Returns a new instance of SslCertificateAggregatedList.
64619 64620 64621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64619 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64580 64581 64582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64580 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>
A list of SslCertificatesScopedList resources.
Corresponds to the JSON property items
64585 64586 64587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64585 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
sslCertificateAggregatedList for lists of SSL
Certificates.
Corresponds to the JSON property kind
64592 64593 64594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64592 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64602 64603 64604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64602 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64607 64608 64609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64607 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64612 64613 64614 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64612 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::SslCertificateAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64617 64618 64619 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64617 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64624 64625 64626 64627 64628 64629 64630 64631 64632 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64624 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |