Class: Google::Apis::ComputeBeta::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



64544
64545
64546
# File 'lib/google/apis/compute_beta/classes.rb', line 64544

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64505
64506
64507
# File 'lib/google/apis/compute_beta/classes.rb', line 64505

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



64510
64511
64512
# File 'lib/google/apis/compute_beta/classes.rb', line 64510

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


64517
64518
64519
# File 'lib/google/apis/compute_beta/classes.rb', line 64517

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64527
64528
64529
# File 'lib/google/apis/compute_beta/classes.rb', line 64527

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64532
64533
64534
# File 'lib/google/apis/compute_beta/classes.rb', line 64532

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64537
64538
64539
# File 'lib/google/apis/compute_beta/classes.rb', line 64537

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64542
64543
64544
# File 'lib/google/apis/compute_beta/classes.rb', line 64542

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64549
64550
64551
64552
64553
64554
64555
64556
64557
# File 'lib/google/apis/compute_beta/classes.rb', line 64549

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end