Class: Google::Apis::ComputeBeta::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



63170
63171
63172
# File 'lib/google/apis/compute_beta/classes.rb', line 63170

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63131
63132
63133
# File 'lib/google/apis/compute_beta/classes.rb', line 63131

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



63136
63137
63138
# File 'lib/google/apis/compute_beta/classes.rb', line 63136

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


63143
63144
63145
# File 'lib/google/apis/compute_beta/classes.rb', line 63143

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63153
63154
63155
# File 'lib/google/apis/compute_beta/classes.rb', line 63153

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63158
63159
63160
# File 'lib/google/apis/compute_beta/classes.rb', line 63158

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63163
63164
63165
# File 'lib/google/apis/compute_beta/classes.rb', line 63163

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63168
63169
63170
# File 'lib/google/apis/compute_beta/classes.rb', line 63168

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63175
63176
63177
63178
63179
63180
63181
63182
63183
# File 'lib/google/apis/compute_beta/classes.rb', line 63175

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end