Class: Google::Apis::ComputeBeta::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



61139
61140
61141
# File 'lib/google/apis/compute_beta/classes.rb', line 61139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61100
61101
61102
# File 'lib/google/apis/compute_beta/classes.rb', line 61100

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



61105
61106
61107
# File 'lib/google/apis/compute_beta/classes.rb', line 61105

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


61112
61113
61114
# File 'lib/google/apis/compute_beta/classes.rb', line 61112

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61122
61123
61124
# File 'lib/google/apis/compute_beta/classes.rb', line 61122

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61127
61128
61129
# File 'lib/google/apis/compute_beta/classes.rb', line 61127

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


61132
61133
61134
# File 'lib/google/apis/compute_beta/classes.rb', line 61132

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61137
61138
61139
# File 'lib/google/apis/compute_beta/classes.rb', line 61137

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61144
61145
61146
61147
61148
61149
61150
61151
61152
# File 'lib/google/apis/compute_beta/classes.rb', line 61144

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end