Class: Google::Apis::ComputeBeta::SslCertificateAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateAggregatedList

Returns a new instance of SslCertificateAggregatedList.



59040
59041
59042
# File 'lib/google/apis/compute_beta/classes.rb', line 59040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


59001
59002
59003
# File 'lib/google/apis/compute_beta/classes.rb', line 59001

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslCertificatesScopedList>

A list of SslCertificatesScopedList resources. Corresponds to the JSON property items



59006
59007
59008
# File 'lib/google/apis/compute_beta/classes.rb', line 59006

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslCertificateAggregatedList for lists of SSL Certificates. Corresponds to the JSON property kind

Returns:

  • (String)


59013
59014
59015
# File 'lib/google/apis/compute_beta/classes.rb', line 59013

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


59023
59024
59025
# File 'lib/google/apis/compute_beta/classes.rb', line 59023

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


59028
59029
59030
# File 'lib/google/apis/compute_beta/classes.rb', line 59028

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


59033
59034
59035
# File 'lib/google/apis/compute_beta/classes.rb', line 59033

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslCertificateAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



59038
59039
59040
# File 'lib/google/apis/compute_beta/classes.rb', line 59038

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



59045
59046
59047
59048
59049
59050
59051
59052
59053
# File 'lib/google/apis/compute_beta/classes.rb', line 59045

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end