Class: Google::Apis::ComputeBeta::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



64744
64745
64746
# File 'lib/google/apis/compute_beta/classes.rb', line 64744

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64712
64713
64714
# File 'lib/google/apis/compute_beta/classes.rb', line 64712

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



64717
64718
64719
# File 'lib/google/apis/compute_beta/classes.rb', line 64717

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64722
64723
64724
# File 'lib/google/apis/compute_beta/classes.rb', line 64722

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64732
64733
64734
# File 'lib/google/apis/compute_beta/classes.rb', line 64732

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64737
64738
64739
# File 'lib/google/apis/compute_beta/classes.rb', line 64737

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64742
64743
64744
# File 'lib/google/apis/compute_beta/classes.rb', line 64742

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64749
64750
64751
64752
64753
64754
64755
64756
# File 'lib/google/apis/compute_beta/classes.rb', line 64749

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end