Class: Google::Apis::ComputeBeta::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
64637 64638 64639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64637 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64605 64606 64607 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64605 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
64610 64611 64612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64610 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64615 64616 64617 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64615 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64625 64626 64627 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64625 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64630 64631 64632 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64630 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64635 64636 64637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64635 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64642 64643 64644 64645 64646 64647 64648 64649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64642 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |