Class: Google::Apis::ComputeBeta::SslCertificateList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslCertificateList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of SslCertificate resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::SslCertificate>
A list of SslCertificate resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SslCertificateList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateList
constructor
A new instance of SslCertificateList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateList
Returns a new instance of SslCertificateList.
64203 64204 64205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64203 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64171 64172 64173 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64171 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::SslCertificate>
A list of SslCertificate resources.
Corresponds to the JSON property items
64176 64177 64178 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64176 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64181 64182 64183 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64181 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64191 64192 64193 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64191 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64196 64197 64198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64196 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SslCertificateList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64201 64202 64203 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64201 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64208 64209 64210 64211 64212 64213 64214 64215 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64208 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |