Class: Google::Apis::ComputeBeta::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



64173
64174
64175
# File 'lib/google/apis/compute_beta/classes.rb', line 64173

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64141
64142
64143
# File 'lib/google/apis/compute_beta/classes.rb', line 64141

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



64146
64147
64148
# File 'lib/google/apis/compute_beta/classes.rb', line 64146

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64151
64152
64153
# File 'lib/google/apis/compute_beta/classes.rb', line 64151

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64161
64162
64163
# File 'lib/google/apis/compute_beta/classes.rb', line 64161

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64166
64167
64168
# File 'lib/google/apis/compute_beta/classes.rb', line 64166

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64171
64172
64173
# File 'lib/google/apis/compute_beta/classes.rb', line 64171

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64178
64179
64180
64181
64182
64183
64184
64185
# File 'lib/google/apis/compute_beta/classes.rb', line 64178

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end