Class: Google::Apis::ComputeBeta::SslCertificateList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of SslCertificate resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslCertificateList

Returns a new instance of SslCertificateList.



63354
63355
63356
# File 'lib/google/apis/compute_beta/classes.rb', line 63354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63322
63323
63324
# File 'lib/google/apis/compute_beta/classes.rb', line 63322

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SslCertificate>

A list of SslCertificate resources. Corresponds to the JSON property items



63327
63328
63329
# File 'lib/google/apis/compute_beta/classes.rb', line 63327

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


63332
63333
63334
# File 'lib/google/apis/compute_beta/classes.rb', line 63332

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63342
63343
63344
# File 'lib/google/apis/compute_beta/classes.rb', line 63342

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63347
63348
63349
# File 'lib/google/apis/compute_beta/classes.rb', line 63347

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SslCertificateList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63352
63353
63354
# File 'lib/google/apis/compute_beta/classes.rb', line 63352

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63359
63360
63361
63362
63363
63364
63365
63366
# File 'lib/google/apis/compute_beta/classes.rb', line 63359

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end