Class: Google::Apis::ComputeBeta::SslCertificateSelfManagedSslCertificate
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslCertificateSelfManagedSslCertificate
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration and status of a self-managed SSL certificate.
Instance Attribute Summary collapse
-
#certificate ⇒ String
A local certificate file.
-
#private_key ⇒ String
A write-only private key in PEM format.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslCertificateSelfManagedSslCertificate
constructor
A new instance of SslCertificateSelfManagedSslCertificate.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslCertificateSelfManagedSslCertificate
Returns a new instance of SslCertificateSelfManagedSslCertificate.
59303 59304 59305 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#certificate ⇒ String
A local certificate file. The certificate must be in
PEM format. The certificate chain must be no greater than 5 certs
long. The chain must include at least one intermediate cert.
Corresponds to the JSON property certificate
59295 59296 59297 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59295 def certificate @certificate end |
#private_key ⇒ String
A write-only private key in PEM format. Only insert
requests will include this field.
Corresponds to the JSON property privateKey
59301 59302 59303 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59301 def private_key @private_key end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59308 59309 59310 59311 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59308 def update!(**args) @certificate = args[:certificate] if args.key?(:certificate) @private_key = args[:private_key] if args.key?(:private_key) end |