Class: Google::Apis::ComputeBeta::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



65044
65045
65046
# File 'lib/google/apis/compute_beta/classes.rb', line 65044

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65001
65002
65003
# File 'lib/google/apis/compute_beta/classes.rb', line 65001

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65006
65007
65008
# File 'lib/google/apis/compute_beta/classes.rb', line 65006

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



65011
65012
65013
# File 'lib/google/apis/compute_beta/classes.rb', line 65011

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


65017
65018
65019
# File 'lib/google/apis/compute_beta/classes.rb', line 65017

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65027
65028
65029
# File 'lib/google/apis/compute_beta/classes.rb', line 65027

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65032
65033
65034
# File 'lib/google/apis/compute_beta/classes.rb', line 65032

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65037
65038
65039
# File 'lib/google/apis/compute_beta/classes.rb', line 65037

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65042
65043
65044
# File 'lib/google/apis/compute_beta/classes.rb', line 65042

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65049
65050
65051
65052
65053
65054
65055
65056
65057
65058
# File 'lib/google/apis/compute_beta/classes.rb', line 65049

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end