Class: Google::Apis::ComputeBeta::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



65040
65041
65042
# File 'lib/google/apis/compute_beta/classes.rb', line 65040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64997
64998
64999
# File 'lib/google/apis/compute_beta/classes.rb', line 64997

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65002
65003
65004
# File 'lib/google/apis/compute_beta/classes.rb', line 65002

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



65007
65008
65009
# File 'lib/google/apis/compute_beta/classes.rb', line 65007

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


65013
65014
65015
# File 'lib/google/apis/compute_beta/classes.rb', line 65013

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65023
65024
65025
# File 'lib/google/apis/compute_beta/classes.rb', line 65023

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65028
65029
65030
# File 'lib/google/apis/compute_beta/classes.rb', line 65028

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65033
65034
65035
# File 'lib/google/apis/compute_beta/classes.rb', line 65033

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65038
65039
65040
# File 'lib/google/apis/compute_beta/classes.rb', line 65038

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65045
65046
65047
65048
65049
65050
65051
65052
65053
65054
# File 'lib/google/apis/compute_beta/classes.rb', line 65045

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end