Class: Google::Apis::ComputeBeta::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



64933
64934
64935
# File 'lib/google/apis/compute_beta/classes.rb', line 64933

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64890
64891
64892
# File 'lib/google/apis/compute_beta/classes.rb', line 64890

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64895
64896
64897
# File 'lib/google/apis/compute_beta/classes.rb', line 64895

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



64900
64901
64902
# File 'lib/google/apis/compute_beta/classes.rb', line 64900

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


64906
64907
64908
# File 'lib/google/apis/compute_beta/classes.rb', line 64906

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64916
64917
64918
# File 'lib/google/apis/compute_beta/classes.rb', line 64916

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64921
64922
64923
# File 'lib/google/apis/compute_beta/classes.rb', line 64921

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64926
64927
64928
# File 'lib/google/apis/compute_beta/classes.rb', line 64926

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64931
64932
64933
# File 'lib/google/apis/compute_beta/classes.rb', line 64931

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64938
64939
64940
64941
64942
64943
64944
64945
64946
64947
# File 'lib/google/apis/compute_beta/classes.rb', line 64938

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end