Class: Google::Apis::ComputeBeta::SslPoliciesAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesAggregatedList

Returns a new instance of SslPoliciesAggregatedList.



62771
62772
62773
# File 'lib/google/apis/compute_beta/classes.rb', line 62771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62728
62729
62730
# File 'lib/google/apis/compute_beta/classes.rb', line 62728

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62733
62734
62735
# File 'lib/google/apis/compute_beta/classes.rb', line 62733

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SslPoliciesScopedList>

A list of SslPoliciesScopedList resources. Corresponds to the JSON property items



62738
62739
62740
# File 'lib/google/apis/compute_beta/classes.rb', line 62738

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# sslPolicyAggregatedList for lists of SSL Policies. Corresponds to the JSON property kind

Returns:

  • (String)


62744
62745
62746
# File 'lib/google/apis/compute_beta/classes.rb', line 62744

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62754
62755
62756
# File 'lib/google/apis/compute_beta/classes.rb', line 62754

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62759
62760
62761
# File 'lib/google/apis/compute_beta/classes.rb', line 62759

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62764
62765
62766
# File 'lib/google/apis/compute_beta/classes.rb', line 62764

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SslPoliciesAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



62769
62770
62771
# File 'lib/google/apis/compute_beta/classes.rb', line 62769

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62776
62777
62778
62779
62780
62781
62782
62783
62784
62785
# File 'lib/google/apis/compute_beta/classes.rb', line 62776

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end