Class: Google::Apis::ComputeBeta::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



64628
64629
64630
# File 'lib/google/apis/compute_beta/classes.rb', line 64628

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64594
64595
64596
# File 'lib/google/apis/compute_beta/classes.rb', line 64594

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



64599
64600
64601
# File 'lib/google/apis/compute_beta/classes.rb', line 64599

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


64605
64606
64607
# File 'lib/google/apis/compute_beta/classes.rb', line 64605

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64616
64617
64618
# File 'lib/google/apis/compute_beta/classes.rb', line 64616

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64621
64622
64623
# File 'lib/google/apis/compute_beta/classes.rb', line 64621

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64626
64627
64628
# File 'lib/google/apis/compute_beta/classes.rb', line 64626

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64633
64634
64635
64636
64637
64638
64639
64640
# File 'lib/google/apis/compute_beta/classes.rb', line 64633

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end