Class: Google::Apis::ComputeBeta::SslPoliciesList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SslPoliciesList

Returns a new instance of SslPoliciesList.



61689
61690
61691
# File 'lib/google/apis/compute_beta/classes.rb', line 61689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


61655
61656
61657
# File 'lib/google/apis/compute_beta/classes.rb', line 61655

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::SslPolicy>

Output only. A list of SslPolicy resources. Corresponds to the JSON property items



61660
61661
61662
# File 'lib/google/apis/compute_beta/classes.rb', line 61660

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#sslPoliciesList for lists of sslPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


61666
61667
61668
# File 'lib/google/apis/compute_beta/classes.rb', line 61666

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


61677
61678
61679
# File 'lib/google/apis/compute_beta/classes.rb', line 61677

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


61682
61683
61684
# File 'lib/google/apis/compute_beta/classes.rb', line 61682

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SslPoliciesList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



61687
61688
61689
# File 'lib/google/apis/compute_beta/classes.rb', line 61687

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



61694
61695
61696
61697
61698
61699
61700
61701
# File 'lib/google/apis/compute_beta/classes.rb', line 61694

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end