Class: Google::Apis::ComputeBeta::SslPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an SSL Policy resource. Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#custom_features ⇒ Array<String>
A list of features enabled when the selected profile is CUSTOM.
-
#description ⇒ String
An optional description of this resource.
-
#enabled_features ⇒ Array<String>
Output only.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#min_tls_version ⇒ String
The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer.
-
#name ⇒ String
Name of the resource.
-
#post_quantum_key_exchange ⇒ String
One of DEFAULT, ENABLED, orDEFERRED.
-
#profile ⇒ String
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::ComputeBeta::SslPolicy::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPolicy
constructor
A new instance of SslPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPolicy
Returns a new instance of SslPolicy.
65487 65488 65489 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65487 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
65382 65383 65384 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65382 def @creation_timestamp end |
#custom_features ⇒ Array<String>
A list of features enabled when the selected profile is CUSTOM. The
method returns the set of features that can be
specified in this list. This field must be empty if the profile is notCUSTOM.
Corresponds to the JSON property customFeatures
65389 65390 65391 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65389 def custom_features @custom_features end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
65395 65396 65397 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65395 def description @description end |
#enabled_features ⇒ Array<String>
Output only. [Output Only] The list of features enabled in the SSL policy.
Corresponds to the JSON property enabledFeatures
65400 65401 65402 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65400 def enabled_features @enabled_features end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a SslPolicy. An up-to-date fingerprint must be
provided in order to update the SslPolicy, otherwise the
request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an SslPolicy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
65412 65413 65414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65412 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
65419 65420 65421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65419 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor
SSL policies.
Corresponds to the JSON property kind
65425 65426 65427 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65425 def kind @kind end |
#min_tls_version ⇒ String
The minimum version of SSL protocol that can be used by the clients to
establish a connection with the load balancer. This can be one ofTLS_1_0,
TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
must be set to RESTRICTED.
Corresponds to the JSON property minTlsVersion
65433 65434 65435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65433 def min_tls_version @min_tls_version end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
65444 65445 65446 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65444 def name @name end |
#post_quantum_key_exchange ⇒ String
One of DEFAULT, ENABLED, orDEFERRED. Controls whether the load balancer
negotiates
X25519MLKEM768 key exchange when clients advertise support for it. When set
to DEFAULT, or if no SSL Policy is attached to the target
proxy, the load balancer disallows X25519MLKEM768 key exchange before
October 2026, and allows it afterward. When set to ENABLED,
the load balancer allows X25519MLKEM768 key exchange. When set toDEFERRED, the
load balancer disallows X25519MLKEM768 key
exchange until October 2027, and allows it afterward.
Corresponds to the JSON property postQuantumKeyExchange
65457 65458 65459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65457 def post_quantum_key_exchange @post_quantum_key_exchange end |
#profile ⇒ String
Profile specifies the set of SSL features that can be used by the load
balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE,
MODERN, RESTRICTED,FIPS_202205, or CUSTOM. If usingCUSTOM, the set of SSL
features to enable must be specified in
the customFeatures field. If using FIPS_202205,
the min_tls_version field must be set to TLS_1_2.
Corresponds to the JSON property profile
65467 65468 65469 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65467 def profile @profile end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional SSL policy
resides. This field is not applicable to global SSL policies.
Corresponds to the JSON property region
65473 65474 65475 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65473 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
65478 65479 65480 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65478 def self_link @self_link end |
#warnings ⇒ Array<Google::Apis::ComputeBeta::SslPolicy::Warning>
Output only. [Output Only] If potential misconfigurations are detected for
this
SSL policy, this field will be populated with warning messages.
Corresponds to the JSON property warnings
65485 65486 65487 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65485 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65492 65493 65494 65495 65496 65497 65498 65499 65500 65501 65502 65503 65504 65505 65506 65507 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65492 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_features = args[:custom_features] if args.key?(:custom_features) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version) @name = args[:name] if args.key?(:name) @post_quantum_key_exchange = args[:post_quantum_key_exchange] if args.key?(:post_quantum_key_exchange) @profile = args[:profile] if args.key?(:profile) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @warnings = args[:warnings] if args.key?(:warnings) end |