Class: Google::Apis::ComputeBeta::SslPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SslPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents an SSL Policy resource. Use SSL policies to control SSL features, such as versions and cipher suites, that are offered by Application Load Balancers and proxy Network Load Balancers. For more information, read SSL policies overview.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#custom_features ⇒ Array<String>
A list of features enabled when the selected profile is CUSTOM.
-
#description ⇒ String
An optional description of this resource.
-
#enabled_features ⇒ Array<String>
Output only.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#min_tls_version ⇒ String
The minimum version of SSL protocol that can be used by the clients to establish a connection with the load balancer.
-
#name ⇒ String
Name of the resource.
-
#profile ⇒ String
Profile specifies the set of SSL features that can be used by the load balancer when negotiating SSL with clients.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#warnings ⇒ Array<Google::Apis::ComputeBeta::SslPolicy::Warning>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SslPolicy
constructor
A new instance of SslPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SslPolicy
Returns a new instance of SslPolicy.
59893 59894 59895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
59803 59804 59805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59803 def @creation_timestamp end |
#custom_features ⇒ Array<String>
A list of features enabled when the selected profile is CUSTOM. The
method returns the set of features that can be
specified in this list. This field must be empty if the profile is notCUSTOM.
Corresponds to the JSON property customFeatures
59810 59811 59812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59810 def custom_features @custom_features end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
59816 59817 59818 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59816 def description @description end |
#enabled_features ⇒ Array<String>
Output only. [Output Only] The list of features enabled in the SSL policy.
Corresponds to the JSON property enabledFeatures
59821 59822 59823 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59821 def enabled_features @enabled_features end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a SslPolicy. An up-to-date fingerprint must be
provided in order to update the SslPolicy, otherwise the
request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve an SslPolicy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
59833 59834 59835 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59833 def fingerprint @fingerprint end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
59840 59841 59842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59840 def id @id end |
#kind ⇒ String
Output only. [Output only] Type of the resource. Alwayscompute#sslPolicyfor
SSL policies.
Corresponds to the JSON property kind
59846 59847 59848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59846 def kind @kind end |
#min_tls_version ⇒ String
The minimum version of SSL protocol that can be used by the clients to
establish a connection with the load balancer. This can be one ofTLS_1_0,
TLS_1_1, TLS_1_2,TLS_1_3. When set to TLS_1_3, the profile field
must be set to RESTRICTED.
Corresponds to the JSON property minTlsVersion
59854 59855 59856 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59854 def min_tls_version @min_tls_version end |
#name ⇒ String
Name of the resource. The name must be 1-63 characters long, and comply
with RFC1035. Specifically, the name must be 1-63 characters
long and match the regular expression
[a-z]([-a-z0-9]*[a-z0-9])? which means the first character
must be a lowercase letter, and all following characters must be a dash,
lowercase letter, or digit, except the last character, which cannot be a
dash.
Corresponds to the JSON property name
59865 59866 59867 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59865 def name @name end |
#profile ⇒ String
Profile specifies the set of SSL features that can be used by the load
balancer when negotiating SSL with clients. This can be one ofCOMPATIBLE,
MODERN, RESTRICTED, orCUSTOM. If using CUSTOM, the set of SSL features
to enable must be specified in the customFeatures field.
Corresponds to the JSON property profile
59873 59874 59875 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59873 def profile @profile end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional SSL policy
resides. This field is not applicable to global SSL policies.
Corresponds to the JSON property region
59879 59880 59881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59879 def region @region end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
59884 59885 59886 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59884 def self_link @self_link end |
#warnings ⇒ Array<Google::Apis::ComputeBeta::SslPolicy::Warning>
Output only. [Output Only] If potential misconfigurations are detected for
this
SSL policy, this field will be populated with warning messages.
Corresponds to the JSON property warnings
59891 59892 59893 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59891 def warnings @warnings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
59898 59899 59900 59901 59902 59903 59904 59905 59906 59907 59908 59909 59910 59911 59912 |
# File 'lib/google/apis/compute_beta/classes.rb', line 59898 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @custom_features = args[:custom_features] if args.key?(:custom_features) @description = args[:description] if args.key?(:description) @enabled_features = args[:enabled_features] if args.key?(:enabled_features) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @min_tls_version = args[:min_tls_version] if args.key?(:min_tls_version) @name = args[:name] if args.key?(:name) @profile = args[:profile] if args.key?(:profile) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @warnings = args[:warnings] if args.key?(:warnings) end |