Class: Google::Apis::ComputeBeta::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



65643
65644
65645
# File 'lib/google/apis/compute_beta/classes.rb', line 65643

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



65627
65628
65629
# File 'lib/google/apis/compute_beta/classes.rb', line 65627

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property externalIPs



65634
65635
65636
# File 'lib/google/apis/compute_beta/classes.rb', line 65634

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>

Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property internalIPs



65641
65642
65643
# File 'lib/google/apis/compute_beta/classes.rb', line 65641

def internal_i_ps
  @internal_i_ps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65648
65649
65650
65651
65652
# File 'lib/google/apis/compute_beta/classes.rb', line 65648

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
end