Class: Google::Apis::ComputeBeta::StatefulPolicyPreservedState
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StatefulPolicyPreservedState
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Configuration of preserved resources.
Instance Attribute Summary collapse
-
#disks ⇒ Hash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice>
Disks created on the instances that will be preserved on instance delete, update, etc.
-
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>
External network IPs assigned to the instances that will be preserved on instance delete, update, etc.
-
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>
Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedState
constructor
A new instance of StatefulPolicyPreservedState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedState
Returns a new instance of StatefulPolicyPreservedState.
65103 65104 65105 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65103 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Hash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice>
Disks created on the instances that will be preserved on instance
delete, update, etc. This map is keyed with the device names of
the disks.
Corresponds to the JSON property disks
65087 65088 65089 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65087 def disks @disks end |
#external_i_ps ⇒ Hash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>
External network IPs assigned to the instances that will be preserved on
instance delete, update, etc. This map is keyed with the network
interface name.
Corresponds to the JSON property externalIPs
65094 65095 65096 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65094 def external_i_ps @external_i_ps end |
#internal_i_ps ⇒ Hash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>
Internal network IPs assigned to the instances that will be preserved on
instance delete, update, etc. This map is keyed with the network
interface name.
Corresponds to the JSON property internalIPs
65101 65102 65103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65101 def internal_i_ps @internal_i_ps end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65108 65109 65110 65111 65112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65108 def update!(**args) @disks = args[:disks] if args.key?(:disks) @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps) @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps) end |