Class: Google::Apis::ComputeBeta::StatefulPolicyPreservedState

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Configuration of preserved resources.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StatefulPolicyPreservedState

Returns a new instance of StatefulPolicyPreservedState.



64254
64255
64256
# File 'lib/google/apis/compute_beta/classes.rb', line 64254

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksHash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice>

Disks created on the instances that will be preserved on instance delete, update, etc. This map is keyed with the device names of the disks. Corresponds to the JSON property disks



64238
64239
64240
# File 'lib/google/apis/compute_beta/classes.rb', line 64238

def disks
  @disks
end

#external_i_psHash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>

External network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property externalIPs



64245
64246
64247
# File 'lib/google/apis/compute_beta/classes.rb', line 64245

def external_i_ps
  @external_i_ps
end

#internal_i_psHash<String,Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp>

Internal network IPs assigned to the instances that will be preserved on instance delete, update, etc. This map is keyed with the network interface name. Corresponds to the JSON property internalIPs



64252
64253
64254
# File 'lib/google/apis/compute_beta/classes.rb', line 64252

def internal_i_ps
  @internal_i_ps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64259
64260
64261
64262
64263
# File 'lib/google/apis/compute_beta/classes.rb', line 64259

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @external_i_ps = args[:external_i_ps] if args.key?(:external_i_ps)
  @internal_i_ps = args[:internal_i_ps] if args.key?(:internal_i_ps)
end