Class: Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing, update or VM instance recreate operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice
constructor
A new instance of StatefulPolicyPreservedStateDiskDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice
Returns a new instance of StatefulPolicyPreservedStateDiskDevice.
64221 64222 64223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64221 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the disk should be deleted after it
is no longer used by the group, e.g. when the given instance or
the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be
auto-deleted.
Corresponds to the JSON property autoDelete
64219 64220 64221 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64219 def auto_delete @auto_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64226 64227 64228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64226 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) end |