Class: Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StatefulPolicyPreservedStateDiskDevice
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing, update or VM instance recreate operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice
constructor
A new instance of StatefulPolicyPreservedStateDiskDevice.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedStateDiskDevice
Returns a new instance of StatefulPolicyPreservedStateDiskDevice.
62174 62175 62176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful disks will never be deleted during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the disk should be deleted after it
is no longer used by the group, e.g. when the given instance or
the whole group is deleted. Note: disks attached inREAD_ONLY mode cannot be
auto-deleted.
Corresponds to the JSON property autoDelete
62172 62173 62174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62172 def auto_delete @auto_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62179 62180 62181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62179 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) end |