Class: Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StatefulPolicyPreservedStateNetworkIp
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing, update or VM instance recreate operations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp
constructor
A new instance of StatefulPolicyPreservedStateNetworkIp.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StatefulPolicyPreservedStateNetworkIp
Returns a new instance of StatefulPolicyPreservedStateNetworkIp.
63410 63411 63412 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63410 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_delete ⇒ String
These stateful IPs will never be released during autohealing,
update or VM instance recreate operations.
This flag is used to configure if the IP reservation should be deleted
after it is no longer used by the group, e.g. when the given instance
or the whole group is deleted.
Corresponds to the JSON property autoDelete
63408 63409 63410 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63408 def auto_delete @auto_delete end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63415 63416 63417 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63415 def update!(**args) @auto_delete = args[:auto_delete] if args.key?(:auto_delete) end |