Class: Google::Apis::ComputeBeta::StoragePool
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a zonal storage pool resource.
Instance Attribute Summary collapse
-
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeBeta::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type Corresponds to the JSON property
exapoolProvisionedCapacityGb. -
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeBeta::StoragePoolParams
Additional storage pool params.
-
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool, such as throughput and IOPS.
-
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB.
-
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool.
-
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s.
-
#resource_status ⇒ Google::Apis::ComputeBeta::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#share_settings ⇒ Google::Apis::ComputeBeta::StoragePoolShareSettings
Share settings for the storage pool.
-
#state ⇒ String
Output only.
-
#status ⇒ Google::Apis::ComputeBeta::StoragePoolResourceStatus
[Output Only] Contains output only fields.
-
#storage_pool_type ⇒ String
Type of the storage pool.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePool
constructor
A new instance of StoragePool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePool
Returns a new instance of StoragePool.
65893 65894 65895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65893 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_provisioning_type ⇒ String
Provisioning type of the byte capacity of the pool.
Corresponds to the JSON property capacityProvisioningType
65752 65753 65754 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65752 def capacity_provisioning_type @capacity_provisioning_type end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
65758 65759 65760 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65758 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
65764 65765 65766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65764 def description @description end |
#exapool_provisioned_capacity_gb ⇒ Google::Apis::ComputeBeta::StoragePoolExapoolProvisionedCapacityGb
Exapool provisioned capacities for each SKU type
Corresponds to the JSON property exapoolProvisionedCapacityGb
65769 65770 65771 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65769 def exapool_provisioned_capacity_gb @exapool_provisioned_capacity_gb end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
65776 65777 65778 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65776 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#storagePool
for storage pools.
Corresponds to the JSON property kind
65782 65783 65784 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65782 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this storage pool, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a storage pool.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
65795 65796 65797 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65795 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels to apply to this storage pool. These can be later modified by
the setLabels method.
Corresponds to the JSON property labels
65801 65802 65803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65801 def labels @labels end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
65812 65813 65814 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65812 def name @name end |
#params ⇒ Google::Apis::ComputeBeta::StoragePoolParams
Additional storage pool params.
Corresponds to the JSON property params
65817 65818 65819 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65817 def params @params end |
#performance_provisioning_type ⇒ String
Provisioning type of the performance-related parameters of the pool,
such as throughput and IOPS.
Corresponds to the JSON property performanceProvisioningType
65823 65824 65825 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65823 def performance_provisioning_type @performance_provisioning_type end |
#pool_provisioned_capacity_gb ⇒ Fixnum
Size of the storage pool in GiB. For more information about the size
limits, see https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolProvisionedCapacityGb
65829 65830 65831 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65829 def pool_provisioned_capacity_gb @pool_provisioned_capacity_gb end |
#pool_provisioned_iops ⇒ Fixnum
Provisioned IOPS of the storage pool. Only relevant if the storage pool
type is hyperdisk-balanced.
Corresponds to the JSON property poolProvisionedIops
65835 65836 65837 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65835 def pool_provisioned_iops @pool_provisioned_iops end |
#pool_provisioned_throughput ⇒ Fixnum
Provisioned throughput of the storage pool in MiB/s. Only relevant if the
storage pool type is hyperdisk-balanced or hyperdisk-throughput.
Corresponds to the JSON property poolProvisionedThroughput
65841 65842 65843 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65841 def pool_provisioned_throughput @pool_provisioned_throughput end |
#resource_status ⇒ Google::Apis::ComputeBeta::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property resourceStatus
65846 65847 65848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65846 def resource_status @resource_status end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
65852 65853 65854 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65852 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
65857 65858 65859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65857 def self_link_with_id @self_link_with_id end |
#share_settings ⇒ Google::Apis::ComputeBeta::StoragePoolShareSettings
Share settings for the storage pool.
Corresponds to the JSON property shareSettings
65862 65863 65864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65862 def share_settings @share_settings end |
#state ⇒ String
Output only. [Output Only] The status of storage pool creation.
- CREATING: Storage pool is provisioning. storagePool.
- FAILED: Storage pool creation failed.
- READY: Storage pool is ready for use.
- DELETING: Storage pool is deleting.
Corresponds to the JSON property
state
65874 65875 65876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65874 def state @state end |
#status ⇒ Google::Apis::ComputeBeta::StoragePoolResourceStatus
[Output Only] Contains output only fields.
Corresponds to the JSON property status
65879 65880 65881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65879 def status @status end |
#storage_pool_type ⇒ String
Type of the storage pool.
Corresponds to the JSON property storagePoolType
65884 65885 65886 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65884 def storage_pool_type @storage_pool_type end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the storage pool resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
65891 65892 65893 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65891 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65898 65899 65900 65901 65902 65903 65904 65905 65906 65907 65908 65909 65910 65911 65912 65913 65914 65915 65916 65917 65918 65919 65920 65921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65898 def update!(**args) @capacity_provisioning_type = args[:capacity_provisioning_type] if args.key?(:capacity_provisioning_type) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @exapool_provisioned_capacity_gb = args[:exapool_provisioned_capacity_gb] if args.key?(:exapool_provisioned_capacity_gb) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @performance_provisioning_type = args[:performance_provisioning_type] if args.key?(:performance_provisioning_type) @pool_provisioned_capacity_gb = args[:pool_provisioned_capacity_gb] if args.key?(:pool_provisioned_capacity_gb) @pool_provisioned_iops = args[:pool_provisioned_iops] if args.key?(:pool_provisioned_iops) @pool_provisioned_throughput = args[:pool_provisioned_throughput] if args.key?(:pool_provisioned_throughput) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @share_settings = args[:share_settings] if args.key?(:share_settings) @state = args[:state] if args.key?(:state) @status = args[:status] if args.key?(:status) @storage_pool_type = args[:storage_pool_type] if args.key?(:storage_pool_type) @zone = args[:zone] if args.key?(:zone) end |