Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
65975 65976 65977 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65975 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
65931 65932 65933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65931 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65936 65937 65938 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65936 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
65941 65942 65943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65941 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
65948 65949 65950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65948 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65958 65959 65960 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65958 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65963 65964 65965 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65963 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
65968 65969 65970 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65968 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65973 65974 65975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65973 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65980 65981 65982 65983 65984 65985 65986 65987 65988 65989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65980 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |