Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



65890
65891
65892
# File 'lib/google/apis/compute_beta/classes.rb', line 65890

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65846
65847
65848
# File 'lib/google/apis/compute_beta/classes.rb', line 65846

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65851
65852
65853
# File 'lib/google/apis/compute_beta/classes.rb', line 65851

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



65856
65857
65858
# File 'lib/google/apis/compute_beta/classes.rb', line 65856

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


65863
65864
65865
# File 'lib/google/apis/compute_beta/classes.rb', line 65863

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65873
65874
65875
# File 'lib/google/apis/compute_beta/classes.rb', line 65873

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65878
65879
65880
# File 'lib/google/apis/compute_beta/classes.rb', line 65878

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65883
65884
65885
# File 'lib/google/apis/compute_beta/classes.rb', line 65883

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65888
65889
65890
# File 'lib/google/apis/compute_beta/classes.rb', line 65888

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65895
65896
65897
65898
65899
65900
65901
65902
65903
65904
# File 'lib/google/apis/compute_beta/classes.rb', line 65895

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end