Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



65858
65859
65860
# File 'lib/google/apis/compute_beta/classes.rb', line 65858

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65814
65815
65816
# File 'lib/google/apis/compute_beta/classes.rb', line 65814

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65819
65820
65821
# File 'lib/google/apis/compute_beta/classes.rb', line 65819

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



65824
65825
65826
# File 'lib/google/apis/compute_beta/classes.rb', line 65824

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


65831
65832
65833
# File 'lib/google/apis/compute_beta/classes.rb', line 65831

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65841
65842
65843
# File 'lib/google/apis/compute_beta/classes.rb', line 65841

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65846
65847
65848
# File 'lib/google/apis/compute_beta/classes.rb', line 65846

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65851
65852
65853
# File 'lib/google/apis/compute_beta/classes.rb', line 65851

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65856
65857
65858
# File 'lib/google/apis/compute_beta/classes.rb', line 65856

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65863
65864
65865
65866
65867
65868
65869
65870
65871
65872
# File 'lib/google/apis/compute_beta/classes.rb', line 65863

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end