Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



65425
65426
65427
# File 'lib/google/apis/compute_beta/classes.rb', line 65425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65381
65382
65383
# File 'lib/google/apis/compute_beta/classes.rb', line 65381

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65386
65387
65388
# File 'lib/google/apis/compute_beta/classes.rb', line 65386

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



65391
65392
65393
# File 'lib/google/apis/compute_beta/classes.rb', line 65391

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


65398
65399
65400
# File 'lib/google/apis/compute_beta/classes.rb', line 65398

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65408
65409
65410
# File 'lib/google/apis/compute_beta/classes.rb', line 65408

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65413
65414
65415
# File 'lib/google/apis/compute_beta/classes.rb', line 65413

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65418
65419
65420
# File 'lib/google/apis/compute_beta/classes.rb', line 65418

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65423
65424
65425
# File 'lib/google/apis/compute_beta/classes.rb', line 65423

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65430
65431
65432
65433
65434
65435
65436
65437
65438
65439
# File 'lib/google/apis/compute_beta/classes.rb', line 65430

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end