Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolAggregatedList
constructor
A new instance of StoragePoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolAggregatedList
Returns a new instance of StoragePoolAggregatedList.
64576 64577 64578 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64532 64533 64534 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64532 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64537 64538 64539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64537 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>
A list of StoragePoolsScopedList resources.
Corresponds to the JSON property items
64542 64543 64544 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64542 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
storagePoolAggregatedList for aggregated lists of
storage pools.
Corresponds to the JSON property kind
64549 64550 64551 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64549 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64559 64560 64561 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64559 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64564 64565 64566 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64564 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64569 64570 64571 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64569 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64574 64575 64576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64574 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64581 64582 64583 64584 64585 64586 64587 64588 64589 64590 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64581 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |