Class: Google::Apis::ComputeBeta::StoragePoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolAggregatedList

Returns a new instance of StoragePoolAggregatedList.



64517
64518
64519
# File 'lib/google/apis/compute_beta/classes.rb', line 64517

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64473
64474
64475
# File 'lib/google/apis/compute_beta/classes.rb', line 64473

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64478
64479
64480
# File 'lib/google/apis/compute_beta/classes.rb', line 64478

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::StoragePoolsScopedList>

A list of StoragePoolsScopedList resources. Corresponds to the JSON property items



64483
64484
64485
# File 'lib/google/apis/compute_beta/classes.rb', line 64483

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolAggregatedList for aggregated lists of storage pools. Corresponds to the JSON property kind

Returns:

  • (String)


64490
64491
64492
# File 'lib/google/apis/compute_beta/classes.rb', line 64490

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64500
64501
64502
# File 'lib/google/apis/compute_beta/classes.rb', line 64500

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64505
64506
64507
# File 'lib/google/apis/compute_beta/classes.rb', line 64505

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64510
64511
64512
# File 'lib/google/apis/compute_beta/classes.rb', line 64510

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64515
64516
64517
# File 'lib/google/apis/compute_beta/classes.rb', line 64515

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64522
64523
64524
64525
64526
64527
64528
64529
64530
64531
# File 'lib/google/apis/compute_beta/classes.rb', line 64522

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end