Class: Google::Apis::ComputeBeta::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
66141 66142 66143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
66097 66098 66099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66097 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66102 66103 66104 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66102 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
66107 66108 66109 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66107 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
66113 66114 66115 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66113 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66123 66124 66125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66123 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66128 66129 66130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66128 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
66134 66135 66136 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66134 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66139 66140 66141 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66139 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66146 66147 66148 66149 66150 66151 66152 66153 66154 66155 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66146 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |