Class: Google::Apis::ComputeBeta::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



66109
66110
66111
# File 'lib/google/apis/compute_beta/classes.rb', line 66109

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


66065
66066
66067
# File 'lib/google/apis/compute_beta/classes.rb', line 66065

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66070
66071
66072
# File 'lib/google/apis/compute_beta/classes.rb', line 66070

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



66075
66076
66077
# File 'lib/google/apis/compute_beta/classes.rb', line 66075

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


66081
66082
66083
# File 'lib/google/apis/compute_beta/classes.rb', line 66081

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66091
66092
66093
# File 'lib/google/apis/compute_beta/classes.rb', line 66091

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66096
66097
66098
# File 'lib/google/apis/compute_beta/classes.rb', line 66096

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66102
66103
66104
# File 'lib/google/apis/compute_beta/classes.rb', line 66102

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66107
66108
66109
# File 'lib/google/apis/compute_beta/classes.rb', line 66107

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66114
66115
66116
66117
66118
66119
66120
66121
66122
66123
# File 'lib/google/apis/compute_beta/classes.rb', line 66114

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end