Class: Google::Apis::ComputeBeta::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



65676
65677
65678
# File 'lib/google/apis/compute_beta/classes.rb', line 65676

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65632
65633
65634
# File 'lib/google/apis/compute_beta/classes.rb', line 65632

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65637
65638
65639
# File 'lib/google/apis/compute_beta/classes.rb', line 65637

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



65642
65643
65644
# File 'lib/google/apis/compute_beta/classes.rb', line 65642

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


65648
65649
65650
# File 'lib/google/apis/compute_beta/classes.rb', line 65648

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65658
65659
65660
# File 'lib/google/apis/compute_beta/classes.rb', line 65658

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65663
65664
65665
# File 'lib/google/apis/compute_beta/classes.rb', line 65663

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65669
65670
65671
# File 'lib/google/apis/compute_beta/classes.rb', line 65669

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65674
65675
65676
# File 'lib/google/apis/compute_beta/classes.rb', line 65674

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65681
65682
65683
65684
65685
65686
65687
65688
65689
65690
# File 'lib/google/apis/compute_beta/classes.rb', line 65681

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end