Class: Google::Apis::ComputeBeta::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
64827 64828 64829 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64827 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
64783 64784 64785 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64783 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64788 64789 64790 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64788 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
64793 64794 64795 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64793 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
64799 64800 64801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64799 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64809 64810 64811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64809 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64814 64815 64816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64814 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
64820 64821 64822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64820 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64825 64826 64827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64825 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64832 64833 64834 64835 64836 64837 64838 64839 64840 64841 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64832 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |