Class: Google::Apis::ComputeBeta::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



64768
64769
64770
# File 'lib/google/apis/compute_beta/classes.rb', line 64768

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64724
64725
64726
# File 'lib/google/apis/compute_beta/classes.rb', line 64724

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64729
64730
64731
# File 'lib/google/apis/compute_beta/classes.rb', line 64729

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



64734
64735
64736
# File 'lib/google/apis/compute_beta/classes.rb', line 64734

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


64740
64741
64742
# File 'lib/google/apis/compute_beta/classes.rb', line 64740

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64750
64751
64752
# File 'lib/google/apis/compute_beta/classes.rb', line 64750

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64755
64756
64757
# File 'lib/google/apis/compute_beta/classes.rb', line 64755

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64761
64762
64763
# File 'lib/google/apis/compute_beta/classes.rb', line 64761

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64766
64767
64768
# File 'lib/google/apis/compute_beta/classes.rb', line 64766

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64773
64774
64775
64776
64777
64778
64779
64780
64781
64782
# File 'lib/google/apis/compute_beta/classes.rb', line 64773

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end