Class: Google::Apis::ComputeBeta::StoragePoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of StoragePool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolList

Returns a new instance of StoragePoolList.



63934
63935
63936
# File 'lib/google/apis/compute_beta/classes.rb', line 63934

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


63890
63891
63892
# File 'lib/google/apis/compute_beta/classes.rb', line 63890

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63895
63896
63897
# File 'lib/google/apis/compute_beta/classes.rb', line 63895

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePool>

A list of StoragePool resources. Corresponds to the JSON property items



63900
63901
63902
# File 'lib/google/apis/compute_beta/classes.rb', line 63900

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#storagePoolList for lists of storagePools. Corresponds to the JSON property kind

Returns:

  • (String)


63906
63907
63908
# File 'lib/google/apis/compute_beta/classes.rb', line 63906

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63916
63917
63918
# File 'lib/google/apis/compute_beta/classes.rb', line 63916

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63921
63922
63923
# File 'lib/google/apis/compute_beta/classes.rb', line 63921

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63927
63928
63929
# File 'lib/google/apis/compute_beta/classes.rb', line 63927

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63932
63933
63934
# File 'lib/google/apis/compute_beta/classes.rb', line 63932

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63939
63940
63941
63942
63943
63944
63945
63946
63947
63948
# File 'lib/google/apis/compute_beta/classes.rb', line 63939

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end