Class: Google::Apis::ComputeBeta::StoragePoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of StoragePool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::StoragePool>
A list of StoragePool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolList
constructor
A new instance of StoragePoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolList
Returns a new instance of StoragePoolList.
62721 62722 62723 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62721 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
62677 62678 62679 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62677 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62682 62683 62684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62682 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::StoragePool>
A list of StoragePool resources.
Corresponds to the JSON property items
62687 62688 62689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62687 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#storagePoolList
for lists of storagePools.
Corresponds to the JSON property kind
62693 62694 62695 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62693 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62703 62704 62705 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62703 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62708 62709 62710 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62708 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
62714 62715 62716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62714 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::StoragePoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62719 62720 62721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62719 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62726 62727 62728 62729 62730 62731 62732 62733 62734 62735 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62726 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |