Class: Google::Apis::ComputeBeta::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



66250
66251
66252
# File 'lib/google/apis/compute_beta/classes.rb', line 66250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


66203
66204
66205
# File 'lib/google/apis/compute_beta/classes.rb', line 66203

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66209
66210
66211
# File 'lib/google/apis/compute_beta/classes.rb', line 66209

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



66214
66215
66216
# File 'lib/google/apis/compute_beta/classes.rb', line 66214

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


66221
66222
66223
# File 'lib/google/apis/compute_beta/classes.rb', line 66221

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66232
66233
66234
# File 'lib/google/apis/compute_beta/classes.rb', line 66232

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66237
66238
66239
# File 'lib/google/apis/compute_beta/classes.rb', line 66237

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66243
66244
66245
# File 'lib/google/apis/compute_beta/classes.rb', line 66243

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



66248
66249
66250
# File 'lib/google/apis/compute_beta/classes.rb', line 66248

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66255
66256
66257
66258
66259
66260
66261
66262
66263
66264
# File 'lib/google/apis/compute_beta/classes.rb', line 66255

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end