Class: Google::Apis::ComputeBeta::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



65817
65818
65819
# File 'lib/google/apis/compute_beta/classes.rb', line 65817

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


65770
65771
65772
# File 'lib/google/apis/compute_beta/classes.rb', line 65770

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65776
65777
65778
# File 'lib/google/apis/compute_beta/classes.rb', line 65776

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



65781
65782
65783
# File 'lib/google/apis/compute_beta/classes.rb', line 65781

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


65788
65789
65790
# File 'lib/google/apis/compute_beta/classes.rb', line 65788

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65799
65800
65801
# File 'lib/google/apis/compute_beta/classes.rb', line 65799

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65804
65805
65806
# File 'lib/google/apis/compute_beta/classes.rb', line 65804

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65810
65811
65812
# File 'lib/google/apis/compute_beta/classes.rb', line 65810

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



65815
65816
65817
# File 'lib/google/apis/compute_beta/classes.rb', line 65815

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65822
65823
65824
65825
65826
65827
65828
65829
65830
65831
# File 'lib/google/apis/compute_beta/classes.rb', line 65822

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end