Class: Google::Apis::ComputeBeta::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



64909
64910
64911
# File 'lib/google/apis/compute_beta/classes.rb', line 64909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


64862
64863
64864
# File 'lib/google/apis/compute_beta/classes.rb', line 64862

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64868
64869
64870
# File 'lib/google/apis/compute_beta/classes.rb', line 64868

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



64873
64874
64875
# File 'lib/google/apis/compute_beta/classes.rb', line 64873

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


64880
64881
64882
# File 'lib/google/apis/compute_beta/classes.rb', line 64880

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64891
64892
64893
# File 'lib/google/apis/compute_beta/classes.rb', line 64891

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64896
64897
64898
# File 'lib/google/apis/compute_beta/classes.rb', line 64896

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


64902
64903
64904
# File 'lib/google/apis/compute_beta/classes.rb', line 64902

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



64907
64908
64909
# File 'lib/google/apis/compute_beta/classes.rb', line 64907

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64914
64915
64916
64917
64918
64919
64920
64921
64922
64923
# File 'lib/google/apis/compute_beta/classes.rb', line 64914

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end