Class: Google::Apis::ComputeBeta::StoragePoolListDisks

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolListDisks

Returns a new instance of StoragePoolListDisks.



62862
62863
62864
# File 'lib/google/apis/compute_beta/classes.rb', line 62862

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


62815
62816
62817
# File 'lib/google/apis/compute_beta/classes.rb', line 62815

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


62821
62822
62823
# File 'lib/google/apis/compute_beta/classes.rb', line 62821

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::StoragePoolDisk>

A list of StoragePoolDisk resources. Corresponds to the JSON property items



62826
62827
62828
# File 'lib/google/apis/compute_beta/classes.rb', line 62826

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# storagePoolListDisks for lists of disks in a storagePool. Corresponds to the JSON property kind

Returns:

  • (String)


62833
62834
62835
# File 'lib/google/apis/compute_beta/classes.rb', line 62833

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


62844
62845
62846
# File 'lib/google/apis/compute_beta/classes.rb', line 62844

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


62849
62850
62851
# File 'lib/google/apis/compute_beta/classes.rb', line 62849

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


62855
62856
62857
# File 'lib/google/apis/compute_beta/classes.rb', line 62855

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::StoragePoolListDisks::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



62860
62861
62862
# File 'lib/google/apis/compute_beta/classes.rb', line 62860

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62867
62868
62869
62870
62871
62872
62873
62874
62875
62876
# File 'lib/google/apis/compute_beta/classes.rb', line 62867

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end