Class: Google::Apis::ComputeBeta::StoragePoolResourceStatus

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

[Output Only] Contains output only fields.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ StoragePoolResourceStatus

Returns a new instance of StoragePoolResourceStatus.



66567
66568
66569
# File 'lib/google/apis/compute_beta/classes.rb', line 66567

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disk_countFixnum

[Output Only] Number of disks used. Corresponds to the JSON property diskCount

Returns:

  • (Fixnum)


66487
66488
66489
# File 'lib/google/apis/compute_beta/classes.rb', line 66487

def disk_count
  @disk_count
end

#exapool_max_read_iopsFixnum

Output only. [Output Only] Maximum allowed read IOPS for this Exapool. Corresponds to the JSON property exapoolMaxReadIops

Returns:

  • (Fixnum)


66492
66493
66494
# File 'lib/google/apis/compute_beta/classes.rb', line 66492

def exapool_max_read_iops
  @exapool_max_read_iops
end

#exapool_max_read_throughputFixnum

Output only. [Output Only] Maximum allowed read throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxReadThroughput

Returns:

  • (Fixnum)


66498
66499
66500
# File 'lib/google/apis/compute_beta/classes.rb', line 66498

def exapool_max_read_throughput
  @exapool_max_read_throughput
end

#exapool_max_write_iopsFixnum

Output only. [Output Only] Maximum allowed write IOPS for this Exapool. Corresponds to the JSON property exapoolMaxWriteIops

Returns:

  • (Fixnum)


66503
66504
66505
# File 'lib/google/apis/compute_beta/classes.rb', line 66503

def exapool_max_write_iops
  @exapool_max_write_iops
end

#exapool_max_write_throughputFixnum

Output only. [Output Only] Maximum allowed write throughput in MiB/s for this Exapool. Corresponds to the JSON property exapoolMaxWriteThroughput

Returns:

  • (Fixnum)


66509
66510
66511
# File 'lib/google/apis/compute_beta/classes.rb', line 66509

def exapool_max_write_throughput
  @exapool_max_write_throughput
end

#last_resize_timestampString

Output only. [Output Only] Timestamp of the last successful resize inRFC3339 text format. Corresponds to the JSON property lastResizeTimestamp

Returns:

  • (String)


66515
66516
66517
# File 'lib/google/apis/compute_beta/classes.rb', line 66515

def last_resize_timestamp
  @last_resize_timestamp
end

#max_total_provisioned_disk_capacity_gbFixnum

[Output Only] Maximum allowed aggregate disk size in GiB. Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


66520
66521
66522
# File 'lib/google/apis/compute_beta/classes.rb', line 66520

def max_total_provisioned_disk_capacity_gb
  @max_total_provisioned_disk_capacity_gb
end

#pool_used_capacity_bytesFixnum

[Output Only] Space used by data stored in disks within the storage pool (in bytes). This will reflect the total number of bytes written to the disks in the pool, in contrast to the capacity of those disks. Corresponds to the JSON property poolUsedCapacityBytes

Returns:

  • (Fixnum)


66527
66528
66529
# File 'lib/google/apis/compute_beta/classes.rb', line 66527

def pool_used_capacity_bytes
  @pool_used_capacity_bytes
end

#pool_used_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity. For more information, see https://cloud.google.com/compute/docs/disks/storage-pools. Corresponds to the JSON property poolUsedIops

Returns:

  • (Fixnum)


66535
66536
66537
# File 'lib/google/apis/compute_beta/classes.rb', line 66535

def pool_used_iops
  @pool_used_iops
end

#pool_used_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s. Corresponds to the JSON property poolUsedThroughput

Returns:

  • (Fixnum)


66540
66541
66542
# File 'lib/google/apis/compute_beta/classes.rb', line 66540

def pool_used_throughput
  @pool_used_throughput
end

#pool_user_written_bytesFixnum

[Output Only] Amount of data written into the pool, before it is compacted. Corresponds to the JSON property poolUserWrittenBytes

Returns:

  • (Fixnum)


66546
66547
66548
# File 'lib/google/apis/compute_beta/classes.rb', line 66546

def pool_user_written_bytes
  @pool_user_written_bytes
end

#total_provisioned_disk_capacity_gbFixnum

[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool. A disk's provisioned capacity is the same as its total capacity. Corresponds to the JSON property totalProvisionedDiskCapacityGb

Returns:

  • (Fixnum)


66553
66554
66555
# File 'lib/google/apis/compute_beta/classes.rb', line 66553

def total_provisioned_disk_capacity_gb
  @total_provisioned_disk_capacity_gb
end

#total_provisioned_disk_iopsFixnum

[Output Only] Sum of all the disks' provisioned IOPS. Corresponds to the JSON property totalProvisionedDiskIops

Returns:

  • (Fixnum)


66558
66559
66560
# File 'lib/google/apis/compute_beta/classes.rb', line 66558

def total_provisioned_disk_iops
  @total_provisioned_disk_iops
end

#total_provisioned_disk_throughputFixnum

[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity. Corresponds to the JSON property totalProvisionedDiskThroughput

Returns:

  • (Fixnum)


66565
66566
66567
# File 'lib/google/apis/compute_beta/classes.rb', line 66565

def total_provisioned_disk_throughput
  @total_provisioned_disk_throughput
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66572
66573
66574
66575
66576
66577
66578
66579
66580
66581
66582
66583
66584
66585
66586
66587
# File 'lib/google/apis/compute_beta/classes.rb', line 66572

def update!(**args)
  @disk_count = args[:disk_count] if args.key?(:disk_count)
  @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops)
  @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput)
  @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops)
  @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput)
  @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp)
  @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb)
  @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes)
  @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops)
  @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput)
  @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes)
  @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb)
  @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops)
  @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput)
end