Class: Google::Apis::ComputeBeta::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
-
#exapool_max_read_iops ⇒ Fixnum
Output only.
-
#exapool_max_read_throughput ⇒ Fixnum
Output only.
-
#exapool_max_write_iops ⇒ Fixnum
Output only.
-
#exapool_max_write_throughput ⇒ Fixnum
Output only.
-
#last_resize_timestamp ⇒ String
Output only.
-
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
-
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
-
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
-
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolResourceStatus
constructor
A new instance of StoragePoolResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolResourceStatus
Returns a new instance of StoragePoolResourceStatus.
66017 66018 66019 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
Corresponds to the JSON property diskCount
65937 65938 65939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65937 def disk_count @disk_count end |
#exapool_max_read_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed read IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxReadIops
65942 65943 65944 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65942 def exapool_max_read_iops @exapool_max_read_iops end |
#exapool_max_read_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed read throughput in MiB/s for
this Exapool.
Corresponds to the JSON property exapoolMaxReadThroughput
65948 65949 65950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65948 def exapool_max_read_throughput @exapool_max_read_throughput end |
#exapool_max_write_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed write IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxWriteIops
65953 65954 65955 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65953 def exapool_max_write_iops @exapool_max_write_iops end |
#exapool_max_write_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed write throughput in MiB/s
for this Exapool.
Corresponds to the JSON property exapoolMaxWriteThroughput
65959 65960 65961 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65959 def exapool_max_write_throughput @exapool_max_write_throughput end |
#last_resize_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last successful resize inRFC3339
text format.
Corresponds to the JSON property lastResizeTimestamp
65965 65966 65967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65965 def @last_resize_timestamp end |
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb
65970 65971 65972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65970 def max_total_provisioned_disk_capacity_gb @max_total_provisioned_disk_capacity_gb end |
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool
(in bytes). This will reflect the total number of bytes written to the
disks in the pool, in contrast to the capacity of those disks.
Corresponds to the JSON property poolUsedCapacityBytes
65977 65978 65979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65977 def pool_used_capacity_bytes @pool_used_capacity_bytes end |
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount
that is allowed per disk that is not counted towards pool's IOPS
capacity. For more information, see
https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolUsedIops
65985 65986 65987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65985 def pool_used_iops @pool_used_iops end |
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
Corresponds to the JSON property poolUsedThroughput
65990 65991 65992 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65990 def pool_used_throughput @pool_used_throughput end |
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is
compacted.
Corresponds to the JSON property poolUserWrittenBytes
65996 65997 65998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65996 def pool_user_written_bytes @pool_user_written_bytes end |
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in
this storage pool. A disk's provisioned capacity is the same as its total
capacity.
Corresponds to the JSON property totalProvisionedDiskCapacityGb
66003 66004 66005 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66003 def total_provisioned_disk_capacity_gb @total_provisioned_disk_capacity_gb end |
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
Corresponds to the JSON property totalProvisionedDiskIops
66008 66009 66010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66008 def total_provisioned_disk_iops @total_provisioned_disk_iops end |
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s,
minus some amount that is allowed per disk that is not counted towards
pool's throughput capacity.
Corresponds to the JSON property totalProvisionedDiskThroughput
66015 66016 66017 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66015 def total_provisioned_disk_throughput @total_provisioned_disk_throughput end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66022 66023 66024 66025 66026 66027 66028 66029 66030 66031 66032 66033 66034 66035 66036 66037 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66022 def update!(**args) @disk_count = args[:disk_count] if args.key?(:disk_count) @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops) @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput) @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops) @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput) @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp) @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb) @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes) @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops) @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput) @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes) @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb) @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops) @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput) end |