Class: Google::Apis::ComputeBeta::StoragePoolResourceStatus
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::StoragePoolResourceStatus
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
[Output Only] Contains output only fields.
Instance Attribute Summary collapse
-
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
-
#exapool_max_read_iops ⇒ Fixnum
Output only.
-
#exapool_max_read_throughput ⇒ Fixnum
Output only.
-
#exapool_max_write_iops ⇒ Fixnum
Output only.
-
#exapool_max_write_throughput ⇒ Fixnum
Output only.
-
#last_resize_timestamp ⇒ String
Output only.
-
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
-
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool (in bytes).
-
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount that is allowed per disk that is not counted towards pool's IOPS capacity.
-
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
-
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is compacted.
-
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in this storage pool.
-
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
-
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s, minus some amount that is allowed per disk that is not counted towards pool's throughput capacity.
Instance Method Summary collapse
-
#initialize(**args) ⇒ StoragePoolResourceStatus
constructor
A new instance of StoragePoolResourceStatus.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ StoragePoolResourceStatus
Returns a new instance of StoragePoolResourceStatus.
65987 65988 65989 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65987 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disk_count ⇒ Fixnum
[Output Only] Number of disks used.
Corresponds to the JSON property diskCount
65907 65908 65909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65907 def disk_count @disk_count end |
#exapool_max_read_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed read IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxReadIops
65912 65913 65914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65912 def exapool_max_read_iops @exapool_max_read_iops end |
#exapool_max_read_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed read throughput in MiB/s for
this Exapool.
Corresponds to the JSON property exapoolMaxReadThroughput
65918 65919 65920 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65918 def exapool_max_read_throughput @exapool_max_read_throughput end |
#exapool_max_write_iops ⇒ Fixnum
Output only. [Output Only] Maximum allowed write IOPS for this Exapool.
Corresponds to the JSON property exapoolMaxWriteIops
65923 65924 65925 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65923 def exapool_max_write_iops @exapool_max_write_iops end |
#exapool_max_write_throughput ⇒ Fixnum
Output only. [Output Only] Maximum allowed write throughput in MiB/s
for this Exapool.
Corresponds to the JSON property exapoolMaxWriteThroughput
65929 65930 65931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65929 def exapool_max_write_throughput @exapool_max_write_throughput end |
#last_resize_timestamp ⇒ String
Output only. [Output Only] Timestamp of the last successful resize inRFC3339
text format.
Corresponds to the JSON property lastResizeTimestamp
65935 65936 65937 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65935 def @last_resize_timestamp end |
#max_total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Maximum allowed aggregate disk size in GiB.
Corresponds to the JSON property maxTotalProvisionedDiskCapacityGb
65940 65941 65942 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65940 def max_total_provisioned_disk_capacity_gb @max_total_provisioned_disk_capacity_gb end |
#pool_used_capacity_bytes ⇒ Fixnum
[Output Only] Space used by data stored in disks within the storage pool
(in bytes). This will reflect the total number of bytes written to the
disks in the pool, in contrast to the capacity of those disks.
Corresponds to the JSON property poolUsedCapacityBytes
65947 65948 65949 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65947 def pool_used_capacity_bytes @pool_used_capacity_bytes end |
#pool_used_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS, minus some amount
that is allowed per disk that is not counted towards pool's IOPS
capacity. For more information, see
https://cloud.google.com/compute/docs/disks/storage-pools.
Corresponds to the JSON property poolUsedIops
65955 65956 65957 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65955 def pool_used_iops @pool_used_iops end |
#pool_used_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s.
Corresponds to the JSON property poolUsedThroughput
65960 65961 65962 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65960 def pool_used_throughput @pool_used_throughput end |
#pool_user_written_bytes ⇒ Fixnum
[Output Only] Amount of data written into the pool, before it is
compacted.
Corresponds to the JSON property poolUserWrittenBytes
65966 65967 65968 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65966 def pool_user_written_bytes @pool_user_written_bytes end |
#total_provisioned_disk_capacity_gb ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned capacity (in GiB) in
this storage pool. A disk's provisioned capacity is the same as its total
capacity.
Corresponds to the JSON property totalProvisionedDiskCapacityGb
65973 65974 65975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65973 def total_provisioned_disk_capacity_gb @total_provisioned_disk_capacity_gb end |
#total_provisioned_disk_iops ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned IOPS.
Corresponds to the JSON property totalProvisionedDiskIops
65978 65979 65980 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65978 def total_provisioned_disk_iops @total_provisioned_disk_iops end |
#total_provisioned_disk_throughput ⇒ Fixnum
[Output Only] Sum of all the disks' provisioned throughput in MiB/s,
minus some amount that is allowed per disk that is not counted towards
pool's throughput capacity.
Corresponds to the JSON property totalProvisionedDiskThroughput
65985 65986 65987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65985 def total_provisioned_disk_throughput @total_provisioned_disk_throughput end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65992 65993 65994 65995 65996 65997 65998 65999 66000 66001 66002 66003 66004 66005 66006 66007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65992 def update!(**args) @disk_count = args[:disk_count] if args.key?(:disk_count) @exapool_max_read_iops = args[:exapool_max_read_iops] if args.key?(:exapool_max_read_iops) @exapool_max_read_throughput = args[:exapool_max_read_throughput] if args.key?(:exapool_max_read_throughput) @exapool_max_write_iops = args[:exapool_max_write_iops] if args.key?(:exapool_max_write_iops) @exapool_max_write_throughput = args[:exapool_max_write_throughput] if args.key?(:exapool_max_write_throughput) @last_resize_timestamp = args[:last_resize_timestamp] if args.key?(:last_resize_timestamp) @max_total_provisioned_disk_capacity_gb = args[:max_total_provisioned_disk_capacity_gb] if args.key?(:max_total_provisioned_disk_capacity_gb) @pool_used_capacity_bytes = args[:pool_used_capacity_bytes] if args.key?(:pool_used_capacity_bytes) @pool_used_iops = args[:pool_used_iops] if args.key?(:pool_used_iops) @pool_used_throughput = args[:pool_used_throughput] if args.key?(:pool_used_throughput) @pool_user_written_bytes = args[:pool_user_written_bytes] if args.key?(:pool_user_written_bytes) @total_provisioned_disk_capacity_gb = args[:total_provisioned_disk_capacity_gb] if args.key?(:total_provisioned_disk_capacity_gb) @total_provisioned_disk_iops = args[:total_provisioned_disk_iops] if args.key?(:total_provisioned_disk_iops) @total_provisioned_disk_throughput = args[:total_provisioned_disk_throughput] if args.key?(:total_provisioned_disk_throughput) end |