Class: Google::Apis::ComputeBeta::Subnetwork
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Subnetwork
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.
Instance Attribute Summary collapse
-
#allow_subnet_cidr_routes_overlap ⇒ Boolean
(also: #allow_subnet_cidr_routes_overlap?)
Whether this subnetwork's ranges can conflict with existing custom routes.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#enable_flow_logs ⇒ Boolean
(also: #enable_flow_logs?)
Whether to enable flow logging for this subnetwork.
-
#external_ipv6_prefix ⇒ String
The external IPv6 address range that is owned by this subnetwork.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#gateway_address ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#internal_ipv6_prefix ⇒ String
The internal IPv6 address range that is owned by this subnetwork.
-
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
-
#ip_collection ⇒ String
Reference to the source of IP, like a PublicDelegatedPrefix (PDP) for BYOIP.
-
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds.
-
#ipv6_cidr_range ⇒ String
Output only.
-
#ipv6_gce_endpoint ⇒ String
Output only.
-
#ipv6_network_tier ⇒ String
Specifies the network tier for EXTERNAL IPv6.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeBeta::SubnetworkLogConfig
The available logging options for this subnetwork.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#network ⇒ String
The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork.
-
#params ⇒ Google::Apis::ComputeBeta::SubnetworkParams
Additional subnetwork parameters.
-
#private_ip_google_access ⇒ Boolean
(also: #private_ip_google_access?)
Whether the VMs in this subnet can access Google services without assigned external IP addresses.
-
#private_ipv6_google_access ⇒ String
This field is for internal use.
-
#purpose ⇒ String
Corresponds to the JSON property
purpose. -
#region ⇒ String
URL of the region where the Subnetwork resides.
-
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
-
#resolve_subnet_mask ⇒ String
Configures subnet mask resolution for this subnetwork.
-
#role ⇒ String
The role of subnetwork.
-
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::SubnetworkSecondaryRange>
An array of configurations for secondary IP ranges for VM instances contained in this subnetwork.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#stack_type ⇒ String
The stack type for the subnet.
-
#state ⇒ String
Output only.
-
#system_reserved_external_ipv6_ranges ⇒ Array<String>
Output only.
-
#system_reserved_internal_ipv6_ranges ⇒ Array<String>
Output only.
-
#utilization_details ⇒ Google::Apis::ComputeBeta::SubnetworkUtilizationDetails
The current IP utilization of all subnetwork ranges.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subnetwork
constructor
A new instance of Subnetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subnetwork
Returns a new instance of Subnetwork.
67903 67904 67905 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67903 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_subnet_cidr_routes_overlap ⇒ Boolean Also known as: allow_subnet_cidr_routes_overlap?
Whether this subnetwork's ranges can conflict with existing custom routes.
Setting this to true allows this subnetwork's primary and secondary ranges
to overlap with (and contain) custom routes that have already been
configured on the corresponding network.
For example if a static route has range 10.1.0.0/16, a subnet
range 10.0.0.0/8 could only be created if allow_conflicting_routes=true.
Overlapping is only allowed on subnetwork operations; routes
whose ranges conflict with this subnetwork's ranges won't be allowed unless
route.allow_conflicting_subnetworks is set to true.
Typically packets destined to IPs within the subnetwork (which may contain
private/sensitive data) are prevented from leaving the virtual network.
Setting this field to true will disable this feature.
The default value is false and applies to all existing subnetworks and
automatically created subnetworks.
Corresponds to the JSON property allowSubnetCidrRoutesOverlap
67638 67639 67640 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67638 def allow_subnet_cidr_routes_overlap @allow_subnet_cidr_routes_overlap end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
67645 67646 67647 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67645 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource. This field can be set only at resource creation time.
Corresponds to the JSON property description
67651 67652 67653 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67651 def description @description end |
#enable_flow_logs ⇒ Boolean Also known as: enable_flow_logs?
Whether to enable flow logging for this subnetwork. If this field is not
explicitly set, it will not appear in get listings. If not set
the default behavior is determined by the org policy, if there is no org
policy specified, then it will default to disabled. This field isn't
supported if the subnet purpose field is set toREGIONAL_MANAGED_PROXY. It is
recommended to uselogConfig.enable field instead.
Corresponds to the JSON property enableFlowLogs
67661 67662 67663 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67661 def enable_flow_logs @enable_flow_logs end |
#external_ipv6_prefix ⇒ String
The external IPv6 address range that is owned by this
subnetwork.
Corresponds to the JSON property externalIpv6Prefix
67668 67669 67670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67668 def external_ipv6_prefix @external_ipv6_prefix end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a Subnetwork. An up-to-date fingerprint must be
provided in order to update the Subnetwork, otherwise the
request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a Subnetwork.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
67680 67681 67682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67680 def fingerprint @fingerprint end |
#gateway_address ⇒ String
Output only. [Output Only] The gateway address for default routes to reach
destination
addresses outside this subnetwork.
Corresponds to the JSON property gatewayAddress
67687 67688 67689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67687 def gateway_address @gateway_address end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
67694 67695 67696 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67694 def id @id end |
#internal_ipv6_prefix ⇒ String
The internal IPv6 address range that is owned by this
subnetwork.
Corresponds to the JSON property internalIpv6Prefix
67700 67701 67702 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67700 def internal_ipv6_prefix @internal_ipv6_prefix end |
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
Provide this property when you create the subnetwork. For example,10.0.0.0/8
or 100.64.0.0/10. Ranges must
be unique and non-overlapping within a network. Only IPv4 is supported.
This field is set at resource creation time. The range can be any range
listed in theValid
ranges list. The range can be expanded after creation usingexpandIpCidrRange.
Corresponds to the JSON property ipCidrRange
67711 67712 67713 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67711 def ip_cidr_range @ip_cidr_range end |
#ip_collection ⇒ String
Reference to the source of IP, like a PublicDelegatedPrefix (PDP) for BYOIP. The PDP must be a sub-PDP in EXTERNAL_IPV6_SUBNETWORK_CREATION or INTERNAL_IPV6_SUBNETWORK_CREATION mode. Use one of the following formats to specify a sub-PDP when creating a dual stack or IPv6-only subnetwork with external access using BYOIP:
- Full resource URL, as inhttps://www.googleapis.com/compute/v1/projects/
projectId/regions/region/publicDelegatedPrefixes/sub-pdp-name
Partial URL, as in
- projects/projectId/regions/region/publicDelegatedPrefixes/sub-pdp- name
- regions/region/publicDelegatedPrefixes/sub-pdp-name
Corresponds to the JSON property
ipCollection
67732 67733 67734 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67732 def ip_collection @ip_collection end |
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds. It's immutable and can
only be specified during creation or the first time the subnet is updated
into IPV4_IPV6 dual stack.
Corresponds to the JSON property ipv6AccessType
67739 67740 67741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67739 def ipv6_access_type @ipv6_access_type end |
#ipv6_cidr_range ⇒ String
Output only. [Output Only] This field is for internal use.
Corresponds to the JSON property ipv6CidrRange
67744 67745 67746 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67744 def ipv6_cidr_range @ipv6_cidr_range end |
#ipv6_gce_endpoint ⇒ String
Output only. [Output Only] Possible endpoints of this subnetwork. It can be one of the following:
- VM_ONLY: The subnetwork can be used for creating instances and IPv6 addresses with VM endpoint type. Such a subnetwork gets external IPv6 ranges from a public delegated prefix and cannot be used to create NetLb.
- VM_AND_FR: The subnetwork can be used for creating both VM
instances and Forwarding Rules. It can also be used to reserve IPv6
addresses with both VM and FR endpoint types. Such a subnetwork gets its
IPv6 range from Google IP Pool directly.
Corresponds to the JSON property
ipv6GceEndpoint
67759 67760 67761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67759 def ipv6_gce_endpoint @ipv6_gce_endpoint end |
#ipv6_network_tier ⇒ String
Specifies the network tier for EXTERNAL IPv6. Can only be set when
ipv6_access_type is EXTERNAL. Defaults to project defaultNetworkTier if not
specified during the creation of the subnetwork. This field is IMMUTABLE
once set with EXTERNAL IPv6.
Corresponds to the JSON property ipv6NetworkTier
67767 67768 67769 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67767 def ipv6_network_tier @ipv6_network_tier end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#subnetwork
for Subnetwork resources.
Corresponds to the JSON property kind
67773 67774 67775 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67773 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeBeta::SubnetworkLogConfig
The available logging options for this subnetwork.
Corresponds to the JSON property logConfig
67778 67779 67780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67778 def log_config @log_config end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
67789 67790 67791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67789 def name @name end |
#network ⇒ String
The URL of the network to which this subnetwork belongs, provided by the
client when initially creating the subnetwork. This field can be set only
at resource creation time.
Corresponds to the JSON property network
67796 67797 67798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67796 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::SubnetworkParams
Additional subnetwork parameters.
Corresponds to the JSON property params
67801 67802 67803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67801 def params @params end |
#private_ip_google_access ⇒ Boolean Also known as: private_ip_google_access?
Whether the VMs in this subnet can access Google services without assigned
external IP addresses. This field can be both set at resource creation
time and updated using setPrivateIpGoogleAccess.
Corresponds to the JSON property privateIpGoogleAccess
67808 67809 67810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67808 def private_ip_google_access @private_ip_google_access end |
#private_ipv6_google_access ⇒ String
This field is for internal use.
This field can be both set at resource creation time and updated usingpatch.
Corresponds to the JSON property privateIpv6GoogleAccess
67815 67816 67817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67815 def private_ipv6_google_access @private_ipv6_google_access end |
#purpose ⇒ String
Corresponds to the JSON property purpose
67820 67821 67822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67820 def purpose @purpose end |
#region ⇒ String
URL of the region where the Subnetwork resides. This
field can be set only at resource creation time.
Corresponds to the JSON property region
67826 67827 67828 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67826 def region @region end |
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
Corresponds to the JSON property reservedInternalRange
67831 67832 67833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67831 def reserved_internal_range @reserved_internal_range end |
#resolve_subnet_mask ⇒ String
Configures subnet mask resolution for this subnetwork.
Corresponds to the JSON property resolveSubnetMask
67836 67837 67838 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67836 def resolve_subnet_mask @resolve_subnet_mask end |
#role ⇒ String
The role of subnetwork. Currently, this field is only used when
purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can
be set toACTIVE or BACKUP. An ACTIVE
subnetwork is one that is currently being used for Envoy-based load
balancers in a region. A BACKUP subnetwork is one that is
ready to be promoted to ACTIVE or is currently draining.
This field can be updated with a patch request.
Corresponds to the JSON property role
67847 67848 67849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67847 def role @role end |
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::SubnetworkSecondaryRange>
An array of configurations for secondary IP ranges for VM instances
contained in this subnetwork. The primary IP of such VM must belong to the
primary ipCidrRange of the subnetwork. The alias IPs may belong to either
primary or secondary ranges. This field can be updated with apatch request.
Supports both IPv4 and IPv6 ranges.
Corresponds to the JSON property secondaryIpRanges
67856 67857 67858 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67856 def secondary_ip_ranges @secondary_ip_ranges end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
67861 67862 67863 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67861 def self_link @self_link end |
#stack_type ⇒ String
The stack type for the subnet. If set to IPV4_ONLY, new VMs
in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in
the subnet can be assigned both IPv4 and
IPv6 addresses. If not specified, IPV4_ONLY is used.
This field can be both set at resource creation time and updated usingpatch.
Corresponds to the JSON property stackType
67870 67871 67872 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67870 def stack_type @stack_type end |
#state ⇒ String
Output only. [Output Only] The state of the subnetwork, which can be one of
the
following values:READY: Subnetwork is created and ready to useDRAINING: only
applicable to subnetworks that have the
purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that
connections to the load balancer are being drained. A subnetwork that is
draining cannot be used or modified until it reaches a status ofREADY
Corresponds to the JSON property state
67881 67882 67883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67881 def state @state end |
#system_reserved_external_ipv6_ranges ⇒ Array<String>
Output only. [Output Only] The array of external IPv6 network ranges reserved
from
the subnetwork's external IPv6 range for system use.
Corresponds to the JSON property systemReservedExternalIpv6Ranges
67888 67889 67890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67888 def system_reserved_external_ipv6_ranges @system_reserved_external_ipv6_ranges end |
#system_reserved_internal_ipv6_ranges ⇒ Array<String>
Output only. [Output Only] The array of internal IPv6 network ranges reserved
from
the subnetwork's internal IPv6 range for system use.
Corresponds to the JSON property systemReservedInternalIpv6Ranges
67895 67896 67897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67895 def system_reserved_internal_ipv6_ranges @system_reserved_internal_ipv6_ranges end |
#utilization_details ⇒ Google::Apis::ComputeBeta::SubnetworkUtilizationDetails
The current IP utilization of all subnetwork ranges. Contains the total
number of allocated and free IPs in each range.
Corresponds to the JSON property utilizationDetails
67901 67902 67903 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67901 def utilization_details @utilization_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67908 67909 67910 67911 67912 67913 67914 67915 67916 67917 67918 67919 67920 67921 67922 67923 67924 67925 67926 67927 67928 67929 67930 67931 67932 67933 67934 67935 67936 67937 67938 67939 67940 67941 67942 67943 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67908 def update!(**args) @allow_subnet_cidr_routes_overlap = args[:allow_subnet_cidr_routes_overlap] if args.key?(:allow_subnet_cidr_routes_overlap) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable_flow_logs = args[:enable_flow_logs] if args.key?(:enable_flow_logs) @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @gateway_address = args[:gateway_address] if args.key?(:gateway_address) @id = args[:id] if args.key?(:id) @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ip_collection = args[:ip_collection] if args.key?(:ip_collection) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range) @ipv6_gce_endpoint = args[:ipv6_gce_endpoint] if args.key?(:ipv6_gce_endpoint) @ipv6_network_tier = args[:ipv6_network_tier] if args.key?(:ipv6_network_tier) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @private_ip_google_access = args[:private_ip_google_access] if args.key?(:private_ip_google_access) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @purpose = args[:purpose] if args.key?(:purpose) @region = args[:region] if args.key?(:region) @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range) @resolve_subnet_mask = args[:resolve_subnet_mask] if args.key?(:resolve_subnet_mask) @role = args[:role] if args.key?(:role) @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges) @self_link = args[:self_link] if args.key?(:self_link) @stack_type = args[:stack_type] if args.key?(:stack_type) @state = args[:state] if args.key?(:state) @system_reserved_external_ipv6_ranges = args[:system_reserved_external_ipv6_ranges] if args.key?(:system_reserved_external_ipv6_ranges) @system_reserved_internal_ipv6_ranges = args[:system_reserved_internal_ipv6_ranges] if args.key?(:system_reserved_internal_ipv6_ranges) @utilization_details = args[:utilization_details] if args.key?(:utilization_details) end |