Class: Google::Apis::ComputeBeta::Subnetwork
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Subnetwork
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.
Instance Attribute Summary collapse
-
#allow_subnet_cidr_routes_overlap ⇒ Boolean
(also: #allow_subnet_cidr_routes_overlap?)
Whether this subnetwork's ranges can conflict with existing custom routes.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#enable_flow_logs ⇒ Boolean
(also: #enable_flow_logs?)
Whether to enable flow logging for this subnetwork.
-
#external_ipv6_prefix ⇒ String
The external IPv6 address range that is owned by this subnetwork.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#gateway_address ⇒ String
Output only.
-
#id ⇒ Fixnum
Output only.
-
#internal_ipv6_prefix ⇒ String
The internal IPv6 address range that is owned by this subnetwork.
-
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
-
#ip_collection ⇒ String
Reference to the source of IP, like a PublicDelegatedPrefix (PDP) for BYOIP.
-
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds.
-
#ipv6_cidr_range ⇒ String
Output only.
-
#ipv6_gce_endpoint ⇒ String
Output only.
-
#kind ⇒ String
Output only.
-
#log_config ⇒ Google::Apis::ComputeBeta::SubnetworkLogConfig
The available logging options for this subnetwork.
-
#name ⇒ String
The name of the resource, provided by the client when initially creating the resource.
-
#network ⇒ String
The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork.
-
#params ⇒ Google::Apis::ComputeBeta::SubnetworkParams
Additional subnetwork parameters.
-
#private_ip_google_access ⇒ Boolean
(also: #private_ip_google_access?)
Whether the VMs in this subnet can access Google services without assigned external IP addresses.
-
#private_ipv6_google_access ⇒ String
This field is for internal use.
-
#purpose ⇒ String
Corresponds to the JSON property
purpose. -
#region ⇒ String
URL of the region where the Subnetwork resides.
-
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
-
#resolve_subnet_mask ⇒ String
Configures subnet mask resolution for this subnetwork.
-
#role ⇒ String
The role of subnetwork.
-
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::SubnetworkSecondaryRange>
An array of configurations for secondary IP ranges for VM instances contained in this subnetwork.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#stack_type ⇒ String
The stack type for the subnet.
-
#state ⇒ String
Output only.
-
#system_reserved_external_ipv6_ranges ⇒ Array<String>
Output only.
-
#system_reserved_internal_ipv6_ranges ⇒ Array<String>
Output only.
-
#utilization_details ⇒ Google::Apis::ComputeBeta::SubnetworkUtilizationDetails
The current IP utilization of all subnetwork ranges.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Subnetwork
constructor
A new instance of Subnetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Subnetwork
Returns a new instance of Subnetwork.
66058 66059 66060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66058 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_subnet_cidr_routes_overlap ⇒ Boolean Also known as: allow_subnet_cidr_routes_overlap?
Whether this subnetwork's ranges can conflict with existing custom routes.
Setting this to true allows this subnetwork's primary and secondary ranges
to overlap with (and contain) custom routes that have already been
configured on the corresponding network.
For example if a static route has range 10.1.0.0/16, a subnet
range 10.0.0.0/8 could only be created if allow_conflicting_routes=true.
Overlapping is only allowed on subnetwork operations; routes
whose ranges conflict with this subnetwork's ranges won't be allowed unless
route.allow_conflicting_subnetworks is set to true.
Typically packets destined to IPs within the subnetwork (which may contain
private/sensitive data) are prevented from leaving the virtual network.
Setting this field to true will disable this feature.
The default value is false and applies to all existing subnetworks and
automatically created subnetworks.
Corresponds to the JSON property allowSubnetCidrRoutesOverlap
65801 65802 65803 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65801 def allow_subnet_cidr_routes_overlap @allow_subnet_cidr_routes_overlap end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
65808 65809 65810 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65808 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource. This field can be set only at resource creation time.
Corresponds to the JSON property description
65814 65815 65816 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65814 def description @description end |
#enable_flow_logs ⇒ Boolean Also known as: enable_flow_logs?
Whether to enable flow logging for this subnetwork. If this field is not
explicitly set, it will not appear in get listings. If not set
the default behavior is determined by the org policy, if there is no org
policy specified, then it will default to disabled. This field isn't
supported if the subnet purpose field is set toREGIONAL_MANAGED_PROXY. It is
recommended to uselogConfig.enable field instead.
Corresponds to the JSON property enableFlowLogs
65824 65825 65826 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65824 def enable_flow_logs @enable_flow_logs end |
#external_ipv6_prefix ⇒ String
The external IPv6 address range that is owned by this
subnetwork.
Corresponds to the JSON property externalIpv6Prefix
65831 65832 65833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65831 def external_ipv6_prefix @external_ipv6_prefix end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a Subnetwork. An up-to-date fingerprint must be
provided in order to update the Subnetwork, otherwise the
request will fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a Subnetwork.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
65843 65844 65845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65843 def fingerprint @fingerprint end |
#gateway_address ⇒ String
Output only. [Output Only] The gateway address for default routes to reach
destination
addresses outside this subnetwork.
Corresponds to the JSON property gatewayAddress
65850 65851 65852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65850 def gateway_address @gateway_address end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
65857 65858 65859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65857 def id @id end |
#internal_ipv6_prefix ⇒ String
The internal IPv6 address range that is owned by this
subnetwork.
Corresponds to the JSON property internalIpv6Prefix
65863 65864 65865 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65863 def internal_ipv6_prefix @internal_ipv6_prefix end |
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
Provide this property when you create the subnetwork. For example,10.0.0.0/8
or 100.64.0.0/10. Ranges must
be unique and non-overlapping within a network. Only IPv4 is supported.
This field is set at resource creation time. The range can be any range
listed in theValid
ranges list. The range can be expanded after creation usingexpandIpCidrRange.
Corresponds to the JSON property ipCidrRange
65874 65875 65876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65874 def ip_cidr_range @ip_cidr_range end |
#ip_collection ⇒ String
Reference to the source of IP, like a PublicDelegatedPrefix (PDP) for BYOIP. The PDP must be a sub-PDP in EXTERNAL_IPV6_SUBNETWORK_CREATION or INTERNAL_IPV6_SUBNETWORK_CREATION mode. Use one of the following formats to specify a sub-PDP when creating a dual stack or IPv6-only subnetwork with external access using BYOIP:
- Full resource URL, as inhttps://www.googleapis.com/compute/v1/projects/
projectId/regions/region/publicDelegatedPrefixes/sub-pdp-name
Partial URL, as in
- projects/projectId/regions/region/publicDelegatedPrefixes/sub-pdp- name
- regions/region/publicDelegatedPrefixes/sub-pdp-name
Corresponds to the JSON property
ipCollection
65895 65896 65897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65895 def ip_collection @ip_collection end |
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds. It's immutable and can
only be specified during creation or the first time the subnet is updated
into IPV4_IPV6 dual stack.
Corresponds to the JSON property ipv6AccessType
65902 65903 65904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65902 def ipv6_access_type @ipv6_access_type end |
#ipv6_cidr_range ⇒ String
Output only. [Output Only] This field is for internal use.
Corresponds to the JSON property ipv6CidrRange
65907 65908 65909 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65907 def ipv6_cidr_range @ipv6_cidr_range end |
#ipv6_gce_endpoint ⇒ String
Output only. [Output Only] Possible endpoints of this subnetwork. It can be one of the following:
- VM_ONLY: The subnetwork can be used for creating instances and IPv6 addresses with VM endpoint type. Such a subnetwork gets external IPv6 ranges from a public delegated prefix and cannot be used to create NetLb.
- VM_AND_FR: The subnetwork can be used for creating both VM
instances and Forwarding Rules. It can also be used to reserve IPv6
addresses with both VM and FR endpoint types. Such a subnetwork gets its
IPv6 range from Google IP Pool directly.
Corresponds to the JSON property
ipv6GceEndpoint
65922 65923 65924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65922 def ipv6_gce_endpoint @ipv6_gce_endpoint end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#subnetwork
for Subnetwork resources.
Corresponds to the JSON property kind
65928 65929 65930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65928 def kind @kind end |
#log_config ⇒ Google::Apis::ComputeBeta::SubnetworkLogConfig
The available logging options for this subnetwork.
Corresponds to the JSON property logConfig
65933 65934 65935 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65933 def log_config @log_config end |
#name ⇒ String
The name of the resource, provided by the client when initially creating
the resource. The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
65944 65945 65946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65944 def name @name end |
#network ⇒ String
The URL of the network to which this subnetwork belongs, provided by the
client when initially creating the subnetwork. This field can be set only
at resource creation time.
Corresponds to the JSON property network
65951 65952 65953 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65951 def network @network end |
#params ⇒ Google::Apis::ComputeBeta::SubnetworkParams
Additional subnetwork parameters.
Corresponds to the JSON property params
65956 65957 65958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65956 def params @params end |
#private_ip_google_access ⇒ Boolean Also known as: private_ip_google_access?
Whether the VMs in this subnet can access Google services without assigned
external IP addresses. This field can be both set at resource creation
time and updated using setPrivateIpGoogleAccess.
Corresponds to the JSON property privateIpGoogleAccess
65963 65964 65965 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65963 def private_ip_google_access @private_ip_google_access end |
#private_ipv6_google_access ⇒ String
This field is for internal use.
This field can be both set at resource creation time and updated usingpatch.
Corresponds to the JSON property privateIpv6GoogleAccess
65970 65971 65972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65970 def private_ipv6_google_access @private_ipv6_google_access end |
#purpose ⇒ String
Corresponds to the JSON property purpose
65975 65976 65977 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65975 def purpose @purpose end |
#region ⇒ String
URL of the region where the Subnetwork resides. This
field can be set only at resource creation time.
Corresponds to the JSON property region
65981 65982 65983 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65981 def region @region end |
#reserved_internal_range ⇒ String
The URL of the reserved internal range.
Corresponds to the JSON property reservedInternalRange
65986 65987 65988 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65986 def reserved_internal_range @reserved_internal_range end |
#resolve_subnet_mask ⇒ String
Configures subnet mask resolution for this subnetwork.
Corresponds to the JSON property resolveSubnetMask
65991 65992 65993 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65991 def resolve_subnet_mask @resolve_subnet_mask end |
#role ⇒ String
The role of subnetwork. Currently, this field is only used when
purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can
be set toACTIVE or BACKUP. An ACTIVE
subnetwork is one that is currently being used for Envoy-based load
balancers in a region. A BACKUP subnetwork is one that is
ready to be promoted to ACTIVE or is currently draining.
This field can be updated with a patch request.
Corresponds to the JSON property role
66002 66003 66004 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66002 def role @role end |
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::SubnetworkSecondaryRange>
An array of configurations for secondary IP ranges for VM instances
contained in this subnetwork. The primary IP of such VM must belong to the
primary ipCidrRange of the subnetwork. The alias IPs may belong to either
primary or secondary ranges. This field can be updated with apatch request.
Supports both IPv4 and IPv6 ranges.
Corresponds to the JSON property secondaryIpRanges
66011 66012 66013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66011 def secondary_ip_ranges @secondary_ip_ranges end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
66016 66017 66018 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66016 def self_link @self_link end |
#stack_type ⇒ String
The stack type for the subnet. If set to IPV4_ONLY, new VMs
in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in
the subnet can be assigned both IPv4 and
IPv6 addresses. If not specified, IPV4_ONLY is used.
This field can be both set at resource creation time and updated usingpatch.
Corresponds to the JSON property stackType
66025 66026 66027 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66025 def stack_type @stack_type end |
#state ⇒ String
Output only. [Output Only] The state of the subnetwork, which can be one of
the
following values:READY: Subnetwork is created and ready to useDRAINING: only
applicable to subnetworks that have the
purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that
connections to the load balancer are being drained. A subnetwork that is
draining cannot be used or modified until it reaches a status ofREADY
Corresponds to the JSON property state
66036 66037 66038 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66036 def state @state end |
#system_reserved_external_ipv6_ranges ⇒ Array<String>
Output only. [Output Only] The array of external IPv6 network ranges reserved
from
the subnetwork's external IPv6 range for system use.
Corresponds to the JSON property systemReservedExternalIpv6Ranges
66043 66044 66045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66043 def system_reserved_external_ipv6_ranges @system_reserved_external_ipv6_ranges end |
#system_reserved_internal_ipv6_ranges ⇒ Array<String>
Output only. [Output Only] The array of internal IPv6 network ranges reserved
from
the subnetwork's internal IPv6 range for system use.
Corresponds to the JSON property systemReservedInternalIpv6Ranges
66050 66051 66052 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66050 def system_reserved_internal_ipv6_ranges @system_reserved_internal_ipv6_ranges end |
#utilization_details ⇒ Google::Apis::ComputeBeta::SubnetworkUtilizationDetails
The current IP utilization of all subnetwork ranges. Contains the total
number of allocated and free IPs in each range.
Corresponds to the JSON property utilizationDetails
66056 66057 66058 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66056 def utilization_details @utilization_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66063 66064 66065 66066 66067 66068 66069 66070 66071 66072 66073 66074 66075 66076 66077 66078 66079 66080 66081 66082 66083 66084 66085 66086 66087 66088 66089 66090 66091 66092 66093 66094 66095 66096 66097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66063 def update!(**args) @allow_subnet_cidr_routes_overlap = args[:allow_subnet_cidr_routes_overlap] if args.key?(:allow_subnet_cidr_routes_overlap) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @enable_flow_logs = args[:enable_flow_logs] if args.key?(:enable_flow_logs) @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @gateway_address = args[:gateway_address] if args.key?(:gateway_address) @id = args[:id] if args.key?(:id) @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ip_collection = args[:ip_collection] if args.key?(:ip_collection) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range) @ipv6_gce_endpoint = args[:ipv6_gce_endpoint] if args.key?(:ipv6_gce_endpoint) @kind = args[:kind] if args.key?(:kind) @log_config = args[:log_config] if args.key?(:log_config) @name = args[:name] if args.key?(:name) @network = args[:network] if args.key?(:network) @params = args[:params] if args.key?(:params) @private_ip_google_access = args[:private_ip_google_access] if args.key?(:private_ip_google_access) @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access) @purpose = args[:purpose] if args.key?(:purpose) @region = args[:region] if args.key?(:region) @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range) @resolve_subnet_mask = args[:resolve_subnet_mask] if args.key?(:resolve_subnet_mask) @role = args[:role] if args.key?(:role) @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges) @self_link = args[:self_link] if args.key?(:self_link) @stack_type = args[:stack_type] if args.key?(:stack_type) @state = args[:state] if args.key?(:state) @system_reserved_external_ipv6_ranges = args[:system_reserved_external_ipv6_ranges] if args.key?(:system_reserved_external_ipv6_ranges) @system_reserved_internal_ipv6_ranges = args[:system_reserved_internal_ipv6_ranges] if args.key?(:system_reserved_internal_ipv6_ranges) @utilization_details = args[:utilization_details] if args.key?(:utilization_details) end |