Class: Google::Apis::ComputeBeta::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



65999
66000
66001
# File 'lib/google/apis/compute_beta/classes.rb', line 65999

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_subnet_cidr_routes_overlapBoolean Also known as: allow_subnet_cidr_routes_overlap?

Whether this subnetwork's ranges can conflict with existing custom routes. Setting this to true allows this subnetwork's primary and secondary ranges to overlap with (and contain) custom routes that have already been configured on the corresponding network. For example if a static route has range 10.1.0.0/16, a subnet range 10.0.0.0/8 could only be created if allow_conflicting_routes=true. Overlapping is only allowed on subnetwork operations; routes whose ranges conflict with this subnetwork's ranges won't be allowed unless route.allow_conflicting_subnetworks is set to true. Typically packets destined to IPs within the subnetwork (which may contain private/sensitive data) are prevented from leaving the virtual network. Setting this field to true will disable this feature. The default value is false and applies to all existing subnetworks and automatically created subnetworks. Corresponds to the JSON property allowSubnetCidrRoutesOverlap

Returns:

  • (Boolean)


65742
65743
65744
# File 'lib/google/apis/compute_beta/classes.rb', line 65742

def allow_subnet_cidr_routes_overlap
  @allow_subnet_cidr_routes_overlap
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


65749
65750
65751
# File 'lib/google/apis/compute_beta/classes.rb', line 65749

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. This field can be set only at resource creation time. Corresponds to the JSON property description

Returns:

  • (String)


65755
65756
65757
# File 'lib/google/apis/compute_beta/classes.rb', line 65755

def description
  @description
end

#enable_flow_logsBoolean Also known as: enable_flow_logs?

Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. This field isn't supported if the subnet purpose field is set toREGIONAL_MANAGED_PROXY. It is recommended to uselogConfig.enable field instead. Corresponds to the JSON property enableFlowLogs

Returns:

  • (Boolean)


65765
65766
65767
# File 'lib/google/apis/compute_beta/classes.rb', line 65765

def enable_flow_logs
  @enable_flow_logs
end

#external_ipv6_prefixString

The external IPv6 address range that is owned by this subnetwork. Corresponds to the JSON property externalIpv6Prefix

Returns:

  • (String)


65772
65773
65774
# File 'lib/google/apis/compute_beta/classes.rb', line 65772

def external_ipv6_prefix
  @external_ipv6_prefix
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a Subnetwork. An up-to-date fingerprint must be provided in order to update the Subnetwork, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a Subnetwork. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


65784
65785
65786
# File 'lib/google/apis/compute_beta/classes.rb', line 65784

def fingerprint
  @fingerprint
end

#gateway_addressString

Output only. [Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork. Corresponds to the JSON property gatewayAddress

Returns:

  • (String)


65791
65792
65793
# File 'lib/google/apis/compute_beta/classes.rb', line 65791

def gateway_address
  @gateway_address
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


65798
65799
65800
# File 'lib/google/apis/compute_beta/classes.rb', line 65798

def id
  @id
end

#internal_ipv6_prefixString

The internal IPv6 address range that is owned by this subnetwork. Corresponds to the JSON property internalIpv6Prefix

Returns:

  • (String)


65804
65805
65806
# File 'lib/google/apis/compute_beta/classes.rb', line 65804

def internal_ipv6_prefix
  @internal_ipv6_prefix
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example,10.0.0.0/8 or 100.64.0.0/10. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. This field is set at resource creation time. The range can be any range listed in theValid ranges list. The range can be expanded after creation usingexpandIpCidrRange. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


65815
65816
65817
# File 'lib/google/apis/compute_beta/classes.rb', line 65815

def ip_cidr_range
  @ip_cidr_range
end

#ip_collectionString

Reference to the source of IP, like a PublicDelegatedPrefix (PDP) for BYOIP. The PDP must be a sub-PDP in EXTERNAL_IPV6_SUBNETWORK_CREATION or INTERNAL_IPV6_SUBNETWORK_CREATION mode. Use one of the following formats to specify a sub-PDP when creating a dual stack or IPv6-only subnetwork with external access using BYOIP:

- Full resource URL, as inhttps://www.googleapis.com/compute/v1/projects/

projectId/regions/region/publicDelegatedPrefixes/sub-pdp-name

Partial URL, as in

  • projects/projectId/regions/region/publicDelegatedPrefixes/sub-pdp- name
  • regions/region/publicDelegatedPrefixes/sub-pdp-name Corresponds to the JSON property ipCollection

Returns:

  • (String)


65836
65837
65838
# File 'lib/google/apis/compute_beta/classes.rb', line 65836

def ip_collection
  @ip_collection
end

#ipv6_access_typeString

The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


65843
65844
65845
# File 'lib/google/apis/compute_beta/classes.rb', line 65843

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_cidr_rangeString

Output only. [Output Only] This field is for internal use. Corresponds to the JSON property ipv6CidrRange

Returns:

  • (String)


65848
65849
65850
# File 'lib/google/apis/compute_beta/classes.rb', line 65848

def ipv6_cidr_range
  @ipv6_cidr_range
end

#ipv6_gce_endpointString

Output only. [Output Only] Possible endpoints of this subnetwork. It can be one of the following:

  • VM_ONLY: The subnetwork can be used for creating instances and IPv6 addresses with VM endpoint type. Such a subnetwork gets external IPv6 ranges from a public delegated prefix and cannot be used to create NetLb.
  • VM_AND_FR: The subnetwork can be used for creating both VM instances and Forwarding Rules. It can also be used to reserve IPv6 addresses with both VM and FR endpoint types. Such a subnetwork gets its IPv6 range from Google IP Pool directly. Corresponds to the JSON property ipv6GceEndpoint

Returns:

  • (String)


65863
65864
65865
# File 'lib/google/apis/compute_beta/classes.rb', line 65863

def ipv6_gce_endpoint
  @ipv6_gce_endpoint
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources. Corresponds to the JSON property kind

Returns:

  • (String)


65869
65870
65871
# File 'lib/google/apis/compute_beta/classes.rb', line 65869

def kind
  @kind
end

#log_configGoogle::Apis::ComputeBeta::SubnetworkLogConfig

The available logging options for this subnetwork. Corresponds to the JSON property logConfig



65874
65875
65876
# File 'lib/google/apis/compute_beta/classes.rb', line 65874

def log_config
  @log_config
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


65885
65886
65887
# File 'lib/google/apis/compute_beta/classes.rb', line 65885

def name
  @name
end

#networkString

The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. This field can be set only at resource creation time. Corresponds to the JSON property network

Returns:

  • (String)


65892
65893
65894
# File 'lib/google/apis/compute_beta/classes.rb', line 65892

def network
  @network
end

#paramsGoogle::Apis::ComputeBeta::SubnetworkParams

Additional subnetwork parameters. Corresponds to the JSON property params



65897
65898
65899
# File 'lib/google/apis/compute_beta/classes.rb', line 65897

def params
  @params
end

#private_ip_google_accessBoolean Also known as: private_ip_google_access?

Whether the VMs in this subnet can access Google services without assigned external IP addresses. This field can be both set at resource creation time and updated using setPrivateIpGoogleAccess. Corresponds to the JSON property privateIpGoogleAccess

Returns:

  • (Boolean)


65904
65905
65906
# File 'lib/google/apis/compute_beta/classes.rb', line 65904

def private_ip_google_access
  @private_ip_google_access
end

#private_ipv6_google_accessString

This field is for internal use. This field can be both set at resource creation time and updated usingpatch. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


65911
65912
65913
# File 'lib/google/apis/compute_beta/classes.rb', line 65911

def private_ipv6_google_access
  @private_ipv6_google_access
end

#purposeString

Corresponds to the JSON property purpose

Returns:

  • (String)


65916
65917
65918
# File 'lib/google/apis/compute_beta/classes.rb', line 65916

def purpose
  @purpose
end

#regionString

URL of the region where the Subnetwork resides. This field can be set only at resource creation time. Corresponds to the JSON property region

Returns:

  • (String)


65922
65923
65924
# File 'lib/google/apis/compute_beta/classes.rb', line 65922

def region
  @region
end

#reserved_internal_rangeString

The URL of the reserved internal range. Corresponds to the JSON property reservedInternalRange

Returns:

  • (String)


65927
65928
65929
# File 'lib/google/apis/compute_beta/classes.rb', line 65927

def reserved_internal_range
  @reserved_internal_range
end

#resolve_subnet_maskString

Configures subnet mask resolution for this subnetwork. Corresponds to the JSON property resolveSubnetMask

Returns:

  • (String)


65932
65933
65934
# File 'lib/google/apis/compute_beta/classes.rb', line 65932

def resolve_subnet_mask
  @resolve_subnet_mask
end

#roleString

The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Corresponds to the JSON property role

Returns:

  • (String)


65943
65944
65945
# File 'lib/google/apis/compute_beta/classes.rb', line 65943

def role
  @role
end

#secondary_ip_rangesArray<Google::Apis::ComputeBeta::SubnetworkSecondaryRange>

An array of configurations for secondary IP ranges for VM instances contained in this subnetwork. The primary IP of such VM must belong to the primary ipCidrRange of the subnetwork. The alias IPs may belong to either primary or secondary ranges. This field can be updated with apatch request. Supports both IPv4 and IPv6 ranges. Corresponds to the JSON property secondaryIpRanges



65952
65953
65954
# File 'lib/google/apis/compute_beta/classes.rb', line 65952

def secondary_ip_ranges
  @secondary_ip_ranges
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65957
65958
65959
# File 'lib/google/apis/compute_beta/classes.rb', line 65957

def self_link
  @self_link
end

#stack_typeString

The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated usingpatch. Corresponds to the JSON property stackType

Returns:

  • (String)


65966
65967
65968
# File 'lib/google/apis/compute_beta/classes.rb', line 65966

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] The state of the subnetwork, which can be one of the following values:READY: Subnetwork is created and ready to useDRAINING: only applicable to subnetworks that have the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load balancer are being drained. A subnetwork that is draining cannot be used or modified until it reaches a status ofREADY Corresponds to the JSON property state

Returns:

  • (String)


65977
65978
65979
# File 'lib/google/apis/compute_beta/classes.rb', line 65977

def state
  @state
end

#system_reserved_external_ipv6_rangesArray<String>

Output only. [Output Only] The array of external IPv6 network ranges reserved from the subnetwork's external IPv6 range for system use. Corresponds to the JSON property systemReservedExternalIpv6Ranges

Returns:

  • (Array<String>)


65984
65985
65986
# File 'lib/google/apis/compute_beta/classes.rb', line 65984

def system_reserved_external_ipv6_ranges
  @system_reserved_external_ipv6_ranges
end

#system_reserved_internal_ipv6_rangesArray<String>

Output only. [Output Only] The array of internal IPv6 network ranges reserved from the subnetwork's internal IPv6 range for system use. Corresponds to the JSON property systemReservedInternalIpv6Ranges

Returns:

  • (Array<String>)


65991
65992
65993
# File 'lib/google/apis/compute_beta/classes.rb', line 65991

def system_reserved_internal_ipv6_ranges
  @system_reserved_internal_ipv6_ranges
end

#utilization_detailsGoogle::Apis::ComputeBeta::SubnetworkUtilizationDetails

The current IP utilization of all subnetwork ranges. Contains the total number of allocated and free IPs in each range. Corresponds to the JSON property utilizationDetails



65997
65998
65999
# File 'lib/google/apis/compute_beta/classes.rb', line 65997

def utilization_details
  @utilization_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66004
66005
66006
66007
66008
66009
66010
66011
66012
66013
66014
66015
66016
66017
66018
66019
66020
66021
66022
66023
66024
66025
66026
66027
66028
66029
66030
66031
66032
66033
66034
66035
66036
66037
66038
# File 'lib/google/apis/compute_beta/classes.rb', line 66004

def update!(**args)
  @allow_subnet_cidr_routes_overlap = args[:allow_subnet_cidr_routes_overlap] if args.key?(:allow_subnet_cidr_routes_overlap)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable_flow_logs = args[:enable_flow_logs] if args.key?(:enable_flow_logs)
  @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @gateway_address = args[:gateway_address] if args.key?(:gateway_address)
  @id = args[:id] if args.key?(:id)
  @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ip_collection = args[:ip_collection] if args.key?(:ip_collection)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range)
  @ipv6_gce_endpoint = args[:ipv6_gce_endpoint] if args.key?(:ipv6_gce_endpoint)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @private_ip_google_access = args[:private_ip_google_access] if args.key?(:private_ip_google_access)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range)
  @resolve_subnet_mask = args[:resolve_subnet_mask] if args.key?(:resolve_subnet_mask)
  @role = args[:role] if args.key?(:role)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @system_reserved_external_ipv6_ranges = args[:system_reserved_external_ipv6_ranges] if args.key?(:system_reserved_external_ipv6_ranges)
  @system_reserved_internal_ipv6_ranges = args[:system_reserved_internal_ipv6_ranges] if args.key?(:system_reserved_internal_ipv6_ranges)
  @utilization_details = args[:utilization_details] if args.key?(:utilization_details)
end