Class: Google::Apis::ComputeBeta::Subnetwork

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Subnetwork resource. A subnetwork (also known as a subnet) is a logical partition of a Virtual Private Cloud network with one primary IP range and zero or more secondary IP ranges. For more information, read Virtual Private Cloud (VPC) Network.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Subnetwork

Returns a new instance of Subnetwork.



63952
63953
63954
# File 'lib/google/apis/compute_beta/classes.rb', line 63952

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_subnet_cidr_routes_overlapBoolean Also known as: allow_subnet_cidr_routes_overlap?

Whether this subnetwork's ranges can conflict with existing custom routes. Setting this to true allows this subnetwork's primary and secondary ranges to overlap with (and contain) custom routes that have already been configured on the corresponding network. For example if a static route has range 10.1.0.0/16, a subnet range 10.0.0.0/8 could only be created if allow_conflicting_routes=true. Overlapping is only allowed on subnetwork operations; routes whose ranges conflict with this subnetwork's ranges won't be allowed unless route.allow_conflicting_subnetworks is set to true. Typically packets destined to IPs within the subnetwork (which may contain private/sensitive data) are prevented from leaving the virtual network. Setting this field to true will disable this feature. The default value is false and applies to all existing subnetworks and automatically created subnetworks. Corresponds to the JSON property allowSubnetCidrRoutesOverlap

Returns:

  • (Boolean)


63695
63696
63697
# File 'lib/google/apis/compute_beta/classes.rb', line 63695

def allow_subnet_cidr_routes_overlap
  @allow_subnet_cidr_routes_overlap
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


63702
63703
63704
# File 'lib/google/apis/compute_beta/classes.rb', line 63702

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. This field can be set only at resource creation time. Corresponds to the JSON property description

Returns:

  • (String)


63708
63709
63710
# File 'lib/google/apis/compute_beta/classes.rb', line 63708

def description
  @description
end

#enable_flow_logsBoolean Also known as: enable_flow_logs?

Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. This field isn't supported if the subnet purpose field is set toREGIONAL_MANAGED_PROXY. It is recommended to uselogConfig.enable field instead. Corresponds to the JSON property enableFlowLogs

Returns:

  • (Boolean)


63718
63719
63720
# File 'lib/google/apis/compute_beta/classes.rb', line 63718

def enable_flow_logs
  @enable_flow_logs
end

#external_ipv6_prefixString

The external IPv6 address range that is owned by this subnetwork. Corresponds to the JSON property externalIpv6Prefix

Returns:

  • (String)


63725
63726
63727
# File 'lib/google/apis/compute_beta/classes.rb', line 63725

def external_ipv6_prefix
  @external_ipv6_prefix
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a Subnetwork. An up-to-date fingerprint must be provided in order to update the Subnetwork, otherwise the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve a Subnetwork. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


63737
63738
63739
# File 'lib/google/apis/compute_beta/classes.rb', line 63737

def fingerprint
  @fingerprint
end

#gateway_addressString

Output only. [Output Only] The gateway address for default routes to reach destination addresses outside this subnetwork. Corresponds to the JSON property gatewayAddress

Returns:

  • (String)


63744
63745
63746
# File 'lib/google/apis/compute_beta/classes.rb', line 63744

def gateway_address
  @gateway_address
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


63751
63752
63753
# File 'lib/google/apis/compute_beta/classes.rb', line 63751

def id
  @id
end

#internal_ipv6_prefixString

The internal IPv6 address range that is owned by this subnetwork. Corresponds to the JSON property internalIpv6Prefix

Returns:

  • (String)


63757
63758
63759
# File 'lib/google/apis/compute_beta/classes.rb', line 63757

def internal_ipv6_prefix
  @internal_ipv6_prefix
end

#ip_cidr_rangeString

The range of internal addresses that are owned by this subnetwork. Provide this property when you create the subnetwork. For example,10.0.0.0/8 or 100.64.0.0/10. Ranges must be unique and non-overlapping within a network. Only IPv4 is supported. This field is set at resource creation time. The range can be any range listed in theValid ranges list. The range can be expanded after creation usingexpandIpCidrRange. Corresponds to the JSON property ipCidrRange

Returns:

  • (String)


63768
63769
63770
# File 'lib/google/apis/compute_beta/classes.rb', line 63768

def ip_cidr_range
  @ip_cidr_range
end

#ip_collectionString

Reference to the source of IP, like a PublicDelegatedPrefix (PDP) for BYOIP. The PDP must be a sub-PDP in EXTERNAL_IPV6_SUBNETWORK_CREATION or INTERNAL_IPV6_SUBNETWORK_CREATION mode. Use one of the following formats to specify a sub-PDP when creating a dual stack or IPv6-only subnetwork with external access using BYOIP:

- Full resource URL, as inhttps://www.googleapis.com/compute/v1/projects/

projectId/regions/region/publicDelegatedPrefixes/sub-pdp-name

Partial URL, as in

  • projects/projectId/regions/region/publicDelegatedPrefixes/sub-pdp- name
  • regions/region/publicDelegatedPrefixes/sub-pdp-name Corresponds to the JSON property ipCollection

Returns:

  • (String)


63789
63790
63791
# File 'lib/google/apis/compute_beta/classes.rb', line 63789

def ip_collection
  @ip_collection
end

#ipv6_access_typeString

The access type of IPv6 address this subnet holds. It's immutable and can only be specified during creation or the first time the subnet is updated into IPV4_IPV6 dual stack. Corresponds to the JSON property ipv6AccessType

Returns:

  • (String)


63796
63797
63798
# File 'lib/google/apis/compute_beta/classes.rb', line 63796

def ipv6_access_type
  @ipv6_access_type
end

#ipv6_cidr_rangeString

Output only. [Output Only] This field is for internal use. Corresponds to the JSON property ipv6CidrRange

Returns:

  • (String)


63801
63802
63803
# File 'lib/google/apis/compute_beta/classes.rb', line 63801

def ipv6_cidr_range
  @ipv6_cidr_range
end

#ipv6_gce_endpointString

Output only. [Output Only] Possible endpoints of this subnetwork. It can be one of the following:

  • VM_ONLY: The subnetwork can be used for creating instances and IPv6 addresses with VM endpoint type. Such a subnetwork gets external IPv6 ranges from a public delegated prefix and cannot be used to create NetLb.
  • VM_AND_FR: The subnetwork can be used for creating both VM instances and Forwarding Rules. It can also be used to reserve IPv6 addresses with both VM and FR endpoint types. Such a subnetwork gets its IPv6 range from Google IP Pool directly. Corresponds to the JSON property ipv6GceEndpoint

Returns:

  • (String)


63816
63817
63818
# File 'lib/google/apis/compute_beta/classes.rb', line 63816

def ipv6_gce_endpoint
  @ipv6_gce_endpoint
end

#kindString

Output only. [Output Only] Type of the resource. Always compute#subnetwork for Subnetwork resources. Corresponds to the JSON property kind

Returns:

  • (String)


63822
63823
63824
# File 'lib/google/apis/compute_beta/classes.rb', line 63822

def kind
  @kind
end

#log_configGoogle::Apis::ComputeBeta::SubnetworkLogConfig

The available logging options for this subnetwork. Corresponds to the JSON property logConfig



63827
63828
63829
# File 'lib/google/apis/compute_beta/classes.rb', line 63827

def log_config
  @log_config
end

#nameString

The name of the resource, provided by the client when initially creating the resource. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


63838
63839
63840
# File 'lib/google/apis/compute_beta/classes.rb', line 63838

def name
  @name
end

#networkString

The URL of the network to which this subnetwork belongs, provided by the client when initially creating the subnetwork. This field can be set only at resource creation time. Corresponds to the JSON property network

Returns:

  • (String)


63845
63846
63847
# File 'lib/google/apis/compute_beta/classes.rb', line 63845

def network
  @network
end

#paramsGoogle::Apis::ComputeBeta::SubnetworkParams

Additional subnetwork parameters. Corresponds to the JSON property params



63850
63851
63852
# File 'lib/google/apis/compute_beta/classes.rb', line 63850

def params
  @params
end

#private_ip_google_accessBoolean Also known as: private_ip_google_access?

Whether the VMs in this subnet can access Google services without assigned external IP addresses. This field can be both set at resource creation time and updated using setPrivateIpGoogleAccess. Corresponds to the JSON property privateIpGoogleAccess

Returns:

  • (Boolean)


63857
63858
63859
# File 'lib/google/apis/compute_beta/classes.rb', line 63857

def private_ip_google_access
  @private_ip_google_access
end

#private_ipv6_google_accessString

This field is for internal use. This field can be both set at resource creation time and updated usingpatch. Corresponds to the JSON property privateIpv6GoogleAccess

Returns:

  • (String)


63864
63865
63866
# File 'lib/google/apis/compute_beta/classes.rb', line 63864

def private_ipv6_google_access
  @private_ipv6_google_access
end

#purposeString

Corresponds to the JSON property purpose

Returns:

  • (String)


63869
63870
63871
# File 'lib/google/apis/compute_beta/classes.rb', line 63869

def purpose
  @purpose
end

#regionString

URL of the region where the Subnetwork resides. This field can be set only at resource creation time. Corresponds to the JSON property region

Returns:

  • (String)


63875
63876
63877
# File 'lib/google/apis/compute_beta/classes.rb', line 63875

def region
  @region
end

#reserved_internal_rangeString

The URL of the reserved internal range. Corresponds to the JSON property reservedInternalRange

Returns:

  • (String)


63880
63881
63882
# File 'lib/google/apis/compute_beta/classes.rb', line 63880

def reserved_internal_range
  @reserved_internal_range
end

#resolve_subnet_maskString

Configures subnet mask resolution for this subnetwork. Corresponds to the JSON property resolveSubnetMask

Returns:

  • (String)


63885
63886
63887
# File 'lib/google/apis/compute_beta/classes.rb', line 63885

def resolve_subnet_mask
  @resolve_subnet_mask
end

#roleString

The role of subnetwork. Currently, this field is only used when purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can be set toACTIVE or BACKUP. An ACTIVE subnetwork is one that is currently being used for Envoy-based load balancers in a region. A BACKUP subnetwork is one that is ready to be promoted to ACTIVE or is currently draining. This field can be updated with a patch request. Corresponds to the JSON property role

Returns:

  • (String)


63896
63897
63898
# File 'lib/google/apis/compute_beta/classes.rb', line 63896

def role
  @role
end

#secondary_ip_rangesArray<Google::Apis::ComputeBeta::SubnetworkSecondaryRange>

An array of configurations for secondary IP ranges for VM instances contained in this subnetwork. The primary IP of such VM must belong to the primary ipCidrRange of the subnetwork. The alias IPs may belong to either primary or secondary ranges. This field can be updated with apatch request. Supports both IPv4 and IPv6 ranges. Corresponds to the JSON property secondaryIpRanges



63905
63906
63907
# File 'lib/google/apis/compute_beta/classes.rb', line 63905

def secondary_ip_ranges
  @secondary_ip_ranges
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63910
63911
63912
# File 'lib/google/apis/compute_beta/classes.rb', line 63910

def self_link
  @self_link
end

#stack_typeString

The stack type for the subnet. If set to IPV4_ONLY, new VMs in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in the subnet can be assigned both IPv4 and IPv6 addresses. If not specified, IPV4_ONLY is used. This field can be both set at resource creation time and updated usingpatch. Corresponds to the JSON property stackType

Returns:

  • (String)


63919
63920
63921
# File 'lib/google/apis/compute_beta/classes.rb', line 63919

def stack_type
  @stack_type
end

#stateString

Output only. [Output Only] The state of the subnetwork, which can be one of the following values:READY: Subnetwork is created and ready to useDRAINING: only applicable to subnetworks that have the purpose set to INTERNAL_HTTPS_LOAD_BALANCER and indicates that connections to the load balancer are being drained. A subnetwork that is draining cannot be used or modified until it reaches a status ofREADY Corresponds to the JSON property state

Returns:

  • (String)


63930
63931
63932
# File 'lib/google/apis/compute_beta/classes.rb', line 63930

def state
  @state
end

#system_reserved_external_ipv6_rangesArray<String>

Output only. [Output Only] The array of external IPv6 network ranges reserved from the subnetwork's external IPv6 range for system use. Corresponds to the JSON property systemReservedExternalIpv6Ranges

Returns:

  • (Array<String>)


63937
63938
63939
# File 'lib/google/apis/compute_beta/classes.rb', line 63937

def system_reserved_external_ipv6_ranges
  @system_reserved_external_ipv6_ranges
end

#system_reserved_internal_ipv6_rangesArray<String>

Output only. [Output Only] The array of internal IPv6 network ranges reserved from the subnetwork's internal IPv6 range for system use. Corresponds to the JSON property systemReservedInternalIpv6Ranges

Returns:

  • (Array<String>)


63944
63945
63946
# File 'lib/google/apis/compute_beta/classes.rb', line 63944

def system_reserved_internal_ipv6_ranges
  @system_reserved_internal_ipv6_ranges
end

#utilization_detailsGoogle::Apis::ComputeBeta::SubnetworkUtilizationDetails

The current IP utilization of all subnetwork ranges. Contains the total number of allocated and free IPs in each range. Corresponds to the JSON property utilizationDetails



63950
63951
63952
# File 'lib/google/apis/compute_beta/classes.rb', line 63950

def utilization_details
  @utilization_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63957
63958
63959
63960
63961
63962
63963
63964
63965
63966
63967
63968
63969
63970
63971
63972
63973
63974
63975
63976
63977
63978
63979
63980
63981
63982
63983
63984
63985
63986
63987
63988
63989
63990
63991
# File 'lib/google/apis/compute_beta/classes.rb', line 63957

def update!(**args)
  @allow_subnet_cidr_routes_overlap = args[:allow_subnet_cidr_routes_overlap] if args.key?(:allow_subnet_cidr_routes_overlap)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @enable_flow_logs = args[:enable_flow_logs] if args.key?(:enable_flow_logs)
  @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @gateway_address = args[:gateway_address] if args.key?(:gateway_address)
  @id = args[:id] if args.key?(:id)
  @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix)
  @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range)
  @ip_collection = args[:ip_collection] if args.key?(:ip_collection)
  @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type)
  @ipv6_cidr_range = args[:ipv6_cidr_range] if args.key?(:ipv6_cidr_range)
  @ipv6_gce_endpoint = args[:ipv6_gce_endpoint] if args.key?(:ipv6_gce_endpoint)
  @kind = args[:kind] if args.key?(:kind)
  @log_config = args[:log_config] if args.key?(:log_config)
  @name = args[:name] if args.key?(:name)
  @network = args[:network] if args.key?(:network)
  @params = args[:params] if args.key?(:params)
  @private_ip_google_access = args[:private_ip_google_access] if args.key?(:private_ip_google_access)
  @private_ipv6_google_access = args[:private_ipv6_google_access] if args.key?(:private_ipv6_google_access)
  @purpose = args[:purpose] if args.key?(:purpose)
  @region = args[:region] if args.key?(:region)
  @reserved_internal_range = args[:reserved_internal_range] if args.key?(:reserved_internal_range)
  @resolve_subnet_mask = args[:resolve_subnet_mask] if args.key?(:resolve_subnet_mask)
  @role = args[:role] if args.key?(:role)
  @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges)
  @self_link = args[:self_link] if args.key?(:self_link)
  @stack_type = args[:stack_type] if args.key?(:stack_type)
  @state = args[:state] if args.key?(:state)
  @system_reserved_external_ipv6_ranges = args[:system_reserved_external_ipv6_ranges] if args.key?(:system_reserved_external_ipv6_ranges)
  @system_reserved_internal_ipv6_ranges = args[:system_reserved_internal_ipv6_ranges] if args.key?(:system_reserved_internal_ipv6_ranges)
  @utilization_details = args[:utilization_details] if args.key?(:utilization_details)
end