Class: Google::Apis::ComputeBeta::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



67437
67438
67439
# File 'lib/google/apis/compute_beta/classes.rb', line 67437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67398
67399
67400
# File 'lib/google/apis/compute_beta/classes.rb', line 67398

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



67403
67404
67405
# File 'lib/google/apis/compute_beta/classes.rb', line 67403

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


67410
67411
67412
# File 'lib/google/apis/compute_beta/classes.rb', line 67410

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67420
67421
67422
# File 'lib/google/apis/compute_beta/classes.rb', line 67420

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67425
67426
67427
# File 'lib/google/apis/compute_beta/classes.rb', line 67425

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67430
67431
67432
# File 'lib/google/apis/compute_beta/classes.rb', line 67430

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67435
67436
67437
# File 'lib/google/apis/compute_beta/classes.rb', line 67435

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67442
67443
67444
67445
67446
67447
67448
67449
67450
# File 'lib/google/apis/compute_beta/classes.rb', line 67442

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end