Class: Google::Apis::ComputeBeta::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



66995
66996
66997
# File 'lib/google/apis/compute_beta/classes.rb', line 66995

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66956
66957
66958
# File 'lib/google/apis/compute_beta/classes.rb', line 66956

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



66961
66962
66963
# File 'lib/google/apis/compute_beta/classes.rb', line 66961

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


66968
66969
66970
# File 'lib/google/apis/compute_beta/classes.rb', line 66968

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66978
66979
66980
# File 'lib/google/apis/compute_beta/classes.rb', line 66978

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66983
66984
66985
# File 'lib/google/apis/compute_beta/classes.rb', line 66983

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66988
66989
66990
# File 'lib/google/apis/compute_beta/classes.rb', line 66988

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66993
66994
66995
# File 'lib/google/apis/compute_beta/classes.rb', line 66993

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67000
67001
67002
67003
67004
67005
67006
67007
67008
# File 'lib/google/apis/compute_beta/classes.rb', line 67000

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end