Class: Google::Apis::ComputeBeta::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



66146
66147
66148
# File 'lib/google/apis/compute_beta/classes.rb', line 66146

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66107
66108
66109
# File 'lib/google/apis/compute_beta/classes.rb', line 66107

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



66112
66113
66114
# File 'lib/google/apis/compute_beta/classes.rb', line 66112

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


66119
66120
66121
# File 'lib/google/apis/compute_beta/classes.rb', line 66119

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66129
66130
66131
# File 'lib/google/apis/compute_beta/classes.rb', line 66129

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66134
66135
66136
# File 'lib/google/apis/compute_beta/classes.rb', line 66134

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66139
66140
66141
# File 'lib/google/apis/compute_beta/classes.rb', line 66139

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66144
66145
66146
# File 'lib/google/apis/compute_beta/classes.rb', line 66144

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66151
66152
66153
66154
66155
66156
66157
66158
66159
# File 'lib/google/apis/compute_beta/classes.rb', line 66151

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end