Class: Google::Apis::ComputeBeta::SubnetworkAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkAggregatedList

Returns a new instance of SubnetworkAggregatedList.



65253
65254
65255
# File 'lib/google/apis/compute_beta/classes.rb', line 65253

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65214
65215
65216
# File 'lib/google/apis/compute_beta/classes.rb', line 65214

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>

A list of SubnetworksScopedList resources. Corresponds to the JSON property items



65219
65220
65221
# File 'lib/google/apis/compute_beta/classes.rb', line 65219

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# subnetworkAggregatedList for aggregated lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


65226
65227
65228
# File 'lib/google/apis/compute_beta/classes.rb', line 65226

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65236
65237
65238
# File 'lib/google/apis/compute_beta/classes.rb', line 65236

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65241
65242
65243
# File 'lib/google/apis/compute_beta/classes.rb', line 65241

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65246
65247
65248
# File 'lib/google/apis/compute_beta/classes.rb', line 65246

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::SubnetworkAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65251
65252
65253
# File 'lib/google/apis/compute_beta/classes.rb', line 65251

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65258
65259
65260
65261
65262
65263
65264
65265
65266
# File 'lib/google/apis/compute_beta/classes.rb', line 65258

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end