Class: Google::Apis::ComputeBeta::SubnetworkAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworkAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkAggregatedList
constructor
A new instance of SubnetworkAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkAggregatedList
Returns a new instance of SubnetworkAggregatedList.
64040 64041 64042 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64040 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64001 64002 64003 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64001 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::SubnetworksScopedList>
A list of SubnetworksScopedList resources.
Corresponds to the JSON property items
64006 64007 64008 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64006 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
subnetworkAggregatedList for aggregated lists of
subnetworks.
Corresponds to the JSON property kind
64013 64014 64015 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64013 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64023 64024 64025 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64023 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64028 64029 64030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64028 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64033 64034 64035 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64033 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64038 64039 64040 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64038 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64045 64046 64047 64048 64049 64050 64051 64052 64053 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64045 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |