Class: Google::Apis::ComputeBeta::SubnetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Subnetwork resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Subnetwork>
A list of Subnetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkList
constructor
A new instance of SubnetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkList
Returns a new instance of SubnetworkList.
67121 67122 67123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67121 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67088 67089 67090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67088 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Subnetwork>
A list of Subnetwork resources.
Corresponds to the JSON property items
67093 67094 67095 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67093 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#subnetworkList
for lists of subnetworks.
Corresponds to the JSON property kind
67099 67100 67101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67099 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67109 67110 67111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67109 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67114 67115 67116 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67114 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67119 67120 67121 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67119 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67126 67127 67128 67129 67130 67131 67132 67133 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67126 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |