Class: Google::Apis::ComputeBeta::SubnetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Subnetwork resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Subnetwork>
A list of Subnetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkList
constructor
A new instance of SubnetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkList
Returns a new instance of SubnetworkList.
66272 66273 66274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66239 66240 66241 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66239 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Subnetwork>
A list of Subnetwork resources.
Corresponds to the JSON property items
66244 66245 66246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66244 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#subnetworkList
for lists of subnetworks.
Corresponds to the JSON property kind
66250 66251 66252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66250 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66260 66261 66262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66260 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66265 66266 66267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66265 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66270 66271 66272 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66270 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66277 66278 66279 66280 66281 66282 66283 66284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66277 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |