Class: Google::Apis::ComputeBeta::SubnetworkList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of Subnetwork resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkList

Returns a new instance of SubnetworkList.



65379
65380
65381
# File 'lib/google/apis/compute_beta/classes.rb', line 65379

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65346
65347
65348
# File 'lib/google/apis/compute_beta/classes.rb', line 65346

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Subnetwork>

A list of Subnetwork resources. Corresponds to the JSON property items



65351
65352
65353
# File 'lib/google/apis/compute_beta/classes.rb', line 65351

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#subnetworkList for lists of subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


65357
65358
65359
# File 'lib/google/apis/compute_beta/classes.rb', line 65357

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65367
65368
65369
# File 'lib/google/apis/compute_beta/classes.rb', line 65367

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65372
65373
65374
# File 'lib/google/apis/compute_beta/classes.rb', line 65372

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::SubnetworkList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65377
65378
65379
# File 'lib/google/apis/compute_beta/classes.rb', line 65377

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65384
65385
65386
65387
65388
65389
65390
65391
# File 'lib/google/apis/compute_beta/classes.rb', line 65384

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end