Class: Google::Apis::ComputeBeta::SubnetworkList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworkList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of Subnetwork resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Subnetwork>
A list of Subnetwork resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkList
constructor
A new instance of SubnetworkList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkList
Returns a new instance of SubnetworkList.
62070 62071 62072 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62070 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62037 62038 62039 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62037 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Subnetwork>
A list of Subnetwork resources.
Corresponds to the JSON property items
62042 62043 62044 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62042 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#subnetworkList
for lists of subnetworks.
Corresponds to the JSON property kind
62048 62049 62050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62048 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62058 62059 62060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62058 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62063 62064 62065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62063 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::SubnetworkList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62068 62069 62070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62068 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62075 62076 62077 62078 62079 62080 62081 62082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62075 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |