Class: Google::Apis::ComputeBeta::SubnetworkLogConfig

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The available logging options for this subnetwork.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworkLogConfig

Returns a new instance of SubnetworkLogConfig.



66351
66352
66353
# File 'lib/google/apis/compute_beta/classes.rb', line 66351

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_intervalString

Can only be specified if VPC flow logging for this subnetwork is enabled. Toggles the aggregation interval for collecting flow logs. Increasing the interval time will reduce the amount of generated flow logs for long lasting connections. Default is an interval of 5 seconds per connection. Corresponds to the JSON property aggregationInterval

Returns:

  • (String)


66308
66309
66310
# File 'lib/google/apis/compute_beta/classes.rb', line 66308

def aggregation_interval
  @aggregation_interval
end

#enableBoolean Also known as: enable?

Whether to enable flow logging for this subnetwork. If this field is not explicitly set, it will not appear in get listings. If not set the default behavior is determined by the org policy, if there is no org policy specified, then it will default to disabled. Flow logging isn't supported if the subnet purpose field is set to REGIONAL_MANAGED_PROXY. Corresponds to the JSON property enable

Returns:

  • (Boolean)


66318
66319
66320
# File 'lib/google/apis/compute_beta/classes.rb', line 66318

def enable
  @enable
end

#filter_exprString

Can only be specified if VPC flow logs for this subnetwork is enabled. The filter expression is used to define which VPC flow logs should be exported to Cloud Logging. Corresponds to the JSON property filterExpr

Returns:

  • (String)


66326
66327
66328
# File 'lib/google/apis/compute_beta/classes.rb', line 66326

def filter_expr
  @filter_expr
end

#flow_samplingFloat

Can only be specified if VPC flow logging for this subnetwork is enabled. The value of the field must be in [0, 1]. Set the sampling rate of VPC flow logs within the subnetwork where 1.0 means all collected logs are reported and 0.0 means no logs are reported. Default is 0.5 unless otherwise specified by the org policy, which means half of all collected logs are reported. Corresponds to the JSON property flowSampling

Returns:

  • (Float)


66336
66337
66338
# File 'lib/google/apis/compute_beta/classes.rb', line 66336

def flow_sampling
  @flow_sampling
end

#metadataString

Can only be specified if VPC flow logs for this subnetwork is enabled. Configures whether all, none or a subset of metadata fields should be added to the reported VPC flow logs. Default isEXCLUDE_ALL_METADATA. Corresponds to the JSON property metadata

Returns:

  • (String)


66343
66344
66345
# File 'lib/google/apis/compute_beta/classes.rb', line 66343

def 
  @metadata
end

#metadata_fieldsArray<String>

Can only be specified if VPC flow logs for this subnetwork is enabled and "metadata" was set to CUSTOM_METADATA. Corresponds to the JSON property metadataFields

Returns:

  • (Array<String>)


66349
66350
66351
# File 'lib/google/apis/compute_beta/classes.rb', line 66349

def 
  @metadata_fields
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66356
66357
66358
66359
66360
66361
66362
66363
# File 'lib/google/apis/compute_beta/classes.rb', line 66356

def update!(**args)
  @aggregation_interval = args[:aggregation_interval] if args.key?(:aggregation_interval)
  @enable = args[:enable] if args.key?(:enable)
  @filter_expr = args[:filter_expr] if args.key?(:filter_expr)
  @flow_sampling = args[:flow_sampling] if args.key?(:flow_sampling)
  @metadata = args[:metadata] if args.key?(:metadata)
  @metadata_fields = args[:metadata_fields] if args.key?(:metadata_fields)
end