Class: Google::Apis::ComputeBeta::SubnetworkParams
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworkParams
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Additional subnetwork parameters.
Instance Attribute Summary collapse
-
#resource_manager_tags ⇒ Hash<String,String>
Tag keys/values directly bound to this resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworkParams
constructor
A new instance of SubnetworkParams.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworkParams
Returns a new instance of SubnetworkParams.
62243 62244 62245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62243 def initialize(**args) update!(**args) end |
Instance Attribute Details
#resource_manager_tags ⇒ Hash<String,String>
Tag keys/values directly bound to this resource.
Tag keys and values have the same definition as resource
manager tags. The field is allowed for INSERT
only. The keys/values to set on the resource should be specified in
either ID : or Namespaced format
:.
For example the following are valid inputs:
"tagKeys/333" : "tagValues/444", "tagKeys/123" : "tagValues/456""123/environment" : "production", "345/abc" : "xyz"Note:- Invalid combinations of ID & namespaced format is not supported. For
instance:
"123/environment" : "tagValues/444"is invalid. Corresponds to the JSON propertyresourceManagerTags
62241 62242 62243 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62241 def @resource_manager_tags end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62248 62249 62250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62248 def update!(**args) @resource_manager_tags = args[:resource_manager_tags] if args.key?(:resource_manager_tags) end |