Class: Google::Apis::ComputeBeta::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



65841
65842
65843
# File 'lib/google/apis/compute_beta/classes.rb', line 65841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


65834
65835
65836
# File 'lib/google/apis/compute_beta/classes.rb', line 65834

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeBeta::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



65839
65840
65841
# File 'lib/google/apis/compute_beta/classes.rb', line 65839

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65846
65847
65848
65849
# File 'lib/google/apis/compute_beta/classes.rb', line 65846

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end