Class: Google::Apis::ComputeBeta::SubnetworksScopedWarning
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::SubnetworksScopedWarning
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#scope_name ⇒ String
Name of the scope containing this set of Subnetworks.
-
#warning ⇒ Google::Apis::ComputeBeta::SubnetworksScopedWarning::Warning
An informational warning about unreachable scope Corresponds to the JSON property
warning.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SubnetworksScopedWarning
constructor
A new instance of SubnetworksScopedWarning.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SubnetworksScopedWarning
Returns a new instance of SubnetworksScopedWarning.
64628 64629 64630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64628 def initialize(**args) update!(**args) end |
Instance Attribute Details
#scope_name ⇒ String
Name of the scope containing this set of Subnetworks.
Corresponds to the JSON property scopeName
64621 64622 64623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64621 def scope_name @scope_name end |
#warning ⇒ Google::Apis::ComputeBeta::SubnetworksScopedWarning::Warning
An informational warning about unreachable scope
Corresponds to the JSON property warning
64626 64627 64628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64626 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64633 64634 64635 64636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64633 def update!(**args) @scope_name = args[:scope_name] if args.key?(:scope_name) @warning = args[:warning] if args.key?(:warning) end |