Class: Google::Apis::ComputeBeta::SubnetworksScopedWarning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SubnetworksScopedWarning

Returns a new instance of SubnetworksScopedWarning.



62520
62521
62522
# File 'lib/google/apis/compute_beta/classes.rb', line 62520

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#scope_nameString

Name of the scope containing this set of Subnetworks. Corresponds to the JSON property scopeName

Returns:

  • (String)


62513
62514
62515
# File 'lib/google/apis/compute_beta/classes.rb', line 62513

def scope_name
  @scope_name
end

#warningGoogle::Apis::ComputeBeta::SubnetworksScopedWarning::Warning

An informational warning about unreachable scope Corresponds to the JSON property warning



62518
62519
62520
# File 'lib/google/apis/compute_beta/classes.rb', line 62518

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



62525
62526
62527
62528
# File 'lib/google/apis/compute_beta/classes.rb', line 62525

def update!(**args)
  @scope_name = args[:scope_name] if args.key?(:scope_name)
  @warning = args[:warning] if args.key?(:warning)
end