Class: Google::Apis::ComputeBeta::TargetGrpcProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Target gRPC Proxy resource. A target gRPC proxy is a component of load balancers intended for load balancing gRPC traffic. Only global forwarding rules with load balancing scheme INTERNAL_SELF_MANAGED can reference a target gRPC proxy. The target gRPC Proxy references a URL map that specifies how traffic is routed to gRPC backend services.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxy

Returns a new instance of TargetGrpcProxy.



64970
64971
64972
# File 'lib/google/apis/compute_beta/classes.rb', line 64970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


64894
64895
64896
# File 'lib/google/apis/compute_beta/classes.rb', line 64894

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


64900
64901
64902
# File 'lib/google/apis/compute_beta/classes.rb', line 64900

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetGrpcProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetGrpcProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetGrpcProxy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


64912
64913
64914
# File 'lib/google/apis/compute_beta/classes.rb', line 64912

def fingerprint
  @fingerprint
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


64919
64920
64921
# File 'lib/google/apis/compute_beta/classes.rb', line 64919

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


64925
64926
64927
# File 'lib/google/apis/compute_beta/classes.rb', line 64925

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


64936
64937
64938
# File 'lib/google/apis/compute_beta/classes.rb', line 64936

def name
  @name
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64941
64942
64943
# File 'lib/google/apis/compute_beta/classes.rb', line 64941

def self_link
  @self_link
end

Output only. [Output Only] Server-defined URL with id for the resource. Corresponds to the JSON property selfLinkWithId

Returns:

  • (String)


64946
64947
64948
# File 'lib/google/apis/compute_beta/classes.rb', line 64946

def self_link_with_id
  @self_link_with_id
end

#url_mapString

URL to the UrlMap resource that defines the mapping from URL to the BackendService. The protocol field in the BackendService must be set to GRPC. Corresponds to the JSON property urlMap

Returns:

  • (String)


64953
64954
64955
# File 'lib/google/apis/compute_beta/classes.rb', line 64953

def url_map
  @url_map
end

#validate_for_proxylessBoolean Also known as: validate_for_proxyless?

If true, indicates that the BackendServices referenced by the urlMap may be accessed by gRPC applications without using a sidecar proxy. This will enable configuration checks on urlMap and its referenced BackendServices to not allow unsupported features. A gRPC application must use "xds:///" scheme in the target URI of the service it is connecting to. If false, indicates that the BackendServices referenced by the urlMap will be accessed by gRPC applications via a sidecar proxy. In this case, a gRPC application must not use "xds:///" scheme in the target URI of the service it is connecting to Corresponds to the JSON property validateForProxyless

Returns:

  • (Boolean)


64967
64968
64969
# File 'lib/google/apis/compute_beta/classes.rb', line 64967

def validate_for_proxyless
  @validate_for_proxyless
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64975
64976
64977
64978
64979
64980
64981
64982
64983
64984
64985
64986
# File 'lib/google/apis/compute_beta/classes.rb', line 64975

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @self_link = args[:self_link] if args.key?(:self_link)
  @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id)
  @url_map = args[:url_map] if args.key?(:url_map)
  @validate_for_proxyless = args[:validate_for_proxyless] if args.key?(:validate_for_proxyless)
end