Class: Google::Apis::ComputeBeta::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



68600
68601
68602
# File 'lib/google/apis/compute_beta/classes.rb', line 68600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68567
68568
68569
# File 'lib/google/apis/compute_beta/classes.rb', line 68567

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



68572
68573
68574
# File 'lib/google/apis/compute_beta/classes.rb', line 68572

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68578
68579
68580
# File 'lib/google/apis/compute_beta/classes.rb', line 68578

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68588
68589
68590
# File 'lib/google/apis/compute_beta/classes.rb', line 68588

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68593
68594
68595
# File 'lib/google/apis/compute_beta/classes.rb', line 68593

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68598
68599
68600
# File 'lib/google/apis/compute_beta/classes.rb', line 68598

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68605
68606
68607
68608
68609
68610
68611
68612
# File 'lib/google/apis/compute_beta/classes.rb', line 68605

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end