Class: Google::Apis::ComputeBeta::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



68596
68597
68598
# File 'lib/google/apis/compute_beta/classes.rb', line 68596

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68563
68564
68565
# File 'lib/google/apis/compute_beta/classes.rb', line 68563

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



68568
68569
68570
# File 'lib/google/apis/compute_beta/classes.rb', line 68568

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68574
68575
68576
# File 'lib/google/apis/compute_beta/classes.rb', line 68574

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68584
68585
68586
# File 'lib/google/apis/compute_beta/classes.rb', line 68584

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68589
68590
68591
# File 'lib/google/apis/compute_beta/classes.rb', line 68589

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68594
68595
68596
# File 'lib/google/apis/compute_beta/classes.rb', line 68594

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68601
68602
68603
68604
68605
68606
68607
68608
# File 'lib/google/apis/compute_beta/classes.rb', line 68601

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end