Class: Google::Apis::ComputeBeta::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



67972
67973
67974
# File 'lib/google/apis/compute_beta/classes.rb', line 67972

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67939
67940
67941
# File 'lib/google/apis/compute_beta/classes.rb', line 67939

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



67944
67945
67946
# File 'lib/google/apis/compute_beta/classes.rb', line 67944

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


67950
67951
67952
# File 'lib/google/apis/compute_beta/classes.rb', line 67950

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67960
67961
67962
# File 'lib/google/apis/compute_beta/classes.rb', line 67960

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67965
67966
67967
# File 'lib/google/apis/compute_beta/classes.rb', line 67965

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67970
67971
67972
# File 'lib/google/apis/compute_beta/classes.rb', line 67970

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67977
67978
67979
67980
67981
67982
67983
67984
# File 'lib/google/apis/compute_beta/classes.rb', line 67977

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end