Class: Google::Apis::ComputeBeta::TargetGrpcProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetGrpcProxyList

Returns a new instance of TargetGrpcProxyList.



66242
66243
66244
# File 'lib/google/apis/compute_beta/classes.rb', line 66242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66209
66210
66211
# File 'lib/google/apis/compute_beta/classes.rb', line 66209

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetGrpcProxy>

A list of TargetGrpcProxy resources. Corresponds to the JSON property items



66214
66215
66216
# File 'lib/google/apis/compute_beta/classes.rb', line 66214

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy for target grpc proxies. Corresponds to the JSON property kind

Returns:

  • (String)


66220
66221
66222
# File 'lib/google/apis/compute_beta/classes.rb', line 66220

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66230
66231
66232
# File 'lib/google/apis/compute_beta/classes.rb', line 66230

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66235
66236
66237
# File 'lib/google/apis/compute_beta/classes.rb', line 66235

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetGrpcProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66240
66241
66242
# File 'lib/google/apis/compute_beta/classes.rb', line 66240

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66247
66248
66249
66250
66251
66252
66253
66254
# File 'lib/google/apis/compute_beta/classes.rb', line 66247

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end