Class: Google::Apis::ComputeBeta::TargetGrpcProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetGrpcProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetGrpcProxyList
constructor
A new instance of TargetGrpcProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetGrpcProxyList
Returns a new instance of TargetGrpcProxyList.
62921 62922 62923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62921 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
62888 62889 62890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62888 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetGrpcProxy>
A list of TargetGrpcProxy resources.
Corresponds to the JSON property items
62893 62894 62895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62893 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetGrpcProxy
for target grpc proxies.
Corresponds to the JSON property kind
62899 62900 62901 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62899 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
62909 62910 62911 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62909 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
62914 62915 62916 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62914 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetGrpcProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
62919 62920 62921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62919 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
62926 62927 62928 62929 62930 62931 62932 62933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 62926 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |