Class: Google::Apis::ComputeBeta::TargetHttpProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Target HTTP Proxy resource. Google Compute Engine has two Target HTTP Proxy resources:

  • Global
  • Regional A target HTTP proxy is a component of Google Cloud HTTP load balancers.
  • targetHttpProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director.
  • regionTargetHttpProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTP proxy, and the target proxy then references a URL map. For more information, readUsing Target Proxies and Forwarding rule concepts.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxy

Returns a new instance of TargetHttpProxy.



66548
66549
66550
# File 'lib/google/apis/compute_beta/classes.rb', line 66548

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


66445
66446
66447
# File 'lib/google/apis/compute_beta/classes.rb', line 66445

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


66451
66452
66453
# File 'lib/google/apis/compute_beta/classes.rb', line 66451

def description
  @description
end

#fingerprintString

Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a TargetHttpProxy. An up-to-date fingerprint must be provided in order to patch/update the TargetHttpProxy; otherwise, the request will fail with error 412 conditionNotMet. To see the latest fingerprint, make a get() request to retrieve the TargetHttpProxy. Corresponds to the JSON property fingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


66463
66464
66465
# File 'lib/google/apis/compute_beta/classes.rb', line 66463

def fingerprint
  @fingerprint
end

#http_filtersArray<String>

URLs to networkservices.HttpFilter resources enabled for xDS clients using this configuration. For example,https:// networkservices.googleapis.com/v1alpha1/projects/project/locations/ locationhttpFilters/httpFilter Only filters that handle outbound connection and stream events may be specified. These filters work in conjunction with a default set of HTTP filters that may already be configured by Traffic Director. Traffic Director will determine the final location of these filters within xDS configuration based on the name of the HTTP filter. If Traffic Director positions multiple filters at the same location, those filters will be in the same order as specified in this list. httpFilters only applies for loadbalancers withloadBalancingScheme set to INTERNAL_SELF_MANAGED. See ForwardingRule for more details. Corresponds to the JSON property httpFilters

Returns:

  • (Array<String>)


66481
66482
66483
# File 'lib/google/apis/compute_beta/classes.rb', line 66481

def http_filters
  @http_filters
end

#http_keep_alive_timeout_secFixnum

Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds). If an HTTP keep-alive is not specified, a default value (610 seconds) will be used. For global external Application Load Balancers, the minimum allowed value is 5 seconds and the maximum allowed value is 1200 seconds. For classic Application Load Balancers, this option is not supported. Corresponds to the JSON property httpKeepAliveTimeoutSec

Returns:

  • (Fixnum)


66491
66492
66493
# File 'lib/google/apis/compute_beta/classes.rb', line 66491

def http_keep_alive_timeout_sec
  @http_keep_alive_timeout_sec
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


66497
66498
66499
# File 'lib/google/apis/compute_beta/classes.rb', line 66497

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetHttpProxy for target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


66503
66504
66505
# File 'lib/google/apis/compute_beta/classes.rb', line 66503

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


66514
66515
66516
# File 'lib/google/apis/compute_beta/classes.rb', line 66514

def name
  @name
end

#proxy_bindBoolean Also known as: proxy_bind?

This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED. When this field is set to true, Envoy proxies set up inbound traffic interception and bind to the IP address and port specified in the forwarding rule. This is generally useful when using Traffic Director to configure Envoy as a gateway or middle proxy (in other words, not a sidecar proxy). The Envoy proxy listens for inbound requests and handles requests when it receives them. The default is false. Corresponds to the JSON property proxyBind

Returns:

  • (Boolean)


66527
66528
66529
# File 'lib/google/apis/compute_beta/classes.rb', line 66527

def proxy_bind
  @proxy_bind
end

#regionString

Output only. [Output Only] URL of the region where the regional Target HTTP Proxy resides. This field is not applicable to global Target HTTP Proxies. Corresponds to the JSON property region

Returns:

  • (String)


66535
66536
66537
# File 'lib/google/apis/compute_beta/classes.rb', line 66535

def region
  @region
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66540
66541
66542
# File 'lib/google/apis/compute_beta/classes.rb', line 66540

def self_link
  @self_link
end

#url_mapString

URL to the UrlMap resource that defines the mapping from URL to the BackendService. Corresponds to the JSON property urlMap

Returns:

  • (String)


66546
66547
66548
# File 'lib/google/apis/compute_beta/classes.rb', line 66546

def url_map
  @url_map
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66553
66554
66555
66556
66557
66558
66559
66560
66561
66562
66563
66564
66565
66566
# File 'lib/google/apis/compute_beta/classes.rb', line 66553

def update!(**args)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @fingerprint = args[:fingerprint] if args.key?(:fingerprint)
  @http_filters = args[:http_filters] if args.key?(:http_filters)
  @http_keep_alive_timeout_sec = args[:http_keep_alive_timeout_sec] if args.key?(:http_keep_alive_timeout_sec)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind)
  @region = args[:region] if args.key?(:region)
  @self_link = args[:self_link] if args.key?(:self_link)
  @url_map = args[:url_map] if args.key?(:url_map)
end