Class: Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



68969
68970
68971
# File 'lib/google/apis/compute_beta/classes.rb', line 68969

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68930
68931
68932
# File 'lib/google/apis/compute_beta/classes.rb', line 68930

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



68935
68936
68937
# File 'lib/google/apis/compute_beta/classes.rb', line 68935

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68942
68943
68944
# File 'lib/google/apis/compute_beta/classes.rb', line 68942

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68952
68953
68954
# File 'lib/google/apis/compute_beta/classes.rb', line 68952

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68957
68958
68959
# File 'lib/google/apis/compute_beta/classes.rb', line 68957

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68962
68963
68964
# File 'lib/google/apis/compute_beta/classes.rb', line 68962

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68967
68968
68969
# File 'lib/google/apis/compute_beta/classes.rb', line 68967

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68974
68975
68976
68977
68978
68979
68980
68981
68982
# File 'lib/google/apis/compute_beta/classes.rb', line 68974

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end