Class: Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetHttpProxiesScopedList>
A list of TargetHttpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyAggregatedList
constructor
A new instance of TargetHttpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyAggregatedList
Returns a new instance of TargetHttpProxyAggregatedList.
68817 68818 68819 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68817 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
68778 68779 68780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68778 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetHttpProxiesScopedList>
A list of TargetHttpProxiesScopedList resources.
Corresponds to the JSON property items
68783 68784 68785 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68783 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetHttpProxyAggregatedList for lists of Target HTTP
Proxies.
Corresponds to the JSON property kind
68790 68791 68792 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68790 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
68800 68801 68802 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68800 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68805 68806 68807 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68805 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
68810 68811 68812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68810 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68815 68816 68817 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68815 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68822 68823 68824 68825 68826 68827 68828 68829 68830 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68822 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |