Class: Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



66615
66616
66617
# File 'lib/google/apis/compute_beta/classes.rb', line 66615

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66576
66577
66578
# File 'lib/google/apis/compute_beta/classes.rb', line 66576

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



66581
66582
66583
# File 'lib/google/apis/compute_beta/classes.rb', line 66581

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


66588
66589
66590
# File 'lib/google/apis/compute_beta/classes.rb', line 66588

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66598
66599
66600
# File 'lib/google/apis/compute_beta/classes.rb', line 66598

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66603
66604
66605
# File 'lib/google/apis/compute_beta/classes.rb', line 66603

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66608
66609
66610
# File 'lib/google/apis/compute_beta/classes.rb', line 66608

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66613
66614
66615
# File 'lib/google/apis/compute_beta/classes.rb', line 66613

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66620
66621
66622
66623
66624
66625
66626
66627
66628
# File 'lib/google/apis/compute_beta/classes.rb', line 66620

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end