Class: Google::Apis::ComputeBeta::TargetHttpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyAggregatedList

Returns a new instance of TargetHttpProxyAggregatedList.



63294
63295
63296
# File 'lib/google/apis/compute_beta/classes.rb', line 63294

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63255
63256
63257
# File 'lib/google/apis/compute_beta/classes.rb', line 63255

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpProxiesScopedList>

A list of TargetHttpProxiesScopedList resources. Corresponds to the JSON property items



63260
63261
63262
# File 'lib/google/apis/compute_beta/classes.rb', line 63260

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63267
63268
63269
# File 'lib/google/apis/compute_beta/classes.rb', line 63267

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63277
63278
63279
# File 'lib/google/apis/compute_beta/classes.rb', line 63277

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63282
63283
63284
# File 'lib/google/apis/compute_beta/classes.rb', line 63282

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63287
63288
63289
# File 'lib/google/apis/compute_beta/classes.rb', line 63287

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63292
63293
63294
# File 'lib/google/apis/compute_beta/classes.rb', line 63292

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63299
63300
63301
63302
63303
63304
63305
63306
63307
# File 'lib/google/apis/compute_beta/classes.rb', line 63299

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end