Class: Google::Apis::ComputeBeta::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



69099
69100
69101
# File 'lib/google/apis/compute_beta/classes.rb', line 69099

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69066
69067
69068
# File 'lib/google/apis/compute_beta/classes.rb', line 69066

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



69071
69072
69073
# File 'lib/google/apis/compute_beta/classes.rb', line 69071

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


69077
69078
69079
# File 'lib/google/apis/compute_beta/classes.rb', line 69077

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69087
69088
69089
# File 'lib/google/apis/compute_beta/classes.rb', line 69087

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69092
69093
69094
# File 'lib/google/apis/compute_beta/classes.rb', line 69092

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69097
69098
69099
# File 'lib/google/apis/compute_beta/classes.rb', line 69097

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69104
69105
69106
69107
69108
69109
69110
69111
# File 'lib/google/apis/compute_beta/classes.rb', line 69104

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end