Class: Google::Apis::ComputeBeta::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
67593 67594 67595 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67593 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67560 67561 67562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67560 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
67565 67566 67567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67565 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpProxyList for lists
of target HTTP proxies.
Corresponds to the JSON property kind
67571 67572 67573 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67571 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67581 67582 67583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67581 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67586 67587 67588 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67586 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67591 67592 67593 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67591 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67598 67599 67600 67601 67602 67603 67604 67605 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67598 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |