Class: Google::Apis::ComputeBeta::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



66741
66742
66743
# File 'lib/google/apis/compute_beta/classes.rb', line 66741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66708
66709
66710
# File 'lib/google/apis/compute_beta/classes.rb', line 66708

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



66713
66714
66715
# File 'lib/google/apis/compute_beta/classes.rb', line 66713

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


66719
66720
66721
# File 'lib/google/apis/compute_beta/classes.rb', line 66719

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66729
66730
66731
# File 'lib/google/apis/compute_beta/classes.rb', line 66729

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66734
66735
66736
# File 'lib/google/apis/compute_beta/classes.rb', line 66734

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66739
66740
66741
# File 'lib/google/apis/compute_beta/classes.rb', line 66739

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66746
66747
66748
66749
66750
66751
66752
66753
# File 'lib/google/apis/compute_beta/classes.rb', line 66746

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end