Class: Google::Apis::ComputeBeta::TargetHttpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A list of TargetHttpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpProxy>
A list of TargetHttpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpProxyList
constructor
A new instance of TargetHttpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpProxyList
Returns a new instance of TargetHttpProxyList.
65528 65529 65530 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65528 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65495 65496 65497 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65495 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpProxy>
A list of TargetHttpProxy resources.
Corresponds to the JSON property items
65500 65501 65502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65500 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpProxyList for lists
of target HTTP proxies.
Corresponds to the JSON property kind
65506 65507 65508 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65506 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65516 65517 65518 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65516 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65521 65522 65523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65521 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65526 65527 65528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65526 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65533 65534 65535 65536 65537 65538 65539 65540 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65533 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |