Class: Google::Apis::ComputeBeta::TargetHttpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A list of TargetHttpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpProxyList

Returns a new instance of TargetHttpProxyList.



63420
63421
63422
# File 'lib/google/apis/compute_beta/classes.rb', line 63420

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63387
63388
63389
# File 'lib/google/apis/compute_beta/classes.rb', line 63387

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpProxy>

A list of TargetHttpProxy resources. Corresponds to the JSON property items



63392
63393
63394
# File 'lib/google/apis/compute_beta/classes.rb', line 63392

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpProxyList for lists of target HTTP proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63398
63399
63400
# File 'lib/google/apis/compute_beta/classes.rb', line 63398

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63408
63409
63410
# File 'lib/google/apis/compute_beta/classes.rb', line 63408

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63413
63414
63415
# File 'lib/google/apis/compute_beta/classes.rb', line 63413

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63418
63419
63420
# File 'lib/google/apis/compute_beta/classes.rb', line 63418

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63425
63426
63427
63428
63429
63430
63431
63432
# File 'lib/google/apis/compute_beta/classes.rb', line 63425

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end