Class: Google::Apis::ComputeBeta::TargetHttpsProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpsProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Target HTTPS Proxy resource. Google Compute Engine has two Target HTTPS Proxy resources:
- Global
- Regional A target HTTPS proxy is a component of Google Cloud HTTPS load balancers.
- targetHttpsProxies are used by global external Application Load Balancers, classic Application Load Balancers, cross-region internal Application Load Balancers, and Traffic Director.
- regionTargetHttpsProxies are used by regional internal Application Load Balancers and regional external Application Load Balancers. Forwarding rules reference a target HTTPS proxy, and the target proxy then references a URL map. For more information, readUsing Target Proxies and Forwarding rule concepts.
Instance Attribute Summary collapse
-
#authentication ⇒ String
[Deprecated] Use serverTlsPolicy instead.
-
#authorization ⇒ String
[Deprecated] Use authorizationPolicy instead.
-
#authorization_policy ⇒ String
Optional.
-
#certificate_map ⇒ String
URL of a certificate map that identifies a certificate map associated with the given target proxy.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#http_filters ⇒ Array<String>
URLs to networkservices.HttpFilter resources enabled for xDS clients using this configuration.
-
#http_keep_alive_timeout_sec ⇒ Fixnum
Specifies how long to keep a connection open, after completing a response, while there is no matching traffic (in seconds).
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#proxy_bind ⇒ Boolean
(also: #proxy_bind?)
This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
-
#quic_override ⇒ String
Specifies the QUIC override policy for this TargetHttpsProxy resource.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#server_tls_policy ⇒ String
Optional.
-
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer.
-
#ssl_policy ⇒ String
URL of SslPolicy resource that will be associated with the TargetHttpsProxy resource.
-
#tls_early_data ⇒ String
Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted for this service.
-
#url_map ⇒ String
A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxy
constructor
A new instance of TargetHttpsProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxy
Returns a new instance of TargetHttpsProxy.
63913 63914 63915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63913 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authentication ⇒ String
[Deprecated] Use serverTlsPolicy instead.
Corresponds to the JSON property authentication
63684 63685 63686 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63684 def authentication @authentication end |
#authorization ⇒ String
[Deprecated] Use authorizationPolicy instead.
Corresponds to the JSON property authorization
63689 63690 63691 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63689 def @authorization end |
#authorization_policy ⇒ String
Optional. A URL referring to a networksecurity.AuthorizationPolicy resource
that describes how the proxy should authorize inbound traffic. If left
blank, access will not be restricted by an authorization policy.
Refer to the AuthorizationPolicy resource for additional
details.
authorizationPolicy only applies to a globalTargetHttpsProxy attached
toglobalForwardingRules with theloadBalancingScheme set to
INTERNAL_SELF_MANAGED.
Note: This field currently has no impact.
Corresponds to the JSON property authorizationPolicy
63702 63703 63704 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63702 def @authorization_policy end |
#certificate_map ⇒ String
URL of a certificate map that identifies a certificate map associated with
the given target proxy.
This field can only be set for Global external Application Load Balancer or
Classic Application Load Balancer. For other products use Certificate
Manager Certificates instead.
If set, sslCertificates will be ignored.
Accepted format is//certificatemanager.googleapis.com/projects/project/
locations/location/certificateMaps/resourceName.
Corresponds to the JSON property certificateMap
63714 63715 63716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63714 def certificate_map @certificate_map end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
63720 63721 63722 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63720 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
63726 63727 63728 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63726 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field will be ignored when
inserting a TargetHttpsProxy. An up-to-date fingerprint must
be provided in order to patch the TargetHttpsProxy; otherwise, the request
will fail with error 412 conditionNotMet. To see the latest
fingerprint, make a get() request to retrieve the
TargetHttpsProxy.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
63738 63739 63740 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63738 def fingerprint @fingerprint end |
#http_filters ⇒ Array<String>
URLs to networkservices.HttpFilter resources
enabled for xDS clients using this configuration. For example,https://
networkservices.googleapis.com/beta/projects/project/locations/location/
httpFilters/httpFilter
Only filters that handle outbound connection and
stream events may be specified. These filters work in conjunction with
a default set of HTTP filters that may already be configured by Traffic
Director. Traffic Director will determine the final location of these
filters within xDS configuration based on the name of the HTTP filter. If
Traffic Director positions multiple filters at the same location, those
filters will be in the same order as specified in this list.
httpFilters only applies for loadbalancers withloadBalancingScheme set to
INTERNAL_SELF_MANAGED.
See ForwardingRule for more details.
Corresponds to the JSON property httpFilters
63756 63757 63758 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63756 def http_filters @http_filters end |
#http_keep_alive_timeout_sec ⇒ Fixnum
Specifies how long to keep a connection open, after completing a response,
while there is no matching traffic (in seconds). If an HTTP keep-alive is
not specified, a default value (610 seconds) will be used.
For global external Application Load Balancers, the minimum allowed value
is 5 seconds and the maximum allowed value is 1200 seconds.
For classic Application Load Balancers, this option is not supported.
Corresponds to the JSON property httpKeepAliveTimeoutSec
63766 63767 63768 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63766 def http_keep_alive_timeout_sec @http_keep_alive_timeout_sec end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
63772 63773 63774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63772 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetHttpsProxy
for target HTTPS proxies.
Corresponds to the JSON property kind
63778 63779 63780 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63778 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
63789 63790 63791 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63789 def name @name end |
#proxy_bind ⇒ Boolean Also known as: proxy_bind?
This field only applies when the forwarding rule that references this
target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
When this field is set to true, Envoy proxies set up inbound
traffic interception and bind to the IP address and port specified in the
forwarding rule. This is generally useful when using Traffic Director to
configure Envoy as a gateway or middle proxy (in other words, not a
sidecar proxy). The Envoy proxy listens for inbound requests and handles
requests when it receives them.
The default is false.
Corresponds to the JSON property proxyBind
63802 63803 63804 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63802 def proxy_bind @proxy_bind end |
#quic_override ⇒ String
Specifies the QUIC override policy for this TargetHttpsProxy resource. This setting determines whether the load balancer attempts to negotiate QUIC with clients. You can specify NONE, ENABLE, orDISABLE.
- When quic-override is set to NONE, Google manages whether QUIC is used.
- When quic-override is set to ENABLE, the load balancer uses QUIC when possible.
- When quic-override is set to DISABLE, the load balancer doesn't use QUIC.
- If the quic-override flag is not specified,NONE is implied.
Corresponds to the JSON property
quicOverride
63819 63820 63821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63819 def quic_override @quic_override end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional
TargetHttpsProxy
resides. This field is not applicable to global TargetHttpsProxies.
Corresponds to the JSON property region
63826 63827 63828 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63826 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
63831 63832 63833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63831 def self_link @self_link end |
#server_tls_policy ⇒ String
Optional. A URL referring to a networksecurity.ServerTlsPolicy resource
that describes how the proxy should authenticate inbound traffic.
serverTlsPolicy only applies to a globalTargetHttpsProxy attached
toglobalForwardingRules with theloadBalancingScheme set to
INTERNAL_SELF_MANAGED
or EXTERNAL orEXTERNAL_MANAGED or INTERNAL_MANAGED.
It also applies to a regional TargetHttpsProxy attached to
regional forwardingRules with theloadBalancingScheme set to EXTERNAL_MANAGED
orINTERNAL_MANAGED. For details whichServerTlsPolicy resources are accepted
withINTERNAL_SELF_MANAGED and which with EXTERNAL,INTERNAL_MANAGED,
EXTERNAL_MANAGEDloadBalancingScheme consult ServerTlsPolicy
documentation.
If left blank, communications are not encrypted.
Corresponds to the JSON property serverTlsPolicy
63848 63849 63850 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63848 def server_tls_policy @server_tls_policy end |
#ssl_certificates ⇒ Array<String>
URLs to SslCertificate resources that are used to authenticate connections between users and the load balancer. At least one SSL certificate must be specified. SslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED. The URLs should refer to a SSL Certificate resource or Certificate Manager Certificate resource. Mixing Classic Certificates and Certificate Manager Certificates is not allowed. Certificate Manager Certificates must include the certificatemanager API namespace. Using Certificate Manager Certificates in this field is not supported by Global external Application Load Balancer or Classic Application Load Balancer, use certificate_map instead. Currently, you may specify up to 15 Classic SSL Certificates or up to 100 Certificate Manager Certificates. Certificate Manager Certificates accepted formats are:
- //certificatemanager.googleapis.com/projects/
project/locations/location/certificates/resourceName. - https://certificatemanager.googleapis.com/v1alpha1/projects/`project`/
locations/
location/certificates/resourceName. Corresponds to the JSON propertysslCertificates
63871 63872 63873 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63871 def ssl_certificates @ssl_certificates end |
#ssl_policy ⇒ String
URL of SslPolicy resource that will be associated with the TargetHttpsProxy
resource. If not set, the TargetHttpsProxy resource has no
SSL policy configured.
Corresponds to the JSON property sslPolicy
63878 63879 63880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63878 def ssl_policy @ssl_policy end |
#tls_early_data ⇒ String
Specifies whether TLS 1.3 0-RTT Data ("Early Data") should be accepted
for this service. Early Data allows a TLS resumption handshake to include
the initial application payload (a HTTP request) alongside the handshake,
reducing the effective round trips to "zero". This applies to TLS 1.3
connections over TCP (HTTP/2) as well as over UDP (QUIC/h3).
This can improve application performance, especially on networks where
interruptions may be common, such as on mobile.
Requests with Early Data will have the "Early-Data" HTTP header set on
the request, with a value of "1", to allow the backend to determine whether
Early Data was included.
Note: TLS Early Data may allow requests to be replayed, as the data is
sent to the backend before the handshake has fully completed. Applications
that allow idempotent HTTP methods to make non-idempotent changes, such as
a GET request updating a database, should not accept Early Data on those
requests, and reject requests with the "Early-Data: 1" HTTP header by
returning a HTTP 425 (Too Early) status code, in order to remain RFC
compliant.
The default value is DISABLED.
Corresponds to the JSON property tlsEarlyData
63900 63901 63902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63900 def tls_early_data @tls_early_data end |
#url_map ⇒ String
A fully-qualified or valid partial URL to the UrlMap resource that defines the mapping from URL to the BackendService. For example, the following are all valid URLs for specifying a URL map:
- https://www.googleapis.compute/v1/projects/project/global/urlMaps/url-map
- projects/project/global/urlMaps/url-map
- global/urlMaps/url-map
Corresponds to the JSON property
urlMap
63911 63912 63913 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63911 def url_map @url_map end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
63918 63919 63920 63921 63922 63923 63924 63925 63926 63927 63928 63929 63930 63931 63932 63933 63934 63935 63936 63937 63938 63939 63940 |
# File 'lib/google/apis/compute_beta/classes.rb', line 63918 def update!(**args) @authentication = args[:authentication] if args.key?(:authentication) @authorization = args[:authorization] if args.key?(:authorization) @authorization_policy = args[:authorization_policy] if args.key?(:authorization_policy) @certificate_map = args[:certificate_map] if args.key?(:certificate_map) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @http_filters = args[:http_filters] if args.key?(:http_filters) @http_keep_alive_timeout_sec = args[:http_keep_alive_timeout_sec] if args.key?(:http_keep_alive_timeout_sec) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind) @quic_override = args[:quic_override] if args.key?(:quic_override) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @server_tls_policy = args[:server_tls_policy] if args.key?(:server_tls_policy) @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates) @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy) @tls_early_data = args[:tls_early_data] if args.key?(:tls_early_data) @url_map = args[:url_map] if args.key?(:url_map) end |