Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>
A list of TargetHttpsProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyAggregatedList
constructor
A new instance of TargetHttpsProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyAggregatedList
Returns a new instance of TargetHttpsProxyAggregatedList.
69668 69669 69670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69668 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69629 69630 69631 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69629 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>
A list of TargetHttpsProxiesScopedList resources.
Corresponds to the JSON property items
69634 69635 69636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69634 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetHttpsProxyAggregatedList for lists of Target
HTTP Proxies.
Corresponds to the JSON property kind
69641 69642 69643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69641 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69651 69652 69653 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69651 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69656 69657 69658 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69656 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
69661 69662 69663 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69661 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69666 69667 69668 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69666 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69673 69674 69675 69676 69677 69678 69679 69680 69681 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69673 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |