Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>
A list of TargetHttpsProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyAggregatedList
constructor
A new instance of TargetHttpsProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyAggregatedList
Returns a new instance of TargetHttpsProxyAggregatedList.
69544 69545 69546 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69505 69506 69507 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69505 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>
A list of TargetHttpsProxiesScopedList resources.
Corresponds to the JSON property items
69510 69511 69512 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69510 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetHttpsProxyAggregatedList for lists of Target
HTTP Proxies.
Corresponds to the JSON property kind
69517 69518 69519 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69517 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69527 69528 69529 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69527 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69532 69533 69534 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69532 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
69537 69538 69539 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69537 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69542 69543 69544 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69542 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69549 69550 69551 69552 69553 69554 69555 69556 69557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69549 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |