Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



69040
69041
69042
# File 'lib/google/apis/compute_beta/classes.rb', line 69040

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69001
69002
69003
# File 'lib/google/apis/compute_beta/classes.rb', line 69001

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



69006
69007
69008
# File 'lib/google/apis/compute_beta/classes.rb', line 69006

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


69013
69014
69015
# File 'lib/google/apis/compute_beta/classes.rb', line 69013

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69023
69024
69025
# File 'lib/google/apis/compute_beta/classes.rb', line 69023

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69028
69029
69030
# File 'lib/google/apis/compute_beta/classes.rb', line 69028

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69033
69034
69035
# File 'lib/google/apis/compute_beta/classes.rb', line 69033

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69038
69039
69040
# File 'lib/google/apis/compute_beta/classes.rb', line 69038

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69045
69046
69047
69048
69049
69050
69051
69052
69053
# File 'lib/google/apis/compute_beta/classes.rb', line 69045

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end