Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



68221
68222
68223
# File 'lib/google/apis/compute_beta/classes.rb', line 68221

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68182
68183
68184
# File 'lib/google/apis/compute_beta/classes.rb', line 68182

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



68187
68188
68189
# File 'lib/google/apis/compute_beta/classes.rb', line 68187

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68194
68195
68196
# File 'lib/google/apis/compute_beta/classes.rb', line 68194

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68204
68205
68206
# File 'lib/google/apis/compute_beta/classes.rb', line 68204

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68209
68210
68211
# File 'lib/google/apis/compute_beta/classes.rb', line 68209

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68214
68215
68216
# File 'lib/google/apis/compute_beta/classes.rb', line 68214

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68219
68220
68221
# File 'lib/google/apis/compute_beta/classes.rb', line 68219

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68226
68227
68228
68229
68230
68231
68232
68233
68234
# File 'lib/google/apis/compute_beta/classes.rb', line 68226

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end