Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



68162
68163
68164
# File 'lib/google/apis/compute_beta/classes.rb', line 68162

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68123
68124
68125
# File 'lib/google/apis/compute_beta/classes.rb', line 68123

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



68128
68129
68130
# File 'lib/google/apis/compute_beta/classes.rb', line 68128

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68135
68136
68137
# File 'lib/google/apis/compute_beta/classes.rb', line 68135

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68145
68146
68147
# File 'lib/google/apis/compute_beta/classes.rb', line 68145

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68150
68151
68152
# File 'lib/google/apis/compute_beta/classes.rb', line 68150

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68155
68156
68157
# File 'lib/google/apis/compute_beta/classes.rb', line 68155

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68160
68161
68162
# File 'lib/google/apis/compute_beta/classes.rb', line 68160

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68167
68168
68169
68170
68171
68172
68173
68174
68175
# File 'lib/google/apis/compute_beta/classes.rb', line 68167

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end