Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



67310
67311
67312
# File 'lib/google/apis/compute_beta/classes.rb', line 67310

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67271
67272
67273
# File 'lib/google/apis/compute_beta/classes.rb', line 67271

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



67276
67277
67278
# File 'lib/google/apis/compute_beta/classes.rb', line 67276

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


67283
67284
67285
# File 'lib/google/apis/compute_beta/classes.rb', line 67283

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67293
67294
67295
# File 'lib/google/apis/compute_beta/classes.rb', line 67293

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67298
67299
67300
# File 'lib/google/apis/compute_beta/classes.rb', line 67298

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67303
67304
67305
# File 'lib/google/apis/compute_beta/classes.rb', line 67303

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67308
67309
67310
# File 'lib/google/apis/compute_beta/classes.rb', line 67308

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67315
67316
67317
67318
67319
67320
67321
67322
67323
# File 'lib/google/apis/compute_beta/classes.rb', line 67315

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end