Class: Google::Apis::ComputeBeta::TargetHttpsProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyAggregatedList

Returns a new instance of TargetHttpsProxyAggregatedList.



63989
63990
63991
# File 'lib/google/apis/compute_beta/classes.rb', line 63989

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


63950
63951
63952
# File 'lib/google/apis/compute_beta/classes.rb', line 63950

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetHttpsProxiesScopedList>

A list of TargetHttpsProxiesScopedList resources. Corresponds to the JSON property items



63955
63956
63957
# File 'lib/google/apis/compute_beta/classes.rb', line 63955

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetHttpsProxyAggregatedList for lists of Target HTTP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


63962
63963
63964
# File 'lib/google/apis/compute_beta/classes.rb', line 63962

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


63972
63973
63974
# File 'lib/google/apis/compute_beta/classes.rb', line 63972

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


63977
63978
63979
# File 'lib/google/apis/compute_beta/classes.rb', line 63977

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


63982
63983
63984
# File 'lib/google/apis/compute_beta/classes.rb', line 63982

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



63987
63988
63989
# File 'lib/google/apis/compute_beta/classes.rb', line 63987

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



63994
63995
63996
63997
63998
63999
64000
64001
64002
# File 'lib/google/apis/compute_beta/classes.rb', line 63994

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end