Class: Google::Apis::ComputeBeta::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



69794
69795
69796
# File 'lib/google/apis/compute_beta/classes.rb', line 69794

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69761
69762
69763
# File 'lib/google/apis/compute_beta/classes.rb', line 69761

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



69766
69767
69768
# File 'lib/google/apis/compute_beta/classes.rb', line 69766

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


69772
69773
69774
# File 'lib/google/apis/compute_beta/classes.rb', line 69772

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69782
69783
69784
# File 'lib/google/apis/compute_beta/classes.rb', line 69782

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69787
69788
69789
# File 'lib/google/apis/compute_beta/classes.rb', line 69787

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69792
69793
69794
# File 'lib/google/apis/compute_beta/classes.rb', line 69792

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69799
69800
69801
69802
69803
69804
69805
69806
# File 'lib/google/apis/compute_beta/classes.rb', line 69799

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end