Class: Google::Apis::ComputeBeta::TargetHttpsProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpsProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetHttpsProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyList
constructor
A new instance of TargetHttpsProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyList
Returns a new instance of TargetHttpsProxyList.
69670 69671 69672 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69670 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69637 69638 69639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69637 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
Corresponds to the JSON property items
69642 69643 69644 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69642 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpsProxyList for
lists of target HTTPS proxies.
Corresponds to the JSON property kind
69648 69649 69650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69648 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69658 69659 69660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69658 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69663 69664 69665 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69663 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69668 69669 69670 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69668 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69675 69676 69677 69678 69679 69680 69681 69682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69675 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |