Class: Google::Apis::ComputeBeta::TargetHttpsProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetHttpsProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetHttpsProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetHttpsProxyList
constructor
A new instance of TargetHttpsProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetHttpsProxyList
Returns a new instance of TargetHttpsProxyList.
69196 69197 69198 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69196 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69163 69164 69165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69163 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetHttpsProxy>
A list of TargetHttpsProxy resources.
Corresponds to the JSON property items
69168 69169 69170 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69168 def items @items end |
#kind ⇒ String
Output only. Type of resource. Always compute#targetHttpsProxyList for
lists of target HTTPS proxies.
Corresponds to the JSON property kind
69174 69175 69176 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69174 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69184 69185 69186 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69184 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69189 69190 69191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69189 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetHttpsProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69194 69195 69196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69194 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69201 69202 69203 69204 69205 69206 69207 69208 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69201 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |