Class: Google::Apis::ComputeBeta::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



69166
69167
69168
# File 'lib/google/apis/compute_beta/classes.rb', line 69166

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69133
69134
69135
# File 'lib/google/apis/compute_beta/classes.rb', line 69133

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



69138
69139
69140
# File 'lib/google/apis/compute_beta/classes.rb', line 69138

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


69144
69145
69146
# File 'lib/google/apis/compute_beta/classes.rb', line 69144

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69154
69155
69156
# File 'lib/google/apis/compute_beta/classes.rb', line 69154

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69159
69160
69161
# File 'lib/google/apis/compute_beta/classes.rb', line 69159

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69164
69165
69166
# File 'lib/google/apis/compute_beta/classes.rb', line 69164

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69171
69172
69173
69174
69175
69176
69177
69178
# File 'lib/google/apis/compute_beta/classes.rb', line 69171

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end