Class: Google::Apis::ComputeBeta::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



68347
68348
68349
# File 'lib/google/apis/compute_beta/classes.rb', line 68347

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68314
68315
68316
# File 'lib/google/apis/compute_beta/classes.rb', line 68314

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



68319
68320
68321
# File 'lib/google/apis/compute_beta/classes.rb', line 68319

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68325
68326
68327
# File 'lib/google/apis/compute_beta/classes.rb', line 68325

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68335
68336
68337
# File 'lib/google/apis/compute_beta/classes.rb', line 68335

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68340
68341
68342
# File 'lib/google/apis/compute_beta/classes.rb', line 68340

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68345
68346
68347
# File 'lib/google/apis/compute_beta/classes.rb', line 68345

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68352
68353
68354
68355
68356
68357
68358
68359
# File 'lib/google/apis/compute_beta/classes.rb', line 68352

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end