Class: Google::Apis::ComputeBeta::TargetHttpsProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetHttpsProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetHttpsProxyList

Returns a new instance of TargetHttpsProxyList.



67436
67437
67438
# File 'lib/google/apis/compute_beta/classes.rb', line 67436

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67403
67404
67405
# File 'lib/google/apis/compute_beta/classes.rb', line 67403

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetHttpsProxy>

A list of TargetHttpsProxy resources. Corresponds to the JSON property items



67408
67409
67410
# File 'lib/google/apis/compute_beta/classes.rb', line 67408

def items
  @items
end

#kindString

Output only. Type of resource. Always compute#targetHttpsProxyList for lists of target HTTPS proxies. Corresponds to the JSON property kind

Returns:

  • (String)


67414
67415
67416
# File 'lib/google/apis/compute_beta/classes.rb', line 67414

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67424
67425
67426
# File 'lib/google/apis/compute_beta/classes.rb', line 67424

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67429
67430
67431
# File 'lib/google/apis/compute_beta/classes.rb', line 67429

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetHttpsProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67434
67435
67436
# File 'lib/google/apis/compute_beta/classes.rb', line 67434

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67441
67442
67443
67444
67445
67446
67447
67448
# File 'lib/google/apis/compute_beta/classes.rb', line 67441

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end