Class: Google::Apis::ComputeBeta::TargetInstance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Target Instance resource. You can use a target instance to handle traffic for one or more forwarding rules, which is ideal for forwarding protocol traffic that is managed by a single source. For example, ESP, AH, TCP, or UDP. For more information, readTarget instances.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#instance ⇒ String
A URL to the virtual machine instance that handles traffic for this target instance.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#nat_policy ⇒ String
Must have a value of NO_NAT.
-
#network ⇒ String
The URL of the network this target instance uses to forward traffic.
-
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this target instance.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#zone ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstance
constructor
A new instance of TargetInstance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstance
Returns a new instance of TargetInstance.
69370 69371 69372 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69370 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
69294 69295 69296 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69294 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
69300 69301 69302 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69300 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
69306 69307 69308 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69306 def id @id end |
#instance ⇒ String
A URL to the virtual machine instance that handles traffic for this target instance. When creating a target instance, you can provide the fully-qualified URL or a valid partial URL to the desired virtual machine. For example, the following are all valid URLs:
- https://www.googleapis.com/compute/v1/projects/project/zones/zone/ instances/instance
- projects/project/zones/zone/instances/instance
- zones/zone/instances/instance
Corresponds to the JSON property
instance
69319 69320 69321 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69319 def instance @instance end |
#kind ⇒ String
Output only. [Output Only] The type of the resource. Alwayscompute#
targetInstance for target instances.
Corresponds to the JSON property kind
69325 69326 69327 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69325 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
69336 69337 69338 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69336 def name @name end |
#nat_policy ⇒ String
Must have a value of NO_NAT.
Protocol forwarding delivers packets while preserving the destination IP
address of the forwarding rule referencing the target instance.
Corresponds to the JSON property natPolicy
69343 69344 69345 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69343 def nat_policy @nat_policy end |
#network ⇒ String
The URL of the network this target instance uses to forward traffic.
If not specified, the traffic will be forwarded to the network that
the default network interface belongs to.
Corresponds to the JSON property network
69350 69351 69352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69350 def network @network end |
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this
target instance.
Corresponds to the JSON property securityPolicy
69356 69357 69358 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69356 def security_policy @security_policy end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
69361 69362 69363 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69361 def self_link @self_link end |
#zone ⇒ String
Output only. [Output Only] URL of the zone where the target instance resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property zone
69368 69369 69370 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69368 def zone @zone end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69375 69376 69377 69378 69379 69380 69381 69382 69383 69384 69385 69386 69387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69375 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @instance = args[:instance] if args.key?(:instance) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @nat_policy = args[:nat_policy] if args.key?(:nat_policy) @network = args[:network] if args.key?(:network) @security_policy = args[:security_policy] if args.key?(:security_policy) @self_link = args[:self_link] if args.key?(:self_link) @zone = args[:zone] if args.key?(:zone) end |