Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
70431 70432 70433 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70431 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70394 70395 70396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70394 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
70399 70400 70401 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70399 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
70404 70405 70406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70404 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70414 70415 70416 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70414 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70419 70420 70421 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70419 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
70424 70425 70426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70424 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70429 70430 70431 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70429 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70436 70437 70438 70439 70440 70441 70442 70443 70444 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70436 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |