Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
70028 70029 70030 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70028 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69991 69992 69993 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69991 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
69996 69997 69998 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69996 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
70001 70002 70003 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70001 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70011 70012 70013 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70011 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70016 70017 70018 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70016 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
70021 70022 70023 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70021 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70026 70027 70028 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70026 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70033 70034 70035 70036 70037 70038 70039 70040 70041 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70033 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |