Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



69908
69909
69910
# File 'lib/google/apis/compute_beta/classes.rb', line 69908

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69871
69872
69873
# File 'lib/google/apis/compute_beta/classes.rb', line 69871

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



69876
69877
69878
# File 'lib/google/apis/compute_beta/classes.rb', line 69876

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


69881
69882
69883
# File 'lib/google/apis/compute_beta/classes.rb', line 69881

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69891
69892
69893
# File 'lib/google/apis/compute_beta/classes.rb', line 69891

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69896
69897
69898
# File 'lib/google/apis/compute_beta/classes.rb', line 69896

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69901
69902
69903
# File 'lib/google/apis/compute_beta/classes.rb', line 69901

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69906
69907
69908
# File 'lib/google/apis/compute_beta/classes.rb', line 69906

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69913
69914
69915
69916
69917
69918
69919
69920
69921
# File 'lib/google/apis/compute_beta/classes.rb', line 69913

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end