Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
69876 69877 69878 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69839 69840 69841 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69839 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
69844 69845 69846 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69844 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
69849 69850 69851 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69849 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69859 69860 69861 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69859 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69864 69865 69866 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69864 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
69869 69870 69871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69869 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69874 69875 69876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69874 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69881 69882 69883 69884 69885 69886 69887 69888 69889 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69881 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |