Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



68585
68586
68587
# File 'lib/google/apis/compute_beta/classes.rb', line 68585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68548
68549
68550
# File 'lib/google/apis/compute_beta/classes.rb', line 68548

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



68553
68554
68555
# File 'lib/google/apis/compute_beta/classes.rb', line 68553

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


68558
68559
68560
# File 'lib/google/apis/compute_beta/classes.rb', line 68558

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68568
68569
68570
# File 'lib/google/apis/compute_beta/classes.rb', line 68568

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68573
68574
68575
# File 'lib/google/apis/compute_beta/classes.rb', line 68573

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68578
68579
68580
# File 'lib/google/apis/compute_beta/classes.rb', line 68578

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68583
68584
68585
# File 'lib/google/apis/compute_beta/classes.rb', line 68583

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68590
68591
68592
68593
68594
68595
68596
68597
68598
# File 'lib/google/apis/compute_beta/classes.rb', line 68590

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end