Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceAggregatedList

Returns a new instance of TargetInstanceAggregatedList.



67674
67675
67676
# File 'lib/google/apis/compute_beta/classes.rb', line 67674

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67637
67638
67639
# File 'lib/google/apis/compute_beta/classes.rb', line 67637

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>

A list of TargetInstance resources. Corresponds to the JSON property items



67642
67643
67644
# File 'lib/google/apis/compute_beta/classes.rb', line 67642

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


67647
67648
67649
# File 'lib/google/apis/compute_beta/classes.rb', line 67647

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67657
67658
67659
# File 'lib/google/apis/compute_beta/classes.rb', line 67657

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67662
67663
67664
# File 'lib/google/apis/compute_beta/classes.rb', line 67662

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


67667
67668
67669
# File 'lib/google/apis/compute_beta/classes.rb', line 67667

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67672
67673
67674
# File 'lib/google/apis/compute_beta/classes.rb', line 67672

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67679
67680
67681
67682
67683
67684
67685
67686
67687
# File 'lib/google/apis/compute_beta/classes.rb', line 67679

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end