Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
67674 67675 67676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67674 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67637 67638 67639 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67637 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
67642 67643 67644 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67642 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
67647 67648 67649 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67647 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67657 67658 67659 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67657 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67662 67663 67664 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67662 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67667 67668 67669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67667 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67672 67673 67674 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67672 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67679 67680 67681 67682 67683 67684 67685 67686 67687 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67679 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |