Class: Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstanceAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceAggregatedList
constructor
A new instance of TargetInstanceAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceAggregatedList
Returns a new instance of TargetInstanceAggregatedList.
64353 64354 64355 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64353 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
64316 64317 64318 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64316 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetInstancesScopedList>
A list of TargetInstance resources.
Corresponds to the JSON property items
64321 64322 64323 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64321 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
64326 64327 64328 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64326 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
64336 64337 64338 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64336 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
64341 64342 64343 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64341 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
64346 64347 64348 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64346 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
64351 64352 64353 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64351 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
64358 64359 64360 64361 64362 64363 64364 64365 64366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 64358 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |