Class: Google::Apis::ComputeBeta::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



70001
70002
70003
# File 'lib/google/apis/compute_beta/classes.rb', line 70001

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69969
69970
69971
# File 'lib/google/apis/compute_beta/classes.rb', line 69969

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



69974
69975
69976
# File 'lib/google/apis/compute_beta/classes.rb', line 69974

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


69979
69980
69981
# File 'lib/google/apis/compute_beta/classes.rb', line 69979

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69989
69990
69991
# File 'lib/google/apis/compute_beta/classes.rb', line 69989

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69994
69995
69996
# File 'lib/google/apis/compute_beta/classes.rb', line 69994

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69999
70000
70001
# File 'lib/google/apis/compute_beta/classes.rb', line 69999

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70006
70007
70008
70009
70010
70011
70012
70013
# File 'lib/google/apis/compute_beta/classes.rb', line 70006

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end