Class: Google::Apis::ComputeBeta::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



67799
67800
67801
# File 'lib/google/apis/compute_beta/classes.rb', line 67799

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


67767
67768
67769
# File 'lib/google/apis/compute_beta/classes.rb', line 67767

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



67772
67773
67774
# File 'lib/google/apis/compute_beta/classes.rb', line 67772

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


67777
67778
67779
# File 'lib/google/apis/compute_beta/classes.rb', line 67777

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


67787
67788
67789
# File 'lib/google/apis/compute_beta/classes.rb', line 67787

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


67792
67793
67794
# File 'lib/google/apis/compute_beta/classes.rb', line 67792

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



67797
67798
67799
# File 'lib/google/apis/compute_beta/classes.rb', line 67797

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67804
67805
67806
67807
67808
67809
67810
67811
# File 'lib/google/apis/compute_beta/classes.rb', line 67804

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end