Class: Google::Apis::ComputeBeta::TargetInstanceList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetInstanceList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetInstance resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetInstance>
A list of TargetInstance resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetInstanceList
constructor
A new instance of TargetInstanceList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetInstanceList
Returns a new instance of TargetInstanceList.
67799 67800 67801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67799 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67767 67768 67769 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67767 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetInstance>
A list of TargetInstance resources.
Corresponds to the JSON property items
67772 67773 67774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67772 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
67777 67778 67779 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67777 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67787 67788 67789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67787 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67792 67793 67794 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67792 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetInstanceList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67797 67798 67799 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67797 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67804 67805 67806 67807 67808 67809 67810 67811 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67804 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |