Class: Google::Apis::ComputeBeta::TargetInstanceList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetInstance resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstanceList

Returns a new instance of TargetInstanceList.



64478
64479
64480
# File 'lib/google/apis/compute_beta/classes.rb', line 64478

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


64446
64447
64448
# File 'lib/google/apis/compute_beta/classes.rb', line 64446

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetInstance>

A list of TargetInstance resources. Corresponds to the JSON property items



64451
64452
64453
# File 'lib/google/apis/compute_beta/classes.rb', line 64451

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


64456
64457
64458
# File 'lib/google/apis/compute_beta/classes.rb', line 64456

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


64466
64467
64468
# File 'lib/google/apis/compute_beta/classes.rb', line 64466

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


64471
64472
64473
# File 'lib/google/apis/compute_beta/classes.rb', line 64471

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetInstanceList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



64476
64477
64478
# File 'lib/google/apis/compute_beta/classes.rb', line 64476

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



64483
64484
64485
64486
64487
64488
64489
64490
# File 'lib/google/apis/compute_beta/classes.rb', line 64483

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end