Class: Google::Apis::ComputeBeta::TargetInstancesScopedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetInstancesScopedList

Returns a new instance of TargetInstancesScopedList.



67899
67900
67901
# File 'lib/google/apis/compute_beta/classes.rb', line 67899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#target_instancesArray<Google::Apis::ComputeBeta::TargetInstance>

A list of target instances contained in this scope. Corresponds to the JSON property targetInstances



67891
67892
67893
# File 'lib/google/apis/compute_beta/classes.rb', line 67891

def target_instances
  @target_instances
end

#warningGoogle::Apis::ComputeBeta::TargetInstancesScopedList::Warning

Informational warning which replaces the list of addresses when the list is empty. Corresponds to the JSON property warning



67897
67898
67899
# File 'lib/google/apis/compute_beta/classes.rb', line 67897

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67904
67905
67906
67907
# File 'lib/google/apis/compute_beta/classes.rb', line 67904

def update!(**args)
  @target_instances = args[:target_instances] if args.key?(:target_instances)
  @warning = args[:warning] if args.key?(:warning)
end