Class: Google::Apis::ComputeBeta::TargetPool
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetPool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Target Pool resource. Target pools are used with external passthrough Network Load Balancers. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, readUsing target pools.
Instance Attribute Summary collapse
-
#backup_pool ⇒ String
The server-defined URL for the resource.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#failover_ratio ⇒ Float
This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool).
-
#health_checks ⇒ Array<String>
The URL of the HttpHealthCheck resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#instances ⇒ Array<String>
A list of resource URLs to the virtual machine instances serving this pool.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this target pool.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#session_affinity ⇒ String
Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPool
constructor
A new instance of TargetPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPool
Returns a new instance of TargetPool.
69012 69013 69014 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69012 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_pool ⇒ String
The server-defined URL for the resource. This field is applicable only when
the containing target pool is serving a forwarding rule as the primary
pool, and its failoverRatio field is properly set to a value
between [0, 1].backupPool and failoverRatio together define
the fallback behavior of the primary target pool: if the ratio of the
healthy instances in the primary pool is at or belowfailoverRatio, traffic
arriving at the load-balanced
IP will be directed to the backup pool.
In case where failoverRatio and backupPool
are not set, or all the instances in the backup pool are unhealthy,
the traffic will be directed back to the primary pool in the "force"
mode, where traffic will be spread to the healthy instances with the
best effort, or to all instances when no instance is healthy.
Corresponds to the JSON property backupPool
68915 68916 68917 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68915 def backup_pool @backup_pool end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
68921 68922 68923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68921 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
68927 68928 68929 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68927 def description @description end |
#failover_ratio ⇒ Float
This field is applicable only when the containing target pool is serving a
forwarding rule as the primary pool (i.e., not as a backup pool to some
other target pool). The value of the field must be in [0, 1].
If set, backupPool must also be set. They together define
the fallback behavior of the primary target pool: if the ratio of the
healthy instances in the primary pool is at or below this number,
traffic arriving at the load-balanced IP will be directed to the
backup pool.
In case where failoverRatio is not set or all the
instances in the backup pool are unhealthy, the traffic will be
directed back to the primary pool in the "force" mode, where traffic
will be spread to the healthy instances with the
best effort, or to all instances when no instance is healthy.
Corresponds to the JSON property failoverRatio
68944 68945 68946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68944 def failover_ratio @failover_ratio end |
#health_checks ⇒ Array<String>
The URL of the HttpHealthCheck resource. A member instance in this
pool is considered healthy if and only if the health checks pass.
Only legacy HttpHealthChecks are supported. Only one health check may be
specified.
Corresponds to the JSON property healthChecks
68952 68953 68954 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68952 def health_checks @health_checks end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
68958 68959 68960 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68958 def id @id end |
#instances ⇒ Array<String>
A list of resource URLs to the virtual machine instances serving this pool.
They must live in zones contained in the same region as this pool.
Corresponds to the JSON property instances
68964 68965 68966 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68964 def instances @instances end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#targetPool
for target pools.
Corresponds to the JSON property kind
68970 68971 68972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68970 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
68981 68982 68983 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68981 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the target pool resides.
Corresponds to the JSON property region
68986 68987 68988 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68986 def region @region end |
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this
target pool.
Corresponds to the JSON property securityPolicy
68992 68993 68994 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68992 def security_policy @security_policy end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
68997 68998 68999 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68997 def self_link @self_link end |
#session_affinity ⇒ String
Session affinity option, must be one of the following values:
NONE: Connections from the same client IP may go to any
instance in the pool.
CLIENT_IP: Connections from the same client IP will go
to the same instance in
the pool while that instance remains healthy.
CLIENT_IP_PROTO: Connections from the same client IP
with the same IP protocol will go to the same instance in the
pool while that instance remains healthy.
Corresponds to the JSON property sessionAffinity
69010 69011 69012 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69010 def session_affinity @session_affinity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69017 69018 69019 69020 69021 69022 69023 69024 69025 69026 69027 69028 69029 69030 69031 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69017 def update!(**args) @backup_pool = args[:backup_pool] if args.key?(:backup_pool) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @failover_ratio = args[:failover_ratio] if args.key?(:failover_ratio) @health_checks = args[:health_checks] if args.key?(:health_checks) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @security_policy = args[:security_policy] if args.key?(:security_policy) @self_link = args[:self_link] if args.key?(:self_link) @session_affinity = args[:session_affinity] if args.key?(:session_affinity) end |