Class: Google::Apis::ComputeBeta::TargetPool
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetPool
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Target Pool resource. Target pools are used with external passthrough Network Load Balancers. A target pool references member instances, an associated legacy HttpHealthCheck resource, and, optionally, a backup target pool. For more information, readUsing target pools.
Instance Attribute Summary collapse
-
#backup_pool ⇒ String
The server-defined URL for the resource.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#failover_ratio ⇒ Float
This field is applicable only when the containing target pool is serving a forwarding rule as the primary pool (i.e., not as a backup pool to some other target pool).
-
#health_checks ⇒ Array<String>
The URL of the HttpHealthCheck resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#instances ⇒ Array<String>
A list of resource URLs to the virtual machine instances serving this pool.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#region ⇒ String
Output only.
-
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this target pool.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#session_affinity ⇒ String
Session affinity option, must be one of the following values: NONE: Connections from the same client IP may go to any instance in the pool.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPool
constructor
A new instance of TargetPool.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPool
Returns a new instance of TargetPool.
66888 66889 66890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#backup_pool ⇒ String
The server-defined URL for the resource. This field is applicable only when
the containing target pool is serving a forwarding rule as the primary
pool, and its failoverRatio field is properly set to a value
between [0, 1].backupPool and failoverRatio together define
the fallback behavior of the primary target pool: if the ratio of the
healthy instances in the primary pool is at or belowfailoverRatio, traffic
arriving at the load-balanced
IP will be directed to the backup pool.
In case where failoverRatio and backupPool
are not set, or all the instances in the backup pool are unhealthy,
the traffic will be directed back to the primary pool in the "force"
mode, where traffic will be spread to the healthy instances with the
best effort, or to all instances when no instance is healthy.
Corresponds to the JSON property backupPool
66791 66792 66793 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66791 def backup_pool @backup_pool end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
66797 66798 66799 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66797 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
66803 66804 66805 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66803 def description @description end |
#failover_ratio ⇒ Float
This field is applicable only when the containing target pool is serving a
forwarding rule as the primary pool (i.e., not as a backup pool to some
other target pool). The value of the field must be in [0, 1].
If set, backupPool must also be set. They together define
the fallback behavior of the primary target pool: if the ratio of the
healthy instances in the primary pool is at or below this number,
traffic arriving at the load-balanced IP will be directed to the
backup pool.
In case where failoverRatio is not set or all the
instances in the backup pool are unhealthy, the traffic will be
directed back to the primary pool in the "force" mode, where traffic
will be spread to the healthy instances with the
best effort, or to all instances when no instance is healthy.
Corresponds to the JSON property failoverRatio
66820 66821 66822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66820 def failover_ratio @failover_ratio end |
#health_checks ⇒ Array<String>
The URL of the HttpHealthCheck resource. A member instance in this
pool is considered healthy if and only if the health checks pass.
Only legacy HttpHealthChecks are supported. Only one health check may be
specified.
Corresponds to the JSON property healthChecks
66828 66829 66830 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66828 def health_checks @health_checks end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
66834 66835 66836 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66834 def id @id end |
#instances ⇒ Array<String>
A list of resource URLs to the virtual machine instances serving this pool.
They must live in zones contained in the same region as this pool.
Corresponds to the JSON property instances
66840 66841 66842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66840 def instances @instances end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#targetPool
for target pools.
Corresponds to the JSON property kind
66846 66847 66848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66846 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
66857 66858 66859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66857 def name @name end |
#region ⇒ String
Output only. [Output Only] URL of the region where the target pool resides.
Corresponds to the JSON property region
66862 66863 66864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66862 def region @region end |
#security_policy ⇒ String
[Output Only] The resource URL for the security policy associated with this
target pool.
Corresponds to the JSON property securityPolicy
66868 66869 66870 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66868 def security_policy @security_policy end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
66873 66874 66875 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66873 def self_link @self_link end |
#session_affinity ⇒ String
Session affinity option, must be one of the following values:
NONE: Connections from the same client IP may go to any
instance in the pool.
CLIENT_IP: Connections from the same client IP will go
to the same instance in
the pool while that instance remains healthy.
CLIENT_IP_PROTO: Connections from the same client IP
with the same IP protocol will go to the same instance in the
pool while that instance remains healthy.
Corresponds to the JSON property sessionAffinity
66886 66887 66888 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66886 def session_affinity @session_affinity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66893 66894 66895 66896 66897 66898 66899 66900 66901 66902 66903 66904 66905 66906 66907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66893 def update!(**args) @backup_pool = args[:backup_pool] if args.key?(:backup_pool) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @failover_ratio = args[:failover_ratio] if args.key?(:failover_ratio) @health_checks = args[:health_checks] if args.key?(:health_checks) @id = args[:id] if args.key?(:id) @instances = args[:instances] if args.key?(:instances) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @security_policy = args[:security_policy] if args.key?(:security_policy) @self_link = args[:self_link] if args.key?(:self_link) @session_affinity = args[:session_affinity] if args.key?(:session_affinity) end |