Class: Google::Apis::ComputeBeta::TargetPoolAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetPoolAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolAggregatedList
constructor
A new instance of TargetPoolAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolAggregatedList
Returns a new instance of TargetPoolAggregatedList.
69929 69930 69931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69890 69891 69892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69890 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>
A list of TargetPool resources.
Corresponds to the JSON property items
69895 69896 69897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69895 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetPoolAggregatedList for aggregated lists of
target pools.
Corresponds to the JSON property kind
69902 69903 69904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69902 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69912 69913 69914 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69912 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69917 69918 69919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69917 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
69922 69923 69924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69922 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetPoolAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69927 69928 69929 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69927 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69934 69935 69936 69937 69938 69939 69940 69941 69942 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69934 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |