Class: Google::Apis::ComputeBeta::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



69899
69900
69901
# File 'lib/google/apis/compute_beta/classes.rb', line 69899

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69860
69861
69862
# File 'lib/google/apis/compute_beta/classes.rb', line 69860

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



69865
69866
69867
# File 'lib/google/apis/compute_beta/classes.rb', line 69865

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


69872
69873
69874
# File 'lib/google/apis/compute_beta/classes.rb', line 69872

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69882
69883
69884
# File 'lib/google/apis/compute_beta/classes.rb', line 69882

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69887
69888
69889
# File 'lib/google/apis/compute_beta/classes.rb', line 69887

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69892
69893
69894
# File 'lib/google/apis/compute_beta/classes.rb', line 69892

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69897
69898
69899
# File 'lib/google/apis/compute_beta/classes.rb', line 69897

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69904
69905
69906
69907
69908
69909
69910
69911
69912
# File 'lib/google/apis/compute_beta/classes.rb', line 69904

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end