Class: Google::Apis::ComputeBeta::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



69021
69022
69023
# File 'lib/google/apis/compute_beta/classes.rb', line 69021

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68982
68983
68984
# File 'lib/google/apis/compute_beta/classes.rb', line 68982

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



68987
68988
68989
# File 'lib/google/apis/compute_beta/classes.rb', line 68987

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


68994
68995
68996
# File 'lib/google/apis/compute_beta/classes.rb', line 68994

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69004
69005
69006
# File 'lib/google/apis/compute_beta/classes.rb', line 69004

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69009
69010
69011
# File 'lib/google/apis/compute_beta/classes.rb', line 69009

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69014
69015
69016
# File 'lib/google/apis/compute_beta/classes.rb', line 69014

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69019
69020
69021
# File 'lib/google/apis/compute_beta/classes.rb', line 69019

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69026
69027
69028
69029
69030
69031
69032
69033
69034
# File 'lib/google/apis/compute_beta/classes.rb', line 69026

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end