Class: Google::Apis::ComputeBeta::TargetPoolAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolAggregatedList

Returns a new instance of TargetPoolAggregatedList.



66956
66957
66958
# File 'lib/google/apis/compute_beta/classes.rb', line 66956

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66917
66918
66919
# File 'lib/google/apis/compute_beta/classes.rb', line 66917

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetPoolsScopedList>

A list of TargetPool resources. Corresponds to the JSON property items



66922
66923
66924
# File 'lib/google/apis/compute_beta/classes.rb', line 66922

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetPoolAggregatedList for aggregated lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


66929
66930
66931
# File 'lib/google/apis/compute_beta/classes.rb', line 66929

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66939
66940
66941
# File 'lib/google/apis/compute_beta/classes.rb', line 66939

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66944
66945
66946
# File 'lib/google/apis/compute_beta/classes.rb', line 66944

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66949
66950
66951
# File 'lib/google/apis/compute_beta/classes.rb', line 66949

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetPoolAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66954
66955
66956
# File 'lib/google/apis/compute_beta/classes.rb', line 66954

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66961
66962
66963
66964
66965
66966
66967
66968
66969
# File 'lib/google/apis/compute_beta/classes.rb', line 66961

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end