Class: Google::Apis::ComputeBeta::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



70680
70681
70682
# File 'lib/google/apis/compute_beta/classes.rb', line 70680

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70647
70648
70649
# File 'lib/google/apis/compute_beta/classes.rb', line 70647

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



70652
70653
70654
# File 'lib/google/apis/compute_beta/classes.rb', line 70652

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


70658
70659
70660
# File 'lib/google/apis/compute_beta/classes.rb', line 70658

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70668
70669
70670
# File 'lib/google/apis/compute_beta/classes.rb', line 70668

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70673
70674
70675
# File 'lib/google/apis/compute_beta/classes.rb', line 70673

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70678
70679
70680
# File 'lib/google/apis/compute_beta/classes.rb', line 70678

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70685
70686
70687
70688
70689
70690
70691
70692
# File 'lib/google/apis/compute_beta/classes.rb', line 70685

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end