Class: Google::Apis::ComputeBeta::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
70676 70677 70678 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70676 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70643 70644 70645 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70643 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
70648 70649 70650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70648 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
70654 70655 70656 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70654 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70664 70665 70666 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70664 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70669 70670 70671 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70669 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70674 70675 70676 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70674 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70681 70682 70683 70684 70685 70686 70687 70688 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70681 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |