Class: Google::Apis::ComputeBeta::TargetPoolList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetPoolList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetPool resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetPool>
A list of TargetPool resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetPoolList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetPoolList
constructor
A new instance of TargetPoolList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetPoolList
Returns a new instance of TargetPoolList.
69233 69234 69235 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69233 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69200 69201 69202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69200 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetPool>
A list of TargetPool resources.
Corresponds to the JSON property items
69205 69206 69207 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69205 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#targetPoolList
for lists of target pools.
Corresponds to the JSON property kind
69211 69212 69213 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69211 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69221 69222 69223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69221 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69226 69227 69228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69226 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetPoolList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69231 69232 69233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69231 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69238 69239 69240 69241 69242 69243 69244 69245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69238 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |