Class: Google::Apis::ComputeBeta::TargetPoolList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetPool resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetPoolList

Returns a new instance of TargetPoolList.



69174
69175
69176
# File 'lib/google/apis/compute_beta/classes.rb', line 69174

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69141
69142
69143
# File 'lib/google/apis/compute_beta/classes.rb', line 69141

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetPool>

A list of TargetPool resources. Corresponds to the JSON property items



69146
69147
69148
# File 'lib/google/apis/compute_beta/classes.rb', line 69146

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#targetPoolList for lists of target pools. Corresponds to the JSON property kind

Returns:

  • (String)


69152
69153
69154
# File 'lib/google/apis/compute_beta/classes.rb', line 69152

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69162
69163
69164
# File 'lib/google/apis/compute_beta/classes.rb', line 69162

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69167
69168
69169
# File 'lib/google/apis/compute_beta/classes.rb', line 69167

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetPoolList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69172
69173
69174
# File 'lib/google/apis/compute_beta/classes.rb', line 69172

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69179
69180
69181
69182
69183
69184
69185
69186
# File 'lib/google/apis/compute_beta/classes.rb', line 69179

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end