Class: Google::Apis::ComputeBeta::TargetSslProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Target SSL Proxy resource. A target SSL proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target SSL proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxy

Returns a new instance of TargetSslProxy.



69630
69631
69632
# File 'lib/google/apis/compute_beta/classes.rb', line 69630

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_mapString

URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored. Accepted format is//certificatemanager.googleapis.com/projects/project/ locations/location/certificateMaps/resourceName. Corresponds to the JSON property certificateMap

Returns:

  • (String)


69560
69561
69562
# File 'lib/google/apis/compute_beta/classes.rb', line 69560

def certificate_map
  @certificate_map
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


69566
69567
69568
# File 'lib/google/apis/compute_beta/classes.rb', line 69566

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


69572
69573
69574
# File 'lib/google/apis/compute_beta/classes.rb', line 69572

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


69578
69579
69580
# File 'lib/google/apis/compute_beta/classes.rb', line 69578

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetSslProxy for target SSL proxies. Corresponds to the JSON property kind

Returns:

  • (String)


69584
69585
69586
# File 'lib/google/apis/compute_beta/classes.rb', line 69584

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


69595
69596
69597
# File 'lib/google/apis/compute_beta/classes.rb', line 69595

def name
  @name
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


69602
69603
69604
# File 'lib/google/apis/compute_beta/classes.rb', line 69602

def proxy_header
  @proxy_header
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69607
69608
69609
# File 'lib/google/apis/compute_beta/classes.rb', line 69607

def self_link
  @self_link
end

#serviceString

URL to the BackendService resource. Corresponds to the JSON property service

Returns:

  • (String)


69612
69613
69614
# File 'lib/google/apis/compute_beta/classes.rb', line 69612

def service
  @service
end

#ssl_certificatesArray<String>

URLs to SslCertificate resources that are used to authenticate connections to Backends. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED. Corresponds to the JSON property sslCertificates

Returns:

  • (Array<String>)


69621
69622
69623
# File 'lib/google/apis/compute_beta/classes.rb', line 69621

def ssl_certificates
  @ssl_certificates
end

#ssl_policyString

URL of SslPolicy resource that will be associated with the TargetSslProxy resource. If not set, the TargetSslProxy resource will not have any SSL policy configured. Corresponds to the JSON property sslPolicy

Returns:

  • (String)


69628
69629
69630
# File 'lib/google/apis/compute_beta/classes.rb', line 69628

def ssl_policy
  @ssl_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69635
69636
69637
69638
69639
69640
69641
69642
69643
69644
69645
69646
69647
# File 'lib/google/apis/compute_beta/classes.rb', line 69635

def update!(**args)
  @certificate_map = args[:certificate_map] if args.key?(:certificate_map)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service = args[:service] if args.key?(:service)
  @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates)
  @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy)
end