Class: Google::Apis::ComputeBeta::TargetSslProxy

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Represents a Target SSL Proxy resource. A target SSL proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target SSL proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxy

Returns a new instance of TargetSslProxy.



68778
68779
68780
# File 'lib/google/apis/compute_beta/classes.rb', line 68778

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_mapString

URL of a certificate map that identifies a certificate map associated with the given target proxy. This field can only be set for global target proxies. If set, sslCertificates will be ignored. Accepted format is//certificatemanager.googleapis.com/projects/project/ locations/location/certificateMaps/resourceName. Corresponds to the JSON property certificateMap

Returns:

  • (String)


68708
68709
68710
# File 'lib/google/apis/compute_beta/classes.rb', line 68708

def certificate_map
  @certificate_map
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


68714
68715
68716
# File 'lib/google/apis/compute_beta/classes.rb', line 68714

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of this resource. Provide this property when you create the resource. Corresponds to the JSON property description

Returns:

  • (String)


68720
68721
68722
# File 'lib/google/apis/compute_beta/classes.rb', line 68720

def description
  @description
end

#idFixnum

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (Fixnum)


68726
68727
68728
# File 'lib/google/apis/compute_beta/classes.rb', line 68726

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#targetSslProxy for target SSL proxies. Corresponds to the JSON property kind

Returns:

  • (String)


68732
68733
68734
# File 'lib/google/apis/compute_beta/classes.rb', line 68732

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


68743
68744
68745
# File 'lib/google/apis/compute_beta/classes.rb', line 68743

def name
  @name
end

#proxy_headerString

Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1. The default is NONE. Corresponds to the JSON property proxyHeader

Returns:

  • (String)


68750
68751
68752
# File 'lib/google/apis/compute_beta/classes.rb', line 68750

def proxy_header
  @proxy_header
end

[Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68755
68756
68757
# File 'lib/google/apis/compute_beta/classes.rb', line 68755

def self_link
  @self_link
end

#serviceString

URL to the BackendService resource. Corresponds to the JSON property service

Returns:

  • (String)


68760
68761
68762
# File 'lib/google/apis/compute_beta/classes.rb', line 68760

def service
  @service
end

#ssl_certificatesArray<String>

URLs to SslCertificate resources that are used to authenticate connections to Backends. At least one SSL certificate must be specified. Currently, you may specify up to 15 SSL certificates. sslCertificates do not apply when the load balancing scheme is set to INTERNAL_SELF_MANAGED. Corresponds to the JSON property sslCertificates

Returns:

  • (Array<String>)


68769
68770
68771
# File 'lib/google/apis/compute_beta/classes.rb', line 68769

def ssl_certificates
  @ssl_certificates
end

#ssl_policyString

URL of SslPolicy resource that will be associated with the TargetSslProxy resource. If not set, the TargetSslProxy resource will not have any SSL policy configured. Corresponds to the JSON property sslPolicy

Returns:

  • (String)


68776
68777
68778
# File 'lib/google/apis/compute_beta/classes.rb', line 68776

def ssl_policy
  @ssl_policy
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68783
68784
68785
68786
68787
68788
68789
68790
68791
68792
68793
68794
68795
# File 'lib/google/apis/compute_beta/classes.rb', line 68783

def update!(**args)
  @certificate_map = args[:certificate_map] if args.key?(:certificate_map)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @proxy_header = args[:proxy_header] if args.key?(:proxy_header)
  @self_link = args[:self_link] if args.key?(:self_link)
  @service = args[:service] if args.key?(:service)
  @ssl_certificates = args[:ssl_certificates] if args.key?(:ssl_certificates)
  @ssl_policy = args[:ssl_policy] if args.key?(:ssl_policy)
end