Class: Google::Apis::ComputeBeta::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



71071
71072
71073
# File 'lib/google/apis/compute_beta/classes.rb', line 71071

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71039
71040
71041
# File 'lib/google/apis/compute_beta/classes.rb', line 71039

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



71044
71045
71046
# File 'lib/google/apis/compute_beta/classes.rb', line 71044

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


71049
71050
71051
# File 'lib/google/apis/compute_beta/classes.rb', line 71049

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71059
71060
71061
# File 'lib/google/apis/compute_beta/classes.rb', line 71059

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71064
71065
71066
# File 'lib/google/apis/compute_beta/classes.rb', line 71064

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71069
71070
71071
# File 'lib/google/apis/compute_beta/classes.rb', line 71069

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71076
71077
71078
71079
71080
71081
71082
71083
# File 'lib/google/apis/compute_beta/classes.rb', line 71076

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end