Class: Google::Apis::ComputeBeta::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



69748
69749
69750
# File 'lib/google/apis/compute_beta/classes.rb', line 69748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69716
69717
69718
# File 'lib/google/apis/compute_beta/classes.rb', line 69716

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



69721
69722
69723
# File 'lib/google/apis/compute_beta/classes.rb', line 69721

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


69726
69727
69728
# File 'lib/google/apis/compute_beta/classes.rb', line 69726

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69736
69737
69738
# File 'lib/google/apis/compute_beta/classes.rb', line 69736

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69741
69742
69743
# File 'lib/google/apis/compute_beta/classes.rb', line 69741

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69746
69747
69748
# File 'lib/google/apis/compute_beta/classes.rb', line 69746

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69753
69754
69755
69756
69757
69758
69759
69760
# File 'lib/google/apis/compute_beta/classes.rb', line 69753

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end