Class: Google::Apis::ComputeBeta::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



69689
69690
69691
# File 'lib/google/apis/compute_beta/classes.rb', line 69689

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69657
69658
69659
# File 'lib/google/apis/compute_beta/classes.rb', line 69657

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



69662
69663
69664
# File 'lib/google/apis/compute_beta/classes.rb', line 69662

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


69667
69668
69669
# File 'lib/google/apis/compute_beta/classes.rb', line 69667

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69677
69678
69679
# File 'lib/google/apis/compute_beta/classes.rb', line 69677

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69682
69683
69684
# File 'lib/google/apis/compute_beta/classes.rb', line 69682

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69687
69688
69689
# File 'lib/google/apis/compute_beta/classes.rb', line 69687

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69694
69695
69696
69697
69698
69699
69700
69701
# File 'lib/google/apis/compute_beta/classes.rb', line 69694

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end