Class: Google::Apis::ComputeBeta::TargetSslProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetSslProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetSslProxyList

Returns a new instance of TargetSslProxyList.



68837
68838
68839
# File 'lib/google/apis/compute_beta/classes.rb', line 68837

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68805
68806
68807
# File 'lib/google/apis/compute_beta/classes.rb', line 68805

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetSslProxy>

A list of TargetSslProxy resources. Corresponds to the JSON property items



68810
68811
68812
# File 'lib/google/apis/compute_beta/classes.rb', line 68810

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


68815
68816
68817
# File 'lib/google/apis/compute_beta/classes.rb', line 68815

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68825
68826
68827
# File 'lib/google/apis/compute_beta/classes.rb', line 68825

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68830
68831
68832
# File 'lib/google/apis/compute_beta/classes.rb', line 68830

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetSslProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68835
68836
68837
# File 'lib/google/apis/compute_beta/classes.rb', line 68835

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68842
68843
68844
68845
68846
68847
68848
68849
# File 'lib/google/apis/compute_beta/classes.rb', line 68842

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end