Class: Google::Apis::ComputeBeta::TargetSslProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetSslProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetSslProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetSslProxy>
A list of TargetSslProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetSslProxyList
constructor
A new instance of TargetSslProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetSslProxyList
Returns a new instance of TargetSslProxyList.
65516 65517 65518 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65516 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
65484 65485 65486 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65484 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetSslProxy>
A list of TargetSslProxy resources.
Corresponds to the JSON property items
65489 65490 65491 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65489 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
65494 65495 65496 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65494 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
65504 65505 65506 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65504 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
65509 65510 65511 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65509 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetSslProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
65514 65515 65516 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65514 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
65521 65522 65523 65524 65525 65526 65527 65528 |
# File 'lib/google/apis/compute_beta/classes.rb', line 65521 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |