Class: Google::Apis::ComputeBeta::TargetTcpProxiesScopedList::Warning

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Informational warning which replaces the list of backend services when the list is empty.

Defined Under Namespace

Classes: Datum

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Warning

Returns a new instance of Warning.



67762
67763
67764
# File 'lib/google/apis/compute_beta/classes.rb', line 67762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

[Output Only] A warning code, if applicable. For example, Compute Engine returns NO_RESULTS_ON_PAGE if there are no results in the response. Corresponds to the JSON property code

Returns:

  • (String)


67744
67745
67746
# File 'lib/google/apis/compute_beta/classes.rb', line 67744

def code
  @code
end

#dataArray<Google::Apis::ComputeBeta::TargetTcpProxiesScopedList::Warning::Datum>

[Output Only] Metadata about this warning in key: value format. For example: "data": [ "key": "scope", "value": "zones/us-east1-d" Corresponds to the JSON property data



67755
67756
67757
# File 'lib/google/apis/compute_beta/classes.rb', line 67755

def data
  @data
end

#messageString

[Output Only] A human-readable description of the warning code. Corresponds to the JSON property message

Returns:

  • (String)


67760
67761
67762
# File 'lib/google/apis/compute_beta/classes.rb', line 67760

def message
  @message
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67767
67768
67769
67770
67771
# File 'lib/google/apis/compute_beta/classes.rb', line 67767

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @data = args[:data] if args.key?(:data)
  @message = args[:message] if args.key?(:message)
end