Class: Google::Apis::ComputeBeta::TargetTcpProxy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetTcpProxy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Target TCP Proxy resource. A target TCP proxy is a component of a Proxy Network Load Balancer. The forwarding rule references the target TCP proxy, and the target proxy then references a backend service. For more information, readProxy Network Load Balancer overview.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#load_balancing_scheme ⇒ String
Specifies the type of load balancing scheme used by this target proxy.
-
#name ⇒ String
Name of the resource.
-
#proxy_bind ⇒ Boolean
(also: #proxy_bind?)
This field only applies when the forwarding rule that references this target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
-
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the backend, either NONE or PROXY_V1.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#service ⇒ String
URL to the BackendService resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxy
constructor
A new instance of TargetTcpProxy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxy
Returns a new instance of TargetTcpProxy.
71902 71903 71904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71902 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
71828 71829 71830 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71828 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
71834 71835 71836 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71834 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
71840 71841 71842 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71840 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#targetTcpProxy
for target TCP proxies.
Corresponds to the JSON property kind
71846 71847 71848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71846 def kind @kind end |
#load_balancing_scheme ⇒ String
Specifies the type of load balancing scheme used by this target proxy.
Corresponds to the JSON property loadBalancingScheme
71851 71852 71853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71851 def load_balancing_scheme @load_balancing_scheme end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
71862 71863 71864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71862 def name @name end |
#proxy_bind ⇒ Boolean Also known as: proxy_bind?
This field only applies when the forwarding rule that references this
target proxy has a loadBalancingScheme set toINTERNAL_SELF_MANAGED.
When this field is set to true, Envoy proxies set up inbound
traffic interception and bind to the IP address and port specified in the
forwarding rule. This is generally useful when using Traffic Director to
configure Envoy as a gateway or middle proxy (in other words, not a
sidecar proxy). The Envoy proxy listens for inbound requests and handles
requests when it receives them.
The default is false.
Corresponds to the JSON property proxyBind
71875 71876 71877 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71875 def proxy_bind @proxy_bind end |
#proxy_header ⇒ String
Specifies the type of proxy header to append before sending data to the
backend, either NONE or PROXY_V1. The default
is NONE.
Corresponds to the JSON property proxyHeader
71883 71884 71885 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71883 def proxy_header @proxy_header end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional TCP proxy
resides.
This field is not applicable to global TCP proxy.
Corresponds to the JSON property region
71890 71891 71892 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71890 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
71895 71896 71897 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71895 def self_link @self_link end |
#service ⇒ String
URL to the BackendService resource.
Corresponds to the JSON property service
71900 71901 71902 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71900 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71907 71908 71909 71910 71911 71912 71913 71914 71915 71916 71917 71918 71919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71907 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @load_balancing_scheme = args[:load_balancing_scheme] if args.key?(:load_balancing_scheme) @name = args[:name] if args.key?(:name) @proxy_bind = args[:proxy_bind] if args.key?(:proxy_bind) @proxy_header = args[:proxy_header] if args.key?(:proxy_header) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @service = args[:service] if args.key?(:service) end |