Class: Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
constructor
A new instance of TargetTcpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
Returns a new instance of TargetTcpProxyAggregatedList.
71568 71569 71570 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71568 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71529 71530 71531 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71529 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
Corresponds to the JSON property items
71534 71535 71536 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71534 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetTcpProxyAggregatedList for lists of Target
TCP Proxies.
Corresponds to the JSON property kind
71541 71542 71543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71541 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71551 71552 71553 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71551 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71556 71557 71558 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71556 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
71561 71562 71563 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71561 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71566 71567 71568 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71566 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71573 71574 71575 71576 71577 71578 71579 71580 71581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71573 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |