Class: Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



71564
71565
71566
# File 'lib/google/apis/compute_beta/classes.rb', line 71564

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71525
71526
71527
# File 'lib/google/apis/compute_beta/classes.rb', line 71525

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



71530
71531
71532
# File 'lib/google/apis/compute_beta/classes.rb', line 71530

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


71537
71538
71539
# File 'lib/google/apis/compute_beta/classes.rb', line 71537

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71547
71548
71549
# File 'lib/google/apis/compute_beta/classes.rb', line 71547

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71552
71553
71554
# File 'lib/google/apis/compute_beta/classes.rb', line 71552

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71557
71558
71559
# File 'lib/google/apis/compute_beta/classes.rb', line 71557

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71562
71563
71564
# File 'lib/google/apis/compute_beta/classes.rb', line 71562

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71569
71570
71571
71572
71573
71574
71575
71576
71577
# File 'lib/google/apis/compute_beta/classes.rb', line 71569

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end