Class: Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



70970
70971
70972
# File 'lib/google/apis/compute_beta/classes.rb', line 70970

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70931
70932
70933
# File 'lib/google/apis/compute_beta/classes.rb', line 70931

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



70936
70937
70938
# File 'lib/google/apis/compute_beta/classes.rb', line 70936

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


70943
70944
70945
# File 'lib/google/apis/compute_beta/classes.rb', line 70943

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70953
70954
70955
# File 'lib/google/apis/compute_beta/classes.rb', line 70953

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70958
70959
70960
# File 'lib/google/apis/compute_beta/classes.rb', line 70958

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70963
70964
70965
# File 'lib/google/apis/compute_beta/classes.rb', line 70963

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70968
70969
70970
# File 'lib/google/apis/compute_beta/classes.rb', line 70968

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70975
70976
70977
70978
70979
70980
70981
70982
70983
# File 'lib/google/apis/compute_beta/classes.rb', line 70975

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end