Class: Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



70121
70122
70123
# File 'lib/google/apis/compute_beta/classes.rb', line 70121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70082
70083
70084
# File 'lib/google/apis/compute_beta/classes.rb', line 70082

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



70087
70088
70089
# File 'lib/google/apis/compute_beta/classes.rb', line 70087

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


70094
70095
70096
# File 'lib/google/apis/compute_beta/classes.rb', line 70094

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70104
70105
70106
# File 'lib/google/apis/compute_beta/classes.rb', line 70104

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70109
70110
70111
# File 'lib/google/apis/compute_beta/classes.rb', line 70109

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70114
70115
70116
# File 'lib/google/apis/compute_beta/classes.rb', line 70114

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70119
70120
70121
# File 'lib/google/apis/compute_beta/classes.rb', line 70119

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70126
70127
70128
70129
70130
70131
70132
70133
70134
# File 'lib/google/apis/compute_beta/classes.rb', line 70126

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end