Class: Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
constructor
A new instance of TargetTcpProxyAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyAggregatedList
Returns a new instance of TargetTcpProxyAggregatedList.
67997 67998 67999 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
67958 67959 67960 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67958 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>
A list of TargetTcpProxiesScopedList resources.
Corresponds to the JSON property items
67963 67964 67965 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67963 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
targetTcpProxyAggregatedList for lists of Target
TCP Proxies.
Corresponds to the JSON property kind
67970 67971 67972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67970 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
67980 67981 67982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67980 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67985 67986 67987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67985 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67990 67991 67992 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67990 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67995 67996 67997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67995 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68002 68003 68004 68005 68006 68007 68008 68009 68010 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68002 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |