Class: Google::Apis::ComputeBeta::TargetTcpProxyAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyAggregatedList

Returns a new instance of TargetTcpProxyAggregatedList.



65889
65890
65891
# File 'lib/google/apis/compute_beta/classes.rb', line 65889

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


65850
65851
65852
# File 'lib/google/apis/compute_beta/classes.rb', line 65850

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetTcpProxiesScopedList>

A list of TargetTcpProxiesScopedList resources. Corresponds to the JSON property items



65855
65856
65857
# File 'lib/google/apis/compute_beta/classes.rb', line 65855

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# targetTcpProxyAggregatedList for lists of Target TCP Proxies. Corresponds to the JSON property kind

Returns:

  • (String)


65862
65863
65864
# File 'lib/google/apis/compute_beta/classes.rb', line 65862

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


65872
65873
65874
# File 'lib/google/apis/compute_beta/classes.rb', line 65872

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


65877
65878
65879
# File 'lib/google/apis/compute_beta/classes.rb', line 65877

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


65882
65883
65884
# File 'lib/google/apis/compute_beta/classes.rb', line 65882

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



65887
65888
65889
# File 'lib/google/apis/compute_beta/classes.rb', line 65887

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



65894
65895
65896
65897
65898
65899
65900
65901
65902
# File 'lib/google/apis/compute_beta/classes.rb', line 65894

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end