Class: Google::Apis::ComputeBeta::TargetTcpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetTcpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetTcpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetTcpProxy>
A list of TargetTcpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyList
constructor
A new instance of TargetTcpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyList
Returns a new instance of TargetTcpProxyList.
71689 71690 71691 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71689 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71657 71658 71659 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71657 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetTcpProxy>
A list of TargetTcpProxy resources.
Corresponds to the JSON property items
71662 71663 71664 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71662 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
71667 71668 71669 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71667 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71677 71678 71679 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71677 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71682 71683 71684 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71682 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71687 71688 71689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71687 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71694 71695 71696 71697 71698 71699 71700 71701 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71694 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |