Class: Google::Apis::ComputeBeta::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



71537
71538
71539
# File 'lib/google/apis/compute_beta/classes.rb', line 71537

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71505
71506
71507
# File 'lib/google/apis/compute_beta/classes.rb', line 71505

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



71510
71511
71512
# File 'lib/google/apis/compute_beta/classes.rb', line 71510

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


71515
71516
71517
# File 'lib/google/apis/compute_beta/classes.rb', line 71515

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71525
71526
71527
# File 'lib/google/apis/compute_beta/classes.rb', line 71525

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71530
71531
71532
# File 'lib/google/apis/compute_beta/classes.rb', line 71530

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71535
71536
71537
# File 'lib/google/apis/compute_beta/classes.rb', line 71535

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71542
71543
71544
71545
71546
71547
71548
71549
# File 'lib/google/apis/compute_beta/classes.rb', line 71542

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end