Class: Google::Apis::ComputeBeta::TargetTcpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetTcpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetTcpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetTcpProxy>
A list of TargetTcpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyList
constructor
A new instance of TargetTcpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyList
Returns a new instance of TargetTcpProxyList.
71095 71096 71097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71095 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71063 71064 71065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71063 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetTcpProxy>
A list of TargetTcpProxy resources.
Corresponds to the JSON property items
71068 71069 71070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71068 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
71073 71074 71075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71073 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71083 71084 71085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71083 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71088 71089 71090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71088 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71093 71094 71095 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71093 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71100 71101 71102 71103 71104 71105 71106 71107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71100 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |