Class: Google::Apis::ComputeBeta::TargetTcpProxyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetTcpProxy resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetTcpProxyList

Returns a new instance of TargetTcpProxyList.



70246
70247
70248
# File 'lib/google/apis/compute_beta/classes.rb', line 70246

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70214
70215
70216
# File 'lib/google/apis/compute_beta/classes.rb', line 70214

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetTcpProxy>

A list of TargetTcpProxy resources. Corresponds to the JSON property items



70219
70220
70221
# File 'lib/google/apis/compute_beta/classes.rb', line 70219

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70224
70225
70226
# File 'lib/google/apis/compute_beta/classes.rb', line 70224

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70234
70235
70236
# File 'lib/google/apis/compute_beta/classes.rb', line 70234

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70239
70240
70241
# File 'lib/google/apis/compute_beta/classes.rb', line 70239

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetTcpProxyList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70244
70245
70246
# File 'lib/google/apis/compute_beta/classes.rb', line 70244

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70251
70252
70253
70254
70255
70256
70257
70258
# File 'lib/google/apis/compute_beta/classes.rb', line 70251

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end