Class: Google::Apis::ComputeBeta::TargetTcpProxyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetTcpProxyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetTcpProxy resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetTcpProxy>
A list of TargetTcpProxy resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetTcpProxyList
constructor
A new instance of TargetTcpProxyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetTcpProxyList
Returns a new instance of TargetTcpProxyList.
69335 69336 69337 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69335 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
69303 69304 69305 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69303 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetTcpProxy>
A list of TargetTcpProxy resources.
Corresponds to the JSON property items
69308 69309 69310 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69308 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
69313 69314 69315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69313 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
69323 69324 69325 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69323 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69328 69329 69330 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69328 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetTcpProxyList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69333 69334 69335 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69333 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69340 69341 69342 69343 69344 69345 69346 69347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69340 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |