Class: Google::Apis::ComputeBeta::TargetTcpProxyList::Warning::Datum

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Datum

Returns a new instance of Datum.



71641
71642
71643
# File 'lib/google/apis/compute_beta/classes.rb', line 71641

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#keyString

[Output Only] A key that provides more detail on the warning being returned. For example, for warnings where there are no results in a list request for a particular zone, this key might be scope and the key value might be the zone name. Other examples might be a key indicating a deprecated resource and a suggested replacement, or a warning about invalid network settings (for example, if an instance attempts to perform IP forwarding but is not enabled for IP forwarding). Corresponds to the JSON property key

Returns:

  • (String)


71634
71635
71636
# File 'lib/google/apis/compute_beta/classes.rb', line 71634

def key
  @key
end

#valueString

[Output Only] A warning data value corresponding to the key. Corresponds to the JSON property value

Returns:

  • (String)


71639
71640
71641
# File 'lib/google/apis/compute_beta/classes.rb', line 71639

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71646
71647
71648
71649
# File 'lib/google/apis/compute_beta/classes.rb', line 71646

def update!(**args)
  @key = args[:key] if args.key?(:key)
  @value = args[:value] if args.key?(:value)
end