Class: Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



71954
71955
71956
# File 'lib/google/apis/compute_beta/classes.rb', line 71954

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71916
71917
71918
# File 'lib/google/apis/compute_beta/classes.rb', line 71916

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



71921
71922
71923
# File 'lib/google/apis/compute_beta/classes.rb', line 71921

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


71927
71928
71929
# File 'lib/google/apis/compute_beta/classes.rb', line 71927

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71937
71938
71939
# File 'lib/google/apis/compute_beta/classes.rb', line 71937

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71942
71943
71944
# File 'lib/google/apis/compute_beta/classes.rb', line 71942

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71947
71948
71949
# File 'lib/google/apis/compute_beta/classes.rb', line 71947

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71952
71953
71954
# File 'lib/google/apis/compute_beta/classes.rb', line 71952

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71959
71960
71961
71962
71963
71964
71965
71966
71967
# File 'lib/google/apis/compute_beta/classes.rb', line 71959

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end