Class: Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



71798
71799
71800
# File 'lib/google/apis/compute_beta/classes.rb', line 71798

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71760
71761
71762
# File 'lib/google/apis/compute_beta/classes.rb', line 71760

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



71765
71766
71767
# File 'lib/google/apis/compute_beta/classes.rb', line 71765

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


71771
71772
71773
# File 'lib/google/apis/compute_beta/classes.rb', line 71771

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71781
71782
71783
# File 'lib/google/apis/compute_beta/classes.rb', line 71781

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71786
71787
71788
# File 'lib/google/apis/compute_beta/classes.rb', line 71786

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71791
71792
71793
# File 'lib/google/apis/compute_beta/classes.rb', line 71791

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71796
71797
71798
# File 'lib/google/apis/compute_beta/classes.rb', line 71796

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71803
71804
71805
71806
71807
71808
71809
71810
71811
# File 'lib/google/apis/compute_beta/classes.rb', line 71803

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end