Class: Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



70507
70508
70509
# File 'lib/google/apis/compute_beta/classes.rb', line 70507

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70469
70470
70471
# File 'lib/google/apis/compute_beta/classes.rb', line 70469

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



70474
70475
70476
# File 'lib/google/apis/compute_beta/classes.rb', line 70474

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


70480
70481
70482
# File 'lib/google/apis/compute_beta/classes.rb', line 70480

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70490
70491
70492
# File 'lib/google/apis/compute_beta/classes.rb', line 70490

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70495
70496
70497
# File 'lib/google/apis/compute_beta/classes.rb', line 70495

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70500
70501
70502
# File 'lib/google/apis/compute_beta/classes.rb', line 70500

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70505
70506
70507
# File 'lib/google/apis/compute_beta/classes.rb', line 70505

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70512
70513
70514
70515
70516
70517
70518
70519
70520
# File 'lib/google/apis/compute_beta/classes.rb', line 70512

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end