Class: Google::Apis::ComputeBeta::TargetVpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayAggregatedList

Returns a new instance of TargetVpnGatewayAggregatedList.



66267
66268
66269
# File 'lib/google/apis/compute_beta/classes.rb', line 66267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


66229
66230
66231
# File 'lib/google/apis/compute_beta/classes.rb', line 66229

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::TargetVpnGatewaysScopedList>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



66234
66235
66236
# File 'lib/google/apis/compute_beta/classes.rb', line 66234

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


66240
66241
66242
# File 'lib/google/apis/compute_beta/classes.rb', line 66240

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


66250
66251
66252
# File 'lib/google/apis/compute_beta/classes.rb', line 66250

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


66255
66256
66257
# File 'lib/google/apis/compute_beta/classes.rb', line 66255

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


66260
66261
66262
# File 'lib/google/apis/compute_beta/classes.rb', line 66260

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::TargetVpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



66265
66266
66267
# File 'lib/google/apis/compute_beta/classes.rb', line 66265

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66272
66273
66274
66275
66276
66277
66278
66279
66280
# File 'lib/google/apis/compute_beta/classes.rb', line 66272

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end