Class: Google::Apis::ComputeBeta::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
72080 72081 72082 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72080 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72047 72048 72049 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72047 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
72052 72053 72054 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72052 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
72058 72059 72060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72058 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72068 72069 72070 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72068 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72073 72074 72075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72073 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72078 72079 72080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72078 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72085 72086 72087 72088 72089 72090 72091 72092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72085 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |