Class: Google::Apis::ComputeBeta::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
71956 71957 71958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71923 71924 71925 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71923 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
71928 71929 71930 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71928 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
71934 71935 71936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71934 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71944 71945 71946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71944 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71949 71950 71951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71949 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71954 71955 71956 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71954 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71961 71962 71963 71964 71965 71966 71967 71968 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71961 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |