Class: Google::Apis::ComputeBeta::TargetVpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of TargetVpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TargetVpnGatewayList

Returns a new instance of TargetVpnGatewayList.



71482
71483
71484
# File 'lib/google/apis/compute_beta/classes.rb', line 71482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71449
71450
71451
# File 'lib/google/apis/compute_beta/classes.rb', line 71449

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::TargetVpnGateway>

A list of TargetVpnGateway resources. Corresponds to the JSON property items



71454
71455
71456
# File 'lib/google/apis/compute_beta/classes.rb', line 71454

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway for target VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


71460
71461
71462
# File 'lib/google/apis/compute_beta/classes.rb', line 71460

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71470
71471
71472
# File 'lib/google/apis/compute_beta/classes.rb', line 71470

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71475
71476
71477
# File 'lib/google/apis/compute_beta/classes.rb', line 71475

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::TargetVpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71480
71481
71482
# File 'lib/google/apis/compute_beta/classes.rb', line 71480

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71487
71488
71489
71490
71491
71492
71493
71494
# File 'lib/google/apis/compute_beta/classes.rb', line 71487

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end