Class: Google::Apis::ComputeBeta::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
68509 68510 68511 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68509 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
68476 68477 68478 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68476 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
68481 68482 68483 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68481 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
68487 68488 68489 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68487 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
68497 68498 68499 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68497 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
68502 68503 68504 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68502 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
68507 68508 68509 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68507 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68514 68515 68516 68517 68518 68519 68520 68521 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68514 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |