Class: Google::Apis::ComputeBeta::TargetVpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TargetVpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of TargetVpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TargetVpnGatewayList
constructor
A new instance of TargetVpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TargetVpnGatewayList
Returns a new instance of TargetVpnGatewayList.
66393 66394 66395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66393 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66360 66361 66362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66360 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::TargetVpnGateway>
A list of TargetVpnGateway resources.
Corresponds to the JSON property items
66365 66366 66367 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66365 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#targetVpnGateway
for target VPN gateways.
Corresponds to the JSON property kind
66371 66372 66373 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66371 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66381 66382 66383 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66381 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66386 66387 66388 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66386 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::TargetVpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66391 66392 66393 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66391 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
66398 66399 66400 66401 66402 66403 66404 66405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66398 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |