Class: Google::Apis::ComputeBeta::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



72349
72350
72351
# File 'lib/google/apis/compute_beta/classes.rb', line 72349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


72302
72303
72304
# File 'lib/google/apis/compute_beta/classes.rb', line 72302

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


72308
72309
72310
# File 'lib/google/apis/compute_beta/classes.rb', line 72308

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


72314
72315
72316
# File 'lib/google/apis/compute_beta/classes.rb', line 72314

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


72320
72321
72322
# File 'lib/google/apis/compute_beta/classes.rb', line 72320

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


72326
72327
72328
# File 'lib/google/apis/compute_beta/classes.rb', line 72326

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


72332
72333
72334
# File 'lib/google/apis/compute_beta/classes.rb', line 72332

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeBeta::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



72337
72338
72339
# File 'lib/google/apis/compute_beta/classes.rb', line 72337

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


72342
72343
72344
# File 'lib/google/apis/compute_beta/classes.rb', line 72342

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


72347
72348
72349
# File 'lib/google/apis/compute_beta/classes.rb', line 72347

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72354
72355
72356
72357
72358
72359
72360
72361
72362
72363
72364
# File 'lib/google/apis/compute_beta/classes.rb', line 72354

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end