Class: Google::Apis::ComputeBeta::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



72345
72346
72347
# File 'lib/google/apis/compute_beta/classes.rb', line 72345

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


72298
72299
72300
# File 'lib/google/apis/compute_beta/classes.rb', line 72298

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


72304
72305
72306
# File 'lib/google/apis/compute_beta/classes.rb', line 72304

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


72310
72311
72312
# File 'lib/google/apis/compute_beta/classes.rb', line 72310

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


72316
72317
72318
# File 'lib/google/apis/compute_beta/classes.rb', line 72316

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


72322
72323
72324
# File 'lib/google/apis/compute_beta/classes.rb', line 72322

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


72328
72329
72330
# File 'lib/google/apis/compute_beta/classes.rb', line 72328

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeBeta::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



72333
72334
72335
# File 'lib/google/apis/compute_beta/classes.rb', line 72333

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


72338
72339
72340
# File 'lib/google/apis/compute_beta/classes.rb', line 72338

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


72343
72344
72345
# File 'lib/google/apis/compute_beta/classes.rb', line 72343

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72350
72351
72352
72353
72354
72355
72356
72357
72358
72359
72360
# File 'lib/google/apis/compute_beta/classes.rb', line 72350

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end