Class: Google::Apis::ComputeBeta::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



72193
72194
72195
# File 'lib/google/apis/compute_beta/classes.rb', line 72193

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


72146
72147
72148
# File 'lib/google/apis/compute_beta/classes.rb', line 72146

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


72152
72153
72154
# File 'lib/google/apis/compute_beta/classes.rb', line 72152

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


72158
72159
72160
# File 'lib/google/apis/compute_beta/classes.rb', line 72158

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


72164
72165
72166
# File 'lib/google/apis/compute_beta/classes.rb', line 72164

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


72170
72171
72172
# File 'lib/google/apis/compute_beta/classes.rb', line 72170

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


72176
72177
72178
# File 'lib/google/apis/compute_beta/classes.rb', line 72176

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeBeta::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



72181
72182
72183
# File 'lib/google/apis/compute_beta/classes.rb', line 72181

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


72186
72187
72188
# File 'lib/google/apis/compute_beta/classes.rb', line 72186

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


72191
72192
72193
# File 'lib/google/apis/compute_beta/classes.rb', line 72191

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72198
72199
72200
72201
72202
72203
72204
72205
72206
72207
72208
# File 'lib/google/apis/compute_beta/classes.rb', line 72198

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end