Class: Google::Apis::ComputeBeta::TestFailure
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::TestFailure
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyactualRedirectResponseCode. -
#actual_service ⇒ String
BackendService or BackendBucket returned by load balancer.
-
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with
urlRedirectcalculated by load balancer Corresponds to the JSON propertyexpectedRedirectResponseCode. -
#expected_service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
-
#headers ⇒ Array<Google::Apis::ComputeBeta::UrlMapTestHeader>
HTTP headers of the request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion including query parameters in the URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TestFailure
constructor
A new instance of TestFailure.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TestFailure
Returns a new instance of TestFailure.
71751 71752 71753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71751 def initialize(**args) update!(**args) end |
Instance Attribute Details
#actual_output_url ⇒ String
The actual output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property actualOutputUrl
71704 71705 71706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71704 def actual_output_url @actual_output_url end |
#actual_redirect_response_code ⇒ Fixnum
Actual HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property actualRedirectResponseCode
71710 71711 71712 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71710 def actual_redirect_response_code @actual_redirect_response_code end |
#actual_service ⇒ String
BackendService or BackendBucket returned by load
balancer.
Corresponds to the JSON property actualService
71716 71717 71718 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71716 def actual_service @actual_service end |
#expected_output_url ⇒ String
The expected output URL evaluated by a load balancer containing the scheme,
host, path and query parameters.
Corresponds to the JSON property expectedOutputUrl
71722 71723 71724 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71722 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
Expected HTTP status code for rule with urlRedirect
calculated by load balancer
Corresponds to the JSON property expectedRedirectResponseCode
71728 71729 71730 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71728 def expected_redirect_response_code @expected_redirect_response_code end |
#expected_service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
Corresponds to the JSON property expectedService
71734 71735 71736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71734 def expected_service @expected_service end |
#headers ⇒ Array<Google::Apis::ComputeBeta::UrlMapTestHeader>
HTTP headers of the request.
Corresponds to the JSON property headers
71739 71740 71741 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71739 def headers @headers end |
#host ⇒ String
Host portion of the URL.
Corresponds to the JSON property host
71744 71745 71746 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71744 def host @host end |
#path ⇒ String
Path portion including query parameters in the URL.
Corresponds to the JSON property path
71749 71750 71751 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71749 def path @path end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71756 71757 71758 71759 71760 71761 71762 71763 71764 71765 71766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71756 def update!(**args) @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url) @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code) @actual_service = args[:actual_service] if args.key?(:actual_service) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @expected_service = args[:expected_service] if args.key?(:expected_service) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) end |