Class: Google::Apis::ComputeBeta::TestFailure

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TestFailure

Returns a new instance of TestFailure.



70843
70844
70845
# File 'lib/google/apis/compute_beta/classes.rb', line 70843

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#actual_output_urlString

The actual output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property actualOutputUrl

Returns:

  • (String)


70796
70797
70798
# File 'lib/google/apis/compute_beta/classes.rb', line 70796

def actual_output_url
  @actual_output_url
end

#actual_redirect_response_codeFixnum

Actual HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property actualRedirectResponseCode

Returns:

  • (Fixnum)


70802
70803
70804
# File 'lib/google/apis/compute_beta/classes.rb', line 70802

def actual_redirect_response_code
  @actual_redirect_response_code
end

#actual_serviceString

BackendService or BackendBucket returned by load balancer. Corresponds to the JSON property actualService

Returns:

  • (String)


70808
70809
70810
# File 'lib/google/apis/compute_beta/classes.rb', line 70808

def actual_service
  @actual_service
end

#expected_output_urlString

The expected output URL evaluated by a load balancer containing the scheme, host, path and query parameters. Corresponds to the JSON property expectedOutputUrl

Returns:

  • (String)


70814
70815
70816
# File 'lib/google/apis/compute_beta/classes.rb', line 70814

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

Expected HTTP status code for rule with urlRedirect calculated by load balancer Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


70820
70821
70822
# File 'lib/google/apis/compute_beta/classes.rb', line 70820

def expected_redirect_response_code
  @expected_redirect_response_code
end

#expected_serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. Corresponds to the JSON property expectedService

Returns:

  • (String)


70826
70827
70828
# File 'lib/google/apis/compute_beta/classes.rb', line 70826

def expected_service
  @expected_service
end

#headersArray<Google::Apis::ComputeBeta::UrlMapTestHeader>

HTTP headers of the request. Corresponds to the JSON property headers



70831
70832
70833
# File 'lib/google/apis/compute_beta/classes.rb', line 70831

def headers
  @headers
end

#hostString

Host portion of the URL. Corresponds to the JSON property host

Returns:

  • (String)


70836
70837
70838
# File 'lib/google/apis/compute_beta/classes.rb', line 70836

def host
  @host
end

#pathString

Path portion including query parameters in the URL. Corresponds to the JSON property path

Returns:

  • (String)


70841
70842
70843
# File 'lib/google/apis/compute_beta/classes.rb', line 70841

def path
  @path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70848
70849
70850
70851
70852
70853
70854
70855
70856
70857
70858
# File 'lib/google/apis/compute_beta/classes.rb', line 70848

def update!(**args)
  @actual_output_url = args[:actual_output_url] if args.key?(:actual_output_url)
  @actual_redirect_response_code = args[:actual_redirect_response_code] if args.key?(:actual_redirect_response_code)
  @actual_service = args[:actual_service] if args.key?(:actual_service)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @expected_service = args[:expected_service] if args.key?(:expected_service)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
end