Class: Google::Apis::ComputeBeta::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Upcoming Maintenance notification information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



71879
71880
71881
# File 'lib/google/apis/compute_beta/classes.rb', line 71879

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

Indicates if the maintenance can be customer triggered. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


71837
71838
71839
# File 'lib/google/apis/compute_beta/classes.rb', line 71837

def can_reschedule
  @can_reschedule
end

#latest_window_start_timeString

The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format. Corresponds to the JSON property latestWindowStartTime

Returns:

  • (String)


71844
71845
71846
# File 'lib/google/apis/compute_beta/classes.rb', line 71844

def latest_window_start_time
  @latest_window_start_time
end

#maintenance_on_shutdownBoolean Also known as: maintenance_on_shutdown?

Indicates whether the UpcomingMaintenance will be triggered on VM shutdown. Corresponds to the JSON property maintenanceOnShutdown

Returns:

  • (Boolean)


71849
71850
71851
# File 'lib/google/apis/compute_beta/classes.rb', line 71849

def maintenance_on_shutdown
  @maintenance_on_shutdown
end

#maintenance_reasonsArray<String>

The reasons for the maintenance. Only valid for vms. Corresponds to the JSON property maintenanceReasons

Returns:

  • (Array<String>)


71855
71856
71857
# File 'lib/google/apis/compute_beta/classes.rb', line 71855

def maintenance_reasons
  @maintenance_reasons
end

#maintenance_statusString

Corresponds to the JSON property maintenanceStatus

Returns:

  • (String)


71860
71861
71862
# File 'lib/google/apis/compute_beta/classes.rb', line 71860

def maintenance_status
  @maintenance_status
end

#typeString

Defines the type of maintenance. Corresponds to the JSON property type

Returns:

  • (String)


71865
71866
71867
# File 'lib/google/apis/compute_beta/classes.rb', line 71865

def type
  @type
end

#window_end_timeString

The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowEndTime

Returns:

  • (String)


71871
71872
71873
# File 'lib/google/apis/compute_beta/classes.rb', line 71871

def window_end_time
  @window_end_time
end

#window_start_timeString

The current start time of the maintenance window. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowStartTime

Returns:

  • (String)


71877
71878
71879
# File 'lib/google/apis/compute_beta/classes.rb', line 71877

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71884
71885
71886
71887
71888
71889
71890
71891
71892
71893
# File 'lib/google/apis/compute_beta/classes.rb', line 71884

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time)
  @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown)
  @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons)
  @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end