Class: Google::Apis::ComputeBeta::UpcomingMaintenance
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UpcomingMaintenance
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Upcoming Maintenance notification information.
Instance Attribute Summary collapse
-
#can_reschedule ⇒ Boolean
(also: #can_reschedule?)
Indicates if the maintenance can be customer triggered.
-
#latest_window_start_time ⇒ String
The latest time for the planned maintenance window to start.
-
#maintenance_on_shutdown ⇒ Boolean
(also: #maintenance_on_shutdown?)
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
-
#maintenance_reasons ⇒ Array<String>
The reasons for the maintenance.
-
#maintenance_status ⇒ String
Corresponds to the JSON property
maintenanceStatus. -
#type ⇒ String
Defines the type of maintenance.
-
#window_end_time ⇒ String
The time by which the maintenance disruption will be completed.
-
#window_start_time ⇒ String
The current start time of the maintenance window.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpcomingMaintenance
constructor
A new instance of UpcomingMaintenance.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpcomingMaintenance
Returns a new instance of UpcomingMaintenance.
70123 70124 70125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70123 def initialize(**args) update!(**args) end |
Instance Attribute Details
#can_reschedule ⇒ Boolean Also known as: can_reschedule?
Indicates if the maintenance can be customer triggered.
Corresponds to the JSON property canReschedule
70081 70082 70083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70081 def can_reschedule @can_reschedule end |
#latest_window_start_time ⇒ String
The latest time for the planned maintenance window to start.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property latestWindowStartTime
70088 70089 70090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70088 def latest_window_start_time @latest_window_start_time end |
#maintenance_on_shutdown ⇒ Boolean Also known as: maintenance_on_shutdown?
Indicates whether the UpcomingMaintenance will be triggered on VM shutdown.
Corresponds to the JSON property maintenanceOnShutdown
70093 70094 70095 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70093 def maintenance_on_shutdown @maintenance_on_shutdown end |
#maintenance_reasons ⇒ Array<String>
The reasons for the maintenance. Only valid for vms.
Corresponds to the JSON property maintenanceReasons
70099 70100 70101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70099 def maintenance_reasons @maintenance_reasons end |
#maintenance_status ⇒ String
Corresponds to the JSON property maintenanceStatus
70104 70105 70106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70104 def maintenance_status @maintenance_status end |
#type ⇒ String
Defines the type of maintenance.
Corresponds to the JSON property type
70109 70110 70111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70109 def type @type end |
#window_end_time ⇒ String
The time by which the maintenance disruption will be completed.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property windowEndTime
70115 70116 70117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70115 def window_end_time @window_end_time end |
#window_start_time ⇒ String
The current start time of the maintenance window.
This timestamp value is in RFC3339 text format.
Corresponds to the JSON property windowStartTime
70121 70122 70123 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70121 def window_start_time @window_start_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70128 70129 70130 70131 70132 70133 70134 70135 70136 70137 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70128 def update!(**args) @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule) @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time) @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown) @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons) @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status) @type = args[:type] if args.key?(:type) @window_end_time = args[:window_end_time] if args.key?(:window_end_time) @window_start_time = args[:window_start_time] if args.key?(:window_start_time) end |