Class: Google::Apis::ComputeBeta::UpcomingMaintenance

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Upcoming Maintenance notification information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UpcomingMaintenance

Returns a new instance of UpcomingMaintenance.



66762
66763
66764
# File 'lib/google/apis/compute_beta/classes.rb', line 66762

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#can_rescheduleBoolean Also known as: can_reschedule?

Indicates if the maintenance can be customer triggered. Corresponds to the JSON property canReschedule

Returns:

  • (Boolean)


66720
66721
66722
# File 'lib/google/apis/compute_beta/classes.rb', line 66720

def can_reschedule
  @can_reschedule
end

#latest_window_start_timeString

The latest time for the planned maintenance window to start. This timestamp value is in RFC3339 text format. Corresponds to the JSON property latestWindowStartTime

Returns:

  • (String)


66727
66728
66729
# File 'lib/google/apis/compute_beta/classes.rb', line 66727

def latest_window_start_time
  @latest_window_start_time
end

#maintenance_on_shutdownBoolean Also known as: maintenance_on_shutdown?

Indicates whether the UpcomingMaintenance will be triggered on VM shutdown. Corresponds to the JSON property maintenanceOnShutdown

Returns:

  • (Boolean)


66732
66733
66734
# File 'lib/google/apis/compute_beta/classes.rb', line 66732

def maintenance_on_shutdown
  @maintenance_on_shutdown
end

#maintenance_reasonsArray<String>

The reasons for the maintenance. Only valid for vms. Corresponds to the JSON property maintenanceReasons

Returns:

  • (Array<String>)


66738
66739
66740
# File 'lib/google/apis/compute_beta/classes.rb', line 66738

def maintenance_reasons
  @maintenance_reasons
end

#maintenance_statusString

Corresponds to the JSON property maintenanceStatus

Returns:

  • (String)


66743
66744
66745
# File 'lib/google/apis/compute_beta/classes.rb', line 66743

def maintenance_status
  @maintenance_status
end

#typeString

Defines the type of maintenance. Corresponds to the JSON property type

Returns:

  • (String)


66748
66749
66750
# File 'lib/google/apis/compute_beta/classes.rb', line 66748

def type
  @type
end

#window_end_timeString

The time by which the maintenance disruption will be completed. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowEndTime

Returns:

  • (String)


66754
66755
66756
# File 'lib/google/apis/compute_beta/classes.rb', line 66754

def window_end_time
  @window_end_time
end

#window_start_timeString

The current start time of the maintenance window. This timestamp value is in RFC3339 text format. Corresponds to the JSON property windowStartTime

Returns:

  • (String)


66760
66761
66762
# File 'lib/google/apis/compute_beta/classes.rb', line 66760

def window_start_time
  @window_start_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



66767
66768
66769
66770
66771
66772
66773
66774
66775
66776
# File 'lib/google/apis/compute_beta/classes.rb', line 66767

def update!(**args)
  @can_reschedule = args[:can_reschedule] if args.key?(:can_reschedule)
  @latest_window_start_time = args[:latest_window_start_time] if args.key?(:latest_window_start_time)
  @maintenance_on_shutdown = args[:maintenance_on_shutdown] if args.key?(:maintenance_on_shutdown)
  @maintenance_reasons = args[:maintenance_reasons] if args.key?(:maintenance_reasons)
  @maintenance_status = args[:maintenance_status] if args.key?(:maintenance_status)
  @type = args[:type] if args.key?(:type)
  @window_end_time = args[:window_end_time] if args.key?(:window_end_time)
  @window_start_time = args[:window_start_time] if args.key?(:window_start_time)
end