Class: Google::Apis::ComputeBeta::UrlMap
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMap
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a URL Map resource. Compute Engine has two URL Map resources:
- Global
- Regional A URL map resource is a component of certain types of cloud load balancers and Traffic Director:
- urlMaps are used by global external Application Load Balancers, classic Application Load Balancers, and cross-region internal Application Load Balancers.
- regionUrlMaps are used by internal Application Load Balancers, regional external Application Load Balancers and regional internal Application Load Balancers. For a list of supported URL map features by the load balancer type, see the Load balancing features: Routing and traffic management table. For a list of supported URL map features for Traffic Director, see the Traffic Director features: Routing and traffic management table. This resource defines mappings from hostnames and URL paths to either a backend service or a backend bucket. To use the global urlMaps resource, the backend service must have a loadBalancingScheme of either EXTERNAL,EXTERNAL_MANAGED, or INTERNAL_SELF_MANAGED. To use the regionUrlMaps resource, the backend service must have aloadBalancingScheme of INTERNAL_MANAGED. For more information, read URL Map Concepts.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#default_custom_error_response_policy ⇒ Google::Apis::ComputeBeta::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the backend service or backend bucket responds with an error.
-
#default_route_action ⇒ Google::Apis::ComputeBeta::HttpRouteAction
defaultRouteAction takes effect when none of the hostRules match.
-
#default_service ⇒ String
The full or partial URL of the defaultService resource to which traffic is directed if none of the hostRules match.
-
#default_url_redirect ⇒ Google::Apis::ComputeBeta::HttpRedirectAction
Specifies settings for an HTTP redirect.
-
#description ⇒ String
An optional description of this resource.
-
#fingerprint ⇒ String
Fingerprint of this resource.
-
#header_action ⇒ Google::Apis::ComputeBeta::HttpHeaderAction
The request and response header transformations that take effect before the request is passed along to the selected backendService.
-
#host_rules ⇒ Array<Google::Apis::ComputeBeta::HostRule>
The list of host rules to use against the URL.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#path_matchers ⇒ Array<Google::Apis::ComputeBeta::PathMatcher>
The list of named PathMatchers to use against the URL.
-
#region ⇒ String
Output only.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ Google::Apis::ComputeBeta::UrlMapStatus
[Output Only] The status of the URL map.
-
#tests ⇒ Array<Google::Apis::ComputeBeta::UrlMapTest>
The list of expected URL mapping tests.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMap
constructor
A new instance of UrlMap.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMap
Returns a new instance of UrlMap.
71210 71211 71212 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71210 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
71083 71084 71085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71083 def @creation_timestamp end |
#default_custom_error_response_policy ⇒ Google::Apis::ComputeBeta::CustomErrorResponsePolicy
Specifies the custom error response policy that must be applied when the
backend service or backend bucket responds with an error.
Corresponds to the JSON property defaultCustomErrorResponsePolicy
71089 71090 71091 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71089 def default_custom_error_response_policy @default_custom_error_response_policy end |
#default_route_action ⇒ Google::Apis::ComputeBeta::HttpRouteAction
defaultRouteAction takes effect when none of the
hostRules match. The load balancer performs advanced routing
actions, such as URL rewrites and header transformations, before forwarding
the request to the selected backend.
Only one of defaultUrlRedirect, defaultService
or defaultRouteAction.weightedBackendService can be set.
URL maps for classic Application Load Balancers only support
the urlRewrite action within defaultRouteAction.
defaultRouteAction has no effect when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property defaultRouteAction
71104 71105 71106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71104 def default_route_action @default_route_action end |
#default_service ⇒ String
The full or partial URL of the defaultService resource to
which traffic is directed if none of the hostRules match.
If defaultRouteAction is also specified, advanced
routing actions, such as URL rewrites, take effect before sending the
request to the backend.
Only one of defaultUrlRedirect, defaultService
or defaultRouteAction.weightedBackendService can be set.
defaultService has no effect when the URL map is bound
to a target gRPC proxy that has the validateForProxyless field
set to true.
Corresponds to the JSON property defaultService
71118 71119 71120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71118 def default_service @default_service end |
#default_url_redirect ⇒ Google::Apis::ComputeBeta::HttpRedirectAction
Specifies settings for an HTTP redirect.
Corresponds to the JSON property defaultUrlRedirect
71123 71124 71125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71123 def default_url_redirect @default_url_redirect end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
71129 71130 71131 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71129 def description @description end |
#fingerprint ⇒ String
Fingerprint of this resource. A hash of the contents stored in this object.
This field is used in optimistic locking. This field is ignored when
inserting a UrlMap. An up-to-date fingerprint must be provided
in order to update the UrlMap, otherwise the request will
fail with error 412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a UrlMap.
Corresponds to the JSON property fingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
71141 71142 71143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71141 def fingerprint @fingerprint end |
#header_action ⇒ Google::Apis::ComputeBeta::HttpHeaderAction
The request and response header transformations that take effect before
the request is passed along to the selected backendService.
Corresponds to the JSON property headerAction
71147 71148 71149 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71147 def header_action @header_action end |
#host_rules ⇒ Array<Google::Apis::ComputeBeta::HostRule>
The list of host rules to use against the URL.
Corresponds to the JSON property hostRules
71152 71153 71154 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71152 def host_rules @host_rules end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
71158 71159 71160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71158 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#urlMaps for
url maps.
Corresponds to the JSON property kind
71164 71165 71166 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71164 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
71175 71176 71177 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71175 def name @name end |
#path_matchers ⇒ Array<Google::Apis::ComputeBeta::PathMatcher>
The list of named PathMatchers to use against the URL.
Corresponds to the JSON property pathMatchers
71180 71181 71182 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71180 def path_matchers @path_matchers end |
#region ⇒ String
Output only. [Output Only] URL of the region where the regional URL map
resides.
This field is not applicable to global URL maps.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
71189 71190 71191 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71189 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
71194 71195 71196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71194 def self_link @self_link end |
#status ⇒ Google::Apis::ComputeBeta::UrlMapStatus
[Output Only] The status of the URL map.
Corresponds to the JSON property status
71199 71200 71201 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71199 def status @status end |
#tests ⇒ Array<Google::Apis::ComputeBeta::UrlMapTest>
The list of expected URL mapping tests. Request to update theUrlMap succeeds
only if all test cases pass. You can specify a
maximum of 100 tests per UrlMap.
Not supported when the URL map is bound to a target gRPC proxy that
has validateForProxyless field set to true.
Corresponds to the JSON property tests
71208 71209 71210 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71208 def tests @tests end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71215 71216 71217 71218 71219 71220 71221 71222 71223 71224 71225 71226 71227 71228 71229 71230 71231 71232 71233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71215 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @default_custom_error_response_policy = args[:default_custom_error_response_policy] if args.key?(:default_custom_error_response_policy) @default_route_action = args[:default_route_action] if args.key?(:default_route_action) @default_service = args[:default_service] if args.key?(:default_service) @default_url_redirect = args[:default_url_redirect] if args.key?(:default_url_redirect) @description = args[:description] if args.key?(:description) @fingerprint = args[:fingerprint] if args.key?(:fingerprint) @header_action = args[:header_action] if args.key?(:header_action) @host_rules = args[:host_rules] if args.key?(:host_rules) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @path_matchers = args[:path_matchers] if args.key?(:path_matchers) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @tests = args[:tests] if args.key?(:tests) end |