Class: Google::Apis::ComputeBeta::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



72748
72749
72750
# File 'lib/google/apis/compute_beta/classes.rb', line 72748

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72716
72717
72718
# File 'lib/google/apis/compute_beta/classes.rb', line 72716

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



72721
72722
72723
# File 'lib/google/apis/compute_beta/classes.rb', line 72721

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


72726
72727
72728
# File 'lib/google/apis/compute_beta/classes.rb', line 72726

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72736
72737
72738
# File 'lib/google/apis/compute_beta/classes.rb', line 72736

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72741
72742
72743
# File 'lib/google/apis/compute_beta/classes.rb', line 72741

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72746
72747
72748
# File 'lib/google/apis/compute_beta/classes.rb', line 72746

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72753
72754
72755
72756
72757
72758
72759
72760
# File 'lib/google/apis/compute_beta/classes.rb', line 72753

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end