Class: Google::Apis::ComputeBeta::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



72624
72625
72626
# File 'lib/google/apis/compute_beta/classes.rb', line 72624

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72592
72593
72594
# File 'lib/google/apis/compute_beta/classes.rb', line 72592

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



72597
72598
72599
# File 'lib/google/apis/compute_beta/classes.rb', line 72597

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


72602
72603
72604
# File 'lib/google/apis/compute_beta/classes.rb', line 72602

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72612
72613
72614
# File 'lib/google/apis/compute_beta/classes.rb', line 72612

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72617
72618
72619
# File 'lib/google/apis/compute_beta/classes.rb', line 72617

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72622
72623
72624
# File 'lib/google/apis/compute_beta/classes.rb', line 72622

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72629
72630
72631
72632
72633
72634
72635
72636
# File 'lib/google/apis/compute_beta/classes.rb', line 72629

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end