Class: Google::Apis::ComputeBeta::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
72592 72593 72594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72560 72561 72562 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72560 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
72565 72566 72567 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72565 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
72570 72571 72572 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72570 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72580 72581 72582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72580 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72585 72586 72587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72585 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72590 72591 72592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72590 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72597 72598 72599 72600 72601 72602 72603 72604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72597 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |