Class: Google::Apis::ComputeBeta::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
72150 72151 72152 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72150 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72118 72119 72120 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72118 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
72123 72124 72125 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72123 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
72128 72129 72130 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72128 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72138 72139 72140 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72138 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72143 72144 72145 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72143 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72148 72149 72150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72148 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72155 72156 72157 72158 72159 72160 72161 72162 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72155 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |