Class: Google::Apis::ComputeBeta::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
70364 70365 70366 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70364 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
70332 70333 70334 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70332 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
70337 70338 70339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70337 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
70342 70343 70344 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70342 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
70352 70353 70354 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70352 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
70357 70358 70359 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70357 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
70362 70363 70364 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70362 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70369 70370 70371 70372 70373 70374 70375 70376 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70369 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |