Class: Google::Apis::ComputeBeta::UrlMapList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of UrlMap resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapList

Returns a new instance of UrlMapList.



69145
69146
69147
# File 'lib/google/apis/compute_beta/classes.rb', line 69145

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69113
69114
69115
# File 'lib/google/apis/compute_beta/classes.rb', line 69113

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::UrlMap>

A list of UrlMap resources. Corresponds to the JSON property items



69118
69119
69120
# File 'lib/google/apis/compute_beta/classes.rb', line 69118

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


69123
69124
69125
# File 'lib/google/apis/compute_beta/classes.rb', line 69123

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69133
69134
69135
# File 'lib/google/apis/compute_beta/classes.rb', line 69133

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69138
69139
69140
# File 'lib/google/apis/compute_beta/classes.rb', line 69138

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::UrlMapList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69143
69144
69145
# File 'lib/google/apis/compute_beta/classes.rb', line 69143

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69150
69151
69152
69153
69154
69155
69156
69157
# File 'lib/google/apis/compute_beta/classes.rb', line 69150

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end