Class: Google::Apis::ComputeBeta::UrlMapList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of UrlMap resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapList
constructor
A new instance of UrlMapList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapList
Returns a new instance of UrlMapList.
66997 66998 66999 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
66965 66966 66967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66965 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UrlMap>
A list of UrlMap resources.
Corresponds to the JSON property items
66970 66971 66972 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66970 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
66975 66976 66977 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66975 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
66985 66986 66987 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66985 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
66990 66991 66992 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66990 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
66995 66996 66997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 66995 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67002 67003 67004 67005 67006 67007 67008 67009 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67002 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |