Class: Google::Apis::ComputeBeta::UrlMapQuotaUsage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message representing the quota usage for a UrlMap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapQuotaUsage

Returns a new instance of UrlMapQuotaUsage.



72723
72724
72725
# File 'lib/google/apis/compute_beta/classes.rb', line 72723

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarding_rulesFixnum

Output only. The number of forwarding rules that uses this UrlMap. Corresponds to the JSON property forwardingRules

Returns:

  • (Fixnum)


72716
72717
72718
# File 'lib/google/apis/compute_beta/classes.rb', line 72716

def forwarding_rules
  @forwarding_rules
end

#unitsFixnum

Output only. The number of quota units calculated for this UrlMap. Corresponds to the JSON property units

Returns:

  • (Fixnum)


72721
72722
72723
# File 'lib/google/apis/compute_beta/classes.rb', line 72721

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72728
72729
72730
72731
# File 'lib/google/apis/compute_beta/classes.rb', line 72728

def update!(**args)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @units = args[:units] if args.key?(:units)
end