Class: Google::Apis::ComputeBeta::UrlMapQuotaUsage

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message representing the quota usage for a UrlMap.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapQuotaUsage

Returns a new instance of UrlMapQuotaUsage.



72691
72692
72693
# File 'lib/google/apis/compute_beta/classes.rb', line 72691

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#forwarding_rulesFixnum

Output only. The number of forwarding rules that uses this UrlMap. Corresponds to the JSON property forwardingRules

Returns:

  • (Fixnum)


72684
72685
72686
# File 'lib/google/apis/compute_beta/classes.rb', line 72684

def forwarding_rules
  @forwarding_rules
end

#unitsFixnum

Output only. The number of quota units calculated for this UrlMap. Corresponds to the JSON property units

Returns:

  • (Fixnum)


72689
72690
72691
# File 'lib/google/apis/compute_beta/classes.rb', line 72689

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72696
72697
72698
72699
# File 'lib/google/apis/compute_beta/classes.rb', line 72696

def update!(**args)
  @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules)
  @units = args[:units] if args.key?(:units)
end