Class: Google::Apis::ComputeBeta::UrlMapQuotaUsage
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapQuotaUsage
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Message representing the quota usage for a UrlMap.
Instance Attribute Summary collapse
-
#forwarding_rules ⇒ Fixnum
Output only.
-
#units ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapQuotaUsage
constructor
A new instance of UrlMapQuotaUsage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapQuotaUsage
Returns a new instance of UrlMapQuotaUsage.
70463 70464 70465 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70463 def initialize(**args) update!(**args) end |
Instance Attribute Details
#forwarding_rules ⇒ Fixnum
Output only. The number of forwarding rules that uses this UrlMap.
Corresponds to the JSON property forwardingRules
70456 70457 70458 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70456 def forwarding_rules @forwarding_rules end |
#units ⇒ Fixnum
Output only. The number of quota units calculated for this UrlMap.
Corresponds to the JSON property units
70461 70462 70463 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70461 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70468 70469 70470 70471 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70468 def update!(**args) @forwarding_rules = args[:forwarding_rules] if args.key?(:forwarding_rules) @units = args[:units] if args.key?(:units) end |