Class: Google::Apis::ComputeBeta::UrlMapTest
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapTest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Message for the expected URL mappings.
Instance Attribute Summary collapse
-
#description ⇒ String
Description of this test case.
-
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters.
-
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response.
-
#headers ⇒ Array<Google::Apis::ComputeBeta::UrlMapTestHeader>
HTTP headers for this request.
-
#host ⇒ String
Host portion of the URL.
-
#path ⇒ String
Path portion of the URL.
-
#service ⇒ String
Expected BackendService or BackendBucket resource the given URL should be mapped to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapTest
constructor
A new instance of UrlMapTest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapTest
Returns a new instance of UrlMapTest.
72958 72959 72960 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72958 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
Description of this test case.
Corresponds to the JSON property description
72903 72904 72905 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72903 def description @description end |
#expected_output_url ⇒ String
The expected output URL evaluated by the load balancer
containing the scheme, host, path and query parameters.
For rules that forward requests to backends, the test passes only
whenexpectedOutputUrl matches the request forwarded by
the load balancer to backends. For rules with urlRewrite,
the test verifies that the forwarded request matcheshostRewrite and
pathPrefixRewrite in theurlRewrite action. When service is specified,
expectedOutputUrls scheme is ignored.
For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches
the URL in the load balancer's
redirect response. If urlRedirect specifieshttps_redirect, the test passes
only if the scheme inexpectedOutputUrl is also set to HTTPS.
If urlRedirect specifies strip_query, the test
passes only if expectedOutputUrl does not contain any query
parameters.
expectedOutputUrl is optional whenservice is specified.
Corresponds to the JSON propertyexpectedOutputUrl`
72923 72924 72925 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72923 def expected_output_url @expected_output_url end |
#expected_redirect_response_code ⇒ Fixnum
For rules with urlRedirect, the test passes only
ifexpectedRedirectResponseCode matches the HTTP status code in
load balancer's redirect response.
expectedRedirectResponseCode cannot be set whenservice is set.
Corresponds to the JSON property expectedRedirectResponseCode
72931 72932 72933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72931 def expected_redirect_response_code @expected_redirect_response_code end |
#headers ⇒ Array<Google::Apis::ComputeBeta::UrlMapTestHeader>
HTTP headers for this request. If headers contains
a host header, then host must also match the header value.
Corresponds to the JSON property headers
72937 72938 72939 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72937 def headers @headers end |
#host ⇒ String
Host portion of the URL. If headers contains a host header,
then host must also match the header value.
Corresponds to the JSON property host
72943 72944 72945 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72943 def host @host end |
#path ⇒ String
Path portion of the URL.
Corresponds to the JSON property path
72948 72949 72950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72948 def path @path end |
#service ⇒ String
Expected BackendService or BackendBucket resource
the given URL should be mapped to.
The service field cannot
be set if expectedRedirectResponseCode is set.
Corresponds to the JSON property service
72956 72957 72958 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72956 def service @service end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72963 72964 72965 72966 72967 72968 72969 72970 72971 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72963 def update!(**args) @description = args[:description] if args.key?(:description) @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url) @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code) @headers = args[:headers] if args.key?(:headers) @host = args[:host] if args.key?(:host) @path = args[:path] if args.key?(:path) @service = args[:service] if args.key?(:service) end |