Class: Google::Apis::ComputeBeta::UrlMapTest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Message for the expected URL mappings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapTest

Returns a new instance of UrlMapTest.



71426
71427
71428
# File 'lib/google/apis/compute_beta/classes.rb', line 71426

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this test case. Corresponds to the JSON property description

Returns:

  • (String)


71371
71372
71373
# File 'lib/google/apis/compute_beta/classes.rb', line 71371

def description
  @description
end

#expected_output_urlString

The expected output URL evaluated by the load balancer containing the scheme, host, path and query parameters. For rules that forward requests to backends, the test passes only whenexpectedOutputUrl matches the request forwarded by the load balancer to backends. For rules with urlRewrite, the test verifies that the forwarded request matcheshostRewrite and pathPrefixRewrite in theurlRewrite action. When service is specified, expectedOutputUrls scheme is ignored. For rules with urlRedirect, the test passes only ifexpectedOutputUrl matches the URL in the load balancer's redirect response. If urlRedirect specifieshttps_redirect, the test passes only if the scheme inexpectedOutputUrl is also set to HTTPS. If urlRedirect specifies strip_query, the test passes only if expectedOutputUrl does not contain any query parameters. expectedOutputUrl is optional whenservice is specified. Corresponds to the JSON propertyexpectedOutputUrl`

Returns:

  • (String)


71391
71392
71393
# File 'lib/google/apis/compute_beta/classes.rb', line 71391

def expected_output_url
  @expected_output_url
end

#expected_redirect_response_codeFixnum

For rules with urlRedirect, the test passes only ifexpectedRedirectResponseCode matches the HTTP status code in load balancer's redirect response. expectedRedirectResponseCode cannot be set whenservice is set. Corresponds to the JSON property expectedRedirectResponseCode

Returns:

  • (Fixnum)


71399
71400
71401
# File 'lib/google/apis/compute_beta/classes.rb', line 71399

def expected_redirect_response_code
  @expected_redirect_response_code
end

#headersArray<Google::Apis::ComputeBeta::UrlMapTestHeader>

HTTP headers for this request. If headers contains a host header, then host must also match the header value. Corresponds to the JSON property headers



71405
71406
71407
# File 'lib/google/apis/compute_beta/classes.rb', line 71405

def headers
  @headers
end

#hostString

Host portion of the URL. If headers contains a host header, then host must also match the header value. Corresponds to the JSON property host

Returns:

  • (String)


71411
71412
71413
# File 'lib/google/apis/compute_beta/classes.rb', line 71411

def host
  @host
end

#pathString

Path portion of the URL. Corresponds to the JSON property path

Returns:

  • (String)


71416
71417
71418
# File 'lib/google/apis/compute_beta/classes.rb', line 71416

def path
  @path
end

#serviceString

Expected BackendService or BackendBucket resource the given URL should be mapped to. The service field cannot be set if expectedRedirectResponseCode is set. Corresponds to the JSON property service

Returns:

  • (String)


71424
71425
71426
# File 'lib/google/apis/compute_beta/classes.rb', line 71424

def service
  @service
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71431
71432
71433
71434
71435
71436
71437
71438
71439
# File 'lib/google/apis/compute_beta/classes.rb', line 71431

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @expected_output_url = args[:expected_output_url] if args.key?(:expected_output_url)
  @expected_redirect_response_code = args[:expected_redirect_response_code] if args.key?(:expected_redirect_response_code)
  @headers = args[:headers] if args.key?(:headers)
  @host = args[:host] if args.key?(:host)
  @path = args[:path] if args.key?(:path)
  @service = args[:service] if args.key?(:service)
end