Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
73090 73091 73092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73090 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73053 73054 73055 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73053 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
73058 73059 73060 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73058 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
73063 73064 73065 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73063 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73073 73074 73075 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73073 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73078 73079 73080 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73078 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
73083 73084 73085 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73083 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73088 73089 73090 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73088 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73095 73096 73097 73098 73099 73100 73101 73102 73103 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73095 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |