Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
72966 72967 72968 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72929 72930 72931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72929 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
72934 72935 72936 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72934 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
72939 72940 72941 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72939 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72949 72950 72951 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72949 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72954 72955 72956 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72954 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
72959 72960 72961 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72959 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72964 72965 72966 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72964 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72971 72972 72973 72974 72975 72976 72977 72978 72979 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72971 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |