Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



72462
72463
72464
# File 'lib/google/apis/compute_beta/classes.rb', line 72462

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72425
72426
72427
# File 'lib/google/apis/compute_beta/classes.rb', line 72425

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



72430
72431
72432
# File 'lib/google/apis/compute_beta/classes.rb', line 72430

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


72435
72436
72437
# File 'lib/google/apis/compute_beta/classes.rb', line 72435

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72445
72446
72447
# File 'lib/google/apis/compute_beta/classes.rb', line 72445

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72450
72451
72452
# File 'lib/google/apis/compute_beta/classes.rb', line 72450

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72455
72456
72457
# File 'lib/google/apis/compute_beta/classes.rb', line 72455

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72460
72461
72462
# File 'lib/google/apis/compute_beta/classes.rb', line 72460

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72467
72468
72469
72470
72471
72472
72473
72474
72475
# File 'lib/google/apis/compute_beta/classes.rb', line 72467

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end