Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UrlMapsAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UrlMapsAggregatedList
constructor
A new instance of UrlMapsAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UrlMapsAggregatedList
Returns a new instance of UrlMapsAggregatedList.
71617 71618 71619 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71617 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
71580 71581 71582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71580 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>
A list of UrlMapsScopedList resources.
Corresponds to the JSON property items
71585 71586 71587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71585 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
71590 71591 71592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71590 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
71600 71601 71602 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71600 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71605 71606 71607 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71605 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
71610 71611 71612 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71610 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UrlMapsAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71615 71616 71617 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71615 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71622 71623 71624 71625 71626 71627 71628 71629 71630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71622 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |