Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



71558
71559
71560
# File 'lib/google/apis/compute_beta/classes.rb', line 71558

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71521
71522
71523
# File 'lib/google/apis/compute_beta/classes.rb', line 71521

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



71526
71527
71528
# File 'lib/google/apis/compute_beta/classes.rb', line 71526

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


71531
71532
71533
# File 'lib/google/apis/compute_beta/classes.rb', line 71531

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71541
71542
71543
# File 'lib/google/apis/compute_beta/classes.rb', line 71541

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71546
71547
71548
# File 'lib/google/apis/compute_beta/classes.rb', line 71546

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71551
71552
71553
# File 'lib/google/apis/compute_beta/classes.rb', line 71551

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71556
71557
71558
# File 'lib/google/apis/compute_beta/classes.rb', line 71556

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71563
71564
71565
71566
71567
71568
71569
71570
71571
# File 'lib/google/apis/compute_beta/classes.rb', line 71563

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end