Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



70706
70707
70708
# File 'lib/google/apis/compute_beta/classes.rb', line 70706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70669
70670
70671
# File 'lib/google/apis/compute_beta/classes.rb', line 70669

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



70674
70675
70676
# File 'lib/google/apis/compute_beta/classes.rb', line 70674

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


70679
70680
70681
# File 'lib/google/apis/compute_beta/classes.rb', line 70679

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70689
70690
70691
# File 'lib/google/apis/compute_beta/classes.rb', line 70689

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70694
70695
70696
# File 'lib/google/apis/compute_beta/classes.rb', line 70694

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


70699
70700
70701
# File 'lib/google/apis/compute_beta/classes.rb', line 70699

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70704
70705
70706
# File 'lib/google/apis/compute_beta/classes.rb', line 70704

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70711
70712
70713
70714
70715
70716
70717
70718
70719
# File 'lib/google/apis/compute_beta/classes.rb', line 70711

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end