Class: Google::Apis::ComputeBeta::UrlMapsAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlMapsAggregatedList

Returns a new instance of UrlMapsAggregatedList.



69437
69438
69439
# File 'lib/google/apis/compute_beta/classes.rb', line 69437

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


69400
69401
69402
# File 'lib/google/apis/compute_beta/classes.rb', line 69400

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::UrlMapsScopedList>

A list of UrlMapsScopedList resources. Corresponds to the JSON property items



69405
69406
69407
# File 'lib/google/apis/compute_beta/classes.rb', line 69405

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


69410
69411
69412
# File 'lib/google/apis/compute_beta/classes.rb', line 69410

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


69420
69421
69422
# File 'lib/google/apis/compute_beta/classes.rb', line 69420

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


69425
69426
69427
# File 'lib/google/apis/compute_beta/classes.rb', line 69425

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


69430
69431
69432
# File 'lib/google/apis/compute_beta/classes.rb', line 69430

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UrlMapsAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



69435
69436
69437
# File 'lib/google/apis/compute_beta/classes.rb', line 69435

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



69442
69443
69444
69445
69446
69447
69448
69449
69450
# File 'lib/google/apis/compute_beta/classes.rb', line 69442

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end