Class: Google::Apis::ComputeBeta::UrlRewrite

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

The spec for modifying the path before sending the request to the matched backend service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlRewrite

Returns a new instance of UrlRewrite.



67598
67599
67600
# File 'lib/google/apis/compute_beta/classes.rb', line 67598

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#host_rewriteString

Before forwarding the request to the selected service, the request's host header is replaced with contents of hostRewrite. The value must be from 1 to 255 characters. Corresponds to the JSON property hostRewrite

Returns:

  • (String)


67563
67564
67565
# File 'lib/google/apis/compute_beta/classes.rb', line 67563

def host_rewrite
  @host_rewrite
end

#path_prefix_rewriteString

Before forwarding the request to the selected backend service, the matching portion of the request's path is replaced bypathPrefixRewrite. The value must be from 1 to 1024 characters. Corresponds to the JSON property pathPrefixRewrite

Returns:

  • (String)


67570
67571
67572
# File 'lib/google/apis/compute_beta/classes.rb', line 67570

def path_prefix_rewrite
  @path_prefix_rewrite
end

#path_template_rewriteString

If specified, the pattern rewrites the URL path (based on the :path header) using the HTTP template syntax. A corresponding path_template_match must be specified. Any template variables must exist in the path_template_match field.

  • -At least one variable must be specified in the path_template_match field
  • You can omit variables from the rewritten URL
  • The * and ** operators cannot be matched unless they have a corresponding variable name - e.g. format=* or var=**. For example, a path_template_match of /static/format=** could be rewritten as /static/content/format to prefix/content to the URL. Variables can also be re-ordered in a rewrite, so that /country/format/suffix=** can be rewritten as /content/format/country/suffix. At least one non-empty routeRules[].matchRules[].path_template_match is required. Only one of path_prefix_rewrite orpath_template_rewrite may be specified. Corresponds to the JSON property pathTemplateRewrite

Returns:

  • (String)


67596
67597
67598
# File 'lib/google/apis/compute_beta/classes.rb', line 67596

def path_template_rewrite
  @path_template_rewrite
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



67603
67604
67605
67606
67607
# File 'lib/google/apis/compute_beta/classes.rb', line 67603

def update!(**args)
  @host_rewrite = args[:host_rewrite] if args.key?(:host_rewrite)
  @path_prefix_rewrite = args[:path_prefix_rewrite] if args.key?(:path_prefix_rewrite)
  @path_template_rewrite = args[:path_template_rewrite] if args.key?(:path_template_rewrite)
end