Class: Google::Apis::ComputeBeta::UsableSubnetwork
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetwork
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Subnetwork which the current user has compute.subnetworks.use permission on.
Instance Attribute Summary collapse
-
#external_ipv6_prefix ⇒ String
Output only.
-
#internal_ipv6_prefix ⇒ String
Output only.
-
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
-
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds.
-
#network ⇒ String
Network URL.
-
#purpose ⇒ String
Corresponds to the JSON property
purpose. -
#role ⇒ String
The role of subnetwork.
-
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange>
Secondary IP ranges.
-
#stack_type ⇒ String
The stack type for the subnet.
-
#subnetwork ⇒ String
Subnetwork URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetwork
constructor
A new instance of UsableSubnetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetwork
Returns a new instance of UsableSubnetwork.
71097 71098 71099 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71097 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_ipv6_prefix ⇒ String
Output only. [Output Only] The external IPv6 address range that is assigned to
this
subnetwork.
Corresponds to the JSON property externalIpv6Prefix
71036 71037 71038 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71036 def external_ipv6_prefix @external_ipv6_prefix end |
#internal_ipv6_prefix ⇒ String
Output only. [Output Only] The internal IPv6 address range that is assigned to
this
subnetwork.
Corresponds to the JSON property internalIpv6Prefix
71043 71044 71045 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71043 def internal_ipv6_prefix @internal_ipv6_prefix end |
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
Corresponds to the JSON property ipCidrRange
71048 71049 71050 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71048 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds. It's immutable and can
only be specified during creation or the first time the subnet is updated
into IPV4_IPV6 dual stack.
Corresponds to the JSON property ipv6AccessType
71055 71056 71057 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71055 def ipv6_access_type @ipv6_access_type end |
#network ⇒ String
Network URL.
Corresponds to the JSON property network
71060 71061 71062 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71060 def network @network end |
#purpose ⇒ String
Corresponds to the JSON property purpose
71065 71066 71067 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71065 def purpose @purpose end |
#role ⇒ String
The role of subnetwork. Currently, this field is only used when
purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can
be set toACTIVE or BACKUP. An ACTIVE
subnetwork is one that is currently being used for Envoy-based load
balancers in a region. A BACKUP subnetwork is one that is
ready to be promoted to ACTIVE or is currently draining.
This field can be updated with a patch request.
Corresponds to the JSON property role
71076 71077 71078 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71076 def role @role end |
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange>
Secondary IP ranges.
Corresponds to the JSON property secondaryIpRanges
71081 71082 71083 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71081 def secondary_ip_ranges @secondary_ip_ranges end |
#stack_type ⇒ String
The stack type for the subnet. If set to IPV4_ONLY, new VMs
in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in
the subnet can be assigned both IPv4 and
IPv6 addresses. If not specified, IPV4_ONLY is used.
This field can be both set at resource creation time and updated usingpatch.
Corresponds to the JSON property stackType
71090 71091 71092 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71090 def stack_type @stack_type end |
#subnetwork ⇒ String
Subnetwork URL.
Corresponds to the JSON property subnetwork
71095 71096 71097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71095 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71102 71103 71104 71105 71106 71107 71108 71109 71110 71111 71112 71113 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71102 def update!(**args) @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix) @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @network = args[:network] if args.key?(:network) @purpose = args[:purpose] if args.key?(:purpose) @role = args[:role] if args.key?(:role) @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges) @stack_type = args[:stack_type] if args.key?(:stack_type) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |