Class: Google::Apis::ComputeBeta::UsableSubnetwork
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetwork
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Subnetwork which the current user has compute.subnetworks.use permission on.
Instance Attribute Summary collapse
-
#external_ipv6_prefix ⇒ String
Output only.
-
#internal_ipv6_prefix ⇒ String
Output only.
-
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
-
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds.
-
#network ⇒ String
Network URL.
-
#purpose ⇒ String
Corresponds to the JSON property
purpose. -
#role ⇒ String
The role of subnetwork.
-
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange>
Secondary IP ranges.
-
#stack_type ⇒ String
The stack type for the subnet.
-
#subnetwork ⇒ String
Subnetwork URL.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetwork
constructor
A new instance of UsableSubnetwork.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetwork
Returns a new instance of UsableSubnetwork.
67680 67681 67682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67680 def initialize(**args) update!(**args) end |
Instance Attribute Details
#external_ipv6_prefix ⇒ String
Output only. [Output Only] The external IPv6 address range that is assigned to
this
subnetwork.
Corresponds to the JSON property externalIpv6Prefix
67619 67620 67621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67619 def external_ipv6_prefix @external_ipv6_prefix end |
#internal_ipv6_prefix ⇒ String
Output only. [Output Only] The internal IPv6 address range that is assigned to
this
subnetwork.
Corresponds to the JSON property internalIpv6Prefix
67626 67627 67628 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67626 def internal_ipv6_prefix @internal_ipv6_prefix end |
#ip_cidr_range ⇒ String
The range of internal addresses that are owned by this subnetwork.
Corresponds to the JSON property ipCidrRange
67631 67632 67633 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67631 def ip_cidr_range @ip_cidr_range end |
#ipv6_access_type ⇒ String
The access type of IPv6 address this subnet holds. It's immutable and can
only be specified during creation or the first time the subnet is updated
into IPV4_IPV6 dual stack.
Corresponds to the JSON property ipv6AccessType
67638 67639 67640 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67638 def ipv6_access_type @ipv6_access_type end |
#network ⇒ String
Network URL.
Corresponds to the JSON property network
67643 67644 67645 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67643 def network @network end |
#purpose ⇒ String
Corresponds to the JSON property purpose
67648 67649 67650 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67648 def purpose @purpose end |
#role ⇒ String
The role of subnetwork. Currently, this field is only used when
purpose is set to GLOBAL_MANAGED_PROXY orREGIONAL_MANAGED_PROXY. The value can
be set toACTIVE or BACKUP. An ACTIVE
subnetwork is one that is currently being used for Envoy-based load
balancers in a region. A BACKUP subnetwork is one that is
ready to be promoted to ACTIVE or is currently draining.
This field can be updated with a patch request.
Corresponds to the JSON property role
67659 67660 67661 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67659 def role @role end |
#secondary_ip_ranges ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange>
Secondary IP ranges.
Corresponds to the JSON property secondaryIpRanges
67664 67665 67666 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67664 def secondary_ip_ranges @secondary_ip_ranges end |
#stack_type ⇒ String
The stack type for the subnet. If set to IPV4_ONLY, new VMs
in the subnet are assigned IPv4 addresses only. If set toIPV4_IPV6, new VMs in
the subnet can be assigned both IPv4 and
IPv6 addresses. If not specified, IPV4_ONLY is used.
This field can be both set at resource creation time and updated usingpatch.
Corresponds to the JSON property stackType
67673 67674 67675 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67673 def stack_type @stack_type end |
#subnetwork ⇒ String
Subnetwork URL.
Corresponds to the JSON property subnetwork
67678 67679 67680 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67678 def subnetwork @subnetwork end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67685 67686 67687 67688 67689 67690 67691 67692 67693 67694 67695 67696 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67685 def update!(**args) @external_ipv6_prefix = args[:external_ipv6_prefix] if args.key?(:external_ipv6_prefix) @internal_ipv6_prefix = args[:internal_ipv6_prefix] if args.key?(:internal_ipv6_prefix) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @ipv6_access_type = args[:ipv6_access_type] if args.key?(:ipv6_access_type) @network = args[:network] if args.key?(:network) @purpose = args[:purpose] if args.key?(:purpose) @role = args[:role] if args.key?(:role) @secondary_ip_ranges = args[:secondary_ip_ranges] if args.key?(:secondary_ip_ranges) @stack_type = args[:stack_type] if args.key?(:stack_type) @subnetwork = args[:subnetwork] if args.key?(:subnetwork) end |