Class: Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetworkSecondaryRange
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Secondary IP range of a usable subnetwork.
Instance Attribute Summary collapse
-
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
-
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding an alias IP range to a VM instance.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworkSecondaryRange
constructor
A new instance of UsableSubnetworkSecondaryRange.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworkSecondaryRange
Returns a new instance of UsableSubnetworkSecondaryRange.
67716 67717 67718 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67716 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ip_cidr_range ⇒ String
The range of IP addresses belonging to this subnetwork secondary range.
Corresponds to the JSON property ipCidrRange
67706 67707 67708 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67706 def ip_cidr_range @ip_cidr_range end |
#range_name ⇒ String
The name associated with this subnetwork secondary range, used when adding
an alias IP range to a VM instance.
The name must be 1-63 characters long, and comply withRFC1035.
The name must be unique within the subnetwork.
Corresponds to the JSON property rangeName
67714 67715 67716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67714 def range_name @range_name end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67721 67722 67723 67724 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67721 def update!(**args) @ip_cidr_range = args[:ip_cidr_range] if args.key?(:ip_cidr_range) @range_name = args[:range_name] if args.key?(:range_name) end |