Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
73592 73593 73594 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73592 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
73543 73544 73545 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73543 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
73548 73549 73550 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73548 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
73555 73556 73557 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73555 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
73568 73569 73570 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73568 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
73575 73576 73577 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73575 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73580 73581 73582 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73580 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
73585 73586 73587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73585 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73590 73591 73592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73590 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73597 73598 73599 73600 73601 73602 73603 73604 73605 73606 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73597 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |