Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



72958
72959
72960
# File 'lib/google/apis/compute_beta/classes.rb', line 72958

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72909
72910
72911
# File 'lib/google/apis/compute_beta/classes.rb', line 72909

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



72914
72915
72916
# File 'lib/google/apis/compute_beta/classes.rb', line 72914

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


72921
72922
72923
# File 'lib/google/apis/compute_beta/classes.rb', line 72921

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72934
72935
72936
# File 'lib/google/apis/compute_beta/classes.rb', line 72934

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeBeta::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



72941
72942
72943
# File 'lib/google/apis/compute_beta/classes.rb', line 72941

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72946
72947
72948
# File 'lib/google/apis/compute_beta/classes.rb', line 72946

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72951
72952
72953
# File 'lib/google/apis/compute_beta/classes.rb', line 72951

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72956
72957
72958
# File 'lib/google/apis/compute_beta/classes.rb', line 72956

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72963
72964
72965
72966
72967
72968
72969
72970
72971
72972
# File 'lib/google/apis/compute_beta/classes.rb', line 72963

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end