Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UsableSubnetworksAggregatedList

Returns a new instance of UsableSubnetworksAggregatedList.



72113
72114
72115
# File 'lib/google/apis/compute_beta/classes.rb', line 72113

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72064
72065
72066
# File 'lib/google/apis/compute_beta/classes.rb', line 72064

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::UsableSubnetwork>

[Output] A list of usable subnetwork URLs. Corresponds to the JSON property items



72069
72070
72071
# File 'lib/google/apis/compute_beta/classes.rb', line 72069

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# usableSubnetworksAggregatedList for aggregated lists of usable subnetworks. Corresponds to the JSON property kind

Returns:

  • (String)


72076
72077
72078
# File 'lib/google/apis/compute_beta/classes.rb', line 72076

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. In special cases listUsable may return 0 subnetworks andnextPageToken which still should be used to get the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72089
72090
72091
# File 'lib/google/apis/compute_beta/classes.rb', line 72089

def next_page_token
  @next_page_token
end

#scoped_warningsArray<Google::Apis::ComputeBeta::SubnetworksScopedWarning>

Output only. [Output Only] Informational warning messages for failures encountered from scopes. Corresponds to the JSON property scopedWarnings



72096
72097
72098
# File 'lib/google/apis/compute_beta/classes.rb', line 72096

def scoped_warnings
  @scoped_warnings
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72101
72102
72103
# File 'lib/google/apis/compute_beta/classes.rb', line 72101

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72106
72107
72108
# File 'lib/google/apis/compute_beta/classes.rb', line 72106

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



72111
72112
72113
# File 'lib/google/apis/compute_beta/classes.rb', line 72111

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72118
72119
72120
72121
72122
72123
72124
72125
72126
72127
# File 'lib/google/apis/compute_beta/classes.rb', line 72118

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end