Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
71202 71203 71204 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71202 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
71153 71154 71155 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71153 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
71158 71159 71160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71158 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
71165 71166 71167 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71165 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
71178 71179 71180 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71178 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
71185 71186 71187 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71185 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
71190 71191 71192 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71190 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
71195 71196 71197 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71195 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
71200 71201 71202 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71200 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
71207 71208 71209 71210 71211 71212 71213 71214 71215 71216 |
# File 'lib/google/apis/compute_beta/classes.rb', line 71207 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |