Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
69933 69934 69935 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69933 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
69884 69885 69886 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69884 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
69889 69890 69891 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69889 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
69896 69897 69898 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69896 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
69909 69910 69911 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69909 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
69916 69917 69918 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69916 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
69921 69922 69923 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69921 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
69926 69927 69928 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69926 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
69931 69932 69933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69931 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69938 69939 69940 69941 69942 69943 69944 69945 69946 69947 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69938 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |