Class: Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
constructor
A new instance of UsableSubnetworksAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UsableSubnetworksAggregatedList
Returns a new instance of UsableSubnetworksAggregatedList.
67784 67785 67786 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67784 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
67735 67736 67737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67735 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::UsableSubnetwork>
[Output] A list of usable subnetwork URLs.
Corresponds to the JSON property items
67740 67741 67742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67740 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
usableSubnetworksAggregatedList for aggregated lists
of usable subnetworks.
Corresponds to the JSON property kind
67747 67748 67749 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67747 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
In special cases listUsable may return 0 subnetworks andnextPageToken which
still should be used to get the
next page of results.
Corresponds to the JSON property nextPageToken
67760 67761 67762 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67760 def next_page_token @next_page_token end |
#scoped_warnings ⇒ Array<Google::Apis::ComputeBeta::SubnetworksScopedWarning>
Output only. [Output Only] Informational warning messages for failures
encountered from
scopes.
Corresponds to the JSON property scopedWarnings
67767 67768 67769 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67767 def scoped_warnings @scoped_warnings end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
67772 67773 67774 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67772 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
67777 67778 67779 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67777 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::UsableSubnetworksAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
67782 67783 67784 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67782 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
67789 67790 67791 67792 67793 67794 67795 67796 67797 67798 |
# File 'lib/google/apis/compute_beta/classes.rb', line 67789 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scoped_warnings = args[:scoped_warnings] if args.key?(:scoped_warnings) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |