Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsInterfaceNatMappings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contain information of Nat mapping for an interface of this endpoint.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappings

Returns a new instance of VmEndpointNatMappingsInterfaceNatMappings.



73636
73637
73638
# File 'lib/google/apis/compute_beta/classes.rb', line 73636

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drain_nat_ip_port_rangesArray<String>

Output only. List of all drain IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property drainNatIpPortRanges

Returns:

  • (Array<String>)


73595
73596
73597
# File 'lib/google/apis/compute_beta/classes.rb', line 73595

def drain_nat_ip_port_ranges
  @drain_nat_ip_port_ranges
end

#nat_ip_port_rangesArray<String>

Output only. A list of all IP:port-range mappings assigned to this interface. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property natIpPortRanges

Returns:

  • (Array<String>)


73603
73604
73605
# File 'lib/google/apis/compute_beta/classes.rb', line 73603

def nat_ip_port_ranges
  @nat_ip_port_ranges
end

#num_total_drain_nat_portsFixnum

Output only. Total number of drain ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field drain_nat_ip_port_ranges. Corresponds to the JSON property numTotalDrainNatPorts

Returns:

  • (Fixnum)


73610
73611
73612
# File 'lib/google/apis/compute_beta/classes.rb', line 73610

def num_total_drain_nat_ports
  @num_total_drain_nat_ports
end

#num_total_nat_portsFixnum

Output only. Total number of ports across all NAT IPs allocated to this interface. It equals to the aggregated port number in the field nat_ip_port_ranges. Corresponds to the JSON property numTotalNatPorts

Returns:

  • (Fixnum)


73617
73618
73619
# File 'lib/google/apis/compute_beta/classes.rb', line 73617

def num_total_nat_ports
  @num_total_nat_ports
end

#rule_mappingsArray<Google::Apis::ComputeBeta::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings>

Output only. Information about mappings provided by rules in this NAT. Corresponds to the JSON property ruleMappings



73622
73623
73624
# File 'lib/google/apis/compute_beta/classes.rb', line 73622

def rule_mappings
  @rule_mappings
end

#source_alias_ip_rangeString

Output only. Alias IP range for this interface endpoint. It will be a private (RFC 1918) IP range. Examples: "10.33.4.55/32", or "192.168.5.0/24". Corresponds to the JSON property sourceAliasIpRange

Returns:

  • (String)


73629
73630
73631
# File 'lib/google/apis/compute_beta/classes.rb', line 73629

def source_alias_ip_range
  @source_alias_ip_range
end

#source_virtual_ipString

Output only. Primary IP of the VM for this NIC. Corresponds to the JSON property sourceVirtualIp

Returns:

  • (String)


73634
73635
73636
# File 'lib/google/apis/compute_beta/classes.rb', line 73634

def source_virtual_ip
  @source_virtual_ip
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73641
73642
73643
73644
73645
73646
73647
73648
73649
# File 'lib/google/apis/compute_beta/classes.rb', line 73641

def update!(**args)
  @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges)
  @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges)
  @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports)
  @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports)
  @rule_mappings = args[:rule_mappings] if args.key?(:rule_mappings)
  @source_alias_ip_range = args[:source_alias_ip_range] if args.key?(:source_alias_ip_range)
  @source_virtual_ip = args[:source_virtual_ip] if args.key?(:source_virtual_ip)
end