Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains information of NAT Mappings provided by a NAT Rule.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings

Returns a new instance of VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.



73729
73730
73731
# File 'lib/google/apis/compute_beta/classes.rb', line 73729

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#drain_nat_ip_port_rangesArray<String>

Output only. List of all drain IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property drainNatIpPortRanges

Returns:

  • (Array<String>)


73696
73697
73698
# File 'lib/google/apis/compute_beta/classes.rb', line 73696

def drain_nat_ip_port_ranges
  @drain_nat_ip_port_ranges
end

#nat_ip_port_rangesArray<String>

Output only. A list of all IP:port-range mappings assigned to this interface by this rule. These ranges are inclusive, that is, both the first and the last ports can be used for NAT. Example: ["2.2.2.2:12345-12355", "1.1.1.1:2234-2234"]. Corresponds to the JSON property natIpPortRanges

Returns:

  • (Array<String>)


73706
73707
73708
# File 'lib/google/apis/compute_beta/classes.rb', line 73706

def nat_ip_port_ranges
  @nat_ip_port_ranges
end

#num_total_drain_nat_portsFixnum

Output only. Total number of drain ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field drain_nat_ip_port_ranges. Corresponds to the JSON property numTotalDrainNatPorts

Returns:

  • (Fixnum)


73714
73715
73716
# File 'lib/google/apis/compute_beta/classes.rb', line 73714

def num_total_drain_nat_ports
  @num_total_drain_nat_ports
end

#num_total_nat_portsFixnum

Output only. Total number of ports across all NAT IPs allocated to this interface by this rule. It equals the aggregated port number in the field nat_ip_port_ranges. Corresponds to the JSON property numTotalNatPorts

Returns:

  • (Fixnum)


73722
73723
73724
# File 'lib/google/apis/compute_beta/classes.rb', line 73722

def num_total_nat_ports
  @num_total_nat_ports
end

#rule_numberFixnum

Output only. Rule number of the NAT Rule. Corresponds to the JSON property ruleNumber

Returns:

  • (Fixnum)


73727
73728
73729
# File 'lib/google/apis/compute_beta/classes.rb', line 73727

def rule_number
  @rule_number
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73734
73735
73736
73737
73738
73739
73740
# File 'lib/google/apis/compute_beta/classes.rb', line 73734

def update!(**args)
  @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges)
  @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges)
  @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports)
  @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports)
  @rule_number = args[:rule_number] if args.key?(:rule_number)
end