Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains information of NAT Mappings provided by a NAT Rule.
Instance Attribute Summary collapse
-
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#nat_ip_port_ranges ⇒ Array<String>
Output only.
-
#num_total_drain_nat_ports ⇒ Fixnum
Output only.
-
#num_total_nat_ports ⇒ Fixnum
Output only.
-
#rule_number ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
constructor
A new instance of VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings
Returns a new instance of VmEndpointNatMappingsInterfaceNatMappingsNatRuleMappings.
70194 70195 70196 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70194 def initialize(**args) update!(**args) end |
Instance Attribute Details
#drain_nat_ip_port_ranges ⇒ Array<String>
Output only. List of all drain IP:port-range mappings assigned to this
interface
by this rule.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property drainNatIpPortRanges
70161 70162 70163 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70161 def drain_nat_ip_port_ranges @drain_nat_ip_port_ranges end |
#nat_ip_port_ranges ⇒ Array<String>
Output only. A list of all IP:port-range mappings assigned to this interface
by this
rule.
These ranges are inclusive, that is, both the first and the last
ports can be used for NAT. Example: ["2.2.2.2:12345-12355",
"1.1.1.1:2234-2234"].
Corresponds to the JSON property natIpPortRanges
70171 70172 70173 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70171 def nat_ip_port_ranges @nat_ip_port_ranges end |
#num_total_drain_nat_ports ⇒ Fixnum
Output only. Total number of drain ports across all NAT IPs allocated to this
interface by this rule.
It equals the aggregated port number in the field
drain_nat_ip_port_ranges.
Corresponds to the JSON property numTotalDrainNatPorts
70179 70180 70181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70179 def num_total_drain_nat_ports @num_total_drain_nat_ports end |
#num_total_nat_ports ⇒ Fixnum
Output only. Total number of ports across all NAT IPs allocated to this
interface
by this rule.
It equals the aggregated port number in the field nat_ip_port_ranges.
Corresponds to the JSON property numTotalNatPorts
70187 70188 70189 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70187 def num_total_nat_ports @num_total_nat_ports end |
#rule_number ⇒ Fixnum
Output only. Rule number of the NAT Rule.
Corresponds to the JSON property ruleNumber
70192 70193 70194 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70192 def rule_number @rule_number end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70199 70200 70201 70202 70203 70204 70205 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70199 def update!(**args) @drain_nat_ip_port_ranges = args[:drain_nat_ip_port_ranges] if args.key?(:drain_nat_ip_port_ranges) @nat_ip_port_ranges = args[:nat_ip_port_ranges] if args.key?(:nat_ip_port_ranges) @num_total_drain_nat_ports = args[:num_total_drain_nat_ports] if args.key?(:num_total_drain_nat_ports) @num_total_nat_ports = args[:num_total_nat_ports] if args.key?(:num_total_nat_ports) @rule_number = args[:rule_number] if args.key?(:rule_number) end |