Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmEndpointNatMappingsList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of VmEndpointNatMappings.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#result ⇒ Array<Google::Apis::ComputeBeta::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmEndpointNatMappingsList
constructor
A new instance of VmEndpointNatMappingsList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmEndpointNatMappingsList
Returns a new instance of VmEndpointNatMappingsList.
73905 73906 73907 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73905 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
73871 73872 73873 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73871 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
vmEndpointNatMappingsList for lists of Nat mappings of
VM endpoints.
Corresponds to the JSON property kind
73878 73879 73880 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73878 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73888 73889 73890 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73888 def next_page_token @next_page_token end |
#result ⇒ Array<Google::Apis::ComputeBeta::VmEndpointNatMappings>
[Output Only] A list of Nat mapping information of VM endpoints.
Corresponds to the JSON property result
73893 73894 73895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73893 def result @result end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73898 73899 73900 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73898 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::VmEndpointNatMappingsList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73903 73904 73905 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73903 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73910 73911 73912 73913 73914 73915 73916 73917 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73910 def update!(**args) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @result = args[:result] if args.key?(:result) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |