Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



73753
73754
73755
# File 'lib/google/apis/compute_beta/classes.rb', line 73753

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73719
73720
73721
# File 'lib/google/apis/compute_beta/classes.rb', line 73719

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


73726
73727
73728
# File 'lib/google/apis/compute_beta/classes.rb', line 73726

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73736
73737
73738
# File 'lib/google/apis/compute_beta/classes.rb', line 73736

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



73741
73742
73743
# File 'lib/google/apis/compute_beta/classes.rb', line 73741

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73746
73747
73748
# File 'lib/google/apis/compute_beta/classes.rb', line 73746

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73751
73752
73753
# File 'lib/google/apis/compute_beta/classes.rb', line 73751

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73758
73759
73760
73761
73762
73763
73764
73765
# File 'lib/google/apis/compute_beta/classes.rb', line 73758

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end