Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



73305
73306
73307
# File 'lib/google/apis/compute_beta/classes.rb', line 73305

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73271
73272
73273
# File 'lib/google/apis/compute_beta/classes.rb', line 73271

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


73278
73279
73280
# File 'lib/google/apis/compute_beta/classes.rb', line 73278

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73288
73289
73290
# File 'lib/google/apis/compute_beta/classes.rb', line 73288

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



73293
73294
73295
# File 'lib/google/apis/compute_beta/classes.rb', line 73293

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73298
73299
73300
# File 'lib/google/apis/compute_beta/classes.rb', line 73298

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73303
73304
73305
# File 'lib/google/apis/compute_beta/classes.rb', line 73303

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73310
73311
73312
73313
73314
73315
73316
73317
# File 'lib/google/apis/compute_beta/classes.rb', line 73310

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end