Class: Google::Apis::ComputeBeta::VmEndpointNatMappingsList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VmEndpointNatMappings.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmEndpointNatMappingsList

Returns a new instance of VmEndpointNatMappingsList.



70250
70251
70252
# File 'lib/google/apis/compute_beta/classes.rb', line 70250

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] The unique identifier for the resource. This identifier is defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


70216
70217
70218
# File 'lib/google/apis/compute_beta/classes.rb', line 70216

def id
  @id
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# vmEndpointNatMappingsList for lists of Nat mappings of VM endpoints. Corresponds to the JSON property kind

Returns:

  • (String)


70223
70224
70225
# File 'lib/google/apis/compute_beta/classes.rb', line 70223

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


70233
70234
70235
# File 'lib/google/apis/compute_beta/classes.rb', line 70233

def next_page_token
  @next_page_token
end

#resultArray<Google::Apis::ComputeBeta::VmEndpointNatMappings>

[Output Only] A list of Nat mapping information of VM endpoints. Corresponds to the JSON property result



70238
70239
70240
# File 'lib/google/apis/compute_beta/classes.rb', line 70238

def result
  @result
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


70243
70244
70245
# File 'lib/google/apis/compute_beta/classes.rb', line 70243

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VmEndpointNatMappingsList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



70248
70249
70250
# File 'lib/google/apis/compute_beta/classes.rb', line 70248

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70255
70256
70257
70258
70259
70260
70261
70262
# File 'lib/google/apis/compute_beta/classes.rb', line 70255

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @result = args[:result] if args.key?(:result)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end