Class: Google::Apis::ComputeBeta::VmExtensionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmExtensionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a VM extension policy.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#extension_policies ⇒ Hash<String,Google::Apis::ComputeBeta::VmExtensionPolicyExtensionPolicy>
Required.
-
#global_resource_link ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#instance_selectors ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicyInstanceSelector>
Optional.
-
#kind ⇒ String
Output only.
-
#managed_by_global ⇒ Boolean
(also: #managed_by_global?)
Optional.
-
#name ⇒ String
Name of the resource.
-
#priority ⇒ Fixnum
Optional.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Optional.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicy
constructor
A new instance of VmExtensionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicy
Returns a new instance of VmExtensionPolicy.
73589 73590 73591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73589 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
73495 73496 73497 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73495 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
73500 73501 73502 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73500 def description @description end |
#extension_policies ⇒ Hash<String,Google::Apis::ComputeBeta::VmExtensionPolicyExtensionPolicy>
Required. A map of extension names (for example, "ops-agent") to their
corresponding
policy configurations.
Corresponds to the JSON property extensionPolicies
73507 73508 73509 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73507 def extension_policies @extension_policies end |
#global_resource_link ⇒ String
Optional. Output only. [Output Only] Link to the global policy that manages
this zone policy, if
applicable.
Corresponds to the JSON property globalResourceLink
73514 73515 73516 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73514 def global_resource_link @global_resource_link end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
73521 73522 73523 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73521 def id @id end |
#instance_selectors ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicyInstanceSelector>
Optional. Selectors to target VMs for this policy. VMs are selected if they
match
any of the provided selectors (logical OR). If this list is empty, the
policy applies to all VMs.
Corresponds to the JSON property instanceSelectors
73529 73530 73531 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73529 def instance_selectors @instance_selectors end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
vmExtensionPolicy.
Corresponds to the JSON property kind
73535 73536 73537 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73535 def kind @kind end |
#managed_by_global ⇒ Boolean Also known as: managed_by_global?
Optional. Output only. [Output Only] Indicates if this policy is managed by a
global policy.
Corresponds to the JSON property managedByGlobal
73541 73542 73543 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73541 def managed_by_global @managed_by_global end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
73553 73554 73555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73553 def name @name end |
#priority ⇒ Fixnum
Optional. Priority of this policy. Used to resolve conflicts when multiple
policies
apply to the same extension.
The policy priority is an integer from 0 to 65535, inclusive. Lower
integers indicate higher priorities. If you do not specify a priority when
creating a rule, it is assigned a priority of 1000. If priorities are
equal, the policy with the most recent creation timestamp takes precedence.
Corresponds to the JSON property priority
73564 73565 73566 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73564 def priority @priority end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
73570 73571 73572 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73570 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
73575 73576 73577 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73575 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Optional. Output only. [Output Only] Current state of the policy: ACTIVE or
DELETING.
Corresponds to the JSON property state
73581 73582 73583 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73581 def state @state end |
#update_timestamp ⇒ String
Output only. [Output Only] Update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
73587 73588 73589 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73587 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73594 73595 73596 73597 73598 73599 73600 73601 73602 73603 73604 73605 73606 73607 73608 73609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73594 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @extension_policies = args[:extension_policies] if args.key?(:extension_policies) @global_resource_link = args[:global_resource_link] if args.key?(:global_resource_link) @id = args[:id] if args.key?(:id) @instance_selectors = args[:instance_selectors] if args.key?(:instance_selectors) @kind = args[:kind] if args.key?(:kind) @managed_by_global = args[:managed_by_global] if args.key?(:managed_by_global) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |