Class: Google::Apis::ComputeBeta::VmExtensionPolicy
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmExtensionPolicy
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a VM extension policy.
Instance Attribute Summary collapse
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#extension_policies ⇒ Hash<String,Google::Apis::ComputeBeta::VmExtensionPolicyExtensionPolicy>
Required.
-
#global_resource_link ⇒ String
Optional.
-
#id ⇒ Fixnum
Output only.
-
#instance_selectors ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicyInstanceSelector>
Optional.
-
#kind ⇒ String
Output only.
-
#managed_by_global ⇒ Boolean
(also: #managed_by_global?)
Optional.
-
#name ⇒ String
Name of the resource.
-
#priority ⇒ Fixnum
Optional.
-
#self_link ⇒ String
Output only.
-
#self_link_with_id ⇒ String
Output only.
-
#state ⇒ String
Optional.
-
#update_timestamp ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicy
constructor
A new instance of VmExtensionPolicy.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicy
Returns a new instance of VmExtensionPolicy.
68385 68386 68387 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68385 def initialize(**args) update!(**args) end |
Instance Attribute Details
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
68291 68292 68293 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68291 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource.
Corresponds to the JSON property description
68296 68297 68298 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68296 def description @description end |
#extension_policies ⇒ Hash<String,Google::Apis::ComputeBeta::VmExtensionPolicyExtensionPolicy>
Required. A map of extension names (e.g., "cloudops") to their corresponding
policy
configurations.
Corresponds to the JSON property extensionPolicies
68303 68304 68305 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68303 def extension_policies @extension_policies end |
#global_resource_link ⇒ String
Optional. Output only. [Output Only] Link to the global policy that manages
this zone policy, if
applicable.
Corresponds to the JSON property globalResourceLink
68310 68311 68312 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68310 def global_resource_link @global_resource_link end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource. This
identifier is
defined by the server.
Corresponds to the JSON property id
68317 68318 68319 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68317 def id @id end |
#instance_selectors ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicyInstanceSelector>
Optional. Selectors to target VMs for this policy. VMs are selected if they
match
any of the provided selectors (logical OR). If this list is empty, the
policy applies to all VMs.
Corresponds to the JSON property instanceSelectors
68325 68326 68327 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68325 def instance_selectors @instance_selectors end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#
vmExtensionPolicy.
Corresponds to the JSON property kind
68331 68332 68333 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68331 def kind @kind end |
#managed_by_global ⇒ Boolean Also known as: managed_by_global?
Optional. Output only. [Output Only] Indicates if this policy is managed by a
global policy.
Corresponds to the JSON property managedByGlobal
68337 68338 68339 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68337 def managed_by_global @managed_by_global end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])?
which means the first character must be a lowercase letter, and all
following characters must be a dash, lowercase letter, or digit, except
the last character, which cannot be a dash.
Corresponds to the JSON property name
68349 68350 68351 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68349 def name @name end |
#priority ⇒ Fixnum
Optional. Priority of this policy. Used to resolve conflicts when multiple
policies
apply to the same extension.
The policy priority is an integer from 0 to 65535, inclusive. Lower
integers indicate higher priorities. If you do not specify a priority when
creating a rule, it is assigned a priority of 1000. If priorities are
equal, the policy with the more recent creation timestamp takes precedence.
Corresponds to the JSON property priority
68360 68361 68362 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68360 def priority @priority end |
#self_link ⇒ String
Output only. [Output Only] Server-defined fully-qualified URL for this
resource.
Corresponds to the JSON property selfLink
68366 68367 68368 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68366 def self_link @self_link end |
#self_link_with_id ⇒ String
Output only. [Output Only] Server-defined URL for this resource's resource id.
Corresponds to the JSON property selfLinkWithId
68371 68372 68373 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68371 def self_link_with_id @self_link_with_id end |
#state ⇒ String
Optional. Output only. [Output Only] Current state of the policy: ACTIVE or
DELETING.
Corresponds to the JSON property state
68377 68378 68379 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68377 def state @state end |
#update_timestamp ⇒ String
Output only. [Output Only] Update timestamp inRFC3339
text format.
Corresponds to the JSON property updateTimestamp
68383 68384 68385 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68383 def @update_timestamp end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
68390 68391 68392 68393 68394 68395 68396 68397 68398 68399 68400 68401 68402 68403 68404 68405 |
# File 'lib/google/apis/compute_beta/classes.rb', line 68390 def update!(**args) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @extension_policies = args[:extension_policies] if args.key?(:extension_policies) @global_resource_link = args[:global_resource_link] if args.key?(:global_resource_link) @id = args[:id] if args.key?(:id) @instance_selectors = args[:instance_selectors] if args.key?(:instance_selectors) @kind = args[:kind] if args.key?(:kind) @managed_by_global = args[:managed_by_global] if args.key?(:managed_by_global) @name = args[:name] if args.key?(:name) @priority = args[:priority] if args.key?(:priority) @self_link = args[:self_link] if args.key?(:self_link) @self_link_with_id = args[:self_link_with_id] if args.key?(:self_link_with_id) @state = args[:state] if args.key?(:state) @update_timestamp = args[:update_timestamp] if args.key?(:update_timestamp) end |