Class: Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response for the aggregated list of VM extension policies.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
constructor
A new instance of VmExtensionPolicyAggregatedListResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse
Returns a new instance of VmExtensionPolicyAggregatedListResponse.
74143 74144 74145 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74143 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
74099 74100 74101 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74099 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74104 74105 74106 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74104 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VmExtensionPoliciesScopedList>
A list of VmExtensionPoliciesScopedList resources.
Corresponds to the JSON property items
74109 74110 74111 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74109 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Alwayscompute#
VmExtensionPolicyAggregatedList for lists of
VmExtensionPolicies.
Corresponds to the JSON property kind
74116 74117 74118 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74116 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74126 74127 74128 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74126 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74131 74132 74133 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74131 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74136 74137 74138 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74136 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74141 74142 74143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74141 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74148 74149 74150 74151 74152 74153 74154 74155 74156 74157 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74148 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |