Class: Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



73663
73664
73665
# File 'lib/google/apis/compute_beta/classes.rb', line 73663

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


73619
73620
73621
# File 'lib/google/apis/compute_beta/classes.rb', line 73619

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73624
73625
73626
# File 'lib/google/apis/compute_beta/classes.rb', line 73624

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



73629
73630
73631
# File 'lib/google/apis/compute_beta/classes.rb', line 73629

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


73636
73637
73638
# File 'lib/google/apis/compute_beta/classes.rb', line 73636

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73646
73647
73648
# File 'lib/google/apis/compute_beta/classes.rb', line 73646

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73651
73652
73653
# File 'lib/google/apis/compute_beta/classes.rb', line 73651

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73656
73657
73658
# File 'lib/google/apis/compute_beta/classes.rb', line 73656

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73661
73662
73663
# File 'lib/google/apis/compute_beta/classes.rb', line 73661

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73668
73669
73670
73671
73672
73673
73674
73675
73676
73677
# File 'lib/google/apis/compute_beta/classes.rb', line 73668

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end