Class: Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



71877
71878
71879
# File 'lib/google/apis/compute_beta/classes.rb', line 71877

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


71833
71834
71835
# File 'lib/google/apis/compute_beta/classes.rb', line 71833

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71838
71839
71840
# File 'lib/google/apis/compute_beta/classes.rb', line 71838

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



71843
71844
71845
# File 'lib/google/apis/compute_beta/classes.rb', line 71843

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


71850
71851
71852
# File 'lib/google/apis/compute_beta/classes.rb', line 71850

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71860
71861
71862
# File 'lib/google/apis/compute_beta/classes.rb', line 71860

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71865
71866
71867
# File 'lib/google/apis/compute_beta/classes.rb', line 71865

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71870
71871
71872
# File 'lib/google/apis/compute_beta/classes.rb', line 71870

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71875
71876
71877
# File 'lib/google/apis/compute_beta/classes.rb', line 71875

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71882
71883
71884
71885
71886
71887
71888
71889
71890
71891
# File 'lib/google/apis/compute_beta/classes.rb', line 71882

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end