Class: Google::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response for the aggregated list of VM extension policies.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyAggregatedListResponse

Returns a new instance of VmExtensionPolicyAggregatedListResponse.



68459
68460
68461
# File 'lib/google/apis/compute_beta/classes.rb', line 68459

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


68415
68416
68417
# File 'lib/google/apis/compute_beta/classes.rb', line 68415

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


68420
68421
68422
# File 'lib/google/apis/compute_beta/classes.rb', line 68420

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VmExtensionPoliciesScopedList>

A list of VmExtensionPoliciesScopedList resources. Corresponds to the JSON property items



68425
68426
68427
# File 'lib/google/apis/compute_beta/classes.rb', line 68425

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Alwayscompute# VmExtensionPolicyAggregatedList for lists of VmExtensionPolicies. Corresponds to the JSON property kind

Returns:

  • (String)


68432
68433
68434
# File 'lib/google/apis/compute_beta/classes.rb', line 68432

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


68442
68443
68444
# File 'lib/google/apis/compute_beta/classes.rb', line 68442

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


68447
68448
68449
# File 'lib/google/apis/compute_beta/classes.rb', line 68447

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


68452
68453
68454
# File 'lib/google/apis/compute_beta/classes.rb', line 68452

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VmExtensionPolicyAggregatedListResponse::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



68457
68458
68459
# File 'lib/google/apis/compute_beta/classes.rb', line 68457

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



68464
68465
68466
68467
68468
68469
68470
68471
68472
68473
# File 'lib/google/apis/compute_beta/classes.rb', line 68464

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end