Class: Google::Apis::ComputeBeta::VmExtensionPolicyLabelSelector

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A LabelSelector is applied to a VM only if it matches all the specified labels.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyLabelSelector

Returns a new instance of VmExtensionPolicyLabelSelector.



74418
74419
74420
# File 'lib/google/apis/compute_beta/classes.rb', line 74418

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inclusion_labelsHash<String,String>

Optional. A map of key-value pairs representing VM labels. VMs must have all of the labels specified in this map to be selected (logical AND). e.g. If the inclusion_labels are ("key1", "value1"), ("key2", "value2"), the VM labels must contain both ("key1", "value1") and ("key2", "value2") to be selected. If the VM labels are ("key1", "value1") and ("something", "else"), it will not be selected. If the map is empty, it's considered a match. Corresponds to the JSON property inclusionLabels

Returns:

  • (Hash<String,String>)


74416
74417
74418
# File 'lib/google/apis/compute_beta/classes.rb', line 74416

def inclusion_labels
  @inclusion_labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74423
74424
74425
# File 'lib/google/apis/compute_beta/classes.rb', line 74423

def update!(**args)
  @inclusion_labels = args[:inclusion_labels] if args.key?(:inclusion_labels)
end