Class: Google::Apis::ComputeBeta::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
74485 74486 74487 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74485 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
74441 74442 74443 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74441 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
74447 74448 74449 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74447 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
74452 74453 74454 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74452 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
74457 74458 74459 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74457 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74468 74469 74470 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74468 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74473 74474 74475 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74473 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74478 74479 74480 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74478 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
74483 74484 74485 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74483 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74490 74491 74492 74493 74494 74495 74496 74497 74498 74499 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74490 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |