Class: Google::Apis::ComputeBeta::VmExtensionPolicyList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VmExtensionPolicyList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Output only.
-
#id ⇒ String
Output only.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicy>
Output only.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
Output only.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VmExtensionPolicyList::Warning
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VmExtensionPolicyList
constructor
A new instance of VmExtensionPolicyList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VmExtensionPolicyList
Returns a new instance of VmExtensionPolicyList.
73881 73882 73883 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Output only. [Output Only] Fingerprint of this resource. A hash of the
contents stored
in this object. This field is used in optimistic locking. This field will
be ignored when inserting a VmExtensionPolicy. An up-to-date
fingerprint must be provided in order to update the VmExtensionPolicy.
To see the latest value of the fingerprint, make a get() request to
retrieve a VmExtensionPolicy.
Corresponds to the JSON property etag
73837 73838 73839 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73837 def etag @etag end |
#id ⇒ String
Output only. [Output Only] Unique identifier for the resource; defined by the
server.
Corresponds to the JSON property id
73843 73844 73845 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73843 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VmExtensionPolicy>
Output only. [Output Only] A list of VM extension policy resources.
Corresponds to the JSON property items
73848 73849 73850 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73848 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
73853 73854 73855 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73853 def kind @kind end |
#next_page_token ⇒ String
Output only. [Output Only] This token allows you to get the next page of
results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73864 73865 73866 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73864 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73869 73870 73871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73869 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
73874 73875 73876 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73874 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VmExtensionPolicyList::Warning
Output only. [Output Only] Informational warning message.
Corresponds to the JSON property warning
73879 73880 73881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73879 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73886 73887 73888 73889 73890 73891 73892 73893 73894 73895 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73886 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |