Class: Google::Apis::ComputeBeta::VmExtensionPolicyList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmExtensionPolicyList

Returns a new instance of VmExtensionPolicyList.



72095
72096
72097
# File 'lib/google/apis/compute_beta/classes.rb', line 72095

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Output only. [Output Only] Fingerprint of this resource. A hash of the contents stored in this object. This field is used in optimistic locking. This field will be ignored when inserting a VmExtensionPolicy. An up-to-date fingerprint must be provided in order to update the VmExtensionPolicy. To see the latest value of the fingerprint, make a get() request to retrieve a VmExtensionPolicy. Corresponds to the JSON property etag

Returns:

  • (String)


72051
72052
72053
# File 'lib/google/apis/compute_beta/classes.rb', line 72051

def etag
  @etag
end

#idString

Output only. [Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


72057
72058
72059
# File 'lib/google/apis/compute_beta/classes.rb', line 72057

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::VmExtensionPolicy>

Output only. [Output Only] A list of VM extension policy resources. Corresponds to the JSON property items



72062
72063
72064
# File 'lib/google/apis/compute_beta/classes.rb', line 72062

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


72067
72068
72069
# File 'lib/google/apis/compute_beta/classes.rb', line 72067

def kind
  @kind
end

#next_page_tokenString

Output only. [Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


72078
72079
72080
# File 'lib/google/apis/compute_beta/classes.rb', line 72078

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


72083
72084
72085
# File 'lib/google/apis/compute_beta/classes.rb', line 72083

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


72088
72089
72090
# File 'lib/google/apis/compute_beta/classes.rb', line 72088

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VmExtensionPolicyList::Warning

Output only. [Output Only] Informational warning message. Corresponds to the JSON property warning



72093
72094
72095
# File 'lib/google/apis/compute_beta/classes.rb', line 72093

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



72100
72101
72102
72103
72104
72105
72106
72107
72108
72109
# File 'lib/google/apis/compute_beta/classes.rb', line 72100

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end