Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
74747 74748 74749 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74709 74710 74711 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74709 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
74714 74715 74716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74714 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
74720 74721 74722 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74720 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74730 74731 74732 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74730 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74735 74736 74737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74735 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74740 74741 74742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74740 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74745 74746 74747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74745 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74752 74753 74754 74755 74756 74757 74758 74759 74760 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74752 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |