Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
74623 74624 74625 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74623 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74585 74586 74587 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74585 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
74590 74591 74592 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74590 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
74596 74597 74598 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74596 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74606 74607 74608 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74606 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74611 74612 74613 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74611 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74616 74617 74618 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74616 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74621 74622 74623 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74621 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74628 74629 74630 74631 74632 74633 74634 74635 74636 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74628 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |