Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
74591 74592 74593 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74591 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74553 74554 74555 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74553 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
74558 74559 74560 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74558 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
74564 74565 74566 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74564 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74574 74575 74576 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74574 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74579 74580 74581 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74579 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
74584 74585 74586 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74584 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74589 74590 74591 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74589 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74596 74597 74598 74599 74600 74601 74602 74603 74604 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74596 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |