Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



74143
74144
74145
# File 'lib/google/apis/compute_beta/classes.rb', line 74143

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74105
74106
74107
# File 'lib/google/apis/compute_beta/classes.rb', line 74105

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



74110
74111
74112
# File 'lib/google/apis/compute_beta/classes.rb', line 74110

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


74116
74117
74118
# File 'lib/google/apis/compute_beta/classes.rb', line 74116

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74126
74127
74128
# File 'lib/google/apis/compute_beta/classes.rb', line 74126

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74131
74132
74133
# File 'lib/google/apis/compute_beta/classes.rb', line 74131

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


74136
74137
74138
# File 'lib/google/apis/compute_beta/classes.rb', line 74136

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74141
74142
74143
# File 'lib/google/apis/compute_beta/classes.rb', line 74141

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74148
74149
74150
74151
74152
74153
74154
74155
74156
# File 'lib/google/apis/compute_beta/classes.rb', line 74148

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end