Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayAggregatedList

Returns a new instance of VpnGatewayAggregatedList.



73268
73269
73270
# File 'lib/google/apis/compute_beta/classes.rb', line 73268

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73230
73231
73232
# File 'lib/google/apis/compute_beta/classes.rb', line 73230

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>

A list of VpnGateway resources. Corresponds to the JSON property items



73235
73236
73237
# File 'lib/google/apis/compute_beta/classes.rb', line 73235

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


73241
73242
73243
# File 'lib/google/apis/compute_beta/classes.rb', line 73241

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73251
73252
73253
# File 'lib/google/apis/compute_beta/classes.rb', line 73251

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73256
73257
73258
# File 'lib/google/apis/compute_beta/classes.rb', line 73256

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


73261
73262
73263
# File 'lib/google/apis/compute_beta/classes.rb', line 73261

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73266
73267
73268
# File 'lib/google/apis/compute_beta/classes.rb', line 73266

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73273
73274
73275
73276
73277
73278
73279
73280
73281
# File 'lib/google/apis/compute_beta/classes.rb', line 73273

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end