Class: Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayAggregatedList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayAggregatedList
constructor
A new instance of VpnGatewayAggregatedList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayAggregatedList
Returns a new instance of VpnGatewayAggregatedList.
72357 72358 72359 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72357 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
72319 72320 72321 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72319 def id @id end |
#items ⇒ Hash<String,Google::Apis::ComputeBeta::VpnGatewaysScopedList>
A list of VpnGateway resources.
Corresponds to the JSON property items
72324 72325 72326 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72324 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
72330 72331 72332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72330 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
72340 72341 72342 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72340 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
72345 72346 72347 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72345 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
Corresponds to the JSON property unreachables
72350 72351 72352 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72350 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayAggregatedList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
72355 72356 72357 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72355 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72362 72363 72364 72365 72366 72367 72368 72369 72370 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72362 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |