Class: Google::Apis::ComputeBeta::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



74873
74874
74875
# File 'lib/google/apis/compute_beta/classes.rb', line 74873

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74840
74841
74842
# File 'lib/google/apis/compute_beta/classes.rb', line 74840

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



74845
74846
74847
# File 'lib/google/apis/compute_beta/classes.rb', line 74845

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


74851
74852
74853
# File 'lib/google/apis/compute_beta/classes.rb', line 74851

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74861
74862
74863
# File 'lib/google/apis/compute_beta/classes.rb', line 74861

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74866
74867
74868
# File 'lib/google/apis/compute_beta/classes.rb', line 74866

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74871
74872
74873
# File 'lib/google/apis/compute_beta/classes.rb', line 74871

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74878
74879
74880
74881
74882
74883
74884
74885
# File 'lib/google/apis/compute_beta/classes.rb', line 74878

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end