Class: Google::Apis::ComputeBeta::VpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of VpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VpnGateway>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayList
constructor
A new instance of VpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayList
Returns a new instance of VpnGatewayList.
74869 74870 74871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74836 74837 74838 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74836 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VpnGateway>
A list of VpnGateway resources.
Corresponds to the JSON property items
74841 74842 74843 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74841 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
74847 74848 74849 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74847 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74857 74858 74859 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74857 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74862 74863 74864 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74862 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74867 74868 74869 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74867 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74874 74875 74876 74877 74878 74879 74880 74881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74874 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |