Class: Google::Apis::ComputeBeta::VpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of VpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VpnGateway>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayList
constructor
A new instance of VpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayList
Returns a new instance of VpnGatewayList.
74749 74750 74751 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
74716 74717 74718 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74716 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VpnGateway>
A list of VpnGateway resources.
Corresponds to the JSON property items
74721 74722 74723 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74721 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
74727 74728 74729 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74727 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
74737 74738 74739 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74737 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
74742 74743 74744 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74742 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
74747 74748 74749 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74747 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
74754 74755 74756 74757 74758 74759 74760 74761 |
# File 'lib/google/apis/compute_beta/classes.rb', line 74754 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |