Class: Google::Apis::ComputeBeta::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



74239
74240
74241
# File 'lib/google/apis/compute_beta/classes.rb', line 74239

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74206
74207
74208
# File 'lib/google/apis/compute_beta/classes.rb', line 74206

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



74211
74212
74213
# File 'lib/google/apis/compute_beta/classes.rb', line 74211

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


74217
74218
74219
# File 'lib/google/apis/compute_beta/classes.rb', line 74217

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74227
74228
74229
# File 'lib/google/apis/compute_beta/classes.rb', line 74227

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74232
74233
74234
# File 'lib/google/apis/compute_beta/classes.rb', line 74232

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74237
74238
74239
# File 'lib/google/apis/compute_beta/classes.rb', line 74237

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74244
74245
74246
74247
74248
74249
74250
74251
# File 'lib/google/apis/compute_beta/classes.rb', line 74244

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end