Class: Google::Apis::ComputeBeta::VpnGatewayList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of VpnGateway resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VpnGateway>
A list of VpnGateway resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayList
constructor
A new instance of VpnGatewayList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayList
Returns a new instance of VpnGatewayList.
73394 73395 73396 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73361 73362 73363 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73361 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VpnGateway>
A list of VpnGateway resources.
Corresponds to the JSON property items
73366 73367 73368 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73366 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnGateway for
VPN gateways.
Corresponds to the JSON property kind
73372 73373 73374 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73372 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73382 73383 73384 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73382 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73387 73388 73389 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73387 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::VpnGatewayList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73392 73393 73394 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73392 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73399 73400 73401 73402 73403 73404 73405 73406 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73399 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |