Class: Google::Apis::ComputeBeta::VpnGatewayList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VpnGateway resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnGatewayList

Returns a new instance of VpnGatewayList.



73335
73336
73337
# File 'lib/google/apis/compute_beta/classes.rb', line 73335

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


73302
73303
73304
# File 'lib/google/apis/compute_beta/classes.rb', line 73302

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::VpnGateway>

A list of VpnGateway resources. Corresponds to the JSON property items



73307
73308
73309
# File 'lib/google/apis/compute_beta/classes.rb', line 73307

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnGateway for VPN gateways. Corresponds to the JSON property kind

Returns:

  • (String)


73313
73314
73315
# File 'lib/google/apis/compute_beta/classes.rb', line 73313

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


73323
73324
73325
# File 'lib/google/apis/compute_beta/classes.rb', line 73323

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


73328
73329
73330
# File 'lib/google/apis/compute_beta/classes.rb', line 73328

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VpnGatewayList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



73333
73334
73335
# File 'lib/google/apis/compute_beta/classes.rb', line 73333

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



73340
73341
73342
73343
73344
73345
73346
73347
# File 'lib/google/apis/compute_beta/classes.rb', line 73340

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end