Class: Google::Apis::ComputeBeta::VpnGatewayStatusVpnConnection
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnGatewayStatusVpnConnection
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A VPN connection contains all VPN tunnels connected from this VpnGateway to the same peer gateway. The peer gateway could either be an external VPN gateway or a Google Cloud VPN gateway.
Instance Attribute Summary collapse
-
#peer_external_gateway ⇒ String
Output only.
-
#peer_gcp_gateway ⇒ String
Output only.
-
#state ⇒ Google::Apis::ComputeBeta::VpnGatewayStatusHighAvailabilityRequirementState
Describes the high availability requirement state for the VPN connection between this Cloud VPN gateway and a peer gateway.
-
#tunnels ⇒ Array<Google::Apis::ComputeBeta::VpnGatewayStatusTunnel>
List of VPN tunnels that are in this VPN connection.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnGatewayStatusVpnConnection
constructor
A new instance of VpnGatewayStatusVpnConnection.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnGatewayStatusVpnConnection
Returns a new instance of VpnGatewayStatusVpnConnection.
69257 69258 69259 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69257 def initialize(**args) update!(**args) end |
Instance Attribute Details
#peer_external_gateway ⇒ String
Output only. URL reference to the peer external VPN gateways to which the VPN
tunnels
in this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
Corresponds to the JSON property peerExternalGateway
69236 69237 69238 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69236 def peer_external_gateway @peer_external_gateway end |
#peer_gcp_gateway ⇒ String
Output only. URL reference to the peer side VPN gateways to which the VPN
tunnels in
this VPN connection are connected.
This field is mutually exclusive with peer_gcp_gateway.
Corresponds to the JSON property peerGcpGateway
69244 69245 69246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69244 def peer_gcp_gateway @peer_gcp_gateway end |
#state ⇒ Google::Apis::ComputeBeta::VpnGatewayStatusHighAvailabilityRequirementState
Describes the high availability requirement state for the VPN connection
between this Cloud VPN gateway and a peer gateway.
Corresponds to the JSON property state
69250 69251 69252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69250 def state @state end |
#tunnels ⇒ Array<Google::Apis::ComputeBeta::VpnGatewayStatusTunnel>
List of VPN tunnels that are in this VPN connection.
Corresponds to the JSON property tunnels
69255 69256 69257 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69255 def tunnels @tunnels end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
69262 69263 69264 69265 69266 69267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 69262 def update!(**args) @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway) @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway) @state = args[:state] if args.key?(:state) @tunnels = args[:tunnels] if args.key?(:tunnels) end |