Class: Google::Apis::ComputeBeta::VpnTunnel
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnTunnel
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Cloud VPN Tunnel resource. For more information about VPN, read the the Cloud VPN Overview.
Instance Attribute Summary collapse
-
#capacity_tier ⇒ String
Capacity tier of the VPN tunnel.
-
#cipher_suite ⇒ Google::Apis::ComputeBeta::VpnTunnelCipherSuite
User specified list of ciphers to use for the phase 1 and phase 2 of the IKE protocol.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of this resource.
-
#detailed_status ⇒ String
[Output Only] Detailed status message for the VPN tunnel.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#ike_version ⇒ Fixnum
IKE protocol version to use when establishing the VPN tunnel with the peer VPN gateway.
-
#kind ⇒ String
Output only.
-
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnTunnel, which is essentially a hash of the labels set used for optimistic locking.
-
#labels ⇒ Hash<String,String>
Labels for this resource.
-
#local_traffic_selector ⇒ Array<String>
Local traffic selector to use when establishing the VPN tunnel with the peer VPN gateway.
-
#name ⇒ String
Name of the resource.
-
#params ⇒ Google::Apis::ComputeBeta::VpnTunnelParams
Input only.
-
#peer_external_gateway ⇒ String
URL of the peer side external VPN gateway to which this VPN tunnel is connected.
-
#peer_external_gateway_interface ⇒ Fixnum
The interface ID of the external VPN gateway to which this VPN tunnel is connected.
-
#peer_gcp_gateway ⇒ String
URL of the peer side HA VPN gateway to which this VPN tunnel is connected.
-
#peer_ip ⇒ String
IP address of the peer VPN gateway.
-
#region ⇒ String
[Output Only] URL of the region where the VPN tunnel resides.
-
#remote_traffic_selector ⇒ Array<String>
Remote traffic selectors to use when establishing the VPN tunnel with the peer VPN gateway.
-
#router ⇒ String
URL of the router resource to be used for dynamic routing.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#shared_secret ⇒ String
Shared secret used to set the secure session between the Cloud VPN gateway and the peer VPN gateway.
-
#shared_secret_hash ⇒ String
Hash of the shared secret.
-
#status ⇒ String
[Output Only] The status of the VPN tunnel, which can be one of the following:.
-
#target_vpn_gateway ⇒ String
URL of the Target VPN gateway with which this VPN tunnel is associated.
-
#vpn_gateway ⇒ String
URL of the VPN gateway with which this VPN tunnel is associated.
-
#vpn_gateway_interface ⇒ Fixnum
The interface ID of the VPN gateway with which this VPN tunnel is associated.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnel
constructor
A new instance of VpnTunnel.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnel
Returns a new instance of VpnTunnel.
73982 73983 73984 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73982 def initialize(**args) update!(**args) end |
Instance Attribute Details
#capacity_tier ⇒ String
Capacity tier of the VPN tunnel. This is used for IPsec over Interconnect
tunnels to indicate different bandwidth limits.
Corresponds to the JSON property capacityTier
73764 73765 73766 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73764 def capacity_tier @capacity_tier end |
#cipher_suite ⇒ Google::Apis::ComputeBeta::VpnTunnelCipherSuite
User specified list of ciphers to use for the phase 1 and phase 2 of the
IKE protocol.
Corresponds to the JSON property cipherSuite
73770 73771 73772 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73770 def cipher_suite @cipher_suite end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
73776 73777 73778 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73776 def @creation_timestamp end |
#description ⇒ String
An optional description of this resource. Provide this property when you
create the resource.
Corresponds to the JSON property description
73782 73783 73784 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73782 def description @description end |
#detailed_status ⇒ String
[Output Only] Detailed status message for the VPN tunnel.
Corresponds to the JSON property detailedStatus
73787 73788 73789 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73787 def detailed_status @detailed_status end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
73793 73794 73795 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73793 def id @id end |
#ike_version ⇒ Fixnum
IKE protocol version to use when establishing the VPN tunnel with the peer
VPN gateway. Acceptable IKE versions are 1 or 2.
The default version is 2.
Corresponds to the JSON property ikeVersion
73800 73801 73802 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73800 def ike_version @ike_version end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
73806 73807 73808 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73806 def kind @kind end |
#label_fingerprint ⇒ String
A fingerprint for the labels being applied to this VpnTunnel, which is
essentially a hash of the labels set used for optimistic locking. The
fingerprint is initially generated by Compute Engine and changes after
every request to modify or update labels. You must always provide an
up-to-date fingerprint hash in order to update or change labels,
otherwise the request will fail with error412 conditionNotMet.
To see the latest fingerprint, make a get() request to
retrieve a VpnTunnel.
Corresponds to the JSON property labelFingerprint
NOTE: Values are automatically base64 encoded/decoded in the client library.
73819 73820 73821 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73819 def label_fingerprint @label_fingerprint end |
#labels ⇒ Hash<String,String>
Labels for this resource. These can only be added or modified by thesetLabels
method. Each label key/value pair must comply withRFC1035.
Label values may be empty.
Corresponds to the JSON property labels
73826 73827 73828 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73826 def labels @labels end |
#local_traffic_selector ⇒ Array<String>
Local traffic selector to use when establishing the VPN tunnel with the
peer VPN gateway. The value should be a CIDR formatted string, for
example: 192.168.0.0/16. The ranges must be disjoint.
Only IPv4 is supported for Classic VPN tunnels. This field is output only
for HA VPN tunnels.
Corresponds to the JSON property localTrafficSelector
73835 73836 73837 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73835 def local_traffic_selector @local_traffic_selector end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
73846 73847 73848 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73846 def name @name end |
#params ⇒ Google::Apis::ComputeBeta::VpnTunnelParams
Input only. [Input Only] Additional params passed with the request, but not
persisted
as part of resource payload.
Corresponds to the JSON property params
73853 73854 73855 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73853 def params @params end |
#peer_external_gateway ⇒ String
URL of the peer side external VPN gateway to which this VPN tunnel is
connected.
Provided by the client when the VPN tunnel is created.
This field is exclusive with the field peerGcpGateway.
Corresponds to the JSON property peerExternalGateway
73861 73862 73863 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73861 def peer_external_gateway @peer_external_gateway end |
#peer_external_gateway_interface ⇒ Fixnum
The interface ID of the external VPN gateway to which this VPN tunnel is
connected. Provided by the client when the VPN tunnel is created.
Possible values are: 0, 1, 2, 3. The number of IDs in use
depends on the external VPN gateway redundancy type.
Corresponds to the JSON property peerExternalGatewayInterface
73869 73870 73871 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73869 def peer_external_gateway_interface @peer_external_gateway_interface end |
#peer_gcp_gateway ⇒ String
URL of the peer side HA VPN gateway to which this VPN tunnel
is connected. Provided by the client when the VPN tunnel is created.
This field can be used when creating highly available VPN from VPC network
to VPC network, the field is exclusive with the field peerExternalGateway.
If provided, the VPN tunnel will automatically use the same
vpnGatewayInterface ID in the peer Google Cloud VPN gateway.
Corresponds to the JSON property peerGcpGateway
73879 73880 73881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73879 def peer_gcp_gateway @peer_gcp_gateway end |
#peer_ip ⇒ String
IP address of the peer VPN gateway. Only IPv4 is supported. This field can
be set only for Classic VPN tunnels.
Corresponds to the JSON property peerIp
73885 73886 73887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73885 def peer_ip @peer_ip end |
#region ⇒ String
[Output Only] URL of the region where the VPN tunnel resides.
You must specify this field as part of the HTTP request URL. It is
not settable as a field in the request body.
Corresponds to the JSON property region
73892 73893 73894 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73892 def region @region end |
#remote_traffic_selector ⇒ Array<String>
Remote traffic selectors to use when establishing the VPN tunnel with
the peer VPN gateway. The value should be a CIDR formatted string,
for example: 192.168.0.0/16. The ranges should be disjoint. Only IPv4 is
supported for Classic VPN tunnels. This field is output only for HA VPN
tunnels.
Corresponds to the JSON property remoteTrafficSelector
73901 73902 73903 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73901 def remote_traffic_selector @remote_traffic_selector end |
#router ⇒ String
URL of the router resource to be used for dynamic routing.
Corresponds to the JSON property router
73906 73907 73908 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73906 def router @router end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
73911 73912 73913 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73911 def self_link @self_link end |
#shared_secret ⇒ String
Shared secret used to set the secure session between the Cloud VPN gateway
and the peer VPN gateway.
Corresponds to the JSON property sharedSecret
73917 73918 73919 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73917 def shared_secret @shared_secret end |
#shared_secret_hash ⇒ String
Hash of the shared secret.
Corresponds to the JSON property sharedSecretHash
73922 73923 73924 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73922 def shared_secret_hash @shared_secret_hash end |
#status ⇒ String
[Output Only] The status of the VPN tunnel, which can be one of the following:
- PROVISIONING: Resource is being allocated for the VPN tunnel.
- WAITING_FOR_FULL_CONFIG: Waiting to receive all VPN-related configs from the user. Network, TargetVpnGateway, VpnTunnel, ForwardingRule, and Route resources are needed to setup the VPN tunnel.
- FIRST_HANDSHAKE: Successful first handshake with the peer VPN.
- ESTABLISHED: Secure session is successfully established with the peer VPN.
- NETWORK_ERROR: Deprecated, replaced by NO_INCOMING_PACKETS
- AUTHORIZATION_ERROR: Auth error (for example, bad shared secret).
- NEGOTIATION_FAILURE: Handshake failed.
- DEPROVISIONING: Resources are being deallocated for the VPN tunnel.
- FAILED: Tunnel creation has failed and the tunnel is not ready to be used.
- NO_INCOMING_PACKETS: No incoming packets from peer.
- REJECTED: Tunnel configuration was rejected, can be result of being denied access.
- ALLOCATING_RESOURCES: Cloud VPN is in the process of allocating all required resources.
- STOPPED: Tunnel is stopped due to its Forwarding Rules being deleted for Classic VPN tunnels or the project is in frozen state.
- PEER_IDENTITY_MISMATCH: Peer identity does not match peer IP, probably behind NAT.
- TS_NARROWING_NOT_ALLOWED: Traffic selector
narrowing not allowed for an HA-VPN tunnel.
Corresponds to the JSON property
status
73958 73959 73960 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73958 def status @status end |
#target_vpn_gateway ⇒ String
URL of the Target VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created.
This field can be set only for Classic VPN tunnels.
Corresponds to the JSON property targetVpnGateway
73965 73966 73967 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73965 def target_vpn_gateway @target_vpn_gateway end |
#vpn_gateway ⇒ String
URL of the VPN gateway with which this VPN tunnel is associated.
Provided by the client when the VPN tunnel is created. This must be
used (instead of target_vpn_gateway) if a High Availability VPN gateway
resource is created.
Corresponds to the JSON property vpnGateway
73973 73974 73975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73973 def vpn_gateway @vpn_gateway end |
#vpn_gateway_interface ⇒ Fixnum
The interface ID of the VPN gateway with which this VPN tunnel is
associated.
Possible values are: 0, 1.
Corresponds to the JSON property vpnGatewayInterface
73980 73981 73982 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73980 def vpn_gateway_interface @vpn_gateway_interface end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73987 73988 73989 73990 73991 73992 73993 73994 73995 73996 73997 73998 73999 74000 74001 74002 74003 74004 74005 74006 74007 74008 74009 74010 74011 74012 74013 74014 74015 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73987 def update!(**args) @capacity_tier = args[:capacity_tier] if args.key?(:capacity_tier) @cipher_suite = args[:cipher_suite] if args.key?(:cipher_suite) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @detailed_status = args[:detailed_status] if args.key?(:detailed_status) @id = args[:id] if args.key?(:id) @ike_version = args[:ike_version] if args.key?(:ike_version) @kind = args[:kind] if args.key?(:kind) @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint) @labels = args[:labels] if args.key?(:labels) @local_traffic_selector = args[:local_traffic_selector] if args.key?(:local_traffic_selector) @name = args[:name] if args.key?(:name) @params = args[:params] if args.key?(:params) @peer_external_gateway = args[:peer_external_gateway] if args.key?(:peer_external_gateway) @peer_external_gateway_interface = args[:peer_external_gateway_interface] if args.key?(:peer_external_gateway_interface) @peer_gcp_gateway = args[:peer_gcp_gateway] if args.key?(:peer_gcp_gateway) @peer_ip = args[:peer_ip] if args.key?(:peer_ip) @region = args[:region] if args.key?(:region) @remote_traffic_selector = args[:remote_traffic_selector] if args.key?(:remote_traffic_selector) @router = args[:router] if args.key?(:router) @self_link = args[:self_link] if args.key?(:self_link) @shared_secret = args[:shared_secret] if args.key?(:shared_secret) @shared_secret_hash = args[:shared_secret_hash] if args.key?(:shared_secret_hash) @status = args[:status] if args.key?(:status) @target_vpn_gateway = args[:target_vpn_gateway] if args.key?(:target_vpn_gateway) @vpn_gateway = args[:vpn_gateway] if args.key?(:vpn_gateway) @vpn_gateway_interface = args[:vpn_gateway_interface] if args.key?(:vpn_gateway_interface) end |