Class: Google::Apis::ComputeBeta::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



75597
75598
75599
# File 'lib/google/apis/compute_beta/classes.rb', line 75597

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75559
75560
75561
# File 'lib/google/apis/compute_beta/classes.rb', line 75559

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



75564
75565
75566
# File 'lib/google/apis/compute_beta/classes.rb', line 75564

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


75570
75571
75572
# File 'lib/google/apis/compute_beta/classes.rb', line 75570

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75580
75581
75582
# File 'lib/google/apis/compute_beta/classes.rb', line 75580

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75585
75586
75587
# File 'lib/google/apis/compute_beta/classes.rb', line 75585

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75590
75591
75592
# File 'lib/google/apis/compute_beta/classes.rb', line 75590

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75595
75596
75597
# File 'lib/google/apis/compute_beta/classes.rb', line 75595

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75602
75603
75604
75605
75606
75607
75608
75609
75610
# File 'lib/google/apis/compute_beta/classes.rb', line 75602

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end