Class: Google::Apis::ComputeBeta::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



75445
75446
75447
# File 'lib/google/apis/compute_beta/classes.rb', line 75445

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75407
75408
75409
# File 'lib/google/apis/compute_beta/classes.rb', line 75407

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



75412
75413
75414
# File 'lib/google/apis/compute_beta/classes.rb', line 75412

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


75418
75419
75420
# File 'lib/google/apis/compute_beta/classes.rb', line 75418

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75428
75429
75430
# File 'lib/google/apis/compute_beta/classes.rb', line 75428

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75433
75434
75435
# File 'lib/google/apis/compute_beta/classes.rb', line 75433

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


75438
75439
75440
# File 'lib/google/apis/compute_beta/classes.rb', line 75438

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75443
75444
75445
# File 'lib/google/apis/compute_beta/classes.rb', line 75443

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75450
75451
75452
75453
75454
75455
75456
75457
75458
# File 'lib/google/apis/compute_beta/classes.rb', line 75450

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end