Class: Google::Apis::ComputeBeta::VpnTunnelAggregatedList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelAggregatedList

Returns a new instance of VpnTunnelAggregatedList.



71942
71943
71944
# File 'lib/google/apis/compute_beta/classes.rb', line 71942

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


71904
71905
71906
# File 'lib/google/apis/compute_beta/classes.rb', line 71904

def id
  @id
end

#itemsHash<String,Google::Apis::ComputeBeta::VpnTunnelsScopedList>

A list of VpnTunnelsScopedList resources. Corresponds to the JSON property items



71909
71910
71911
# File 'lib/google/apis/compute_beta/classes.rb', line 71909

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


71915
71916
71917
# File 'lib/google/apis/compute_beta/classes.rb', line 71915

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


71925
71926
71927
# File 'lib/google/apis/compute_beta/classes.rb', line 71925

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


71930
71931
71932
# File 'lib/google/apis/compute_beta/classes.rb', line 71930

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


71935
71936
71937
# File 'lib/google/apis/compute_beta/classes.rb', line 71935

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::VpnTunnelAggregatedList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



71940
71941
71942
# File 'lib/google/apis/compute_beta/classes.rb', line 71940

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



71947
71948
71949
71950
71951
71952
71953
71954
71955
# File 'lib/google/apis/compute_beta/classes.rb', line 71947

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end