Class: Google::Apis::ComputeBeta::VpnTunnelList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of VpnTunnel resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VpnTunnelList

Returns a new instance of VpnTunnelList.



75752
75753
75754
# File 'lib/google/apis/compute_beta/classes.rb', line 75752

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75719
75720
75721
# File 'lib/google/apis/compute_beta/classes.rb', line 75719

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::VpnTunnel>

A list of VpnTunnel resources. Corresponds to the JSON property items



75724
75725
75726
# File 'lib/google/apis/compute_beta/classes.rb', line 75724

def items
  @items
end

#kindString

Output only. [Output Only] Type of resource. Always compute#vpnTunnel for VPN tunnels. Corresponds to the JSON property kind

Returns:

  • (String)


75730
75731
75732
# File 'lib/google/apis/compute_beta/classes.rb', line 75730

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75740
75741
75742
# File 'lib/google/apis/compute_beta/classes.rb', line 75740

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75745
75746
75747
# File 'lib/google/apis/compute_beta/classes.rb', line 75745

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::VpnTunnelList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75750
75751
75752
# File 'lib/google/apis/compute_beta/classes.rb', line 75750

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75757
75758
75759
75760
75761
75762
75763
75764
# File 'lib/google/apis/compute_beta/classes.rb', line 75757

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end