Class: Google::Apis::ComputeBeta::VpnTunnelList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::VpnTunnelList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of VpnTunnel resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::VpnTunnel>
A list of VpnTunnel resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::VpnTunnelList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VpnTunnelList
constructor
A new instance of VpnTunnelList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VpnTunnelList
Returns a new instance of VpnTunnelList.
75148 75149 75150 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75148 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75115 75116 75117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75115 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::VpnTunnel>
A list of VpnTunnel resources.
Corresponds to the JSON property items
75120 75121 75122 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75120 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#vpnTunnel for
VPN tunnels.
Corresponds to the JSON property kind
75126 75127 75128 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75126 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75136 75137 75138 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75136 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75141 75142 75143 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75141 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::VpnTunnelList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75146 75147 75148 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75146 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75153 75154 75155 75156 75157 75158 75159 75160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75153 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |