Class: Google::Apis::ComputeBeta::WafExpressionSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WafExpressionSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of alternate IDs.
-
#expressions ⇒ Array<Google::Apis::ComputeBeta::WafExpressionSetExpression>
List of available expressions.
-
#id ⇒ String
Google specified expression set ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WafExpressionSet
constructor
A new instance of WafExpressionSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WafExpressionSet
Returns a new instance of WafExpressionSet.
75426 75427 75428 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75426 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aliases ⇒ Array<String>
A list of alternate IDs. The format should be:
- E.g. XSS-stable
Generic suffix like "stable" is particularly useful if a policy
likes to avail newer set of expressions without having to change
the policy.
A given alias name can't be used for more than one entity set.
Corresponds to the JSON property
aliases
75412 75413 75414 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75412 def aliases @aliases end |
#expressions ⇒ Array<Google::Apis::ComputeBeta::WafExpressionSetExpression>
List of available expressions.
Corresponds to the JSON property expressions
75417 75418 75419 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75417 def expressions @expressions end |
#id ⇒ String
Google specified expression set ID. The format should be:
- E.g. XSS-20170329
required
Corresponds to the JSON property
id
75424 75425 75426 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75424 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75431 75432 75433 75434 75435 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75431 def update!(**args) @aliases = args[:aliases] if args.key?(:aliases) @expressions = args[:expressions] if args.key?(:expressions) @id = args[:id] if args.key?(:id) end |