Class: Google::Apis::ComputeBeta::WafExpressionSet

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSet

Returns a new instance of WafExpressionSet.



74522
74523
74524
# File 'lib/google/apis/compute_beta/classes.rb', line 74522

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aliasesArray<String>

A list of alternate IDs. The format should be:

  • E.g. XSS-stable Generic suffix like "stable" is particularly useful if a policy likes to avail newer set of expressions without having to change the policy. A given alias name can't be used for more than one entity set. Corresponds to the JSON property aliases

Returns:

  • (Array<String>)


74508
74509
74510
# File 'lib/google/apis/compute_beta/classes.rb', line 74508

def aliases
  @aliases
end

#expressionsArray<Google::Apis::ComputeBeta::WafExpressionSetExpression>

List of available expressions. Corresponds to the JSON property expressions



74513
74514
74515
# File 'lib/google/apis/compute_beta/classes.rb', line 74513

def expressions
  @expressions
end

#idString

Google specified expression set ID. The format should be:

  • E.g. XSS-20170329 required Corresponds to the JSON property id

Returns:

  • (String)


74520
74521
74522
# File 'lib/google/apis/compute_beta/classes.rb', line 74520

def id
  @id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74527
74528
74529
74530
74531
# File 'lib/google/apis/compute_beta/classes.rb', line 74527

def update!(**args)
  @aliases = args[:aliases] if args.key?(:aliases)
  @expressions = args[:expressions] if args.key?(:expressions)
  @id = args[:id] if args.key?(:id)
end