Class: Google::Apis::ComputeBeta::WafExpressionSet
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WafExpressionSet
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#aliases ⇒ Array<String>
A list of alternate IDs.
-
#expressions ⇒ Array<Google::Apis::ComputeBeta::WafExpressionSetExpression>
List of available expressions.
-
#id ⇒ String
Google specified expression set ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WafExpressionSet
constructor
A new instance of WafExpressionSet.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WafExpressionSet
Returns a new instance of WafExpressionSet.
70172 70173 70174 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70172 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aliases ⇒ Array<String>
A list of alternate IDs. The format should be:
- E.g. XSS-stable
Generic suffix like "stable" is particularly useful if a policy
likes to avail newer set of expressions without having to change
the policy.
A given alias name can't be used for more than one entity set.
Corresponds to the JSON property
aliases
70158 70159 70160 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70158 def aliases @aliases end |
#expressions ⇒ Array<Google::Apis::ComputeBeta::WafExpressionSetExpression>
List of available expressions.
Corresponds to the JSON property expressions
70163 70164 70165 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70163 def expressions @expressions end |
#id ⇒ String
Google specified expression set ID. The format should be:
- E.g. XSS-20170329
required
Corresponds to the JSON property
id
70170 70171 70172 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70170 def id @id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70177 70178 70179 70180 70181 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70177 def update!(**args) @aliases = args[:aliases] if args.key?(:aliases) @expressions = args[:expressions] if args.key?(:expressions) @id = args[:id] if args.key?(:id) end |