Class: Google::Apis::ComputeBeta::WafExpressionSetExpression

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WafExpressionSetExpression

Returns a new instance of WafExpressionSetExpression.



76094
76095
76096
# File 'lib/google/apis/compute_beta/classes.rb', line 76094

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

Expression ID should uniquely identify the origin of the expression. E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set version 2.9.1 rule id 973337. The ID could be used to determine the individual attack definition that has been detected. It could also be used to exclude it from the policy in case of false positive. required Corresponds to the JSON property id

Returns:

  • (String)


76085
76086
76087
# File 'lib/google/apis/compute_beta/classes.rb', line 76085

def id
  @id
end

#sensitivityFixnum

The sensitivity value associated with the WAF rule ID. This corresponds to the ModSecurity paranoia level, ranging from 1 to 4. 0 is reserved for opt-in only rules. Corresponds to the JSON property sensitivity

Returns:

  • (Fixnum)


76092
76093
76094
# File 'lib/google/apis/compute_beta/classes.rb', line 76092

def sensitivity
  @sensitivity
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76099
76100
76101
76102
# File 'lib/google/apis/compute_beta/classes.rb', line 76099

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @sensitivity = args[:sensitivity] if args.key?(:sensitivity)
end