Class: Google::Apis::ComputeBeta::WafExpressionSetExpression
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WafExpressionSetExpression
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Instance Attribute Summary collapse
-
#id ⇒ String
Expression ID should uniquely identify the origin of the expression.
-
#sensitivity ⇒ Fixnum
The sensitivity value associated with the WAF rule ID.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WafExpressionSetExpression
constructor
A new instance of WafExpressionSetExpression.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WafExpressionSetExpression
Returns a new instance of WafExpressionSetExpression.
75938 75939 75940 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75938 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
Expression ID should uniquely identify the origin of the expression.
E.g. owasp-crs-v020901-id973337 identifies Owasp core rule set
version 2.9.1 rule id 973337.
The ID could be used to determine the individual attack definition
that has been detected. It could also be used to exclude it from
the policy in case of false positive.
required
Corresponds to the JSON property id
75929 75930 75931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75929 def id @id end |
#sensitivity ⇒ Fixnum
The sensitivity value associated with the WAF rule ID. This corresponds
to the ModSecurity paranoia level, ranging from 1 to 4. 0 is reserved for
opt-in only rules.
Corresponds to the JSON property sensitivity
75936 75937 75938 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75936 def sensitivity @sensitivity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75943 75944 75945 75946 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75943 def update!(**args) @id = args[:id] if args.key?(:id) @sensitivity = args[:sensitivity] if args.key?(:sensitivity) end |