Class: Google::Apis::ComputeBeta::WeightedBackendService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

In contrast to a single BackendService in HttpRouteAction to which all matching traffic is directed to, WeightedBackendService allows traffic to be split across multiple backend services. The volume of traffic for each backend service is proportional to the weight specified in each WeightedBackendService

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeightedBackendService

Returns a new instance of WeightedBackendService.



76019
76020
76021
# File 'lib/google/apis/compute_beta/classes.rb', line 76019

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceString

The full or partial URL to the default BackendService resource. Before forwarding the request to backendService, the load balancer applies any relevant headerActions specified as part of thisbackendServiceWeight. Corresponds to the JSON property backendService

Returns:

  • (String)


75997
75998
75999
# File 'lib/google/apis/compute_beta/classes.rb', line 75997

def backend_service
  @backend_service
end

#header_actionGoogle::Apis::ComputeBeta::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



76003
76004
76005
# File 'lib/google/apis/compute_beta/classes.rb', line 76003

def header_action
  @header_action
end

#weightFixnum

Specifies the fraction of traffic sent to a backend service, computed asweight / (sum of all weightedBackendService weights in routeAction). The selection of a backend service is determined only for new traffic. Once a user's request has been directed to a backend service, subsequent requests are sent to the same backend service as determined by the backend service's session affinity policy. Don't configure session affinity if you're using weighted traffic splitting. If you do, the weighted traffic splitting configuration takes precedence. The value must be from 0 to 1000. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


76017
76018
76019
# File 'lib/google/apis/compute_beta/classes.rb', line 76017

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76024
76025
76026
76027
76028
# File 'lib/google/apis/compute_beta/classes.rb', line 76024

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @header_action = args[:header_action] if args.key?(:header_action)
  @weight = args[:weight] if args.key?(:weight)
end