Class: Google::Apis::ComputeBeta::WeightedBackendService

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

In contrast to a single BackendService in HttpRouteAction to which all matching traffic is directed to, WeightedBackendService allows traffic to be split across multiple backend services. The volume of traffic for each backend service is proportional to the weight specified in each WeightedBackendService

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WeightedBackendService

Returns a new instance of WeightedBackendService.



70255
70256
70257
# File 'lib/google/apis/compute_beta/classes.rb', line 70255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#backend_serviceString

The full or partial URL to the default BackendService resource. Before forwarding the request to backendService, the load balancer applies any relevant headerActions specified as part of thisbackendServiceWeight. Corresponds to the JSON property backendService

Returns:

  • (String)


70233
70234
70235
# File 'lib/google/apis/compute_beta/classes.rb', line 70233

def backend_service
  @backend_service
end

#header_actionGoogle::Apis::ComputeBeta::HttpHeaderAction

The request and response header transformations that take effect before the request is passed along to the selected backendService. Corresponds to the JSON property headerAction



70239
70240
70241
# File 'lib/google/apis/compute_beta/classes.rb', line 70239

def header_action
  @header_action
end

#weightFixnum

Specifies the fraction of traffic sent to a backend service, computed asweight / (sum of all weightedBackendService weights in routeAction). The selection of a backend service is determined only for new traffic. Once a user's request has been directed to a backend service, subsequent requests are sent to the same backend service as determined by the backend service's session affinity policy. Don't configure session affinity if you're using weighted traffic splitting. If you do, the weighted traffic splitting configuration takes precedence. The value must be from 0 to 1000. Corresponds to the JSON property weight

Returns:

  • (Fixnum)


70253
70254
70255
# File 'lib/google/apis/compute_beta/classes.rb', line 70253

def weight
  @weight
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



70260
70261
70262
70263
70264
# File 'lib/google/apis/compute_beta/classes.rb', line 70260

def update!(**args)
  @backend_service = args[:backend_service] if args.key?(:backend_service)
  @header_action = args[:header_action] if args.key?(:header_action)
  @weight = args[:weight] if args.key?(:weight)
end