Class: Google::Apis::ComputeBeta::Wire

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A pseudowire that connects two Interconnect connections.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Wire

Returns a new instance of Wire.



75559
75560
75561
# File 'lib/google/apis/compute_beta/classes.rb', line 75559

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Output only. [Output Only] Indicates whether the wire is enabled. When false, the wire is disabled. When true and when the wire group of the wire is also enabled, the wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


75530
75531
75532
# File 'lib/google/apis/compute_beta/classes.rb', line 75530

def admin_enabled
  @admin_enabled
end

#endpointsArray<Google::Apis::ComputeBeta::WireEndpoint>

Output only. Wire endpoints are specific Interconnect connections. Corresponds to the JSON property endpoints



75536
75537
75538
# File 'lib/google/apis/compute_beta/classes.rb', line 75536

def endpoints
  @endpoints
end

#labelString

Output only. [Output Only] A label that identifies the wire. The format of this label combines the existing labels of the wire group endpoints and Interconnect connections used by this wire in alphabetical order as follows: ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1, where:

  • ENDPOINT_A and ENDPOINT_B: are the labels that you entered as map keys when you specified the wire group endpoint objects.
  • CONNECTION_A1 and CONNECTION_B1: are the labels that you entered as map keys when you specified the wire group Interconnect objects. Corresponds to the JSON property label

Returns:

  • (String)


75552
75553
75554
# File 'lib/google/apis/compute_beta/classes.rb', line 75552

def label
  @label
end

#wire_propertiesGoogle::Apis::ComputeBeta::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



75557
75558
75559
# File 'lib/google/apis/compute_beta/classes.rb', line 75557

def wire_properties
  @wire_properties
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75564
75565
75566
75567
75568
75569
# File 'lib/google/apis/compute_beta/classes.rb', line 75564

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @label = args[:label] if args.key?(:label)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
end