Class: Google::Apis::ComputeBeta::Wire
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Wire
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A pseudowire that connects two Interconnect connections.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Output only.
-
#endpoints ⇒ Array<Google::Apis::ComputeBeta::WireEndpoint>
Output only.
-
#label ⇒ String
Output only.
-
#wire_properties ⇒ Google::Apis::ComputeBeta::WireProperties
The properties of a wire.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Wire
constructor
A new instance of Wire.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Wire
Returns a new instance of Wire.
70305 70306 70307 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70305 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Output only. [Output Only] Indicates whether the wire is enabled.
When false, the wire is disabled. When true and when the wire group of
the wire is also enabled, the wire is enabled. Defaults to true.
Corresponds to the JSON property adminEnabled
70276 70277 70278 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70276 def admin_enabled @admin_enabled end |
#endpoints ⇒ Array<Google::Apis::ComputeBeta::WireEndpoint>
Output only. Wire endpoints are specific Interconnect connections.
Corresponds to the JSON property endpoints
70282 70283 70284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70282 def endpoints @endpoints end |
#label ⇒ String
Output only. [Output Only] A label that identifies the wire. The format of
this label
combines the existing labels of the wire group endpoints and Interconnect
connections used by this wire in alphabetical order as follows:
ENDPOINT_A+CONNECTION_A1,ENDPOINT_B+CONNECTION_B1, where:
- ENDPOINT_A and ENDPOINT_B: are the labels that you entered as map keys when you specified the wire group endpoint objects.
- CONNECTION_A1 and CONNECTION_B1: are the
labels that you entered as map keys when you specified the wire group
Interconnect objects.
Corresponds to the JSON property
label
70298 70299 70300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70298 def label @label end |
#wire_properties ⇒ Google::Apis::ComputeBeta::WireProperties
The properties of a wire.
Corresponds to the JSON property wireProperties
70303 70304 70305 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70303 def wire_properties @wire_properties end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70310 70311 70312 70313 70314 70315 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70310 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @endpoints = args[:endpoints] if args.key?(:endpoints) @label = args[:label] if args.key?(:label) @wire_properties = args[:wire_properties] if args.key?(:wire_properties) end |