Class: Google::Apis::ComputeBeta::WireGroup

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

A resource that represents a group of redundant wires.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroup

Returns a new instance of WireGroup.



76197
76198
76199
# File 'lib/google/apis/compute_beta/classes.rb', line 76197

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admin_enabledBoolean Also known as: admin_enabled?

Indicates whether the wires in the wire group are enabled. When false, the wires in the wire group are disabled. When true and when there is simultaneously no wire-specific override of adminEnabled to false, a given wire is enabled. Defaults to true. Corresponds to the JSON property adminEnabled

Returns:

  • (Boolean)


76117
76118
76119
# File 'lib/google/apis/compute_beta/classes.rb', line 76117

def admin_enabled
  @admin_enabled
end

#creation_timestampString

Output only. [Output Only] Creation timestamp inRFC3339 text format. Corresponds to the JSON property creationTimestamp

Returns:

  • (String)


76124
76125
76126
# File 'lib/google/apis/compute_beta/classes.rb', line 76124

def creation_timestamp
  @creation_timestamp
end

#descriptionString

An optional description of the wire group. Corresponds to the JSON property description

Returns:

  • (String)


76129
76130
76131
# File 'lib/google/apis/compute_beta/classes.rb', line 76129

def description
  @description
end

#endpointsHash<String,Google::Apis::ComputeBeta::WireGroupEndpoint>

A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:

  • Key: an RFC1035 user-specified label.
  • Value: an Endpoint object. Corresponds to the JSON property endpoints


76138
76139
76140
# File 'lib/google/apis/compute_beta/classes.rb', line 76138

def endpoints
  @endpoints
end

#idFixnum

Output only. [Output Only] The unique identifier for the resource type. The server generates this identifier. Corresponds to the JSON property id

Returns:

  • (Fixnum)


76145
76146
76147
# File 'lib/google/apis/compute_beta/classes.rb', line 76145

def id
  @id
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


76151
76152
76153
# File 'lib/google/apis/compute_beta/classes.rb', line 76151

def kind
  @kind
end

#nameString

Name of the resource. Provided by the client when the resource is created. The name must be 1-63 characters long, and comply withRFC1035. Specifically, the name must be 1-63 characters long and match the regular expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first character must be a lowercase letter, and all following characters must be a dash, lowercase letter, or digit, except the last character, which cannot be a dash. Corresponds to the JSON property name

Returns:

  • (String)


76162
76163
76164
# File 'lib/google/apis/compute_beta/classes.rb', line 76162

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. [Output Only] Indicates whether there are wire changes yet to be processed. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


76168
76169
76170
# File 'lib/google/apis/compute_beta/classes.rb', line 76168

def reconciling
  @reconciling
end

Output only. [Output Only] Server-defined URL for the resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76174
76175
76176
# File 'lib/google/apis/compute_beta/classes.rb', line 76174

def self_link
  @self_link
end

#topologyGoogle::Apis::ComputeBeta::WireGroupTopology

Topology details for the wire group. Corresponds to the JSON property topology



76179
76180
76181
# File 'lib/google/apis/compute_beta/classes.rb', line 76179

def topology
  @topology
end

#wire_group_propertiesGoogle::Apis::ComputeBeta::WireGroupProperties

The properties of a wire group. These properties determine how a group of redundant wires are created and managed. Corresponds to the JSON property wireGroupProperties



76185
76186
76187
# File 'lib/google/apis/compute_beta/classes.rb', line 76185

def wire_group_properties
  @wire_group_properties
end

#wire_propertiesGoogle::Apis::ComputeBeta::WireProperties

The properties of a wire. Corresponds to the JSON property wireProperties



76190
76191
76192
# File 'lib/google/apis/compute_beta/classes.rb', line 76190

def wire_properties
  @wire_properties
end

#wiresArray<Google::Apis::ComputeBeta::Wire>

Output only. The single/redundant wire(s) managed by the wire group. Corresponds to the JSON property wires



76195
76196
76197
# File 'lib/google/apis/compute_beta/classes.rb', line 76195

def wires
  @wires
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76202
76203
76204
76205
76206
76207
76208
76209
76210
76211
76212
76213
76214
76215
76216
# File 'lib/google/apis/compute_beta/classes.rb', line 76202

def update!(**args)
  @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled)
  @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp)
  @description = args[:description] if args.key?(:description)
  @endpoints = args[:endpoints] if args.key?(:endpoints)
  @id = args[:id] if args.key?(:id)
  @kind = args[:kind] if args.key?(:kind)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @self_link = args[:self_link] if args.key?(:self_link)
  @topology = args[:topology] if args.key?(:topology)
  @wire_group_properties = args[:wire_group_properties] if args.key?(:wire_group_properties)
  @wire_properties = args[:wire_properties] if args.key?(:wire_properties)
  @wires = args[:wires] if args.key?(:wires)
end