Class: Google::Apis::ComputeBeta::WireGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WireGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A resource that represents a group of redundant wires.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Indicates whether the wires in the wire group are enabled.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of the wire group.
-
#endpoints ⇒ Hash<String,Google::Apis::ComputeBeta::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#self_link ⇒ String
Output only.
-
#topology ⇒ Google::Apis::ComputeBeta::WireGroupTopology
Topology details for the wire group.
-
#wire_group_properties ⇒ Google::Apis::ComputeBeta::WireGroupProperties
The properties of a wire group.
-
#wire_properties ⇒ Google::Apis::ComputeBeta::WireProperties
The properties of a wire.
-
#wires ⇒ Array<Google::Apis::ComputeBeta::Wire>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroup
constructor
A new instance of WireGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroup
Returns a new instance of WireGroup.
75687 75688 75689 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75687 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Indicates whether the wires in the wire group are enabled. When false, the
wires in the wire group are disabled. When true and when
there is simultaneously no wire-specific override of adminEnabled to
false, a given wire is enabled. Defaults to true.
Corresponds to the JSON property adminEnabled
75607 75608 75609 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75607 def admin_enabled @admin_enabled end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
75614 75615 75616 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75614 def @creation_timestamp end |
#description ⇒ String
An optional description of the wire group.
Corresponds to the JSON property description
75619 75620 75621 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75619 def description @description end |
#endpoints ⇒ Hash<String,Google::Apis::ComputeBeta::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:
- Key: an RFC1035 user-specified label.
- Value: an Endpoint object.
Corresponds to the JSON property
endpoints
75628 75629 75630 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75628 def endpoints @endpoints end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
75635 75636 75637 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75635 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
75641 75642 75643 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75641 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
75652 75653 75654 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75652 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. [Output Only] Indicates whether there are wire changes yet to be
processed.
Corresponds to the JSON property reconciling
75658 75659 75660 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75658 def reconciling @reconciling end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
75664 75665 75666 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75664 def self_link @self_link end |
#topology ⇒ Google::Apis::ComputeBeta::WireGroupTopology
Topology details for the wire group.
Corresponds to the JSON property topology
75669 75670 75671 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75669 def topology @topology end |
#wire_group_properties ⇒ Google::Apis::ComputeBeta::WireGroupProperties
The properties of a wire group. These properties
determine how a group of redundant wires are created and managed.
Corresponds to the JSON property wireGroupProperties
75675 75676 75677 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75675 def wire_group_properties @wire_group_properties end |
#wire_properties ⇒ Google::Apis::ComputeBeta::WireProperties
The properties of a wire.
Corresponds to the JSON property wireProperties
75680 75681 75682 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75680 def wire_properties @wire_properties end |
#wires ⇒ Array<Google::Apis::ComputeBeta::Wire>
Output only. The single/redundant wire(s) managed by the wire group.
Corresponds to the JSON property wires
75685 75686 75687 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75685 def wires @wires end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75692 75693 75694 75695 75696 75697 75698 75699 75700 75701 75702 75703 75704 75705 75706 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75692 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @endpoints = args[:endpoints] if args.key?(:endpoints) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @self_link = args[:self_link] if args.key?(:self_link) @topology = args[:topology] if args.key?(:topology) @wire_group_properties = args[:wire_group_properties] if args.key?(:wire_group_properties) @wire_properties = args[:wire_properties] if args.key?(:wire_properties) @wires = args[:wires] if args.key?(:wires) end |