Class: Google::Apis::ComputeBeta::WireGroup
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WireGroup
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
A resource that represents a group of redundant wires.
Instance Attribute Summary collapse
-
#admin_enabled ⇒ Boolean
(also: #admin_enabled?)
Indicates whether the wires in the wire group are enabled.
-
#creation_timestamp ⇒ String
Output only.
-
#description ⇒ String
An optional description of the wire group.
-
#endpoints ⇒ Hash<String,Google::Apis::ComputeBeta::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group.
-
#id ⇒ Fixnum
Output only.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
Name of the resource.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#self_link ⇒ String
Output only.
-
#topology ⇒ Google::Apis::ComputeBeta::WireGroupTopology
Topology details for the wire group.
-
#wire_group_properties ⇒ Google::Apis::ComputeBeta::WireGroupProperties
The properties of a wire group.
-
#wire_properties ⇒ Google::Apis::ComputeBeta::WireProperties
The properties of a wire.
-
#wires ⇒ Array<Google::Apis::ComputeBeta::Wire>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroup
constructor
A new instance of WireGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroup
Returns a new instance of WireGroup.
73931 73932 73933 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#admin_enabled ⇒ Boolean Also known as: admin_enabled?
Indicates whether the wires in the wire group are enabled. When false, the
wires in the wire group are disabled. When true and when
there is simultaneously no wire-specific override of adminEnabled to
false, a given wire is enabled. Defaults to true.
Corresponds to the JSON property adminEnabled
73851 73852 73853 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73851 def admin_enabled @admin_enabled end |
#creation_timestamp ⇒ String
Output only. [Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
73858 73859 73860 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73858 def @creation_timestamp end |
#description ⇒ String
An optional description of the wire group.
Corresponds to the JSON property description
73863 73864 73865 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73863 def description @description end |
#endpoints ⇒ Hash<String,Google::Apis::ComputeBeta::WireGroupEndpoint>
A map that contains the logical endpoints of the wire group. Specify key-value pairs for the map as follows:
- Key: an RFC1035 user-specified label.
- Value: an Endpoint object.
Corresponds to the JSON property
endpoints
73872 73873 73874 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73872 def endpoints @endpoints end |
#id ⇒ Fixnum
Output only. [Output Only] The unique identifier for the resource type. The
server
generates this identifier.
Corresponds to the JSON property id
73879 73880 73881 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73879 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
73885 73886 73887 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73885 def kind @kind end |
#name ⇒ String
Name of the resource. Provided by the client when the resource is created.
The name must be 1-63 characters long, and comply withRFC1035.
Specifically, the name must be 1-63 characters long and match the regular
expression [a-z]([-a-z0-9]*[a-z0-9])? which means the first
character must be a lowercase letter, and all following characters must
be a dash, lowercase letter, or digit, except the last character, which
cannot be a dash.
Corresponds to the JSON property name
73896 73897 73898 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73896 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. [Output Only] Indicates whether there are wire changes yet to be
processed.
Corresponds to the JSON property reconciling
73902 73903 73904 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73902 def reconciling @reconciling end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
73908 73909 73910 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73908 def self_link @self_link end |
#topology ⇒ Google::Apis::ComputeBeta::WireGroupTopology
Topology details for the wire group.
Corresponds to the JSON property topology
73913 73914 73915 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73913 def topology @topology end |
#wire_group_properties ⇒ Google::Apis::ComputeBeta::WireGroupProperties
The properties of a wire group. These properties
determine how a group of redundant wires are created and managed.
Corresponds to the JSON property wireGroupProperties
73919 73920 73921 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73919 def wire_group_properties @wire_group_properties end |
#wire_properties ⇒ Google::Apis::ComputeBeta::WireProperties
The properties of a wire.
Corresponds to the JSON property wireProperties
73924 73925 73926 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73924 def wire_properties @wire_properties end |
#wires ⇒ Array<Google::Apis::ComputeBeta::Wire>
Output only. The single/redundant wire(s) managed by the wire group.
Corresponds to the JSON property wires
73929 73930 73931 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73929 def wires @wires end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73936 73937 73938 73939 73940 73941 73942 73943 73944 73945 73946 73947 73948 73949 73950 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73936 def update!(**args) @admin_enabled = args[:admin_enabled] if args.key?(:admin_enabled) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @description = args[:description] if args.key?(:description) @endpoints = args[:endpoints] if args.key?(:endpoints) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @self_link = args[:self_link] if args.key?(:self_link) @topology = args[:topology] if args.key?(:topology) @wire_group_properties = args[:wire_group_properties] if args.key?(:wire_group_properties) @wire_properties = args[:wire_properties] if args.key?(:wire_properties) @wires = args[:wires] if args.key?(:wires) end |