Class: Google::Apis::ComputeBeta::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



76348
76349
76350
# File 'lib/google/apis/compute_beta/classes.rb', line 76348

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


76304
76305
76306
# File 'lib/google/apis/compute_beta/classes.rb', line 76304

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76309
76310
76311
# File 'lib/google/apis/compute_beta/classes.rb', line 76309

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



76314
76315
76316
# File 'lib/google/apis/compute_beta/classes.rb', line 76314

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


76320
76321
76322
# File 'lib/google/apis/compute_beta/classes.rb', line 76320

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76330
76331
76332
# File 'lib/google/apis/compute_beta/classes.rb', line 76330

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76335
76336
76337
# File 'lib/google/apis/compute_beta/classes.rb', line 76335

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


76341
76342
76343
# File 'lib/google/apis/compute_beta/classes.rb', line 76341

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76346
76347
76348
# File 'lib/google/apis/compute_beta/classes.rb', line 76346

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76353
76354
76355
76356
76357
76358
76359
76360
76361
76362
# File 'lib/google/apis/compute_beta/classes.rb', line 76353

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end