Class: Google::Apis::ComputeBeta::WireGroupList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WireGroupList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Response for the list request.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#etag ⇒ String
Corresponds to the JSON property
etag. -
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::WireGroup>
A list of wire group resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
-
#unreachables ⇒ Array<String>
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::WireGroupList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupList
constructor
A new instance of WireGroupList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupList
Returns a new instance of WireGroupList.
75838 75839 75840 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75838 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
Corresponds to the JSON property etag
75794 75795 75796 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75794 def etag @etag end |
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75799 75800 75801 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75799 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::WireGroup>
A list of wire group resources.
Corresponds to the JSON property items
75804 75805 75806 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75804 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for
wire groups.
Corresponds to the JSON property kind
75810 75811 75812 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75810 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75820 75821 75822 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75820 def next_page_token @next_page_token end |
#self_link ⇒ String
[Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75825 75826 75827 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75825 def self_link @self_link end |
#unreachables ⇒ Array<String>
Output only. [Output Only] Unreachable resources.
end_interface: MixerListResponseWithEtagBuilder
Corresponds to the JSON property unreachables
75831 75832 75833 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75831 def unreachables @unreachables end |
#warning ⇒ Google::Apis::ComputeBeta::WireGroupList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75836 75837 75838 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75836 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75843 75844 75845 75846 75847 75848 75849 75850 75851 75852 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75843 def update!(**args) @etag = args[:etag] if args.key?(:etag) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @unreachables = args[:unreachables] if args.key?(:unreachables) @warning = args[:warning] if args.key?(:warning) end |