Class: Google::Apis::ComputeBeta::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



74993
74994
74995
# File 'lib/google/apis/compute_beta/classes.rb', line 74993

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


74949
74950
74951
# File 'lib/google/apis/compute_beta/classes.rb', line 74949

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74954
74955
74956
# File 'lib/google/apis/compute_beta/classes.rb', line 74954

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



74959
74960
74961
# File 'lib/google/apis/compute_beta/classes.rb', line 74959

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


74965
74966
74967
# File 'lib/google/apis/compute_beta/classes.rb', line 74965

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74975
74976
74977
# File 'lib/google/apis/compute_beta/classes.rb', line 74975

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74980
74981
74982
# File 'lib/google/apis/compute_beta/classes.rb', line 74980

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


74986
74987
74988
# File 'lib/google/apis/compute_beta/classes.rb', line 74986

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74991
74992
74993
# File 'lib/google/apis/compute_beta/classes.rb', line 74991

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74998
74999
75000
75001
75002
75003
75004
75005
75006
75007
# File 'lib/google/apis/compute_beta/classes.rb', line 74998

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end