Class: Google::Apis::ComputeBeta::WireGroupList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Response for the list request.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WireGroupList

Returns a new instance of WireGroupList.



74082
74083
74084
# File 'lib/google/apis/compute_beta/classes.rb', line 74082

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Corresponds to the JSON property etag

Returns:

  • (String)


74038
74039
74040
# File 'lib/google/apis/compute_beta/classes.rb', line 74038

def etag
  @etag
end

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


74043
74044
74045
# File 'lib/google/apis/compute_beta/classes.rb', line 74043

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::WireGroup>

A list of wire group resources. Corresponds to the JSON property items



74048
74049
74050
# File 'lib/google/apis/compute_beta/classes.rb', line 74048

def items
  @items
end

#kindString

Output only. [Output Only] Type of the resource. Alwayscompute#wireGroups for wire groups. Corresponds to the JSON property kind

Returns:

  • (String)


74054
74055
74056
# File 'lib/google/apis/compute_beta/classes.rb', line 74054

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


74064
74065
74066
# File 'lib/google/apis/compute_beta/classes.rb', line 74064

def next_page_token
  @next_page_token
end

[Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


74069
74070
74071
# File 'lib/google/apis/compute_beta/classes.rb', line 74069

def self_link
  @self_link
end

#unreachablesArray<String>

Output only. [Output Only] Unreachable resources. end_interface: MixerListResponseWithEtagBuilder Corresponds to the JSON property unreachables

Returns:

  • (Array<String>)


74075
74076
74077
# File 'lib/google/apis/compute_beta/classes.rb', line 74075

def unreachables
  @unreachables
end

#warningGoogle::Apis::ComputeBeta::WireGroupList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



74080
74081
74082
# File 'lib/google/apis/compute_beta/classes.rb', line 74080

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



74087
74088
74089
74090
74091
74092
74093
74094
74095
74096
# File 'lib/google/apis/compute_beta/classes.rb', line 74087

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @unreachables = args[:unreachables] if args.key?(:unreachables)
  @warning = args[:warning] if args.key?(:warning)
end