Class: Google::Apis::ComputeBeta::WireGroupProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WireGroupProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The properties of a wire group. These properties determine how a group of redundant wires are created and managed.
Instance Attribute Summary collapse
-
#type ⇒ String
The type of the wire group, one of the following:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireGroupProperties
constructor
A new instance of WireGroupProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireGroupProperties
Returns a new instance of WireGroupProperties.
72925 72926 72927 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#type ⇒ String
The type of the wire group, one of the following:
- WIRE: a single pseudowire over two Interconnect connections with no redundancy.
- REDUNDANT: two pseudowires over four Interconnect connections, with two connections in one metro and two connections in another metro. Each redundant pair of Interconnect connections spans both edge availability domains of the metro. Each pseudowire connects Interconnect connections in matching edge availability domains of the two metros.
- BOX_AND_CROSS: four pseudowires over four Interconnect connections,
with two connections in one metro and two connections in another metro.
Each redundant pair of Interconnect connections spans both edge
availability domains of the metro. Two pseudowires connect Interconnect
connections in matching edge availability domains of the two metros.
Two additional pseudowires connect the non-matching edge availability
domains of the two metros.
Corresponds to the JSON property
type
72923 72924 72925 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72923 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
72930 72931 72932 |
# File 'lib/google/apis/compute_beta/classes.rb', line 72930 def update!(**args) @type = args[:type] if args.key?(:type) end |