Class: Google::Apis::ComputeBeta::WireProperties
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::WireProperties
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
The properties of a wire.
Instance Attribute Summary collapse
-
#bandwidth_allocation ⇒ String
The configuration of the bandwidth allocation, one of the following:.
-
#bandwidth_unmetered ⇒ Fixnum
The unmetered bandwidth in Gigabits per second, using decimal units.
-
#fault_response ⇒ String
Response when a fault is detected in a pseudowire:.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WireProperties
constructor
A new instance of WireProperties.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WireProperties
Returns a new instance of WireProperties.
70785 70786 70787 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70785 def initialize(**args) update!(**args) end |
Instance Attribute Details
#bandwidth_allocation ⇒ String
The configuration of the bandwidth allocation, one of the following:
- ALLOCATE_PER_WIRE: configures a separate unmetered bandwidth allocation (and associated charges) for each wire in the group.
- SHARED_WITH_WIRE_GROUP: this is the default behavior, which configures
one unmetered bandwidth allocation for the wire group. The unmetered
bandwidth is divided equally across each wire in the group, but dynamic
throttling reallocates unused unmetered bandwidth from unused or underused
wires to other wires in the group.
Corresponds to the JSON property
bandwidthAllocation
70767 70768 70769 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70767 def bandwidth_allocation @bandwidth_allocation end |
#bandwidth_unmetered ⇒ Fixnum
The unmetered bandwidth in Gigabits per second, using decimal units. 10
is 10 Gbps, 100 is 100 Gbps. The bandwidth must be greater than 0.
Corresponds to the JSON property bandwidthUnmetered
70773 70774 70775 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70773 def bandwidth_unmetered @bandwidth_unmetered end |
#fault_response ⇒ String
Response when a fault is detected in a pseudowire:
- NONE: default.
- DISABLE_PORT: set the port line protocol down when inline probes
detect a fault. This setting is only permitted on port mode
pseudowires.
Corresponds to the JSON property
faultResponse
70783 70784 70785 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70783 def fault_response @fault_response end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
70790 70791 70792 70793 70794 |
# File 'lib/google/apis/compute_beta/classes.rb', line 70790 def update!(**args) @bandwidth_allocation = args[:bandwidth_allocation] if args.key?(:bandwidth_allocation) @bandwidth_unmetered = args[:bandwidth_unmetered] if args.key?(:bandwidth_unmetered) @fault_response = args[:fault_response] if args.key?(:fault_response) end |