Class: Google::Apis::ComputeBeta::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
76747 76748 76749 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76747 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76714 76715 76716 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76714 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
76719 76720 76721 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76719 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
76725 76726 76727 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76725 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76735 76736 76737 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76735 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76740 76741 76742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76740 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76745 76746 76747 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76745 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76752 76753 76754 76755 76756 76757 76758 76759 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76752 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |