Class: Google::Apis::ComputeBeta::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
76117 76118 76119 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76117 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76084 76085 76086 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76084 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
76089 76090 76091 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76089 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
76095 76096 76097 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76095 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76105 76106 76107 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76105 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76110 76111 76112 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76110 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76115 76116 76117 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76115 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76122 76123 76124 76125 76126 76127 76128 76129 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76122 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |