Class: Google::Apis::ComputeBeta::XpnHostList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::XpnHostList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Project>
[Output Only] A list of shared VPC host project URLs.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::XpnHostList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ XpnHostList
constructor
A new instance of XpnHostList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ XpnHostList
Returns a new instance of XpnHostList.
75272 75273 75274 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75272 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75239 75240 75241 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75239 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Project>
[Output Only] A list of shared VPC host project URLs.
Corresponds to the JSON property items
75244 75245 75246 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75244 def items @items end |
#kind ⇒ String
Output only. [Output Only] Type of resource. Always compute#xpnHostList for
lists of shared VPC hosts.
Corresponds to the JSON property kind
75250 75251 75252 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75250 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75260 75261 75262 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75260 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75265 75266 75267 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75265 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::XpnHostList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75270 75271 75272 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75270 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75277 75278 75279 75280 75281 75282 75283 75284 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75277 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |