Class: Google::Apis::ComputeBeta::Zone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Zone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.
Instance Attribute Summary collapse
-
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
-
#resource_status ⇒ Google::Apis::ComputeBeta::ZoneResourceStatus
Corresponds to the JSON property
resourceStatus. -
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Zone
constructor
A new instance of Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Zone
Returns a new instance of Zone.
76779 76780 76781 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76779 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
Corresponds to the JSON property availableCpuPlatforms
76718 76719 76720 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76718 def available_cpu_platforms @available_cpu_platforms end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
76724 76725 76726 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76724 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
76729 76730 76731 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76729 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
76734 76735 76736 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76734 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
76740 76741 76742 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76740 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#zone for
zones.
Corresponds to the JSON property kind
76746 76747 76748 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76746 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
76751 76752 76753 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76751 def name @name end |
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
Corresponds to the JSON property region
76756 76757 76758 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76756 def region @region end |
#resource_status ⇒ Google::Apis::ComputeBeta::ZoneResourceStatus
Corresponds to the JSON property resourceStatus
76761 76762 76763 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76761 def resource_status @resource_status end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
76766 76767 76768 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76766 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
Corresponds to the JSON property status
76771 76772 76773 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76771 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
76776 76777 76778 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76776 def supports_pzs @supports_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
76784 76785 76786 76787 76788 76789 76790 76791 76792 76793 76794 76795 76796 76797 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76784 def update!(**args) @available_cpu_platforms = args[:available_cpu_platforms] if args.key?(:available_cpu_platforms) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @resource_status = args[:resource_status] if args.key?(:resource_status) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) end |