Class: Google::Apis::ComputeBeta::Zone
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::Zone
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Represents a Zone resource. A zone is a deployment area. These deployment areas are subsets of a region. For example the zone us-east1-b is located in theus-east1 region. For more information, readRegions and Zones.
Instance Attribute Summary collapse
-
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
-
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339 text format.
-
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
-
#description ⇒ String
[Output Only] Textual description of the resource.
-
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource.
-
#kind ⇒ String
Output only.
-
#name ⇒ String
[Output Only] Name of the resource.
-
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
-
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
-
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
-
#supports_pzs ⇒ Boolean
(also: #supports_pzs?)
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Zone
constructor
A new instance of Zone.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Zone
Returns a new instance of Zone.
73271 73272 73273 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73271 def initialize(**args) update!(**args) end |
Instance Attribute Details
#available_cpu_platforms ⇒ Array<String>
[Output Only] Available cpu/platform selections for the zone.
Corresponds to the JSON property availableCpuPlatforms
73215 73216 73217 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73215 def available_cpu_platforms @available_cpu_platforms end |
#creation_timestamp ⇒ String
[Output Only] Creation timestamp inRFC3339
text format.
Corresponds to the JSON property creationTimestamp
73221 73222 73223 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73221 def @creation_timestamp end |
#deprecated ⇒ Google::Apis::ComputeBeta::DeprecationStatus
Deprecation status for a public resource.
Corresponds to the JSON property deprecated
73226 73227 73228 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73226 def deprecated @deprecated end |
#description ⇒ String
[Output Only] Textual description of the resource.
Corresponds to the JSON property description
73231 73232 73233 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73231 def description @description end |
#id ⇒ Fixnum
[Output Only] The unique identifier for the resource. This identifier is
defined by the server.
Corresponds to the JSON property id
73237 73238 73239 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73237 def id @id end |
#kind ⇒ String
Output only. [Output Only] Type of the resource. Always compute#zone for
zones.
Corresponds to the JSON property kind
73243 73244 73245 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73243 def kind @kind end |
#name ⇒ String
[Output Only] Name of the resource.
Corresponds to the JSON property name
73248 73249 73250 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73248 def name @name end |
#region ⇒ String
[Output Only] Full URL reference to the region which hosts the zone.
Corresponds to the JSON property region
73253 73254 73255 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73253 def region @region end |
#self_link ⇒ String
[Output Only] Server-defined URL for the resource.
Corresponds to the JSON property selfLink
73258 73259 73260 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73258 def self_link @self_link end |
#status ⇒ String
[Output Only] Status of the zone, either UP orDOWN.
Corresponds to the JSON property status
73263 73264 73265 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73263 def status @status end |
#supports_pzs ⇒ Boolean Also known as: supports_pzs?
Output only. [Output Only] Reserved for future use.
Corresponds to the JSON property supportsPzs
73268 73269 73270 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73268 def supports_pzs @supports_pzs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73276 73277 73278 73279 73280 73281 73282 73283 73284 73285 73286 73287 73288 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73276 def update!(**args) @available_cpu_platforms = args[:available_cpu_platforms] if args.key?(:available_cpu_platforms) @creation_timestamp = args[:creation_timestamp] if args.key?(:creation_timestamp) @deprecated = args[:deprecated] if args.key?(:deprecated) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @name = args[:name] if args.key?(:name) @region = args[:region] if args.key?(:region) @self_link = args[:self_link] if args.key?(:self_link) @status = args[:status] if args.key?(:status) @supports_pzs = args[:supports_pzs] if args.key?(:supports_pzs) end |