Class: Google::Apis::ComputeBeta::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
77395 77396 77397 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77395 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
77363 77364 77365 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77363 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
Corresponds to the JSON property items
77368 77369 77370 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77368 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
77373 77374 77375 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77373 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
77383 77384 77385 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77383 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
77388 77389 77390 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77388 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
77393 77394 77395 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77393 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77400 77401 77402 77403 77404 77405 77406 77407 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77400 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |