Class: Google::Apis::ComputeBeta::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
76995 76996 76997 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76995 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
76963 76964 76965 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76963 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
Corresponds to the JSON property items
76968 76969 76970 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76968 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
76973 76974 76975 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76973 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
76983 76984 76985 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76983 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
76988 76989 76990 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76988 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
76993 76994 76995 |
# File 'lib/google/apis/compute_beta/classes.rb', line 76993 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
77000 77001 77002 77003 77004 77005 77006 77007 |
# File 'lib/google/apis/compute_beta/classes.rb', line 77000 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |