Class: Google::Apis::ComputeBeta::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



76991
76992
76993
# File 'lib/google/apis/compute_beta/classes.rb', line 76991

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76959
76960
76961
# File 'lib/google/apis/compute_beta/classes.rb', line 76959

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Zone>

A list of Zone resources. Corresponds to the JSON property items



76964
76965
76966
# File 'lib/google/apis/compute_beta/classes.rb', line 76964

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


76969
76970
76971
# File 'lib/google/apis/compute_beta/classes.rb', line 76969

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76979
76980
76981
# File 'lib/google/apis/compute_beta/classes.rb', line 76979

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76984
76985
76986
# File 'lib/google/apis/compute_beta/classes.rb', line 76984

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76989
76990
76991
# File 'lib/google/apis/compute_beta/classes.rb', line 76989

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76996
76997
76998
76999
77000
77001
77002
77003
# File 'lib/google/apis/compute_beta/classes.rb', line 76996

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end