Class: Google::Apis::ComputeBeta::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



76839
76840
76841
# File 'lib/google/apis/compute_beta/classes.rb', line 76839

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76807
76808
76809
# File 'lib/google/apis/compute_beta/classes.rb', line 76807

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Zone>

A list of Zone resources. Corresponds to the JSON property items



76812
76813
76814
# File 'lib/google/apis/compute_beta/classes.rb', line 76812

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


76817
76818
76819
# File 'lib/google/apis/compute_beta/classes.rb', line 76817

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76827
76828
76829
# File 'lib/google/apis/compute_beta/classes.rb', line 76827

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76832
76833
76834
# File 'lib/google/apis/compute_beta/classes.rb', line 76832

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76837
76838
76839
# File 'lib/google/apis/compute_beta/classes.rb', line 76837

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76844
76845
76846
76847
76848
76849
76850
76851
# File 'lib/google/apis/compute_beta/classes.rb', line 76844

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end