Class: Google::Apis::ComputeBeta::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



76391
76392
76393
# File 'lib/google/apis/compute_beta/classes.rb', line 76391

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76359
76360
76361
# File 'lib/google/apis/compute_beta/classes.rb', line 76359

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Zone>

A list of Zone resources. Corresponds to the JSON property items



76364
76365
76366
# File 'lib/google/apis/compute_beta/classes.rb', line 76364

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


76369
76370
76371
# File 'lib/google/apis/compute_beta/classes.rb', line 76369

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76379
76380
76381
# File 'lib/google/apis/compute_beta/classes.rb', line 76379

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76384
76385
76386
# File 'lib/google/apis/compute_beta/classes.rb', line 76384

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76389
76390
76391
# File 'lib/google/apis/compute_beta/classes.rb', line 76389

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76396
76397
76398
76399
76400
76401
76402
76403
# File 'lib/google/apis/compute_beta/classes.rb', line 76396

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end