Class: Google::Apis::ComputeBeta::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



76361
76362
76363
# File 'lib/google/apis/compute_beta/classes.rb', line 76361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


76329
76330
76331
# File 'lib/google/apis/compute_beta/classes.rb', line 76329

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Zone>

A list of Zone resources. Corresponds to the JSON property items



76334
76335
76336
# File 'lib/google/apis/compute_beta/classes.rb', line 76334

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


76339
76340
76341
# File 'lib/google/apis/compute_beta/classes.rb', line 76339

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


76349
76350
76351
# File 'lib/google/apis/compute_beta/classes.rb', line 76349

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


76354
76355
76356
# File 'lib/google/apis/compute_beta/classes.rb', line 76354

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



76359
76360
76361
# File 'lib/google/apis/compute_beta/classes.rb', line 76359

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



76366
76367
76368
76369
76370
76371
76372
76373
# File 'lib/google/apis/compute_beta/classes.rb', line 76366

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end