Class: Google::Apis::ComputeBeta::ZoneList

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Overview

Contains a list of zone resources.

Defined Under Namespace

Classes: Warning

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneList

Returns a new instance of ZoneList.



75510
75511
75512
# File 'lib/google/apis/compute_beta/classes.rb', line 75510

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#idString

[Output Only] Unique identifier for the resource; defined by the server. Corresponds to the JSON property id

Returns:

  • (String)


75478
75479
75480
# File 'lib/google/apis/compute_beta/classes.rb', line 75478

def id
  @id
end

#itemsArray<Google::Apis::ComputeBeta::Zone>

A list of Zone resources. Corresponds to the JSON property items



75483
75484
75485
# File 'lib/google/apis/compute_beta/classes.rb', line 75483

def items
  @items
end

#kindString

Output only. Type of resource. Corresponds to the JSON property kind

Returns:

  • (String)


75488
75489
75490
# File 'lib/google/apis/compute_beta/classes.rb', line 75488

def kind
  @kind
end

#next_page_tokenString

[Output Only] This token allows you to get the next page of results for list requests. If the number of results is larger thanmaxResults, use the nextPageToken as a value for the query parameter pageToken in the next list request. Subsequent list requests will have their own nextPageToken to continue paging through the results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


75498
75499
75500
# File 'lib/google/apis/compute_beta/classes.rb', line 75498

def next_page_token
  @next_page_token
end

Output only. [Output Only] Server-defined URL for this resource. Corresponds to the JSON property selfLink

Returns:

  • (String)


75503
75504
75505
# File 'lib/google/apis/compute_beta/classes.rb', line 75503

def self_link
  @self_link
end

#warningGoogle::Apis::ComputeBeta::ZoneList::Warning

[Output Only] Informational warning message. Corresponds to the JSON property warning



75508
75509
75510
# File 'lib/google/apis/compute_beta/classes.rb', line 75508

def warning
  @warning
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75515
75516
75517
75518
75519
75520
75521
75522
# File 'lib/google/apis/compute_beta/classes.rb', line 75515

def update!(**args)
  @id = args[:id] if args.key?(:id)
  @items = args[:items] if args.key?(:items)
  @kind = args[:kind] if args.key?(:kind)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @self_link = args[:self_link] if args.key?(:self_link)
  @warning = args[:warning] if args.key?(:warning)
end