Class: Google::Apis::ComputeBeta::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
75510 75511 75512 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75510 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
75478 75479 75480 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75478 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
Corresponds to the JSON property items
75483 75484 75485 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75483 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
75488 75489 75490 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75488 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
75498 75499 75500 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75498 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
75503 75504 75505 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75503 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
75508 75509 75510 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75508 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
75515 75516 75517 75518 75519 75520 75521 75522 |
# File 'lib/google/apis/compute_beta/classes.rb', line 75515 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |