Class: Google::Apis::ComputeBeta::ZoneList
- Inherits:
-
Object
- Object
- Google::Apis::ComputeBeta::ZoneList
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb
Overview
Contains a list of zone resources.
Defined Under Namespace
Classes: Warning
Instance Attribute Summary collapse
-
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
-
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
-
#kind ⇒ String
Output only.
-
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for list requests.
-
#self_link ⇒ String
Output only.
-
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ZoneList
constructor
A new instance of ZoneList.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ZoneList
Returns a new instance of ZoneList.
73330 73331 73332 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73330 def initialize(**args) update!(**args) end |
Instance Attribute Details
#id ⇒ String
[Output Only] Unique identifier for the resource; defined by the server.
Corresponds to the JSON property id
73298 73299 73300 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73298 def id @id end |
#items ⇒ Array<Google::Apis::ComputeBeta::Zone>
A list of Zone resources.
Corresponds to the JSON property items
73303 73304 73305 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73303 def items @items end |
#kind ⇒ String
Output only. Type of resource.
Corresponds to the JSON property kind
73308 73309 73310 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73308 def kind @kind end |
#next_page_token ⇒ String
[Output Only] This token allows you to get the next page of results for
list requests. If the number of results is larger thanmaxResults, use the
nextPageToken as a value for
the query parameter pageToken in the next list request.
Subsequent list requests will have their own nextPageToken to
continue paging through the results.
Corresponds to the JSON property nextPageToken
73318 73319 73320 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73318 def next_page_token @next_page_token end |
#self_link ⇒ String
Output only. [Output Only] Server-defined URL for this resource.
Corresponds to the JSON property selfLink
73323 73324 73325 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73323 def self_link @self_link end |
#warning ⇒ Google::Apis::ComputeBeta::ZoneList::Warning
[Output Only] Informational warning message.
Corresponds to the JSON property warning
73328 73329 73330 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73328 def warning @warning end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
73335 73336 73337 73338 73339 73340 73341 73342 |
# File 'lib/google/apis/compute_beta/classes.rb', line 73335 def update!(**args) @id = args[:id] if args.key?(:id) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @self_link = args[:self_link] if args.key?(:self_link) @warning = args[:warning] if args.key?(:warning) end |