Class: Google::Apis::ComputeBeta::ZoneSetLabelsRequest

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/compute_beta/classes.rb,
lib/google/apis/compute_beta/representations.rb,
lib/google/apis/compute_beta/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ZoneSetLabelsRequest

Returns a new instance of ZoneSetLabelsRequest.



75556
75557
75558
# File 'lib/google/apis/compute_beta/classes.rb', line 75556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#label_fingerprintString

The fingerprint of the previous set of labels for this resource, used to detect conflicts. The fingerprint is initially generated by Compute Engine and changes after every request to modify or update labels. You must always provide an up-to-date fingerprint hash in order to update or change labels. Make a get() request to the resource to get the latest fingerprint. Corresponds to the JSON property labelFingerprint NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


75549
75550
75551
# File 'lib/google/apis/compute_beta/classes.rb', line 75549

def label_fingerprint
  @label_fingerprint
end

#labelsHash<String,String>

The labels to set for this resource. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


75554
75555
75556
# File 'lib/google/apis/compute_beta/classes.rb', line 75554

def labels
  @labels
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



75561
75562
75563
75564
# File 'lib/google/apis/compute_beta/classes.rb', line 75561

def update!(**args)
  @label_fingerprint = args[:label_fingerprint] if args.key?(:label_fingerprint)
  @labels = args[:labels] if args.key?(:labels)
end